/* drivers/media/video/s5k4ecgx_regs_1_0.h
 *
 * Driver for s5k4ecgx (5MP Camera) from SEC(LSI), firmware EVT1.0
 *
 * Copyright (C) 2010, SAMSUNG ELECTRONICS
 * Copyright (C) 2012, Insignal Co,. Ltd
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 */

#include "s5k4ecgx_regset.h"

#if !defined(__S5K4ECGX_V1_0_DEFINE_REGSET__)

#define S5K4ECGX_DEFINE_REGSET(NAME) static const struct s5k4ecgx_reg NAME[]
#define S5K4ECGX_REGSET_END \
	{ .type = S5K4ECGX_REGTYPE_END, .data_len = 0 }
#define S5K4ECGX_CMD_WRITE(ADDR, DATA) \
	{ .type = S5K4ECGX_REGTYPE_CMD, .data_len = 4 }
#define S5K4ECGX_REG_WRITE(ADDR, DATA) \
	{ .type = S5K4ECGX_REGTYPE_WRITE, .data_len = 2, { .addr = ADDR } }
#define S5K4ECGX_REG_READ(ADDR) \
	{ .type = S5K4ECGX_REGTYPE_READ, .data_len = 1, { .addr = ADDR } }
#define S5K4ECGX_MDELAY(MSEC) \
	{ .type = S5K4ECGX_REGTYPE_DELAY, .data_len = 1, { .msec = MSEC } }

#elif !defined(__S5K4ECGX_V1_0_DEFINE_REGSET_DATA__)

#define _SWAB16(X) ((X >> 8) & 0xFF), (X & 0xFF)
#define _DUMMY 0
#define S5K4ECGX_DEFINE_REGSET(NAME) static const u8 NAME##_data[]
#define S5K4ECGX_REGSET_END
#define S5K4ECGX_CMD_WRITE(ADDR, DATA) _SWAB16(ADDR), _SWAB16(DATA)
#define S5K4ECGX_REG_WRITE(ADDR, DATA) _SWAB16(DATA)
#define S5K4ECGX_REG_READ(ADDR) _DUMMY
#define S5K4ECGX_MDELAY(MSEC) _DUMMY

#endif

#if !defined(__S5K4ECGX_V1_0_DEFINE_REGSET__) \
	|| !defined(__S5K4ECGX_V1_0_DEFINE_REGSET_DATA__)

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_init_reg_v1) = {
	/* direct addressing, hw addresses */
	S5K4ECGX_CMD_WRITE(0xFCFC, 0xD000),
	S5K4ECGX_CMD_WRITE(0x0004, 0x0000),
	S5K4ECGX_CMD_WRITE(0xFCFC, 0xD000),
	S5K4ECGX_CMD_WRITE(0x0010, 0x0001),
	S5K4ECGX_CMD_WRITE(0xFCFC, 0xD000),
	S5K4ECGX_CMD_WRITE(0x1030, 0x0000),
	S5K4ECGX_CMD_WRITE(0x0014, 0x0001),

	S5K4ECGX_MDELAY(10),

	/* start analog settings, indirect addressing mode */

	S5K4ECGX_REG_WRITE(0xD000007A, 0x0000),

	S5K4ECGX_REG_WRITE(0xD000E406, 0x0092),

	S5K4ECGX_REG_WRITE(0xD000E410, 0x3804),

	S5K4ECGX_REG_WRITE(0xD000E420, 0x0003),
	S5K4ECGX_REG_WRITE(0xD000E422, 0x0060),

	S5K4ECGX_REG_WRITE(0xD000E42E, 0x0004),

	S5K4ECGX_REG_WRITE(0xD000F400, 0x5A3C),
	S5K4ECGX_REG_WRITE(0xD000F402, 0x0023),
	S5K4ECGX_REG_WRITE(0xD000F404, 0x8080),
	S5K4ECGX_REG_WRITE(0xD000F406, 0x03AF),
	S5K4ECGX_REG_WRITE(0xD000F408, 0x000A),
	S5K4ECGX_REG_WRITE(0xD000F40A, 0xAA54),
	S5K4ECGX_REG_WRITE(0xD000F40C, 0x0040),
	S5K4ECGX_REG_WRITE(0xD000F40E, 0x464E),
	S5K4ECGX_REG_WRITE(0xD000F410, 0x0240),
	S5K4ECGX_REG_WRITE(0xD000F412, 0x0240),
	S5K4ECGX_REG_WRITE(0xD000F414, 0x0040),
	S5K4ECGX_REG_WRITE(0xD000F416, 0x1000),
	S5K4ECGX_REG_WRITE(0xD000F418, 0x5558),
	S5K4ECGX_REG_WRITE(0xD000F41A, 0xD000),
	S5K4ECGX_REG_WRITE(0xD000F41C, 0x0010),
	S5K4ECGX_REG_WRITE(0xD000F41E, 0x0202),
	S5K4ECGX_REG_WRITE(0xD000F420, 0x0401),
	S5K4ECGX_REG_WRITE(0xD000F422, 0x0022),
	S5K4ECGX_REG_WRITE(0xD000F424, 0x0088),
	S5K4ECGX_REG_WRITE(0xD000F426, 0x009F),
	S5K4ECGX_REG_WRITE(0xD000F428, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F42A, 0x1800),
	S5K4ECGX_REG_WRITE(0xD000F42C, 0x0088),
	S5K4ECGX_REG_WRITE(0xD000F42E, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F430, 0x2428),
	S5K4ECGX_REG_WRITE(0xD000F432, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F434, 0x03EE),
	S5K4ECGX_REG_WRITE(0xD000F436, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F438, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F43A, 0x0000),

	S5K4ECGX_REG_WRITE(0xD000F480, 0x0004),
	S5K4ECGX_REG_WRITE(0xD000F482, 0x05B6),
	S5K4ECGX_REG_WRITE(0xD000F484, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F486, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F488, 0x0001),
	S5K4ECGX_REG_WRITE(0xD000F48A, 0x05BA),
	S5K4ECGX_REG_WRITE(0xD000F48C, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F48E, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F490, 0x0007),
	S5K4ECGX_REG_WRITE(0xD000F492, 0x05BA),
	S5K4ECGX_REG_WRITE(0xD000F494, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F496, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F498, 0x01F4),
	S5K4ECGX_REG_WRITE(0xD000F49A, 0x024E),
	S5K4ECGX_REG_WRITE(0xD000F49C, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F49E, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4A0, 0x01F4),
	S5K4ECGX_REG_WRITE(0xD000F4A2, 0x05B6),
	S5K4ECGX_REG_WRITE(0xD000F4A4, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4A6, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4A8, 0x01F4),
	S5K4ECGX_REG_WRITE(0xD000F4AA, 0x05BA),
	S5K4ECGX_REG_WRITE(0xD000F4AC, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4AE, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4B0, 0x01F4),
	S5K4ECGX_REG_WRITE(0xD000F4B2, 0x024F),
	S5K4ECGX_REG_WRITE(0xD000F4B4, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4B6, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4B8, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4BA, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4BC, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4BE, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4C0, 0x0075),
	S5K4ECGX_REG_WRITE(0xD000F4C2, 0x00CF),
	S5K4ECGX_REG_WRITE(0xD000F4C4, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4C6, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4C8, 0x0075),
	S5K4ECGX_REG_WRITE(0xD000F4CA, 0x00D6),
	S5K4ECGX_REG_WRITE(0xD000F4CC, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4CE, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4D0, 0x0004),
	S5K4ECGX_REG_WRITE(0xD000F4D2, 0x01F4),
	S5K4ECGX_REG_WRITE(0xD000F4D4, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4D6, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4D8, 0x00F0),
	S5K4ECGX_REG_WRITE(0xD000F4DA, 0x01F4),
	S5K4ECGX_REG_WRITE(0xD000F4DC, 0x029E),
	S5K4ECGX_REG_WRITE(0xD000F4DE, 0x05B2),
	S5K4ECGX_REG_WRITE(0xD000F4E0, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4E2, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4E4, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4E6, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4E8, 0x01F8),
	S5K4ECGX_REG_WRITE(0xD000F4EA, 0x0228),
	S5K4ECGX_REG_WRITE(0xD000F4EC, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4EE, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4F0, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4F2, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4F4, 0x0208),
	S5K4ECGX_REG_WRITE(0xD000F4F6, 0x0238),
	S5K4ECGX_REG_WRITE(0xD000F4F8, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4FA, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F4FC, 0x0000),

	S5K4ECGX_REG_WRITE(0xD000F590, 0x0000),

	S5K4ECGX_REG_WRITE(0xD000F500, 0x0218),
	S5K4ECGX_REG_WRITE(0xD000F502, 0x0238),
	S5K4ECGX_REG_WRITE(0xD000F504, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F506, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F508, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F50A, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F50C, 0x0001),
	S5K4ECGX_REG_WRITE(0xD000F50E, 0x0009),
	S5K4ECGX_REG_WRITE(0xD000F510, 0x00DE),
	S5K4ECGX_REG_WRITE(0xD000F512, 0x05C0),
	S5K4ECGX_REG_WRITE(0xD000F514, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F516, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F518, 0x00DF),
	S5K4ECGX_REG_WRITE(0xD000F51A, 0x00E4),
	S5K4ECGX_REG_WRITE(0xD000F51C, 0x01F8),
	S5K4ECGX_REG_WRITE(0xD000F51E, 0x01FD),
	S5K4ECGX_REG_WRITE(0xD000F520, 0x05B6),
	S5K4ECGX_REG_WRITE(0xD000F522, 0x05BB),
	S5K4ECGX_REG_WRITE(0xD000F524, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F526, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F528, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F52A, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F52C, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F52E, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F530, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F532, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F534, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F536, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F538, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F53A, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F53C, 0x01F8),
	S5K4ECGX_REG_WRITE(0xD000F53E, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F540, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F542, 0x0077),
	S5K4ECGX_REG_WRITE(0xD000F544, 0x007E),
	S5K4ECGX_REG_WRITE(0xD000F546, 0x024F),
	S5K4ECGX_REG_WRITE(0xD000F548, 0x025E),
	S5K4ECGX_REG_WRITE(0xD000F54A, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F54C, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F54E, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F550, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F552, 0x0708),
	S5K4ECGX_REG_WRITE(0xD000F554, 0x080C),

	S5K4ECGX_REG_WRITE(0xD0001082, 0x5555),
	S5K4ECGX_REG_WRITE(0xD0001084, 0x5555),

	S5K4ECGX_REG_WRITE(0xD0001088, 0x055D),

	S5K4ECGX_REG_WRITE(0xD000100E, 0x0000),

	/* switch to sw address bank */

	S5K4ECGX_REG_WRITE(0x70000716, 0x0100),

	/* Start of Patch Data for firmware */
	S5K4ECGX_REG_WRITE(0x70003A10, 0xB5F8),
	S5K4ECGX_REG_WRITE(0x70003A12, 0x4A3E),
	S5K4ECGX_REG_WRITE(0x70003A14, 0x493E),
	S5K4ECGX_REG_WRITE(0x70003A16, 0x483F),
	S5K4ECGX_REG_WRITE(0x70003A18, 0xC004),
	S5K4ECGX_REG_WRITE(0x70003A1A, 0x6001),
	S5K4ECGX_REG_WRITE(0x70003A1C, 0x4C3E),
	S5K4ECGX_REG_WRITE(0x70003A1E, 0x2500),
	S5K4ECGX_REG_WRITE(0x70003A20, 0x8265),
	S5K4ECGX_REG_WRITE(0x70003A22, 0x8025),
	S5K4ECGX_REG_WRITE(0x70003A24, 0x493D),
	S5K4ECGX_REG_WRITE(0x70003A26, 0x483E),
	S5K4ECGX_REG_WRITE(0x70003A28, 0x2701),
	S5K4ECGX_REG_WRITE(0x70003A2A, 0x002A),
	S5K4ECGX_REG_WRITE(0x70003A2C, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003A2E, 0xFC38),
	S5K4ECGX_REG_WRITE(0x70003A30, 0x493C),
	S5K4ECGX_REG_WRITE(0x70003A32, 0x483D),
	S5K4ECGX_REG_WRITE(0x70003A34, 0x2602),
	S5K4ECGX_REG_WRITE(0x70003A36, 0x003A),
	S5K4ECGX_REG_WRITE(0x70003A38, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003A3A, 0xFC32),
	S5K4ECGX_REG_WRITE(0x70003A3C, 0x493B),
	S5K4ECGX_REG_WRITE(0x70003A3E, 0x483C),
	S5K4ECGX_REG_WRITE(0x70003A40, 0x0032),
	S5K4ECGX_REG_WRITE(0x70003A42, 0x2703),
	S5K4ECGX_REG_WRITE(0x70003A44, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003A46, 0xFC2C),
	S5K4ECGX_REG_WRITE(0x70003A48, 0x8225),
	S5K4ECGX_REG_WRITE(0x70003A4A, 0x493A),
	S5K4ECGX_REG_WRITE(0x70003A4C, 0x483A),
	S5K4ECGX_REG_WRITE(0x70003A4E, 0x2604),
	S5K4ECGX_REG_WRITE(0x70003A50, 0x003A),
	S5K4ECGX_REG_WRITE(0x70003A52, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003A54, 0xFC25),
	S5K4ECGX_REG_WRITE(0x70003A56, 0x200E),
	S5K4ECGX_REG_WRITE(0x70003A58, 0x8420),
	S5K4ECGX_REG_WRITE(0x70003A5A, 0x2701),
	S5K4ECGX_REG_WRITE(0x70003A5C, 0x83E7),
	S5K4ECGX_REG_WRITE(0x70003A5E, 0x4937),
	S5K4ECGX_REG_WRITE(0x70003A60, 0x4837),
	S5K4ECGX_REG_WRITE(0x70003A62, 0x0032),
	S5K4ECGX_REG_WRITE(0x70003A64, 0x2405),
	S5K4ECGX_REG_WRITE(0x70003A66, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003A68, 0xFC1B),
	S5K4ECGX_REG_WRITE(0x70003A6A, 0x4936),
	S5K4ECGX_REG_WRITE(0x70003A6C, 0x4836),
	S5K4ECGX_REG_WRITE(0x70003A6E, 0x2606),
	S5K4ECGX_REG_WRITE(0x70003A70, 0x0022),
	S5K4ECGX_REG_WRITE(0x70003A72, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003A74, 0xFC15),
	S5K4ECGX_REG_WRITE(0x70003A76, 0x4C28),
	S5K4ECGX_REG_WRITE(0x70003A78, 0x3460),
	S5K4ECGX_REG_WRITE(0x70003A7A, 0x81E7),
	S5K4ECGX_REG_WRITE(0x70003A7C, 0x4825),
	S5K4ECGX_REG_WRITE(0x70003A7E, 0x3824),
	S5K4ECGX_REG_WRITE(0x70003A80, 0x86C5),
	S5K4ECGX_REG_WRITE(0x70003A82, 0x4932),
	S5K4ECGX_REG_WRITE(0x70003A84, 0x4832),
	S5K4ECGX_REG_WRITE(0x70003A86, 0x0032),
	S5K4ECGX_REG_WRITE(0x70003A88, 0x2707),
	S5K4ECGX_REG_WRITE(0x70003A8A, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003A8C, 0xFC09),
	S5K4ECGX_REG_WRITE(0x70003A8E, 0x4931),
	S5K4ECGX_REG_WRITE(0x70003A90, 0x4831),
	S5K4ECGX_REG_WRITE(0x70003A92, 0x2608),
	S5K4ECGX_REG_WRITE(0x70003A94, 0x003A),
	S5K4ECGX_REG_WRITE(0x70003A96, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003A98, 0xFC03),
	S5K4ECGX_REG_WRITE(0x70003A9A, 0x4930),
	S5K4ECGX_REG_WRITE(0x70003A9C, 0x4830),
	S5K4ECGX_REG_WRITE(0x70003A9E, 0x0032),
	S5K4ECGX_REG_WRITE(0x70003AA0, 0x2709),
	S5K4ECGX_REG_WRITE(0x70003AA2, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003AA4, 0xFBFD),
	S5K4ECGX_REG_WRITE(0x70003AA6, 0x2005),
	S5K4ECGX_REG_WRITE(0x70003AA8, 0x8160),
	S5K4ECGX_REG_WRITE(0x70003AAA, 0x492E),
	S5K4ECGX_REG_WRITE(0x70003AAC, 0x482E),
	S5K4ECGX_REG_WRITE(0x70003AAE, 0x6281),
	S5K4ECGX_REG_WRITE(0x70003AB0, 0x8225),
	S5K4ECGX_REG_WRITE(0x70003AB2, 0x8265),
	S5K4ECGX_REG_WRITE(0x70003AB4, 0x482D),
	S5K4ECGX_REG_WRITE(0x70003AB6, 0x8320),
	S5K4ECGX_REG_WRITE(0x70003AB8, 0x482D),
	S5K4ECGX_REG_WRITE(0x70003ABA, 0x8360),
	S5K4ECGX_REG_WRITE(0x70003ABC, 0x0270),
	S5K4ECGX_REG_WRITE(0x70003ABE, 0x83A0),
	S5K4ECGX_REG_WRITE(0x70003AC0, 0x2005),
	S5K4ECGX_REG_WRITE(0x70003AC2, 0x0300),
	S5K4ECGX_REG_WRITE(0x70003AC4, 0x83E0),
	S5K4ECGX_REG_WRITE(0x70003AC6, 0x4828),
	S5K4ECGX_REG_WRITE(0x70003AC8, 0x492A),
	S5K4ECGX_REG_WRITE(0x70003ACA, 0x3840),
	S5K4ECGX_REG_WRITE(0x70003ACC, 0x6001),
	S5K4ECGX_REG_WRITE(0x70003ACE, 0x492A),
	S5K4ECGX_REG_WRITE(0x70003AD0, 0x482A),
	S5K4ECGX_REG_WRITE(0x70003AD2, 0x240A),
	S5K4ECGX_REG_WRITE(0x70003AD4, 0x003A),
	S5K4ECGX_REG_WRITE(0x70003AD6, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003AD8, 0xFBE3),
	S5K4ECGX_REG_WRITE(0x70003ADA, 0x4929),
	S5K4ECGX_REG_WRITE(0x70003ADC, 0x4829),
	S5K4ECGX_REG_WRITE(0x70003ADE, 0x0022),
	S5K4ECGX_REG_WRITE(0x70003AE0, 0x250B),
	S5K4ECGX_REG_WRITE(0x70003AE2, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003AE4, 0xFBDD),
	S5K4ECGX_REG_WRITE(0x70003AE6, 0x4820),
	S5K4ECGX_REG_WRITE(0x70003AE8, 0x4927),
	S5K4ECGX_REG_WRITE(0x70003AEA, 0x3080),
	S5K4ECGX_REG_WRITE(0x70003AEC, 0x6381),
	S5K4ECGX_REG_WRITE(0x70003AEE, 0x4927),
	S5K4ECGX_REG_WRITE(0x70003AF0, 0x4827),
	S5K4ECGX_REG_WRITE(0x70003AF2, 0x240C),
	S5K4ECGX_REG_WRITE(0x70003AF4, 0x002A),
	S5K4ECGX_REG_WRITE(0x70003AF6, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003AF8, 0xFBD3),
	S5K4ECGX_REG_WRITE(0x70003AFA, 0x4926),
	S5K4ECGX_REG_WRITE(0x70003AFC, 0x4826),
	S5K4ECGX_REG_WRITE(0x70003AFE, 0x0022),
	S5K4ECGX_REG_WRITE(0x70003B00, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003B02, 0xFBCE),
	S5K4ECGX_REG_WRITE(0x70003B04, 0xBCF8),
	S5K4ECGX_REG_WRITE(0x70003B06, 0xBC08),
	S5K4ECGX_REG_WRITE(0x70003B08, 0x4718),
	S5K4ECGX_REG_WRITE(0x70003B0A, 0x0000),
	S5K4ECGX_REG_WRITE(0x70003B0C, 0x0174),
	S5K4ECGX_REG_WRITE(0x70003B0E, 0x4EC1),
	S5K4ECGX_REG_WRITE(0x70003B10, 0xFFFE),
	S5K4ECGX_REG_WRITE(0x70003B12, 0x0000),
	S5K4ECGX_REG_WRITE(0x70003B14, 0x1EF0),
	S5K4ECGX_REG_WRITE(0x70003B16, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003B18, 0x4780),
	S5K4ECGX_REG_WRITE(0x70003B1A, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003B1C, 0x3BF3),
	S5K4ECGX_REG_WRITE(0x70003B1E, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003B20, 0xA1D9),
	S5K4ECGX_REG_WRITE(0x70003B22, 0x0000),
	S5K4ECGX_REG_WRITE(0x70003B24, 0x3B9D),
	S5K4ECGX_REG_WRITE(0x70003B26, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003B28, 0xA0BD),
	S5K4ECGX_REG_WRITE(0x70003B2A, 0x0000),
	S5K4ECGX_REG_WRITE(0x70003B2C, 0x3C8D),
	S5K4ECGX_REG_WRITE(0x70003B2E, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003B30, 0x217B),
	S5K4ECGX_REG_WRITE(0x70003B32, 0x0000),
	S5K4ECGX_REG_WRITE(0x70003B34, 0x3CE9),
	S5K4ECGX_REG_WRITE(0x70003B36, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003B38, 0xE0DF),
	S5K4ECGX_REG_WRITE(0x70003B3A, 0x0000),
	S5K4ECGX_REG_WRITE(0x70003B3C, 0x3E73),
	S5K4ECGX_REG_WRITE(0x70003B3E, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003B40, 0x053B),
	S5K4ECGX_REG_WRITE(0x70003B42, 0x0000),
	S5K4ECGX_REG_WRITE(0x70003B44, 0x3D71),
	S5K4ECGX_REG_WRITE(0x70003B46, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003B48, 0x509B),
	S5K4ECGX_REG_WRITE(0x70003B4A, 0x0000),
	S5K4ECGX_REG_WRITE(0x70003B4C, 0x3FF9),
	S5K4ECGX_REG_WRITE(0x70003B4E, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003B50, 0xD42F),
	S5K4ECGX_REG_WRITE(0x70003B52, 0x0000),
	S5K4ECGX_REG_WRITE(0x70003B54, 0x3EB5),
	S5K4ECGX_REG_WRITE(0x70003B56, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003B58, 0x49D1),
	S5K4ECGX_REG_WRITE(0x70003B5A, 0x0000),
	S5K4ECGX_REG_WRITE(0x70003B5C, 0x3F4F),
	S5K4ECGX_REG_WRITE(0x70003B5E, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003B60, 0x1E57),
	S5K4ECGX_REG_WRITE(0x70003B62, 0x0000),
	S5K4ECGX_REG_WRITE(0x70003B64, 0x4033),
	S5K4ECGX_REG_WRITE(0x70003B66, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003B68, 0x00C0),
	S5K4ECGX_REG_WRITE(0x70003B6A, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003B6C, 0x4E34),
	S5K4ECGX_REG_WRITE(0x70003B6E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70003B70, 0x7C53),
	S5K4ECGX_REG_WRITE(0x70003B72, 0x0000),
	S5K4ECGX_REG_WRITE(0x70003B74, 0x40BF),
	S5K4ECGX_REG_WRITE(0x70003B76, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003B78, 0x40FB),
	S5K4ECGX_REG_WRITE(0x70003B7A, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003B7C, 0xF5D7),
	S5K4ECGX_REG_WRITE(0x70003B7E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70003B80, 0x406F),
	S5K4ECGX_REG_WRITE(0x70003B82, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003B84, 0xBAB1),
	S5K4ECGX_REG_WRITE(0x70003B86, 0x0000),
	S5K4ECGX_REG_WRITE(0x70003B88, 0x4187),
	S5K4ECGX_REG_WRITE(0x70003B8A, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003B8C, 0x4129),
	S5K4ECGX_REG_WRITE(0x70003B8E, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003B90, 0xC10D),
	S5K4ECGX_REG_WRITE(0x70003B92, 0x0000),
	S5K4ECGX_REG_WRITE(0x70003B94, 0x4203),
	S5K4ECGX_REG_WRITE(0x70003B96, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003B98, 0xB231),
	S5K4ECGX_REG_WRITE(0x70003B9A, 0x0000),
	S5K4ECGX_REG_WRITE(0x70003B9C, 0xB570),
	S5K4ECGX_REG_WRITE(0x70003B9E, 0x000C),
	S5K4ECGX_REG_WRITE(0x70003BA0, 0x6820),
	S5K4ECGX_REG_WRITE(0x70003BA2, 0x6865),
	S5K4ECGX_REG_WRITE(0x70003BA4, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003BA6, 0xFB84),
	S5K4ECGX_REG_WRITE(0x70003BA8, 0x4BFC),
	S5K4ECGX_REG_WRITE(0x70003BAA, 0x0402),
	S5K4ECGX_REG_WRITE(0x70003BAC, 0x0C12),
	S5K4ECGX_REG_WRITE(0x70003BAE, 0x819A),
	S5K4ECGX_REG_WRITE(0x70003BB0, 0x48FB),
	S5K4ECGX_REG_WRITE(0x70003BB2, 0x89C1),
	S5K4ECGX_REG_WRITE(0x70003BB4, 0x428A),
	S5K4ECGX_REG_WRITE(0x70003BB6, 0xD305),
	S5K4ECGX_REG_WRITE(0x70003BB8, 0x4AFA),
	S5K4ECGX_REG_WRITE(0x70003BBA, 0x8986),
	S5K4ECGX_REG_WRITE(0x70003BBC, 0x8852),
	S5K4ECGX_REG_WRITE(0x70003BBE, 0x42B2),
	S5K4ECGX_REG_WRITE(0x70003BC0, 0xD300),
	S5K4ECGX_REG_WRITE(0x70003BC2, 0x8199),
	S5K4ECGX_REG_WRITE(0x70003BC4, 0x8801),
	S5K4ECGX_REG_WRITE(0x70003BC6, 0x2900),
	S5K4ECGX_REG_WRITE(0x70003BC8, 0xD008),
	S5K4ECGX_REG_WRITE(0x70003BCA, 0x49F7),
	S5K4ECGX_REG_WRITE(0x70003BCC, 0x002B),
	S5K4ECGX_REG_WRITE(0x70003BCE, 0x6E0A),
	S5K4ECGX_REG_WRITE(0x70003BD0, 0x2105),
	S5K4ECGX_REG_WRITE(0x70003BD2, 0x1C80),
	S5K4ECGX_REG_WRITE(0x70003BD4, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003BD6, 0xFB74),
	S5K4ECGX_REG_WRITE(0x70003BD8, 0x6020),
	S5K4ECGX_REG_WRITE(0x70003BDA, 0xE006),
	S5K4ECGX_REG_WRITE(0x70003BDC, 0x899A),
	S5K4ECGX_REG_WRITE(0x70003BDE, 0x48F3),
	S5K4ECGX_REG_WRITE(0x70003BE0, 0x002B),
	S5K4ECGX_REG_WRITE(0x70003BE2, 0x2105),
	S5K4ECGX_REG_WRITE(0x70003BE4, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003BE6, 0xFB6C),
	S5K4ECGX_REG_WRITE(0x70003BE8, 0x6020),
	S5K4ECGX_REG_WRITE(0x70003BEA, 0x6820),
	S5K4ECGX_REG_WRITE(0x70003BEC, 0xBC70),
	S5K4ECGX_REG_WRITE(0x70003BEE, 0xBC08),
	S5K4ECGX_REG_WRITE(0x70003BF0, 0x4718),
	S5K4ECGX_REG_WRITE(0x70003BF2, 0xB5F8),
	S5K4ECGX_REG_WRITE(0x70003BF4, 0x0004),
	S5K4ECGX_REG_WRITE(0x70003BF6, 0x2000),
	S5K4ECGX_REG_WRITE(0x70003BF8, 0x9000),
	S5K4ECGX_REG_WRITE(0x70003BFA, 0x0020),
	S5K4ECGX_REG_WRITE(0x70003BFC, 0x2501),
	S5K4ECGX_REG_WRITE(0x70003BFE, 0x3810),
	S5K4ECGX_REG_WRITE(0x70003C00, 0x2601),
	S5K4ECGX_REG_WRITE(0x70003C02, 0x40A5),
	S5K4ECGX_REG_WRITE(0x70003C04, 0x4086),
	S5K4ECGX_REG_WRITE(0x70003C06, 0x4FEA),
	S5K4ECGX_REG_WRITE(0x70003C08, 0x2C10),
	S5K4ECGX_REG_WRITE(0x70003C0A, 0xDA03),
	S5K4ECGX_REG_WRITE(0x70003C0C, 0x8838),
	S5K4ECGX_REG_WRITE(0x70003C0E, 0x43A8),
	S5K4ECGX_REG_WRITE(0x70003C10, 0x8038),
	S5K4ECGX_REG_WRITE(0x70003C12, 0xE002),
	S5K4ECGX_REG_WRITE(0x70003C14, 0x8878),
	S5K4ECGX_REG_WRITE(0x70003C16, 0x43B0),
	S5K4ECGX_REG_WRITE(0x70003C18, 0x8078),
	S5K4ECGX_REG_WRITE(0x70003C1A, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003C1C, 0xFB59),
	S5K4ECGX_REG_WRITE(0x70003C1E, 0x2C10),
	S5K4ECGX_REG_WRITE(0x70003C20, 0xDA03),
	S5K4ECGX_REG_WRITE(0x70003C22, 0x8838),
	S5K4ECGX_REG_WRITE(0x70003C24, 0x4328),
	S5K4ECGX_REG_WRITE(0x70003C26, 0x8038),
	S5K4ECGX_REG_WRITE(0x70003C28, 0xE002),
	S5K4ECGX_REG_WRITE(0x70003C2A, 0x8878),
	S5K4ECGX_REG_WRITE(0x70003C2C, 0x4330),
	S5K4ECGX_REG_WRITE(0x70003C2E, 0x8078),
	S5K4ECGX_REG_WRITE(0x70003C30, 0x48DA),
	S5K4ECGX_REG_WRITE(0x70003C32, 0x2105),
	S5K4ECGX_REG_WRITE(0x70003C34, 0x8982),
	S5K4ECGX_REG_WRITE(0x70003C36, 0x48DD),
	S5K4ECGX_REG_WRITE(0x70003C38, 0x466B),
	S5K4ECGX_REG_WRITE(0x70003C3A, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003C3C, 0xFB41),
	S5K4ECGX_REG_WRITE(0x70003C3E, 0x1C41),
	S5K4ECGX_REG_WRITE(0x70003C40, 0x4CD7),
	S5K4ECGX_REG_WRITE(0x70003C42, 0x0049),
	S5K4ECGX_REG_WRITE(0x70003C44, 0x0040),
	S5K4ECGX_REG_WRITE(0x70003C46, 0x1909),
	S5K4ECGX_REG_WRITE(0x70003C48, 0x1900),
	S5K4ECGX_REG_WRITE(0x70003C4A, 0x466B),
	S5K4ECGX_REG_WRITE(0x70003C4C, 0x8A89),
	S5K4ECGX_REG_WRITE(0x70003C4E, 0x8A80),
	S5K4ECGX_REG_WRITE(0x70003C50, 0x881A),
	S5K4ECGX_REG_WRITE(0x70003C52, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003C54, 0xFB45),
	S5K4ECGX_REG_WRITE(0x70003C56, 0x8A61),
	S5K4ECGX_REG_WRITE(0x70003C58, 0x0540),
	S5K4ECGX_REG_WRITE(0x70003C5A, 0x02C9),
	S5K4ECGX_REG_WRITE(0x70003C5C, 0x0D40),
	S5K4ECGX_REG_WRITE(0x70003C5E, 0x4301),
	S5K4ECGX_REG_WRITE(0x70003C60, 0x48D4),
	S5K4ECGX_REG_WRITE(0x70003C62, 0x8081),
	S5K4ECGX_REG_WRITE(0x70003C64, 0x49D4),
	S5K4ECGX_REG_WRITE(0x70003C66, 0x48D4),
	S5K4ECGX_REG_WRITE(0x70003C68, 0x3120),
	S5K4ECGX_REG_WRITE(0x70003C6A, 0x8BC0),
	S5K4ECGX_REG_WRITE(0x70003C6C, 0x8809),
	S5K4ECGX_REG_WRITE(0x70003C6E, 0x1841),
	S5K4ECGX_REG_WRITE(0x70003C70, 0x0020),
	S5K4ECGX_REG_WRITE(0x70003C72, 0x3060),
	S5K4ECGX_REG_WRITE(0x70003C74, 0x8A82),
	S5K4ECGX_REG_WRITE(0x70003C76, 0x4291),
	S5K4ECGX_REG_WRITE(0x70003C78, 0xD205),
	S5K4ECGX_REG_WRITE(0x70003C7A, 0x8AC0),
	S5K4ECGX_REG_WRITE(0x70003C7C, 0x49CF),
	S5K4ECGX_REG_WRITE(0x70003C7E, 0x7388),
	S5K4ECGX_REG_WRITE(0x70003C80, 0x2001),
	S5K4ECGX_REG_WRITE(0x70003C82, 0x31A0),
	S5K4ECGX_REG_WRITE(0x70003C84, 0x70C8),
	S5K4ECGX_REG_WRITE(0x70003C86, 0xBCF8),
	S5K4ECGX_REG_WRITE(0x70003C88, 0xBC08),
	S5K4ECGX_REG_WRITE(0x70003C8A, 0x4718),
	S5K4ECGX_REG_WRITE(0x70003C8C, 0xB5F8),
	S5K4ECGX_REG_WRITE(0x70003C8E, 0x48C6),
	S5K4ECGX_REG_WRITE(0x70003C90, 0x2200),
	S5K4ECGX_REG_WRITE(0x70003C92, 0x30A0),
	S5K4ECGX_REG_WRITE(0x70003C94, 0x81C2),
	S5K4ECGX_REG_WRITE(0x70003C96, 0x6808),
	S5K4ECGX_REG_WRITE(0x70003C98, 0x4669),
	S5K4ECGX_REG_WRITE(0x70003C9A, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003C9C, 0xFB29),
	S5K4ECGX_REG_WRITE(0x70003C9E, 0x466B),
	S5K4ECGX_REG_WRITE(0x70003CA0, 0x8818),
	S5K4ECGX_REG_WRITE(0x70003CA2, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003CA4, 0xFB2D),
	S5K4ECGX_REG_WRITE(0x70003CA6, 0x0005),
	S5K4ECGX_REG_WRITE(0x70003CA8, 0x466B),
	S5K4ECGX_REG_WRITE(0x70003CAA, 0x8858),
	S5K4ECGX_REG_WRITE(0x70003CAC, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003CAE, 0xFB30),
	S5K4ECGX_REG_WRITE(0x70003CB0, 0x0004),
	S5K4ECGX_REG_WRITE(0x70003CB2, 0x2101),
	S5K4ECGX_REG_WRITE(0x70003CB4, 0x1928),
	S5K4ECGX_REG_WRITE(0x70003CB6, 0x02C9),
	S5K4ECGX_REG_WRITE(0x70003CB8, 0x1A08),
	S5K4ECGX_REG_WRITE(0x70003CBA, 0x0286),
	S5K4ECGX_REG_WRITE(0x70003CBC, 0x0029),
	S5K4ECGX_REG_WRITE(0x70003CBE, 0x0030),
	S5K4ECGX_REG_WRITE(0x70003CC0, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003CC2, 0xFB2E),
	S5K4ECGX_REG_WRITE(0x70003CC4, 0x0005),
	S5K4ECGX_REG_WRITE(0x70003CC6, 0x2701),
	S5K4ECGX_REG_WRITE(0x70003CC8, 0x02BF),
	S5K4ECGX_REG_WRITE(0x70003CCA, 0x0021),
	S5K4ECGX_REG_WRITE(0x70003CCC, 0x0030),
	S5K4ECGX_REG_WRITE(0x70003CCE, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003CD0, 0xFB27),
	S5K4ECGX_REG_WRITE(0x70003CD2, 0x49B5),
	S5K4ECGX_REG_WRITE(0x70003CD4, 0x4AB8),
	S5K4ECGX_REG_WRITE(0x70003CD6, 0x3140),
	S5K4ECGX_REG_WRITE(0x70003CD8, 0x3220),
	S5K4ECGX_REG_WRITE(0x70003CDA, 0x808D),
	S5K4ECGX_REG_WRITE(0x70003CDC, 0x8295),
	S5K4ECGX_REG_WRITE(0x70003CDE, 0x80CF),
	S5K4ECGX_REG_WRITE(0x70003CE0, 0x82D7),
	S5K4ECGX_REG_WRITE(0x70003CE2, 0x8108),
	S5K4ECGX_REG_WRITE(0x70003CE4, 0x8310),
	S5K4ECGX_REG_WRITE(0x70003CE6, 0xE7CE),
	S5K4ECGX_REG_WRITE(0x70003CE8, 0x6808),
	S5K4ECGX_REG_WRITE(0x70003CEA, 0x0400),
	S5K4ECGX_REG_WRITE(0x70003CEC, 0x0C00),
	S5K4ECGX_REG_WRITE(0x70003CEE, 0x6849),
	S5K4ECGX_REG_WRITE(0x70003CF0, 0x0409),
	S5K4ECGX_REG_WRITE(0x70003CF2, 0x0C09),
	S5K4ECGX_REG_WRITE(0x70003CF4, 0x4AAA),
	S5K4ECGX_REG_WRITE(0x70003CF6, 0x8A12),
	S5K4ECGX_REG_WRITE(0x70003CF8, 0x2A00),
	S5K4ECGX_REG_WRITE(0x70003CFA, 0xD00D),
	S5K4ECGX_REG_WRITE(0x70003CFC, 0x2300),
	S5K4ECGX_REG_WRITE(0x70003CFE, 0x1A89),
	S5K4ECGX_REG_WRITE(0x70003D00, 0xD400),
	S5K4ECGX_REG_WRITE(0x70003D02, 0x000B),
	S5K4ECGX_REG_WRITE(0x70003D04, 0x0419),
	S5K4ECGX_REG_WRITE(0x70003D06, 0x0C09),
	S5K4ECGX_REG_WRITE(0x70003D08, 0x23FF),
	S5K4ECGX_REG_WRITE(0x70003D0A, 0x33C1),
	S5K4ECGX_REG_WRITE(0x70003D0C, 0x1810),
	S5K4ECGX_REG_WRITE(0x70003D0E, 0x4298),
	S5K4ECGX_REG_WRITE(0x70003D10, 0xD800),
	S5K4ECGX_REG_WRITE(0x70003D12, 0x0003),
	S5K4ECGX_REG_WRITE(0x70003D14, 0x0418),
	S5K4ECGX_REG_WRITE(0x70003D16, 0x0C00),
	S5K4ECGX_REG_WRITE(0x70003D18, 0x4AA9),
	S5K4ECGX_REG_WRITE(0x70003D1A, 0x8150),
	S5K4ECGX_REG_WRITE(0x70003D1C, 0x8191),
	S5K4ECGX_REG_WRITE(0x70003D1E, 0x4770),
	S5K4ECGX_REG_WRITE(0x70003D20, 0xB5F8),
	S5K4ECGX_REG_WRITE(0x70003D22, 0x2400),
	S5K4ECGX_REG_WRITE(0x70003D24, 0x4DA7),
	S5K4ECGX_REG_WRITE(0x70003D26, 0x4F9E),
	S5K4ECGX_REG_WRITE(0x70003D28, 0x48A7),
	S5K4ECGX_REG_WRITE(0x70003D2A, 0x8C39),
	S5K4ECGX_REG_WRITE(0x70003D2C, 0x8041),
	S5K4ECGX_REG_WRITE(0x70003D2E, 0x2101),
	S5K4ECGX_REG_WRITE(0x70003D30, 0x8001),
	S5K4ECGX_REG_WRITE(0x70003D32, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003D34, 0xFAFB),
	S5K4ECGX_REG_WRITE(0x70003D36, 0x48A5),
	S5K4ECGX_REG_WRITE(0x70003D38, 0x8BC0),
	S5K4ECGX_REG_WRITE(0x70003D3A, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003D3C, 0xFAFF),
	S5K4ECGX_REG_WRITE(0x70003D3E, 0x260D),
	S5K4ECGX_REG_WRITE(0x70003D40, 0x0736),
	S5K4ECGX_REG_WRITE(0x70003D42, 0x2000),
	S5K4ECGX_REG_WRITE(0x70003D44, 0x00E1),
	S5K4ECGX_REG_WRITE(0x70003D46, 0x19CA),
	S5K4ECGX_REG_WRITE(0x70003D48, 0x0041),
	S5K4ECGX_REG_WRITE(0x70003D4A, 0x194B),
	S5K4ECGX_REG_WRITE(0x70003D4C, 0x199B),
	S5K4ECGX_REG_WRITE(0x70003D4E, 0x881B),
	S5K4ECGX_REG_WRITE(0x70003D50, 0x1851),
	S5K4ECGX_REG_WRITE(0x70003D52, 0x844B),
	S5K4ECGX_REG_WRITE(0x70003D54, 0x1C40),
	S5K4ECGX_REG_WRITE(0x70003D56, 0x0400),
	S5K4ECGX_REG_WRITE(0x70003D58, 0x0C00),
	S5K4ECGX_REG_WRITE(0x70003D5A, 0x2804),
	S5K4ECGX_REG_WRITE(0x70003D5C, 0xD3F4),
	S5K4ECGX_REG_WRITE(0x70003D5E, 0x3508),
	S5K4ECGX_REG_WRITE(0x70003D60, 0x042D),
	S5K4ECGX_REG_WRITE(0x70003D62, 0x0C2D),
	S5K4ECGX_REG_WRITE(0x70003D64, 0x1C64),
	S5K4ECGX_REG_WRITE(0x70003D66, 0x0424),
	S5K4ECGX_REG_WRITE(0x70003D68, 0x0C24),
	S5K4ECGX_REG_WRITE(0x70003D6A, 0x2C07),
	S5K4ECGX_REG_WRITE(0x70003D6C, 0xD3E9),
	S5K4ECGX_REG_WRITE(0x70003D6E, 0xE78A),
	S5K4ECGX_REG_WRITE(0x70003D70, 0xB5F0),
	S5K4ECGX_REG_WRITE(0x70003D72, 0xB087),
	S5K4ECGX_REG_WRITE(0x70003D74, 0x6808),
	S5K4ECGX_REG_WRITE(0x70003D76, 0x9006),
	S5K4ECGX_REG_WRITE(0x70003D78, 0x6848),
	S5K4ECGX_REG_WRITE(0x70003D7A, 0x0405),
	S5K4ECGX_REG_WRITE(0x70003D7C, 0x0C2D),
	S5K4ECGX_REG_WRITE(0x70003D7E, 0x6888),
	S5K4ECGX_REG_WRITE(0x70003D80, 0x0403),
	S5K4ECGX_REG_WRITE(0x70003D82, 0x0C1B),
	S5K4ECGX_REG_WRITE(0x70003D84, 0x4892),
	S5K4ECGX_REG_WRITE(0x70003D86, 0x8B80),
	S5K4ECGX_REG_WRITE(0x70003D88, 0x2800),
	S5K4ECGX_REG_WRITE(0x70003D8A, 0xD100),
	S5K4ECGX_REG_WRITE(0x70003D8C, 0x2300),
	S5K4ECGX_REG_WRITE(0x70003D8E, 0x001C),
	S5K4ECGX_REG_WRITE(0x70003D90, 0x4A90),
	S5K4ECGX_REG_WRITE(0x70003D92, 0x466E),
	S5K4ECGX_REG_WRITE(0x70003D94, 0x1E91),
	S5K4ECGX_REG_WRITE(0x70003D96, 0x1E88),
	S5K4ECGX_REG_WRITE(0x70003D98, 0xC607),
	S5K4ECGX_REG_WRITE(0x70003D9A, 0x498F),
	S5K4ECGX_REG_WRITE(0x70003D9C, 0x0023),
	S5K4ECGX_REG_WRITE(0x70003D9E, 0x2207),
	S5K4ECGX_REG_WRITE(0x70003DA0, 0x0028),
	S5K4ECGX_REG_WRITE(0x70003DA2, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003DA4, 0xFAD3),
	S5K4ECGX_REG_WRITE(0x70003DA6, 0x487E),
	S5K4ECGX_REG_WRITE(0x70003DA8, 0x8BC1),
	S5K4ECGX_REG_WRITE(0x70003DAA, 0x2900),
	S5K4ECGX_REG_WRITE(0x70003DAC, 0xD030),
	S5K4ECGX_REG_WRITE(0x70003DAE, 0x2100),
	S5K4ECGX_REG_WRITE(0x70003DB0, 0x4888),
	S5K4ECGX_REG_WRITE(0x70003DB2, 0x4A7B),
	S5K4ECGX_REG_WRITE(0x70003DB4, 0x380A),
	S5K4ECGX_REG_WRITE(0x70003DB6, 0x88C0),
	S5K4ECGX_REG_WRITE(0x70003DB8, 0x00C3),
	S5K4ECGX_REG_WRITE(0x70003DBA, 0x189A),
	S5K4ECGX_REG_WRITE(0x70003DBC, 0x4696),
	S5K4ECGX_REG_WRITE(0x70003DBE, 0x4A86),
	S5K4ECGX_REG_WRITE(0x70003DC0, 0x1C40),
	S5K4ECGX_REG_WRITE(0x70003DC2, 0x189B),
	S5K4ECGX_REG_WRITE(0x70003DC4, 0x469C),
	S5K4ECGX_REG_WRITE(0x70003DC6, 0x4B76),
	S5K4ECGX_REG_WRITE(0x70003DC8, 0x00C0),
	S5K4ECGX_REG_WRITE(0x70003DCA, 0x18C6),
	S5K4ECGX_REG_WRITE(0x70003DCC, 0x1887),
	S5K4ECGX_REG_WRITE(0x70003DCE, 0x0048),
	S5K4ECGX_REG_WRITE(0x70003DD0, 0x4672),
	S5K4ECGX_REG_WRITE(0x70003DD2, 0x4663),
	S5K4ECGX_REG_WRITE(0x70003DD4, 0x1812),
	S5K4ECGX_REG_WRITE(0x70003DD6, 0x181B),
	S5K4ECGX_REG_WRITE(0x70003DD8, 0x8C52),
	S5K4ECGX_REG_WRITE(0x70003DDA, 0x8EDB),
	S5K4ECGX_REG_WRITE(0x70003DDC, 0x435A),
	S5K4ECGX_REG_WRITE(0x70003DDE, 0x0092),
	S5K4ECGX_REG_WRITE(0x70003DE0, 0x0C15),
	S5K4ECGX_REG_WRITE(0x70003DE2, 0x4A6F),
	S5K4ECGX_REG_WRITE(0x70003DE4, 0x1882),
	S5K4ECGX_REG_WRITE(0x70003DE6, 0x235A),
	S5K4ECGX_REG_WRITE(0x70003DE8, 0x529D),
	S5K4ECGX_REG_WRITE(0x70003DEA, 0x1833),
	S5K4ECGX_REG_WRITE(0x70003DEC, 0x1838),
	S5K4ECGX_REG_WRITE(0x70003DEE, 0x8C5B),
	S5K4ECGX_REG_WRITE(0x70003DF0, 0x8EC0),
	S5K4ECGX_REG_WRITE(0x70003DF2, 0x4343),
	S5K4ECGX_REG_WRITE(0x70003DF4, 0x0098),
	S5K4ECGX_REG_WRITE(0x70003DF6, 0x0C00),
	S5K4ECGX_REG_WRITE(0x70003DF8, 0x3260),
	S5K4ECGX_REG_WRITE(0x70003DFA, 0x8050),
	S5K4ECGX_REG_WRITE(0x70003DFC, 0x1C49),
	S5K4ECGX_REG_WRITE(0x70003DFE, 0x0409),
	S5K4ECGX_REG_WRITE(0x70003E00, 0x0C09),
	S5K4ECGX_REG_WRITE(0x70003E02, 0x2904),
	S5K4ECGX_REG_WRITE(0x70003E04, 0xD3E3),
	S5K4ECGX_REG_WRITE(0x70003E06, 0x4A66),
	S5K4ECGX_REG_WRITE(0x70003E08, 0x325A),
	S5K4ECGX_REG_WRITE(0x70003E0A, 0x0013),
	S5K4ECGX_REG_WRITE(0x70003E0C, 0x3308),
	S5K4ECGX_REG_WRITE(0x70003E0E, 0xE00A),
	S5K4ECGX_REG_WRITE(0x70003E10, 0x4870),
	S5K4ECGX_REG_WRITE(0x70003E12, 0x4971),
	S5K4ECGX_REG_WRITE(0x70003E14, 0x380A),
	S5K4ECGX_REG_WRITE(0x70003E16, 0x88C0),
	S5K4ECGX_REG_WRITE(0x70003E18, 0x00C2),
	S5K4ECGX_REG_WRITE(0x70003E1A, 0x1852),
	S5K4ECGX_REG_WRITE(0x70003E1C, 0x3236),
	S5K4ECGX_REG_WRITE(0x70003E1E, 0x1C40),
	S5K4ECGX_REG_WRITE(0x70003E20, 0x00C0),
	S5K4ECGX_REG_WRITE(0x70003E22, 0x1843),
	S5K4ECGX_REG_WRITE(0x70003E24, 0x3336),
	S5K4ECGX_REG_WRITE(0x70003E26, 0x2100),
	S5K4ECGX_REG_WRITE(0x70003E28, 0x4864),
	S5K4ECGX_REG_WRITE(0x70003E2A, 0x3020),
	S5K4ECGX_REG_WRITE(0x70003E2C, 0x4684),
	S5K4ECGX_REG_WRITE(0x70003E2E, 0x4E69),
	S5K4ECGX_REG_WRITE(0x70003E30, 0x0048),
	S5K4ECGX_REG_WRITE(0x70003E32, 0x3E0A),
	S5K4ECGX_REG_WRITE(0x70003E34, 0x8937),
	S5K4ECGX_REG_WRITE(0x70003E36, 0x5A15),
	S5K4ECGX_REG_WRITE(0x70003E38, 0x8976),
	S5K4ECGX_REG_WRITE(0x70003E3A, 0x437D),
	S5K4ECGX_REG_WRITE(0x70003E3C, 0x5A1F),
	S5K4ECGX_REG_WRITE(0x70003E3E, 0x4377),
	S5K4ECGX_REG_WRITE(0x70003E40, 0x4E65),
	S5K4ECGX_REG_WRITE(0x70003E42, 0x19ED),
	S5K4ECGX_REG_WRITE(0x70003E44, 0x1986),
	S5K4ECGX_REG_WRITE(0x70003E46, 0x3660),
	S5K4ECGX_REG_WRITE(0x70003E48, 0x89F6),
	S5K4ECGX_REG_WRITE(0x70003E4A, 0x4366),
	S5K4ECGX_REG_WRITE(0x70003E4C, 0x19AD),
	S5K4ECGX_REG_WRITE(0x70003E4E, 0x022D),
	S5K4ECGX_REG_WRITE(0x70003E50, 0x0C2D),
	S5K4ECGX_REG_WRITE(0x70003E52, 0xAE04),
	S5K4ECGX_REG_WRITE(0x70003E54, 0x5235),
	S5K4ECGX_REG_WRITE(0x70003E56, 0x4666),
	S5K4ECGX_REG_WRITE(0x70003E58, 0x7C76),
	S5K4ECGX_REG_WRITE(0x70003E5A, 0x4375),
	S5K4ECGX_REG_WRITE(0x70003E5C, 0x9E06),
	S5K4ECGX_REG_WRITE(0x70003E5E, 0x026D),
	S5K4ECGX_REG_WRITE(0x70003E60, 0x0C2D),
	S5K4ECGX_REG_WRITE(0x70003E62, 0x5235),
	S5K4ECGX_REG_WRITE(0x70003E64, 0x1C49),
	S5K4ECGX_REG_WRITE(0x70003E66, 0x2904),
	S5K4ECGX_REG_WRITE(0x70003E68, 0xD3E1),
	S5K4ECGX_REG_WRITE(0x70003E6A, 0xB007),
	S5K4ECGX_REG_WRITE(0x70003E6C, 0xBCF0),
	S5K4ECGX_REG_WRITE(0x70003E6E, 0xBC08),
	S5K4ECGX_REG_WRITE(0x70003E70, 0x4718),
	S5K4ECGX_REG_WRITE(0x70003E72, 0xB5F8),
	S5K4ECGX_REG_WRITE(0x70003E74, 0x0004),
	S5K4ECGX_REG_WRITE(0x70003E76, 0xF7FF),
	S5K4ECGX_REG_WRITE(0x70003E78, 0xFF53),
	S5K4ECGX_REG_WRITE(0x70003E7A, 0x2101),
	S5K4ECGX_REG_WRITE(0x70003E7C, 0x000D),
	S5K4ECGX_REG_WRITE(0x70003E7E, 0x0020),
	S5K4ECGX_REG_WRITE(0x70003E80, 0x3810),
	S5K4ECGX_REG_WRITE(0x70003E82, 0x4081),
	S5K4ECGX_REG_WRITE(0x70003E84, 0x40A5),
	S5K4ECGX_REG_WRITE(0x70003E86, 0x4F4A),
	S5K4ECGX_REG_WRITE(0x70003E88, 0x000E),
	S5K4ECGX_REG_WRITE(0x70003E8A, 0x2C10),
	S5K4ECGX_REG_WRITE(0x70003E8C, 0xDA03),
	S5K4ECGX_REG_WRITE(0x70003E8E, 0x8838),
	S5K4ECGX_REG_WRITE(0x70003E90, 0x43A8),
	S5K4ECGX_REG_WRITE(0x70003E92, 0x8038),
	S5K4ECGX_REG_WRITE(0x70003E94, 0xE002),
	S5K4ECGX_REG_WRITE(0x70003E96, 0x8878),
	S5K4ECGX_REG_WRITE(0x70003E98, 0x43B0),
	S5K4ECGX_REG_WRITE(0x70003E9A, 0x8078),
	S5K4ECGX_REG_WRITE(0x70003E9C, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003E9E, 0xFA5E),
	S5K4ECGX_REG_WRITE(0x70003EA0, 0x2C10),
	S5K4ECGX_REG_WRITE(0x70003EA2, 0xDA03),
	S5K4ECGX_REG_WRITE(0x70003EA4, 0x8838),
	S5K4ECGX_REG_WRITE(0x70003EA6, 0x4328),
	S5K4ECGX_REG_WRITE(0x70003EA8, 0x8038),
	S5K4ECGX_REG_WRITE(0x70003EAA, 0xE6EC),
	S5K4ECGX_REG_WRITE(0x70003EAC, 0x8878),
	S5K4ECGX_REG_WRITE(0x70003EAE, 0x4330),
	S5K4ECGX_REG_WRITE(0x70003EB0, 0x8078),
	S5K4ECGX_REG_WRITE(0x70003EB2, 0xE6E8),
	S5K4ECGX_REG_WRITE(0x70003EB4, 0xB5F8),
	S5K4ECGX_REG_WRITE(0x70003EB6, 0x0004),
	S5K4ECGX_REG_WRITE(0x70003EB8, 0x4F48),
	S5K4ECGX_REG_WRITE(0x70003EBA, 0x4949),
	S5K4ECGX_REG_WRITE(0x70003EBC, 0x78FA),
	S5K4ECGX_REG_WRITE(0x70003EBE, 0x2001),
	S5K4ECGX_REG_WRITE(0x70003EC0, 0x2A00),
	S5K4ECGX_REG_WRITE(0x70003EC2, 0xD102),
	S5K4ECGX_REG_WRITE(0x70003EC4, 0x2000),
	S5K4ECGX_REG_WRITE(0x70003EC6, 0x86C8),
	S5K4ECGX_REG_WRITE(0x70003EC8, 0xE003),
	S5K4ECGX_REG_WRITE(0x70003ECA, 0x7AFA),
	S5K4ECGX_REG_WRITE(0x70003ECC, 0x2A00),
	S5K4ECGX_REG_WRITE(0x70003ECE, 0xD000),
	S5K4ECGX_REG_WRITE(0x70003ED0, 0x86C8),
	S5K4ECGX_REG_WRITE(0x70003ED2, 0x2101),
	S5K4ECGX_REG_WRITE(0x70003ED4, 0x000D),
	S5K4ECGX_REG_WRITE(0x70003ED6, 0x0020),
	S5K4ECGX_REG_WRITE(0x70003ED8, 0x3810),
	S5K4ECGX_REG_WRITE(0x70003EDA, 0x4081),
	S5K4ECGX_REG_WRITE(0x70003EDC, 0x40A5),
	S5K4ECGX_REG_WRITE(0x70003EDE, 0x000E),
	S5K4ECGX_REG_WRITE(0x70003EE0, 0x2C10),
	S5K4ECGX_REG_WRITE(0x70003EE2, 0xDA04),
	S5K4ECGX_REG_WRITE(0x70003EE4, 0x4932),
	S5K4ECGX_REG_WRITE(0x70003EE6, 0x8808),
	S5K4ECGX_REG_WRITE(0x70003EE8, 0x43A8),
	S5K4ECGX_REG_WRITE(0x70003EEA, 0x8008),
	S5K4ECGX_REG_WRITE(0x70003EEC, 0xE003),
	S5K4ECGX_REG_WRITE(0x70003EEE, 0x4930),
	S5K4ECGX_REG_WRITE(0x70003EF0, 0x8848),
	S5K4ECGX_REG_WRITE(0x70003EF2, 0x43B0),
	S5K4ECGX_REG_WRITE(0x70003EF4, 0x8048),
	S5K4ECGX_REG_WRITE(0x70003EF6, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003EF8, 0xFA39),
	S5K4ECGX_REG_WRITE(0x70003EFA, 0x2C10),
	S5K4ECGX_REG_WRITE(0x70003EFC, 0xDA04),
	S5K4ECGX_REG_WRITE(0x70003EFE, 0x482C),
	S5K4ECGX_REG_WRITE(0x70003F00, 0x8801),
	S5K4ECGX_REG_WRITE(0x70003F02, 0x4329),
	S5K4ECGX_REG_WRITE(0x70003F04, 0x8001),
	S5K4ECGX_REG_WRITE(0x70003F06, 0xE003),
	S5K4ECGX_REG_WRITE(0x70003F08, 0x4829),
	S5K4ECGX_REG_WRITE(0x70003F0A, 0x8841),
	S5K4ECGX_REG_WRITE(0x70003F0C, 0x4331),
	S5K4ECGX_REG_WRITE(0x70003F0E, 0x8041),
	S5K4ECGX_REG_WRITE(0x70003F10, 0x4934),
	S5K4ECGX_REG_WRITE(0x70003F12, 0x8B08),
	S5K4ECGX_REG_WRITE(0x70003F14, 0x06C2),
	S5K4ECGX_REG_WRITE(0x70003F16, 0xD50A),
	S5K4ECGX_REG_WRITE(0x70003F18, 0x7ABA),
	S5K4ECGX_REG_WRITE(0x70003F1A, 0x0652),
	S5K4ECGX_REG_WRITE(0x70003F1C, 0xD507),
	S5K4ECGX_REG_WRITE(0x70003F1E, 0x2210),
	S5K4ECGX_REG_WRITE(0x70003F20, 0x4390),
	S5K4ECGX_REG_WRITE(0x70003F22, 0x8308),
	S5K4ECGX_REG_WRITE(0x70003F24, 0x4830),
	S5K4ECGX_REG_WRITE(0x70003F26, 0x7AF9),
	S5K4ECGX_REG_WRITE(0x70003F28, 0x6B00),
	S5K4ECGX_REG_WRITE(0x70003F2A, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003F2C, 0xFA27),
	S5K4ECGX_REG_WRITE(0x70003F2E, 0x481C),
	S5K4ECGX_REG_WRITE(0x70003F30, 0x3060),
	S5K4ECGX_REG_WRITE(0x70003F32, 0x89C0),
	S5K4ECGX_REG_WRITE(0x70003F34, 0x2800),
	S5K4ECGX_REG_WRITE(0x70003F36, 0xD009),
	S5K4ECGX_REG_WRITE(0x70003F38, 0x78F8),
	S5K4ECGX_REG_WRITE(0x70003F3A, 0x2800),
	S5K4ECGX_REG_WRITE(0x70003F3C, 0xD006),
	S5K4ECGX_REG_WRITE(0x70003F3E, 0x7AF8),
	S5K4ECGX_REG_WRITE(0x70003F40, 0x2800),
	S5K4ECGX_REG_WRITE(0x70003F42, 0xD003),
	S5K4ECGX_REG_WRITE(0x70003F44, 0x7AB8),
	S5K4ECGX_REG_WRITE(0x70003F46, 0x2140),
	S5K4ECGX_REG_WRITE(0x70003F48, 0x4308),
	S5K4ECGX_REG_WRITE(0x70003F4A, 0x72B8),
	S5K4ECGX_REG_WRITE(0x70003F4C, 0xE69B),
	S5K4ECGX_REG_WRITE(0x70003F4E, 0xB5F8),
	S5K4ECGX_REG_WRITE(0x70003F50, 0x0004),
	S5K4ECGX_REG_WRITE(0x70003F52, 0x4826),
	S5K4ECGX_REG_WRITE(0x70003F54, 0x8981),
	S5K4ECGX_REG_WRITE(0x70003F56, 0x2900),
	S5K4ECGX_REG_WRITE(0x70003F58, 0xD007),
	S5K4ECGX_REG_WRITE(0x70003F5A, 0x8940),
	S5K4ECGX_REG_WRITE(0x70003F5C, 0x2800),
	S5K4ECGX_REG_WRITE(0x70003F5E, 0xD104),
	S5K4ECGX_REG_WRITE(0x70003F60, 0x481E),
	S5K4ECGX_REG_WRITE(0x70003F62, 0x22BF),
	S5K4ECGX_REG_WRITE(0x70003F64, 0x7A81),
	S5K4ECGX_REG_WRITE(0x70003F66, 0x4011),
	S5K4ECGX_REG_WRITE(0x70003F68, 0x7281),
	S5K4ECGX_REG_WRITE(0x70003F6A, 0x2101),
	S5K4ECGX_REG_WRITE(0x70003F6C, 0x000D),
	S5K4ECGX_REG_WRITE(0x70003F6E, 0x0020),
	S5K4ECGX_REG_WRITE(0x70003F70, 0x3810),
	S5K4ECGX_REG_WRITE(0x70003F72, 0x4081),
	S5K4ECGX_REG_WRITE(0x70003F74, 0x40A5),
	S5K4ECGX_REG_WRITE(0x70003F76, 0x4F0E),
	S5K4ECGX_REG_WRITE(0x70003F78, 0x000E),
	S5K4ECGX_REG_WRITE(0x70003F7A, 0x2C10),
	S5K4ECGX_REG_WRITE(0x70003F7C, 0xDA03),
	S5K4ECGX_REG_WRITE(0x70003F7E, 0x8838),
	S5K4ECGX_REG_WRITE(0x70003F80, 0x43A8),
	S5K4ECGX_REG_WRITE(0x70003F82, 0x8038),
	S5K4ECGX_REG_WRITE(0x70003F84, 0xE002),
	S5K4ECGX_REG_WRITE(0x70003F86, 0x8878),
	S5K4ECGX_REG_WRITE(0x70003F88, 0x43B0),
	S5K4ECGX_REG_WRITE(0x70003F8A, 0x8078),
	S5K4ECGX_REG_WRITE(0x70003F8C, 0xF000),
	S5K4ECGX_REG_WRITE(0x70003F8E, 0xF9FE),
	S5K4ECGX_REG_WRITE(0x70003F90, 0x2C10),
	S5K4ECGX_REG_WRITE(0x70003F92, 0xDA2D),
	S5K4ECGX_REG_WRITE(0x70003F94, 0x8838),
	S5K4ECGX_REG_WRITE(0x70003F96, 0x4328),
	S5K4ECGX_REG_WRITE(0x70003F98, 0x8038),
	S5K4ECGX_REG_WRITE(0x70003F9A, 0xE674),
	S5K4ECGX_REG_WRITE(0x70003F9C, 0x21C0),
	S5K4ECGX_REG_WRITE(0x70003F9E, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003FA0, 0x4780),
	S5K4ECGX_REG_WRITE(0x70003FA2, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003FA4, 0x2D00),
	S5K4ECGX_REG_WRITE(0x70003FA6, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003FA8, 0x2AD0),
	S5K4ECGX_REG_WRITE(0x70003FAA, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003FAC, 0x0924),
	S5K4ECGX_REG_WRITE(0x70003FAE, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003FB0, 0x1100),
	S5K4ECGX_REG_WRITE(0x70003FB2, 0xD000),
	S5K4ECGX_REG_WRITE(0x70003FB4, 0xE300),
	S5K4ECGX_REG_WRITE(0x70003FB6, 0xD000),
	S5K4ECGX_REG_WRITE(0x70003FB8, 0x29D0),
	S5K4ECGX_REG_WRITE(0x70003FBA, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003FBC, 0x2C30),
	S5K4ECGX_REG_WRITE(0x70003FBE, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003FC0, 0x5000),
	S5K4ECGX_REG_WRITE(0x70003FC2, 0xD000),
	S5K4ECGX_REG_WRITE(0x70003FC4, 0xA006),
	S5K4ECGX_REG_WRITE(0x70003FC6, 0x0000),
	S5K4ECGX_REG_WRITE(0x70003FC8, 0xA000),
	S5K4ECGX_REG_WRITE(0x70003FCA, 0xD000),
	S5K4ECGX_REG_WRITE(0x70003FCC, 0x06F8),
	S5K4ECGX_REG_WRITE(0x70003FCE, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003FD0, 0x0888),
	S5K4ECGX_REG_WRITE(0x70003FD2, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003FD4, 0x21DA),
	S5K4ECGX_REG_WRITE(0x70003FD6, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003FD8, 0x08AC),
	S5K4ECGX_REG_WRITE(0x70003FDA, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003FDC, 0x20BC),
	S5K4ECGX_REG_WRITE(0x70003FDE, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003FE0, 0x1ECC),
	S5K4ECGX_REG_WRITE(0x70003FE2, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003FE4, 0x2FA4),
	S5K4ECGX_REG_WRITE(0x70003FE6, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003FE8, 0x235C),
	S5K4ECGX_REG_WRITE(0x70003FEA, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003FEC, 0x0234),
	S5K4ECGX_REG_WRITE(0x70003FEE, 0x7000),
	S5K4ECGX_REG_WRITE(0x70003FF0, 0x8878),
	S5K4ECGX_REG_WRITE(0x70003FF2, 0x4330),
	S5K4ECGX_REG_WRITE(0x70003FF4, 0x8078),
	S5K4ECGX_REG_WRITE(0x70003FF6, 0xE646),
	S5K4ECGX_REG_WRITE(0x70003FF8, 0xB570),
	S5K4ECGX_REG_WRITE(0x70003FFA, 0x4D99),
	S5K4ECGX_REG_WRITE(0x70003FFC, 0x4C99),
	S5K4ECGX_REG_WRITE(0x70003FFE, 0x8B28),
	S5K4ECGX_REG_WRITE(0x70004000, 0x0701),
	S5K4ECGX_REG_WRITE(0x70004002, 0xD507),
	S5K4ECGX_REG_WRITE(0x70004004, 0x2108),
	S5K4ECGX_REG_WRITE(0x70004006, 0x4388),
	S5K4ECGX_REG_WRITE(0x70004008, 0x8328),
	S5K4ECGX_REG_WRITE(0x7000400A, 0x4997),
	S5K4ECGX_REG_WRITE(0x7000400C, 0x6B20),
	S5K4ECGX_REG_WRITE(0x7000400E, 0x68C9),
	S5K4ECGX_REG_WRITE(0x70004010, 0xF000),
	S5K4ECGX_REG_WRITE(0x70004012, 0xF9C4),
	S5K4ECGX_REG_WRITE(0x70004014, 0x8B28),
	S5K4ECGX_REG_WRITE(0x70004016, 0x06C1),
	S5K4ECGX_REG_WRITE(0x70004018, 0xD50A),
	S5K4ECGX_REG_WRITE(0x7000401A, 0x4994),
	S5K4ECGX_REG_WRITE(0x7000401C, 0x7A8A),
	S5K4ECGX_REG_WRITE(0x7000401E, 0x0652),
	S5K4ECGX_REG_WRITE(0x70004020, 0xD406),
	S5K4ECGX_REG_WRITE(0x70004022, 0x2210),
	S5K4ECGX_REG_WRITE(0x70004024, 0x4390),
	S5K4ECGX_REG_WRITE(0x70004026, 0x8328),
	S5K4ECGX_REG_WRITE(0x70004028, 0x7AC9),
	S5K4ECGX_REG_WRITE(0x7000402A, 0x6B20),
	S5K4ECGX_REG_WRITE(0x7000402C, 0xF000),
	S5K4ECGX_REG_WRITE(0x7000402E, 0xF9A6),
	S5K4ECGX_REG_WRITE(0x70004030, 0xE5DC),
	S5K4ECGX_REG_WRITE(0x70004032, 0xB570),
	S5K4ECGX_REG_WRITE(0x70004034, 0x4D8E),
	S5K4ECGX_REG_WRITE(0x70004036, 0x4C8F),
	S5K4ECGX_REG_WRITE(0x70004038, 0x88EA),
	S5K4ECGX_REG_WRITE(0x7000403A, 0x2A14),
	S5K4ECGX_REG_WRITE(0x7000403C, 0xD101),
	S5K4ECGX_REG_WRITE(0x7000403E, 0x2200),
	S5K4ECGX_REG_WRITE(0x70004040, 0x81A2),
	S5K4ECGX_REG_WRITE(0x70004042, 0xF000),
	S5K4ECGX_REG_WRITE(0x70004044, 0xF9B3),
	S5K4ECGX_REG_WRITE(0x70004046, 0x88E8),
	S5K4ECGX_REG_WRITE(0x70004048, 0x2821),
	S5K4ECGX_REG_WRITE(0x7000404A, 0xD10F),
	S5K4ECGX_REG_WRITE(0x7000404C, 0x8B28),
	S5K4ECGX_REG_WRITE(0x7000404E, 0x2800),
	S5K4ECGX_REG_WRITE(0x70004050, 0xD10C),
	S5K4ECGX_REG_WRITE(0x70004052, 0x200C),
	S5K4ECGX_REG_WRITE(0x70004054, 0x5E20),
	S5K4ECGX_REG_WRITE(0x70004056, 0x8961),
	S5K4ECGX_REG_WRITE(0x70004058, 0x4288),
	S5K4ECGX_REG_WRITE(0x7000405A, 0xDC07),
	S5K4ECGX_REG_WRITE(0x7000405C, 0x4882),
	S5K4ECGX_REG_WRITE(0x7000405E, 0x3880),
	S5K4ECGX_REG_WRITE(0x70004060, 0x6B80),
	S5K4ECGX_REG_WRITE(0x70004062, 0xF000),
	S5K4ECGX_REG_WRITE(0x70004064, 0xF9AB),
	S5K4ECGX_REG_WRITE(0x70004066, 0x89A0),
	S5K4ECGX_REG_WRITE(0x70004068, 0x1C40),
	S5K4ECGX_REG_WRITE(0x7000406A, 0x81A0),
	S5K4ECGX_REG_WRITE(0x7000406C, 0xE5BE),
	S5K4ECGX_REG_WRITE(0x7000406E, 0xB5F8),
	S5K4ECGX_REG_WRITE(0x70004070, 0x0004),
	S5K4ECGX_REG_WRITE(0x70004072, 0x2101),
	S5K4ECGX_REG_WRITE(0x70004074, 0x000D),
	S5K4ECGX_REG_WRITE(0x70004076, 0x0020),
	S5K4ECGX_REG_WRITE(0x70004078, 0x3810),
	S5K4ECGX_REG_WRITE(0x7000407A, 0x4081),
	S5K4ECGX_REG_WRITE(0x7000407C, 0x40A5),
	S5K4ECGX_REG_WRITE(0x7000407E, 0x4F7E),
	S5K4ECGX_REG_WRITE(0x70004080, 0x000E),
	S5K4ECGX_REG_WRITE(0x70004082, 0x2C10),
	S5K4ECGX_REG_WRITE(0x70004084, 0xDA03),
	S5K4ECGX_REG_WRITE(0x70004086, 0x8838),
	S5K4ECGX_REG_WRITE(0x70004088, 0x43A8),
	S5K4ECGX_REG_WRITE(0x7000408A, 0x8038),
	S5K4ECGX_REG_WRITE(0x7000408C, 0xE002),
	S5K4ECGX_REG_WRITE(0x7000408E, 0x8878),
	S5K4ECGX_REG_WRITE(0x70004090, 0x43B0),
	S5K4ECGX_REG_WRITE(0x70004092, 0x8078),
	S5K4ECGX_REG_WRITE(0x70004094, 0xF000),
	S5K4ECGX_REG_WRITE(0x70004096, 0xF99A),
	S5K4ECGX_REG_WRITE(0x70004098, 0x2C10),
	S5K4ECGX_REG_WRITE(0x7000409A, 0xDA03),
	S5K4ECGX_REG_WRITE(0x7000409C, 0x8838),
	S5K4ECGX_REG_WRITE(0x7000409E, 0x4328),
	S5K4ECGX_REG_WRITE(0x700040A0, 0x8038),
	S5K4ECGX_REG_WRITE(0x700040A2, 0xE002),
	S5K4ECGX_REG_WRITE(0x700040A4, 0x8878),
	S5K4ECGX_REG_WRITE(0x700040A6, 0x4330),
	S5K4ECGX_REG_WRITE(0x700040A8, 0x8078),
	S5K4ECGX_REG_WRITE(0x700040AA, 0x4874),
	S5K4ECGX_REG_WRITE(0x700040AC, 0x8800),
	S5K4ECGX_REG_WRITE(0x700040AE, 0x0400),
	S5K4ECGX_REG_WRITE(0x700040B0, 0xD504),
	S5K4ECGX_REG_WRITE(0x700040B2, 0xF000),
	S5K4ECGX_REG_WRITE(0x700040B4, 0xF993),
	S5K4ECGX_REG_WRITE(0x700040B6, 0x496E),
	S5K4ECGX_REG_WRITE(0x700040B8, 0x2012),
	S5K4ECGX_REG_WRITE(0x700040BA, 0x80C8),
	S5K4ECGX_REG_WRITE(0x700040BC, 0xE5E3),
	S5K4ECGX_REG_WRITE(0x700040BE, 0xB570),
	S5K4ECGX_REG_WRITE(0x700040C0, 0x4E6A),
	S5K4ECGX_REG_WRITE(0x700040C2, 0x8881),
	S5K4ECGX_REG_WRITE(0x700040C4, 0x78F2),
	S5K4ECGX_REG_WRITE(0x700040C6, 0x4D6E),
	S5K4ECGX_REG_WRITE(0x700040C8, 0x4C6A),
	S5K4ECGX_REG_WRITE(0x700040CA, 0x2A00),
	S5K4ECGX_REG_WRITE(0x700040CC, 0xD005),
	S5K4ECGX_REG_WRITE(0x700040CE, 0x8A62),
	S5K4ECGX_REG_WRITE(0x700040D0, 0x1889),
	S5K4ECGX_REG_WRITE(0x700040D2, 0x8081),
	S5K4ECGX_REG_WRITE(0x700040D4, 0x8B61),
	S5K4ECGX_REG_WRITE(0x700040D6, 0x8029),
	S5K4ECGX_REG_WRITE(0x700040D8, 0xE004),
	S5K4ECGX_REG_WRITE(0x700040DA, 0x8A22),
	S5K4ECGX_REG_WRITE(0x700040DC, 0x1889),
	S5K4ECGX_REG_WRITE(0x700040DE, 0x8081),
	S5K4ECGX_REG_WRITE(0x700040E0, 0x8B21),
	S5K4ECGX_REG_WRITE(0x700040E2, 0x8029),
	S5K4ECGX_REG_WRITE(0x700040E4, 0xF000),
	S5K4ECGX_REG_WRITE(0x700040E6, 0xF982),
	S5K4ECGX_REG_WRITE(0x700040E8, 0x78F0),
	S5K4ECGX_REG_WRITE(0x700040EA, 0x2800),
	S5K4ECGX_REG_WRITE(0x700040EC, 0xD002),
	S5K4ECGX_REG_WRITE(0x700040EE, 0x8BE0),
	S5K4ECGX_REG_WRITE(0x700040F0, 0x82E8),
	S5K4ECGX_REG_WRITE(0x700040F2, 0xE57B),
	S5K4ECGX_REG_WRITE(0x700040F4, 0x8BA0),
	S5K4ECGX_REG_WRITE(0x700040F6, 0x82E8),
	S5K4ECGX_REG_WRITE(0x700040F8, 0xE578),
	S5K4ECGX_REG_WRITE(0x700040FA, 0xB430),
	S5K4ECGX_REG_WRITE(0x700040FC, 0x680B),
	S5K4ECGX_REG_WRITE(0x700040FE, 0x684D),
	S5K4ECGX_REG_WRITE(0x70004100, 0x688C),
	S5K4ECGX_REG_WRITE(0x70004102, 0x68C8),
	S5K4ECGX_REG_WRITE(0x70004104, 0x4A5F),
	S5K4ECGX_REG_WRITE(0x70004106, 0x8054),
	S5K4ECGX_REG_WRITE(0x70004108, 0x4958),
	S5K4ECGX_REG_WRITE(0x7000410A, 0x78CC),
	S5K4ECGX_REG_WRITE(0x7000410C, 0x4959),
	S5K4ECGX_REG_WRITE(0x7000410E, 0x2C00),
	S5K4ECGX_REG_WRITE(0x70004110, 0xD003),
	S5K4ECGX_REG_WRITE(0x70004112, 0x8A49),
	S5K4ECGX_REG_WRITE(0x70004114, 0x1808),
	S5K4ECGX_REG_WRITE(0x70004116, 0x8090),
	S5K4ECGX_REG_WRITE(0x70004118, 0xE002),
	S5K4ECGX_REG_WRITE(0x7000411A, 0x8A09),
	S5K4ECGX_REG_WRITE(0x7000411C, 0x1808),
	S5K4ECGX_REG_WRITE(0x7000411E, 0x8090),
	S5K4ECGX_REG_WRITE(0x70004120, 0x80D3),
	S5K4ECGX_REG_WRITE(0x70004122, 0x8115),
	S5K4ECGX_REG_WRITE(0x70004124, 0xBC30),
	S5K4ECGX_REG_WRITE(0x70004126, 0x4770),
	S5K4ECGX_REG_WRITE(0x70004128, 0xB5F3),
	S5K4ECGX_REG_WRITE(0x7000412A, 0x0004),
	S5K4ECGX_REG_WRITE(0x7000412C, 0xB081),
	S5K4ECGX_REG_WRITE(0x7000412E, 0x9802),
	S5K4ECGX_REG_WRITE(0x70004130, 0x6800),
	S5K4ECGX_REG_WRITE(0x70004132, 0x0600),
	S5K4ECGX_REG_WRITE(0x70004134, 0x0E00),
	S5K4ECGX_REG_WRITE(0x70004136, 0x2201),
	S5K4ECGX_REG_WRITE(0x70004138, 0x0015),
	S5K4ECGX_REG_WRITE(0x7000413A, 0x0021),
	S5K4ECGX_REG_WRITE(0x7000413C, 0x3910),
	S5K4ECGX_REG_WRITE(0x7000413E, 0x408A),
	S5K4ECGX_REG_WRITE(0x70004140, 0x40A5),
	S5K4ECGX_REG_WRITE(0x70004142, 0x4F4D),
	S5K4ECGX_REG_WRITE(0x70004144, 0x0016),
	S5K4ECGX_REG_WRITE(0x70004146, 0x2C10),
	S5K4ECGX_REG_WRITE(0x70004148, 0xDA03),
	S5K4ECGX_REG_WRITE(0x7000414A, 0x8839),
	S5K4ECGX_REG_WRITE(0x7000414C, 0x43A9),
	S5K4ECGX_REG_WRITE(0x7000414E, 0x8039),
	S5K4ECGX_REG_WRITE(0x70004150, 0xE002),
	S5K4ECGX_REG_WRITE(0x70004152, 0x8879),
	S5K4ECGX_REG_WRITE(0x70004154, 0x43B1),
	S5K4ECGX_REG_WRITE(0x70004156, 0x8079),
	S5K4ECGX_REG_WRITE(0x70004158, 0xF000),
	S5K4ECGX_REG_WRITE(0x7000415A, 0xF950),
	S5K4ECGX_REG_WRITE(0x7000415C, 0x2C10),
	S5K4ECGX_REG_WRITE(0x7000415E, 0xDA03),
	S5K4ECGX_REG_WRITE(0x70004160, 0x8839),
	S5K4ECGX_REG_WRITE(0x70004162, 0x4329),
	S5K4ECGX_REG_WRITE(0x70004164, 0x8039),
	S5K4ECGX_REG_WRITE(0x70004166, 0xE002),
	S5K4ECGX_REG_WRITE(0x70004168, 0x8879),
	S5K4ECGX_REG_WRITE(0x7000416A, 0x4331),
	S5K4ECGX_REG_WRITE(0x7000416C, 0x8079),
	S5K4ECGX_REG_WRITE(0x7000416E, 0x4946),
	S5K4ECGX_REG_WRITE(0x70004170, 0x8809),
	S5K4ECGX_REG_WRITE(0x70004172, 0x2900),
	S5K4ECGX_REG_WRITE(0x70004174, 0xD102),
	S5K4ECGX_REG_WRITE(0x70004176, 0xF000),
	S5K4ECGX_REG_WRITE(0x70004178, 0xF949),
	S5K4ECGX_REG_WRITE(0x7000417A, 0x2000),
	S5K4ECGX_REG_WRITE(0x7000417C, 0x9902),
	S5K4ECGX_REG_WRITE(0x7000417E, 0x6008),
	S5K4ECGX_REG_WRITE(0x70004180, 0xBCFE),
	S5K4ECGX_REG_WRITE(0x70004182, 0xBC08),
	S5K4ECGX_REG_WRITE(0x70004184, 0x4718),
	S5K4ECGX_REG_WRITE(0x70004186, 0xB538),
	S5K4ECGX_REG_WRITE(0x70004188, 0x4C40),
	S5K4ECGX_REG_WRITE(0x7000418A, 0x89E5),
	S5K4ECGX_REG_WRITE(0x7000418C, 0xF000),
	S5K4ECGX_REG_WRITE(0x7000418E, 0xF946),
	S5K4ECGX_REG_WRITE(0x70004190, 0x1FE8),
	S5K4ECGX_REG_WRITE(0x70004192, 0x38FD),
	S5K4ECGX_REG_WRITE(0x70004194, 0xD132),
	S5K4ECGX_REG_WRITE(0x70004196, 0x89E0),
	S5K4ECGX_REG_WRITE(0x70004198, 0x1FC1),
	S5K4ECGX_REG_WRITE(0x7000419A, 0x39FF),
	S5K4ECGX_REG_WRITE(0x7000419C, 0xD12E),
	S5K4ECGX_REG_WRITE(0x7000419E, 0x483C),
	S5K4ECGX_REG_WRITE(0x700041A0, 0x69E1),
	S5K4ECGX_REG_WRITE(0x700041A2, 0x6840),
	S5K4ECGX_REG_WRITE(0x700041A4, 0x1809),
	S5K4ECGX_REG_WRITE(0x700041A6, 0x0200),
	S5K4ECGX_REG_WRITE(0x700041A8, 0xF000),
	S5K4ECGX_REG_WRITE(0x700041AA, 0xF8BA),
	S5K4ECGX_REG_WRITE(0x700041AC, 0x0400),
	S5K4ECGX_REG_WRITE(0x700041AE, 0x0C00),
	S5K4ECGX_REG_WRITE(0x700041B0, 0x4A38),
	S5K4ECGX_REG_WRITE(0x700041B2, 0x2305),
	S5K4ECGX_REG_WRITE(0x700041B4, 0x0011),
	S5K4ECGX_REG_WRITE(0x700041B6, 0x3114),
	S5K4ECGX_REG_WRITE(0x700041B8, 0xF000),
	S5K4ECGX_REG_WRITE(0x700041BA, 0xF938),
	S5K4ECGX_REG_WRITE(0x700041BC, 0x0002),
	S5K4ECGX_REG_WRITE(0x700041BE, 0x66E0),
	S5K4ECGX_REG_WRITE(0x700041C0, 0x4D34),
	S5K4ECGX_REG_WRITE(0x700041C2, 0x8CE0),
	S5K4ECGX_REG_WRITE(0x700041C4, 0x3D14),
	S5K4ECGX_REG_WRITE(0x700041C6, 0x89E9),
	S5K4ECGX_REG_WRITE(0x700041C8, 0xF000),
	S5K4ECGX_REG_WRITE(0x700041CA, 0xF88A),
	S5K4ECGX_REG_WRITE(0x700041CC, 0x466B),
	S5K4ECGX_REG_WRITE(0x700041CE, 0x8018),
	S5K4ECGX_REG_WRITE(0x700041D0, 0x8A29),
	S5K4ECGX_REG_WRITE(0x700041D2, 0x8D20),
	S5K4ECGX_REG_WRITE(0x700041D4, 0x6EE2),
	S5K4ECGX_REG_WRITE(0x700041D6, 0xF000),
	S5K4ECGX_REG_WRITE(0x700041D8, 0xF883),
	S5K4ECGX_REG_WRITE(0x700041DA, 0x466B),
	S5K4ECGX_REG_WRITE(0x700041DC, 0x8058),
	S5K4ECGX_REG_WRITE(0x700041DE, 0x0021),
	S5K4ECGX_REG_WRITE(0x700041E0, 0x9800),
	S5K4ECGX_REG_WRITE(0x700041E2, 0x3170),
	S5K4ECGX_REG_WRITE(0x700041E4, 0xF000),
	S5K4ECGX_REG_WRITE(0x700041E6, 0xF92A),
	S5K4ECGX_REG_WRITE(0x700041E8, 0x0020),
	S5K4ECGX_REG_WRITE(0x700041EA, 0x3060),
	S5K4ECGX_REG_WRITE(0x700041EC, 0x8A02),
	S5K4ECGX_REG_WRITE(0x700041EE, 0x4928),
	S5K4ECGX_REG_WRITE(0x700041F0, 0x3980),
	S5K4ECGX_REG_WRITE(0x700041F2, 0x808A),
	S5K4ECGX_REG_WRITE(0x700041F4, 0x8A42),
	S5K4ECGX_REG_WRITE(0x700041F6, 0x80CA),
	S5K4ECGX_REG_WRITE(0x700041F8, 0x8A80),
	S5K4ECGX_REG_WRITE(0x700041FA, 0x8108),
	S5K4ECGX_REG_WRITE(0x700041FC, 0xBC38),
	S5K4ECGX_REG_WRITE(0x700041FE, 0xBC08),
	S5K4ECGX_REG_WRITE(0x70004200, 0x4718),
	S5K4ECGX_REG_WRITE(0x70004202, 0xB5F8),
	S5K4ECGX_REG_WRITE(0x70004204, 0x0004),
	S5K4ECGX_REG_WRITE(0x70004206, 0x6808),
	S5K4ECGX_REG_WRITE(0x70004208, 0x0400),
	S5K4ECGX_REG_WRITE(0x7000420A, 0x0C00),
	S5K4ECGX_REG_WRITE(0x7000420C, 0x2201),
	S5K4ECGX_REG_WRITE(0x7000420E, 0x0015),
	S5K4ECGX_REG_WRITE(0x70004210, 0x0021),
	S5K4ECGX_REG_WRITE(0x70004212, 0x3910),
	S5K4ECGX_REG_WRITE(0x70004214, 0x408A),
	S5K4ECGX_REG_WRITE(0x70004216, 0x40A5),
	S5K4ECGX_REG_WRITE(0x70004218, 0x4F17),
	S5K4ECGX_REG_WRITE(0x7000421A, 0x0016),
	S5K4ECGX_REG_WRITE(0x7000421C, 0x2C10),
	S5K4ECGX_REG_WRITE(0x7000421E, 0xDA03),
	S5K4ECGX_REG_WRITE(0x70004220, 0x8839),
	S5K4ECGX_REG_WRITE(0x70004222, 0x43A9),
	S5K4ECGX_REG_WRITE(0x70004224, 0x8039),
	S5K4ECGX_REG_WRITE(0x70004226, 0xE002),
	S5K4ECGX_REG_WRITE(0x70004228, 0x8879),
	S5K4ECGX_REG_WRITE(0x7000422A, 0x43B1),
	S5K4ECGX_REG_WRITE(0x7000422C, 0x8079),
	S5K4ECGX_REG_WRITE(0x7000422E, 0xF000),
	S5K4ECGX_REG_WRITE(0x70004230, 0xF90D),
	S5K4ECGX_REG_WRITE(0x70004232, 0x2C10),
	S5K4ECGX_REG_WRITE(0x70004234, 0xDA03),
	S5K4ECGX_REG_WRITE(0x70004236, 0x8838),
	S5K4ECGX_REG_WRITE(0x70004238, 0x4328),
	S5K4ECGX_REG_WRITE(0x7000423A, 0x8038),
	S5K4ECGX_REG_WRITE(0x7000423C, 0xE002),
	S5K4ECGX_REG_WRITE(0x7000423E, 0x8878),
	S5K4ECGX_REG_WRITE(0x70004240, 0x4330),
	S5K4ECGX_REG_WRITE(0x70004242, 0x8078),
	S5K4ECGX_REG_WRITE(0x70004244, 0x480D),
	S5K4ECGX_REG_WRITE(0x70004246, 0x8800),
	S5K4ECGX_REG_WRITE(0x70004248, 0x0400),
	S5K4ECGX_REG_WRITE(0x7000424A, 0xD507),
	S5K4ECGX_REG_WRITE(0x7000424C, 0x4B12),
	S5K4ECGX_REG_WRITE(0x7000424E, 0x7819),
	S5K4ECGX_REG_WRITE(0x70004250, 0x4A12),
	S5K4ECGX_REG_WRITE(0x70004252, 0x7810),
	S5K4ECGX_REG_WRITE(0x70004254, 0x7018),
	S5K4ECGX_REG_WRITE(0x70004256, 0x7011),
	S5K4ECGX_REG_WRITE(0x70004258, 0x4905),
	S5K4ECGX_REG_WRITE(0x7000425A, 0x8188),
	S5K4ECGX_REG_WRITE(0x7000425C, 0xE513),
	S5K4ECGX_REG_WRITE(0x7000425E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70004260, 0x2FA4),
	S5K4ECGX_REG_WRITE(0x70004262, 0x7000),
	S5K4ECGX_REG_WRITE(0x70004264, 0x235C),
	S5K4ECGX_REG_WRITE(0x70004266, 0x7000),
	S5K4ECGX_REG_WRITE(0x70004268, 0x0140),
	S5K4ECGX_REG_WRITE(0x7000426A, 0x7000),
	S5K4ECGX_REG_WRITE(0x7000426C, 0x20BC),
	S5K4ECGX_REG_WRITE(0x7000426E, 0x7000),
	S5K4ECGX_REG_WRITE(0x70004270, 0x2DF0),
	S5K4ECGX_REG_WRITE(0x70004272, 0x7000),
	S5K4ECGX_REG_WRITE(0x70004274, 0x47E0),
	S5K4ECGX_REG_WRITE(0x70004276, 0x7000),
	S5K4ECGX_REG_WRITE(0x70004278, 0x1100),
	S5K4ECGX_REG_WRITE(0x7000427A, 0xD000),
	S5K4ECGX_REG_WRITE(0x7000427C, 0x2EE2),
	S5K4ECGX_REG_WRITE(0x7000427E, 0x7000),
	S5K4ECGX_REG_WRITE(0x70004280, 0xF400),
	S5K4ECGX_REG_WRITE(0x70004282, 0xD000),
	S5K4ECGX_REG_WRITE(0x70004284, 0x3200),
	S5K4ECGX_REG_WRITE(0x70004286, 0xD000),
	S5K4ECGX_REG_WRITE(0x70004288, 0x16DE),
	S5K4ECGX_REG_WRITE(0x7000428A, 0x7000),
	S5K4ECGX_REG_WRITE(0x7000428C, 0x36F8),
	S5K4ECGX_REG_WRITE(0x7000428E, 0x7000),
	S5K4ECGX_REG_WRITE(0x70004290, 0x2B90),
	S5K4ECGX_REG_WRITE(0x70004292, 0x7000),
	S5K4ECGX_REG_WRITE(0x70004294, 0x17B4),
	S5K4ECGX_REG_WRITE(0x70004296, 0x7000),
	S5K4ECGX_REG_WRITE(0x70004298, 0x2EDD),
	S5K4ECGX_REG_WRITE(0x7000429A, 0x7000),
	S5K4ECGX_REG_WRITE(0x7000429C, 0x2EDE),
	S5K4ECGX_REG_WRITE(0x7000429E, 0x7000),
	S5K4ECGX_REG_WRITE(0x700042A0, 0x4778),
	S5K4ECGX_REG_WRITE(0x700042A2, 0x46C0),
	S5K4ECGX_REG_WRITE(0x700042A4, 0xC000),
	S5K4ECGX_REG_WRITE(0x700042A6, 0xE59F),
	S5K4ECGX_REG_WRITE(0x700042A8, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x700042AA, 0xE12F),
	S5K4ECGX_REG_WRITE(0x700042AC, 0x13D5),
	S5K4ECGX_REG_WRITE(0x700042AE, 0x0001),
	S5K4ECGX_REG_WRITE(0x700042B0, 0x4778),
	S5K4ECGX_REG_WRITE(0x700042B2, 0x46C0),
	S5K4ECGX_REG_WRITE(0x700042B4, 0xC000),
	S5K4ECGX_REG_WRITE(0x700042B6, 0xE59F),
	S5K4ECGX_REG_WRITE(0x700042B8, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x700042BA, 0xE12F),
	S5K4ECGX_REG_WRITE(0x700042BC, 0xA083),
	S5K4ECGX_REG_WRITE(0x700042BE, 0x0000),
	S5K4ECGX_REG_WRITE(0x700042C0, 0x4778),
	S5K4ECGX_REG_WRITE(0x700042C2, 0x46C0),
	S5K4ECGX_REG_WRITE(0x700042C4, 0xC000),
	S5K4ECGX_REG_WRITE(0x700042C6, 0xE59F),
	S5K4ECGX_REG_WRITE(0x700042C8, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x700042CA, 0xE12F),
	S5K4ECGX_REG_WRITE(0x700042CC, 0xA035),
	S5K4ECGX_REG_WRITE(0x700042CE, 0x0000),
	S5K4ECGX_REG_WRITE(0x700042D0, 0x4778),
	S5K4ECGX_REG_WRITE(0x700042D2, 0x46C0),
	S5K4ECGX_REG_WRITE(0x700042D4, 0xC000),
	S5K4ECGX_REG_WRITE(0x700042D6, 0xE59F),
	S5K4ECGX_REG_WRITE(0x700042D8, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x700042DA, 0xE12F),
	S5K4ECGX_REG_WRITE(0x700042DC, 0xA1D9),
	S5K4ECGX_REG_WRITE(0x700042DE, 0x0000),
	S5K4ECGX_REG_WRITE(0x700042E0, 0x4778),
	S5K4ECGX_REG_WRITE(0x700042E2, 0x46C0),
	S5K4ECGX_REG_WRITE(0x700042E4, 0xC000),
	S5K4ECGX_REG_WRITE(0x700042E6, 0xE59F),
	S5K4ECGX_REG_WRITE(0x700042E8, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x700042EA, 0xE12F),
	S5K4ECGX_REG_WRITE(0x700042EC, 0x2D27),
	S5K4ECGX_REG_WRITE(0x700042EE, 0x0000),
	S5K4ECGX_REG_WRITE(0x700042F0, 0x4778),
	S5K4ECGX_REG_WRITE(0x700042F2, 0x46C0),
	S5K4ECGX_REG_WRITE(0x700042F4, 0xC000),
	S5K4ECGX_REG_WRITE(0x700042F6, 0xE59F),
	S5K4ECGX_REG_WRITE(0x700042F8, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x700042FA, 0xE12F),
	S5K4ECGX_REG_WRITE(0x700042FC, 0x7D47),
	S5K4ECGX_REG_WRITE(0x700042FE, 0x0000),
	S5K4ECGX_REG_WRITE(0x70004300, 0x4778),
	S5K4ECGX_REG_WRITE(0x70004302, 0x46C0),
	S5K4ECGX_REG_WRITE(0x70004304, 0xC000),
	S5K4ECGX_REG_WRITE(0x70004306, 0xE59F),
	S5K4ECGX_REG_WRITE(0x70004308, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x7000430A, 0xE12F),
	S5K4ECGX_REG_WRITE(0x7000430C, 0x7AB1),
	S5K4ECGX_REG_WRITE(0x7000430E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70004310, 0x4778),
	S5K4ECGX_REG_WRITE(0x70004312, 0x46C0),
	S5K4ECGX_REG_WRITE(0x70004314, 0xC000),
	S5K4ECGX_REG_WRITE(0x70004316, 0xE59F),
	S5K4ECGX_REG_WRITE(0x70004318, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x7000431A, 0xE12F),
	S5K4ECGX_REG_WRITE(0x7000431C, 0x7ACB),
	S5K4ECGX_REG_WRITE(0x7000431E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70004320, 0x4778),
	S5K4ECGX_REG_WRITE(0x70004322, 0x46C0),
	S5K4ECGX_REG_WRITE(0x70004324, 0xF004),
	S5K4ECGX_REG_WRITE(0x70004326, 0xE51F),
	S5K4ECGX_REG_WRITE(0x70004328, 0x2630),
	S5K4ECGX_REG_WRITE(0x7000432A, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000432C, 0x4778),
	S5K4ECGX_REG_WRITE(0x7000432E, 0x46C0),
	S5K4ECGX_REG_WRITE(0x70004330, 0xC000),
	S5K4ECGX_REG_WRITE(0x70004332, 0xE59F),
	S5K4ECGX_REG_WRITE(0x70004334, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x70004336, 0xE12F),
	S5K4ECGX_REG_WRITE(0x70004338, 0xED4D),
	S5K4ECGX_REG_WRITE(0x7000433A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000433C, 0x4778),
	S5K4ECGX_REG_WRITE(0x7000433E, 0x46C0),
	S5K4ECGX_REG_WRITE(0x70004340, 0xC000),
	S5K4ECGX_REG_WRITE(0x70004342, 0xE59F),
	S5K4ECGX_REG_WRITE(0x70004344, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x70004346, 0xE12F),
	S5K4ECGX_REG_WRITE(0x70004348, 0xEDDB),
	S5K4ECGX_REG_WRITE(0x7000434A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000434C, 0x4778),
	S5K4ECGX_REG_WRITE(0x7000434E, 0x46C0),
	S5K4ECGX_REG_WRITE(0x70004350, 0xC000),
	S5K4ECGX_REG_WRITE(0x70004352, 0xE59F),
	S5K4ECGX_REG_WRITE(0x70004354, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x70004356, 0xE12F),
	S5K4ECGX_REG_WRITE(0x70004358, 0x4EB5),
	S5K4ECGX_REG_WRITE(0x7000435A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000435C, 0x4778),
	S5K4ECGX_REG_WRITE(0x7000435E, 0x46C0),
	S5K4ECGX_REG_WRITE(0x70004360, 0xC000),
	S5K4ECGX_REG_WRITE(0x70004362, 0xE59F),
	S5K4ECGX_REG_WRITE(0x70004364, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x70004366, 0xE12F),
	S5K4ECGX_REG_WRITE(0x70004368, 0x053B),
	S5K4ECGX_REG_WRITE(0x7000436A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000436C, 0x4778),
	S5K4ECGX_REG_WRITE(0x7000436E, 0x46C0),
	S5K4ECGX_REG_WRITE(0x70004370, 0xC000),
	S5K4ECGX_REG_WRITE(0x70004372, 0xE59F),
	S5K4ECGX_REG_WRITE(0x70004374, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x70004376, 0xE12F),
	S5K4ECGX_REG_WRITE(0x70004378, 0x49D1),
	S5K4ECGX_REG_WRITE(0x7000437A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000437C, 0x4778),
	S5K4ECGX_REG_WRITE(0x7000437E, 0x46C0),
	S5K4ECGX_REG_WRITE(0x70004380, 0xC000),
	S5K4ECGX_REG_WRITE(0x70004382, 0xE59F),
	S5K4ECGX_REG_WRITE(0x70004384, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x70004386, 0xE12F),
	S5K4ECGX_REG_WRITE(0x70004388, 0xD411),
	S5K4ECGX_REG_WRITE(0x7000438A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000438C, 0x4778),
	S5K4ECGX_REG_WRITE(0x7000438E, 0x46C0),
	S5K4ECGX_REG_WRITE(0x70004390, 0xC000),
	S5K4ECGX_REG_WRITE(0x70004392, 0xE59F),
	S5K4ECGX_REG_WRITE(0x70004394, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x70004396, 0xE12F),
	S5K4ECGX_REG_WRITE(0x70004398, 0x1E57),
	S5K4ECGX_REG_WRITE(0x7000439A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000439C, 0x4778),
	S5K4ECGX_REG_WRITE(0x7000439E, 0x46C0),
	S5K4ECGX_REG_WRITE(0x700043A0, 0xC000),
	S5K4ECGX_REG_WRITE(0x700043A2, 0xE59F),
	S5K4ECGX_REG_WRITE(0x700043A4, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x700043A6, 0xE12F),
	S5K4ECGX_REG_WRITE(0x700043A8, 0x2603),
	S5K4ECGX_REG_WRITE(0x700043AA, 0x0001),
	S5K4ECGX_REG_WRITE(0x700043AC, 0x4778),
	S5K4ECGX_REG_WRITE(0x700043AE, 0x46C0),
	S5K4ECGX_REG_WRITE(0x700043B0, 0xC000),
	S5K4ECGX_REG_WRITE(0x700043B2, 0xE59F),
	S5K4ECGX_REG_WRITE(0x700043B4, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x700043B6, 0xE12F),
	S5K4ECGX_REG_WRITE(0x700043B8, 0xBC3D),
	S5K4ECGX_REG_WRITE(0x700043BA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700043BC, 0x4778),
	S5K4ECGX_REG_WRITE(0x700043BE, 0x46C0),
	S5K4ECGX_REG_WRITE(0x700043C0, 0xC000),
	S5K4ECGX_REG_WRITE(0x700043C2, 0xE59F),
	S5K4ECGX_REG_WRITE(0x700043C4, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x700043C6, 0xE12F),
	S5K4ECGX_REG_WRITE(0x700043C8, 0x2601),
	S5K4ECGX_REG_WRITE(0x700043CA, 0x0001),
	S5K4ECGX_REG_WRITE(0x700043CC, 0x4778),
	S5K4ECGX_REG_WRITE(0x700043CE, 0x46C0),
	S5K4ECGX_REG_WRITE(0x700043D0, 0xC000),
	S5K4ECGX_REG_WRITE(0x700043D2, 0xE59F),
	S5K4ECGX_REG_WRITE(0x700043D4, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x700043D6, 0xE12F),
	S5K4ECGX_REG_WRITE(0x700043D8, 0xBAB1),
	S5K4ECGX_REG_WRITE(0x700043DA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700043DC, 0x4778),
	S5K4ECGX_REG_WRITE(0x700043DE, 0x46C0),
	S5K4ECGX_REG_WRITE(0x700043E0, 0xC000),
	S5K4ECGX_REG_WRITE(0x700043E2, 0xE59F),
	S5K4ECGX_REG_WRITE(0x700043E4, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x700043E6, 0xE12F),
	S5K4ECGX_REG_WRITE(0x700043E8, 0xB89F),
	S5K4ECGX_REG_WRITE(0x700043EA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700043EC, 0x4778),
	S5K4ECGX_REG_WRITE(0x700043EE, 0x46C0),
	S5K4ECGX_REG_WRITE(0x700043F0, 0xC000),
	S5K4ECGX_REG_WRITE(0x700043F2, 0xE59F),
	S5K4ECGX_REG_WRITE(0x700043F4, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x700043F6, 0xE12F),
	S5K4ECGX_REG_WRITE(0x700043F8, 0xF077),
	S5K4ECGX_REG_WRITE(0x700043FA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700043FC, 0x4778),
	S5K4ECGX_REG_WRITE(0x700043FE, 0x46C0),
	S5K4ECGX_REG_WRITE(0x70004400, 0xC000),
	S5K4ECGX_REG_WRITE(0x70004402, 0xE59F),
	S5K4ECGX_REG_WRITE(0x70004404, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x70004406, 0xE12F),
	S5K4ECGX_REG_WRITE(0x70004408, 0xC10D),
	S5K4ECGX_REG_WRITE(0x7000440A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000440C, 0x4778),
	S5K4ECGX_REG_WRITE(0x7000440E, 0x46C0),
	S5K4ECGX_REG_WRITE(0x70004410, 0xC000),
	S5K4ECGX_REG_WRITE(0x70004412, 0xE59F),
	S5K4ECGX_REG_WRITE(0x70004414, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x70004416, 0xE12F),
	S5K4ECGX_REG_WRITE(0x70004418, 0xC0C9),
	S5K4ECGX_REG_WRITE(0x7000441A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000441C, 0x4778),
	S5K4ECGX_REG_WRITE(0x7000441E, 0x46C0),
	S5K4ECGX_REG_WRITE(0x70004420, 0xC000),
	S5K4ECGX_REG_WRITE(0x70004422, 0xE59F),
	S5K4ECGX_REG_WRITE(0x70004424, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x70004426, 0xE12F),
	S5K4ECGX_REG_WRITE(0x70004428, 0xEAF9),
	S5K4ECGX_REG_WRITE(0x7000442A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000442C, 0x4778),
	S5K4ECGX_REG_WRITE(0x7000442E, 0x46C0),
	S5K4ECGX_REG_WRITE(0x70004430, 0xC000),
	S5K4ECGX_REG_WRITE(0x70004432, 0xE59F),
	S5K4ECGX_REG_WRITE(0x70004434, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x70004436, 0xE12F),
	S5K4ECGX_REG_WRITE(0x70004438, 0x2E61),
	S5K4ECGX_REG_WRITE(0x7000443A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000443C, 0x4778),
	S5K4ECGX_REG_WRITE(0x7000443E, 0x46C0),
	S5K4ECGX_REG_WRITE(0x70004440, 0xC000),
	S5K4ECGX_REG_WRITE(0x70004442, 0xE59F),
	S5K4ECGX_REG_WRITE(0x70004444, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x70004446, 0xE12F),
	S5K4ECGX_REG_WRITE(0x70004448, 0xE86B),
	S5K4ECGX_REG_WRITE(0x7000444A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000444C, 0x4778),
	S5K4ECGX_REG_WRITE(0x7000444E, 0x46C0),
	S5K4ECGX_REG_WRITE(0x70004450, 0xC000),
	S5K4ECGX_REG_WRITE(0x70004452, 0xE59F),
	S5K4ECGX_REG_WRITE(0x70004454, 0xFF1C),
	S5K4ECGX_REG_WRITE(0x70004456, 0xE12F),
	S5K4ECGX_REG_WRITE(0x70004458, 0xB231),
	S5K4ECGX_REG_WRITE(0x7000445A, 0x0000),
	/* End of Patch Data */

	/* switch to firmware address bank */
	S5K4ECGX_REG_WRITE(0xD0001000, 0x0001),
	/* End of factory settings */

	/* Switch to sw address bank */

	S5K4ECGX_REG_WRITE(0x7000479E, 0x0001),

	S5K4ECGX_REG_WRITE(0x70001432, 0x0000),

	S5K4ECGX_REG_WRITE(0x700047EE, 0x0001),
	S5K4ECGX_REG_WRITE(0x700047F0, 0x000A),
	S5K4ECGX_REG_WRITE(0x700047F2, 0x0014),
	S5K4ECGX_REG_WRITE(0x700047F4, 0x0070),
	S5K4ECGX_REG_WRITE(0x700047F6, 0x0005),
	S5K4ECGX_REG_WRITE(0x700047F8, 0x5A3C),

	S5K4ECGX_REG_WRITE(0x70004780, 0x0000),
	S5K4ECGX_REG_WRITE(0x70004782, 0x0014),
	S5K4ECGX_REG_WRITE(0x70004784, 0x00D2),
	S5K4ECGX_REG_WRITE(0x70004786, 0x0384),
	S5K4ECGX_REG_WRITE(0x70004788, 0x07D0),
	S5K4ECGX_REG_WRITE(0x7000478A, 0x1388),
	S5K4ECGX_REG_WRITE(0x7000478C, 0x0180),
	S5K4ECGX_REG_WRITE(0x7000478E, 0x0196),
	S5K4ECGX_REG_WRITE(0x70004790, 0x0054),
	S5K4ECGX_REG_WRITE(0x70004792, 0x0001),
	S5K4ECGX_REG_WRITE(0x70004794, 0x01CC),
	S5K4ECGX_REG_WRITE(0x70004796, 0x01CC),
	S5K4ECGX_REG_WRITE(0x70004798, 0x01CC),
	S5K4ECGX_REG_WRITE(0x7000479A, 0x01CC),
	S5K4ECGX_REG_WRITE(0x7000479C, 0x01CC),

	S5K4ECGX_REG_WRITE(0x70000EF0, 0x0001),

	S5K4ECGX_REG_WRITE(0x70000EF6, 0x0002),

	S5K4ECGX_REG_WRITE(0x70001A84, 0x001C),

	S5K4ECGX_REG_WRITE(0x700001F8, 0x0000),

	S5K4ECGX_REG_WRITE(0x700016E4, 0x0100),

	S5K4ECGX_REG_WRITE(0x700001FA, 0x0003),
	S5K4ECGX_REG_WRITE(0x700001FC, 0x0000),

	S5K4ECGX_REG_WRITE(0x70000200, 0x0061),

	S5K4ECGX_REG_WRITE(0x70000208, 0x2F0C),
	S5K4ECGX_REG_WRITE(0x7000020A, 0x0190),

	S5K4ECGX_REG_WRITE(0x7000028E, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000290, 0x00E3),
	S5K4ECGX_REG_WRITE(0x70000292, 0x0200),
	S5K4ECGX_REG_WRITE(0x70000294, 0x0238),
	S5K4ECGX_REG_WRITE(0x70000296, 0x01C6),
	S5K4ECGX_REG_WRITE(0x70000298, 0x0166),
	S5K4ECGX_REG_WRITE(0x7000029A, 0x0074),
	S5K4ECGX_REG_WRITE(0x7000029C, 0x0132),
	S5K4ECGX_REG_WRITE(0x7000029E, 0x0001),

	S5K4ECGX_REG_WRITE(0x70000702, 0x00FF),

	S5K4ECGX_REG_WRITE(0x70001600, 0x0000),

	S5K4ECGX_REG_WRITE(0x70000712, 0x0001),

	S5K4ECGX_REG_WRITE(0x7000160C, 0x9002),

	S5K4ECGX_REG_WRITE(0x70001616, 0x0003),

	S5K4ECGX_REG_WRITE(0x700015A4, 0x0902),

	S5K4ECGX_REG_WRITE(0x70001618, 0x0000),

	S5K4ECGX_REG_WRITE(0x70001610, 0x0003),

	S5K4ECGX_REG_WRITE(0x70001602, 0x00E5),
	S5K4ECGX_REG_WRITE(0x70001604, 0x0098),

	S5K4ECGX_REG_WRITE(0x70001598, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000159A, 0xD000),

	S5K4ECGX_REG_WRITE(0x7000165E, 0xFF95),

	S5K4ECGX_REG_WRITE(0x7000162E, 0x0280),

	S5K4ECGX_REG_WRITE(0x7000163A, 0x03A0),
	S5K4ECGX_REG_WRITE(0x7000163C, 0x0320),

	S5K4ECGX_REG_WRITE(0x70001680, 0x0030),

	S5K4ECGX_REG_WRITE(0x700016A4, 0x0060),

	S5K4ECGX_REG_WRITE(0x70001698, 0x0010),

	S5K4ECGX_REG_WRITE(0x7000161A, 0x0000),

	S5K4ECGX_REG_WRITE(0x700015AA, 0x003C),
	S5K4ECGX_REG_WRITE(0x700015AC, 0x0018),
	S5K4ECGX_REG_WRITE(0x700015AE, 0x002A),
	S5K4ECGX_REG_WRITE(0x700015B0, 0x0030),
	S5K4ECGX_REG_WRITE(0x700015B2, 0x0036),
	S5K4ECGX_REG_WRITE(0x700015B4, 0x003C),
	S5K4ECGX_REG_WRITE(0x700015B6, 0x0042),
	S5K4ECGX_REG_WRITE(0x700015B8, 0x0048),
	S5K4ECGX_REG_WRITE(0x700015BA, 0x004E),
	S5K4ECGX_REG_WRITE(0x700015BC, 0x0054),
	S5K4ECGX_REG_WRITE(0x700015BE, 0x005A),
	S5K4ECGX_REG_WRITE(0x700015C0, 0x0060),
	S5K4ECGX_REG_WRITE(0x700015C2, 0x0066),
	S5K4ECGX_REG_WRITE(0x700015C4, 0x006C),
	S5K4ECGX_REG_WRITE(0x700015C6, 0x0072),
	S5K4ECGX_REG_WRITE(0x700015C8, 0x0078),
	S5K4ECGX_REG_WRITE(0x700015CA, 0x007E),
	S5K4ECGX_REG_WRITE(0x700015CC, 0x0084),
	S5K4ECGX_REG_WRITE(0x700015CE, 0x008A),
	S5K4ECGX_REG_WRITE(0x700015D0, 0x0090),
	S5K4ECGX_REG_WRITE(0x700015D2, 0x0096),
	S5K4ECGX_REG_WRITE(0x700015D4, 0x009C),
	S5K4ECGX_REG_WRITE(0x700015D6, 0x00A2),
	S5K4ECGX_REG_WRITE(0x700015D8, 0x00A8),
	S5K4ECGX_REG_WRITE(0x700015DA, 0x00AE),
	S5K4ECGX_REG_WRITE(0x700015DC, 0x00B4),
	S5K4ECGX_REG_WRITE(0x700015DE, 0x00BA),

	S5K4ECGX_REG_WRITE(0x700016E6, 0x8000),
	S5K4ECGX_REG_WRITE(0x700016E8, 0x0006),
	S5K4ECGX_REG_WRITE(0x700016EA, 0x3FF0),
	S5K4ECGX_REG_WRITE(0x700016EC, 0x03E8),
	S5K4ECGX_REG_WRITE(0x700016EE, 0x0000),
	S5K4ECGX_REG_WRITE(0x700016F0, 0x0080),
	S5K4ECGX_REG_WRITE(0x700016F2, 0x0009),
	S5K4ECGX_REG_WRITE(0x700016F4, 0x0020),
	S5K4ECGX_REG_WRITE(0x700016F6, 0x0040),
	S5K4ECGX_REG_WRITE(0x700016F8, 0x0080),
	S5K4ECGX_REG_WRITE(0x700016FA, 0x00C0),
	S5K4ECGX_REG_WRITE(0x700016FC, 0x00E0),

	S5K4ECGX_REG_WRITE(0x70000286, 0x0003),

	S5K4ECGX_REG_WRITE(0x700011B4, 0x012C),
	S5K4ECGX_REG_WRITE(0x700011B6, 0x0121),

	S5K4ECGX_REG_WRITE(0x70001A00, 0x192E),
	S5K4ECGX_REG_WRITE(0x70001A02, 0x7000),

	S5K4ECGX_REG_WRITE(0x7000185C, 0x0004),
	S5K4ECGX_REG_WRITE(0x7000185E, 0x09D1),
	S5K4ECGX_REG_WRITE(0x70001860, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001862, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001864, 0x0001),
	S5K4ECGX_REG_WRITE(0x70001866, 0x09D5),
	S5K4ECGX_REG_WRITE(0x70001868, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000186A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000186C, 0x0008),
	S5K4ECGX_REG_WRITE(0x7000186E, 0x09D5),
	S5K4ECGX_REG_WRITE(0x70001870, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001872, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001874, 0x02AA),
	S5K4ECGX_REG_WRITE(0x70001876, 0x0326),
	S5K4ECGX_REG_WRITE(0x70001878, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000187A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000187C, 0x02AA),
	S5K4ECGX_REG_WRITE(0x7000187E, 0x09D1),
	S5K4ECGX_REG_WRITE(0x70001880, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001882, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001884, 0x02AA),
	S5K4ECGX_REG_WRITE(0x70001886, 0x09D5),
	S5K4ECGX_REG_WRITE(0x70001888, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000188A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000188C, 0x02AA),
	S5K4ECGX_REG_WRITE(0x7000188E, 0x0327),
	S5K4ECGX_REG_WRITE(0x70001890, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001892, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001894, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001896, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001898, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000189A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000189C, 0x0008),
	S5K4ECGX_REG_WRITE(0x7000189E, 0x0084),
	S5K4ECGX_REG_WRITE(0x700018A0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018A2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018A4, 0x0008),
	S5K4ECGX_REG_WRITE(0x700018A6, 0x008D),
	S5K4ECGX_REG_WRITE(0x700018A8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018AA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018AC, 0x0008),
	S5K4ECGX_REG_WRITE(0x700018AE, 0x02AA),
	S5K4ECGX_REG_WRITE(0x700018B0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018B2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018B4, 0x00AA),
	S5K4ECGX_REG_WRITE(0x700018B6, 0x02AA),
	S5K4ECGX_REG_WRITE(0x700018B8, 0x03AD),
	S5K4ECGX_REG_WRITE(0x700018BA, 0x09CD),
	S5K4ECGX_REG_WRITE(0x700018BC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018BE, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018C0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018C2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018C4, 0x02AE),
	S5K4ECGX_REG_WRITE(0x700018C6, 0x02DE),
	S5K4ECGX_REG_WRITE(0x700018C8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018CA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018CC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018CE, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018D0, 0x02BE),
	S5K4ECGX_REG_WRITE(0x700018D2, 0x02EE),
	S5K4ECGX_REG_WRITE(0x700018D4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018D6, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018D8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018DA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018DC, 0x02CE),
	S5K4ECGX_REG_WRITE(0x700018DE, 0x02EE),
	S5K4ECGX_REG_WRITE(0x700018E0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018E2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018E4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018E6, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018E8, 0x0001),
	S5K4ECGX_REG_WRITE(0x700018EA, 0x0009),
	S5K4ECGX_REG_WRITE(0x700018EC, 0x0095),
	S5K4ECGX_REG_WRITE(0x700018EE, 0x09DB),
	S5K4ECGX_REG_WRITE(0x700018F0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018F2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018F4, 0x0096),
	S5K4ECGX_REG_WRITE(0x700018F6, 0x009B),
	S5K4ECGX_REG_WRITE(0x700018F8, 0x02AE),
	S5K4ECGX_REG_WRITE(0x700018FA, 0x02B3),
	S5K4ECGX_REG_WRITE(0x700018FC, 0x09D1),
	S5K4ECGX_REG_WRITE(0x700018FE, 0x09D6),
	S5K4ECGX_REG_WRITE(0x70001900, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001902, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001904, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001906, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001908, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000190A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000190C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000190E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001910, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001912, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001914, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001916, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001918, 0x02AE),
	S5K4ECGX_REG_WRITE(0x7000191A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000191C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000191E, 0x0009),
	S5K4ECGX_REG_WRITE(0x70001920, 0x0010),
	S5K4ECGX_REG_WRITE(0x70001922, 0x0327),
	S5K4ECGX_REG_WRITE(0x70001924, 0x0336),
	S5K4ECGX_REG_WRITE(0x70001926, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001928, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000192A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000192C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000192E, 0x0004),
	S5K4ECGX_REG_WRITE(0x70001930, 0x05B6),
	S5K4ECGX_REG_WRITE(0x70001932, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001934, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001936, 0x0001),
	S5K4ECGX_REG_WRITE(0x70001938, 0x05BA),
	S5K4ECGX_REG_WRITE(0x7000193A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000193C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000193E, 0x0007),
	S5K4ECGX_REG_WRITE(0x70001940, 0x05BA),
	S5K4ECGX_REG_WRITE(0x70001942, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001944, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001946, 0x01F4),
	S5K4ECGX_REG_WRITE(0x70001948, 0x024E),
	S5K4ECGX_REG_WRITE(0x7000194A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000194C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000194E, 0x01F4),
	S5K4ECGX_REG_WRITE(0x70001950, 0x05B6),
	S5K4ECGX_REG_WRITE(0x70001952, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001954, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001956, 0x01F4),
	S5K4ECGX_REG_WRITE(0x70001958, 0x05BA),
	S5K4ECGX_REG_WRITE(0x7000195A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000195C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000195E, 0x01F4),
	S5K4ECGX_REG_WRITE(0x70001960, 0x024F),
	S5K4ECGX_REG_WRITE(0x70001962, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001964, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001966, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001968, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000196A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000196C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000196E, 0x0075),
	S5K4ECGX_REG_WRITE(0x70001970, 0x00CF),
	S5K4ECGX_REG_WRITE(0x70001972, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001974, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001976, 0x0075),
	S5K4ECGX_REG_WRITE(0x70001978, 0x00D6),
	S5K4ECGX_REG_WRITE(0x7000197A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000197C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000197E, 0x0004),
	S5K4ECGX_REG_WRITE(0x70001980, 0x01F4),
	S5K4ECGX_REG_WRITE(0x70001982, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001984, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001986, 0x00F0),
	S5K4ECGX_REG_WRITE(0x70001988, 0x01F4),
	S5K4ECGX_REG_WRITE(0x7000198A, 0x029E),
	S5K4ECGX_REG_WRITE(0x7000198C, 0x05B2),
	S5K4ECGX_REG_WRITE(0x7000198E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001990, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001992, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001994, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001996, 0x01F8),
	S5K4ECGX_REG_WRITE(0x70001998, 0x0228),
	S5K4ECGX_REG_WRITE(0x7000199A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000199C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000199E, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019A0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019A2, 0x0208),
	S5K4ECGX_REG_WRITE(0x700019A4, 0x0238),
	S5K4ECGX_REG_WRITE(0x700019A6, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019A8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019AA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019AC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019AE, 0x0218),
	S5K4ECGX_REG_WRITE(0x700019B0, 0x0238),
	S5K4ECGX_REG_WRITE(0x700019B2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019B4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019B6, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019B8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019BA, 0x0001),
	S5K4ECGX_REG_WRITE(0x700019BC, 0x0009),
	S5K4ECGX_REG_WRITE(0x700019BE, 0x00DE),
	S5K4ECGX_REG_WRITE(0x700019C0, 0x05C0),
	S5K4ECGX_REG_WRITE(0x700019C2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019C4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019C6, 0x00DF),
	S5K4ECGX_REG_WRITE(0x700019C8, 0x00E4),
	S5K4ECGX_REG_WRITE(0x700019CA, 0x01F8),
	S5K4ECGX_REG_WRITE(0x700019CC, 0x01FD),
	S5K4ECGX_REG_WRITE(0x700019CE, 0x05B6),
	S5K4ECGX_REG_WRITE(0x700019D0, 0x05BB),
	S5K4ECGX_REG_WRITE(0x700019D2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019D4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019D6, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019D8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019DA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019DC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019DE, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019E0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019E2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019E4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019E6, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019E8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019EA, 0x01F8),
	S5K4ECGX_REG_WRITE(0x700019EC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019EE, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019F0, 0x0077),
	S5K4ECGX_REG_WRITE(0x700019F2, 0x007E),
	S5K4ECGX_REG_WRITE(0x700019F4, 0x024F),
	S5K4ECGX_REG_WRITE(0x700019F6, 0x025E),
	S5K4ECGX_REG_WRITE(0x700019F8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019FA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019FC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019FE, 0x0000),

	S5K4ECGX_REG_WRITE(0x70001836, 0x0002),
	S5K4ECGX_REG_WRITE(0x70001838, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000183A, 0x0003),

	S5K4ECGX_REG_WRITE(0x7000183E, 0x0FB0),

	S5K4ECGX_REG_WRITE(0x7000184C, 0x0060),
	S5K4ECGX_REG_WRITE(0x7000184E, 0x0060),
	S5K4ECGX_REG_WRITE(0x70001850, 0x05C0),
	S5K4ECGX_REG_WRITE(0x70001852, 0x05C0),

	S5K4ECGX_REG_WRITE(0x70001A8A, 0x8080),
	S5K4ECGX_REG_WRITE(0x70001A8C, 0x0080),

	S5K4ECGX_REG_WRITE(0x70001A80, 0x0000),

	S5K4ECGX_REG_WRITE(0x70001A12, 0x0000),

	S5K4ECGX_REG_WRITE(0x70001842, 0x0004),

	S5K4ECGX_REG_WRITE(0x70001A0A, 0x009A),

	S5K4ECGX_REG_WRITE(0x70003776, 0x024C),

	S5K4ECGX_REG_WRITE(0x70000EB2, 0x0000),

	S5K4ECGX_REG_WRITE(0x700008C6, 0x0001),

	S5K4ECGX_REG_WRITE(0x700008A4, 0x0001),

	S5K4ECGX_REG_WRITE(0x700008E2, 0x4000),
	S5K4ECGX_REG_WRITE(0x700008E4, 0x4000),
	S5K4ECGX_REG_WRITE(0x700008E6, 0x4000),
	S5K4ECGX_REG_WRITE(0x700008E8, 0x4000),
	S5K4ECGX_REG_WRITE(0x700008EA, 0x4000),
	S5K4ECGX_REG_WRITE(0x700008EC, 0x4000),
	S5K4ECGX_REG_WRITE(0x700008EE, 0x4000),
	S5K4ECGX_REG_WRITE(0x700008F0, 0x4000),
	S5K4ECGX_REG_WRITE(0x700008F2, 0x4000),
	S5K4ECGX_REG_WRITE(0x700008F4, 0x4000),
	S5K4ECGX_REG_WRITE(0x700008F6, 0x4000),
	S5K4ECGX_REG_WRITE(0x700008F8, 0x4000),
	S5K4ECGX_REG_WRITE(0x700008FA, 0x4000),
	S5K4ECGX_REG_WRITE(0x700008FC, 0x4000),
	S5K4ECGX_REG_WRITE(0x700008FE, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000900, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000902, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000904, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000906, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000908, 0x4000),
	S5K4ECGX_REG_WRITE(0x7000090A, 0x4000),
	S5K4ECGX_REG_WRITE(0x7000090C, 0x4000),
	S5K4ECGX_REG_WRITE(0x7000090E, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000910, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000912, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000914, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000916, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000918, 0x4000),
	S5K4ECGX_REG_WRITE(0x7000091A, 0x4500),
	S5K4ECGX_REG_WRITE(0x7000091C, 0x4000),
	S5K4ECGX_REG_WRITE(0x7000091E, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000920, 0x4000),

	S5K4ECGX_REG_WRITE(0x700008E0, 0x0001),

	S5K4ECGX_REG_WRITE(0x70001456, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001458, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000145A, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000145C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000145E, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001460, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001462, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001464, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001466, 0x0201),
	S5K4ECGX_REG_WRITE(0x70001468, 0x0303),
	S5K4ECGX_REG_WRITE(0x7000146A, 0x0303),
	S5K4ECGX_REG_WRITE(0x7000146C, 0x0102),
	S5K4ECGX_REG_WRITE(0x7000146E, 0x0201),
	S5K4ECGX_REG_WRITE(0x70001470, 0x0403),
	S5K4ECGX_REG_WRITE(0x70001472, 0x0304),
	S5K4ECGX_REG_WRITE(0x70001474, 0x0102),
	S5K4ECGX_REG_WRITE(0x70001476, 0x0201),
	S5K4ECGX_REG_WRITE(0x70001478, 0x0403),
	S5K4ECGX_REG_WRITE(0x7000147A, 0x0304),
	S5K4ECGX_REG_WRITE(0x7000147C, 0x0102),
	S5K4ECGX_REG_WRITE(0x7000147E, 0x0201),
	S5K4ECGX_REG_WRITE(0x70001480, 0x0403),
	S5K4ECGX_REG_WRITE(0x70001482, 0x0304),
	S5K4ECGX_REG_WRITE(0x70001484, 0x0102),
	S5K4ECGX_REG_WRITE(0x70001486, 0x0201),
	S5K4ECGX_REG_WRITE(0x70001488, 0x0303),
	S5K4ECGX_REG_WRITE(0x7000148A, 0x0303),
	S5K4ECGX_REG_WRITE(0x7000148C, 0x0102),
	S5K4ECGX_REG_WRITE(0x7000148E, 0x0201),
	S5K4ECGX_REG_WRITE(0x70001490, 0x0202),
	S5K4ECGX_REG_WRITE(0x70001492, 0x0202),
	S5K4ECGX_REG_WRITE(0x70001494, 0x0102),

	S5K4ECGX_REG_WRITE(0x70001448, 0x003C),

	S5K4ECGX_REG_WRITE(0x7000144E, 0x000F),

	S5K4ECGX_REG_WRITE(0x70000580, 0x3520),
	S5K4ECGX_REG_WRITE(0x70000582, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000584, 0xC350),
	S5K4ECGX_REG_WRITE(0x70000586, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000588, 0x3520),
	S5K4ECGX_REG_WRITE(0x7000058A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000058C, 0xC350),
	S5K4ECGX_REG_WRITE(0x7000058E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000590, 0x0470),
	S5K4ECGX_REG_WRITE(0x70000592, 0x0C00),
	S5K4ECGX_REG_WRITE(0x70000594, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000596, 0x1000),

	S5K4ECGX_REG_WRITE(0x70000538, 0x0111),
	S5K4ECGX_REG_WRITE(0x7000053A, 0x00EF),

	S5K4ECGX_REG_WRITE(0x700005FC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700005FE, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000600, 0x0600),
	S5K4ECGX_REG_WRITE(0x70000602, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000604, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000606, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000608, 0x0A3C),
	S5K4ECGX_REG_WRITE(0x7000060A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000060C, 0x0D04),
	S5K4ECGX_REG_WRITE(0x7000060E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000610, 0x4008),
	S5K4ECGX_REG_WRITE(0x70000612, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000614, 0x7000),
	S5K4ECGX_REG_WRITE(0x70000616, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000618, 0x9C00),
	S5K4ECGX_REG_WRITE(0x7000061A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000061C, 0xAD00),
	S5K4ECGX_REG_WRITE(0x7000061E, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000620, 0xF1D4),
	S5K4ECGX_REG_WRITE(0x70000622, 0x0002),
	S5K4ECGX_REG_WRITE(0x70000624, 0xDC00),
	S5K4ECGX_REG_WRITE(0x70000626, 0x0005),
	S5K4ECGX_REG_WRITE(0x70000628, 0xDC00),
	S5K4ECGX_REG_WRITE(0x7000062A, 0x0005),
	S5K4ECGX_REG_WRITE(0x7000062C, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000062E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000630, 0x0A3C),
	S5K4ECGX_REG_WRITE(0x70000632, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000634, 0x0D05),
	S5K4ECGX_REG_WRITE(0x70000636, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000638, 0x3408),
	S5K4ECGX_REG_WRITE(0x7000063A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000063C, 0x3408),
	S5K4ECGX_REG_WRITE(0x7000063E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000640, 0x6810),
	S5K4ECGX_REG_WRITE(0x70000642, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000644, 0x8214),
	S5K4ECGX_REG_WRITE(0x70000646, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000648, 0xC350),
	S5K4ECGX_REG_WRITE(0x7000064A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000064C, 0xC350),
	S5K4ECGX_REG_WRITE(0x7000064E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000650, 0xC350),
	S5K4ECGX_REG_WRITE(0x70000652, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000654, 0x0650),
	S5K4ECGX_REG_WRITE(0x70000656, 0x0100),

	S5K4ECGX_REG_WRITE(0x700006AC, 0x452C),
	S5K4ECGX_REG_WRITE(0x700006AE, 0x0004),

	S5K4ECGX_REG_WRITE(0x70000280, 0x0001),

	S5K4ECGX_REG_WRITE(0x700005C4, 0x0000),

	S5K4ECGX_REG_WRITE(0x70000476, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000478, 0x0280),
	S5K4ECGX_REG_WRITE(0x7000047A, 0x01E0),
	S5K4ECGX_REG_WRITE(0x7000047C, 0x0005),

	S5K4ECGX_REG_WRITE(0x700001F4, 0x5DC0),

	S5K4ECGX_REG_WRITE(0x7000020E, 0x0002),
	S5K4ECGX_REG_WRITE(0x70000210, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000212, 0x0000),

	S5K4ECGX_REG_WRITE(0x70000216, 0x3A98),
	S5K4ECGX_REG_WRITE(0x70000218, 0x4F1A),
	S5K4ECGX_REG_WRITE(0x7000021A, 0x4F1A),
	S5K4ECGX_REG_WRITE(0x7000021C, 0x4F1A),
	S5K4ECGX_REG_WRITE(0x7000021E, 0x4F1A),
	S5K4ECGX_REG_WRITE(0x70000220, 0x4F1A),

	S5K4ECGX_REG_WRITE(0x70000228, 0x0001),

	S5K4ECGX_REG_WRITE(0x700002A0, 0x0280),
	S5K4ECGX_REG_WRITE(0x700002A2, 0x01E0),
	S5K4ECGX_REG_WRITE(0x700002A4, 0x0005),
	S5K4ECGX_REG_WRITE(0x700002A6, 0x4F1A),
	S5K4ECGX_REG_WRITE(0x700002A8, 0x4F1A),

	S5K4ECGX_REG_WRITE(0x700002AE, 0x0052),

	S5K4ECGX_REG_WRITE(0x700002B6, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002B8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002BA, 0x0001),
	S5K4ECGX_REG_WRITE(0x700002BC, 0x029A),
	S5K4ECGX_REG_WRITE(0x700002BE, 0x014D),

	S5K4ECGX_REG_WRITE(0x700002AA, 0x0080),

	S5K4ECGX_REG_WRITE(0x7000024C, 0x0A00),
	S5K4ECGX_REG_WRITE(0x7000024E, 0x0780),
	S5K4ECGX_REG_WRITE(0x70000250, 0x0010),
	S5K4ECGX_REG_WRITE(0x70000252, 0x000C),
	S5K4ECGX_REG_WRITE(0x70000254, 0x0A00),
	S5K4ECGX_REG_WRITE(0x70000256, 0x0780),
	S5K4ECGX_REG_WRITE(0x70000258, 0x0010),
	S5K4ECGX_REG_WRITE(0x7000025A, 0x000C),

	S5K4ECGX_REG_WRITE(0x7000048E, 0x0A00),
	S5K4ECGX_REG_WRITE(0x70000490, 0x0780),
	S5K4ECGX_REG_WRITE(0x70000492, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000494, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000496, 0x0A00),
	S5K4ECGX_REG_WRITE(0x70000498, 0x0780),
	S5K4ECGX_REG_WRITE(0x7000049A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000049C, 0x0000),

	S5K4ECGX_REG_WRITE(0x7000025E, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000260, 0x0001),

	S5K4ECGX_REG_WRITE(0x70000392, 0x0A00),
	S5K4ECGX_REG_WRITE(0x70000394, 0x0780),
	S5K4ECGX_REG_WRITE(0x70000396, 0x0009),
	S5K4ECGX_REG_WRITE(0x70000398, 0x4F1A),
	S5K4ECGX_REG_WRITE(0x7000039A, 0x4F1A),

	S5K4ECGX_REG_WRITE(0x700003A0, 0x0002),

	S5K4ECGX_REG_WRITE(0x700003A8, 0x0001),
	S5K4ECGX_REG_WRITE(0x700003AA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700003AC, 0x0002),
	S5K4ECGX_REG_WRITE(0x700003AE, 0x0535),
	S5K4ECGX_REG_WRITE(0x700003B0, 0x029A),

	S5K4ECGX_REG_WRITE(0x7000039C, 0x0080),

	S5K4ECGX_REG_WRITE(0x70000476, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000478, 0x0280),
	S5K4ECGX_REG_WRITE(0x7000047A, 0x01E0),
	S5K4ECGX_REG_WRITE(0x7000047C, 0x0005),

	S5K4ECGX_REG_WRITE(0x70000262, 0x0000),

	S5K4ECGX_REG_WRITE(0x70000266, 0x0001),

	S5K4ECGX_REG_WRITE(0x7000024A, 0x0001),

	S5K4ECGX_REG_WRITE(0x70000264, 0x0001),

	S5K4ECGX_REG_WRITE(0x7000026C, 0x0001),

	S5K4ECGX_REG_WRITE(0x7000023A, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000023C, 0x0001),

	S5K4ECGX_REG_WRITE(0x70000472, 0x005F),
	S5K4ECGX_REG_WRITE(0x70000474, 0x005F),

	S5K4ECGX_REG_WRITE(0x70000FE0, 0x03B8),
	S5K4ECGX_REG_WRITE(0x70000FE2, 0x03CE),
	S5K4ECGX_REG_WRITE(0x70000FE4, 0x0350),
	S5K4ECGX_REG_WRITE(0x70000FE6, 0x03C4),
	S5K4ECGX_REG_WRITE(0x70000FE8, 0x02F2),
	S5K4ECGX_REG_WRITE(0x70000FEA, 0x0394),
	S5K4ECGX_REG_WRITE(0x70000FEC, 0x02C0),
	S5K4ECGX_REG_WRITE(0x70000FEE, 0x0364),
	S5K4ECGX_REG_WRITE(0x70000FF0, 0x029E),
	S5K4ECGX_REG_WRITE(0x70000FF2, 0x0334),
	S5K4ECGX_REG_WRITE(0x70000FF4, 0x027C),
	S5K4ECGX_REG_WRITE(0x70000FF6, 0x0312),
	S5K4ECGX_REG_WRITE(0x70000FF8, 0x025E),
	S5K4ECGX_REG_WRITE(0x70000FFA, 0x02F2),
	S5K4ECGX_REG_WRITE(0x70000FFC, 0x0246),
	S5K4ECGX_REG_WRITE(0x70000FFE, 0x02D0),
	S5K4ECGX_REG_WRITE(0x70001000, 0x0230),
	S5K4ECGX_REG_WRITE(0x70001002, 0x02B0),
	S5K4ECGX_REG_WRITE(0x70001004, 0x0218),
	S5K4ECGX_REG_WRITE(0x70001006, 0x029E),
	S5K4ECGX_REG_WRITE(0x70001008, 0x0208),
	S5K4ECGX_REG_WRITE(0x7000100A, 0x0290),
	S5K4ECGX_REG_WRITE(0x7000100C, 0x01F8),
	S5K4ECGX_REG_WRITE(0x7000100E, 0x0284),
	S5K4ECGX_REG_WRITE(0x70001010, 0x01E8),
	S5K4ECGX_REG_WRITE(0x70001012, 0x0276),
	S5K4ECGX_REG_WRITE(0x70001014, 0x01DA),
	S5K4ECGX_REG_WRITE(0x70001016, 0x026A),
	S5K4ECGX_REG_WRITE(0x70001018, 0x01CE),
	S5K4ECGX_REG_WRITE(0x7000101A, 0x025E),
	S5K4ECGX_REG_WRITE(0x7000101C, 0x01EC),
	S5K4ECGX_REG_WRITE(0x7000101E, 0x022E),
	S5K4ECGX_REG_WRITE(0x70001020, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001022, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001024, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001026, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001028, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000102A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000102C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000102E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001030, 0x0005),

	S5K4ECGX_REG_WRITE(0x70001034, 0x0010),

	S5K4ECGX_REG_WRITE(0x70001038, 0x0126),

	S5K4ECGX_REG_WRITE(0x7000103C, 0x026C),
	S5K4ECGX_REG_WRITE(0x7000103E, 0x029A),
	S5K4ECGX_REG_WRITE(0x70001040, 0x025C),
	S5K4ECGX_REG_WRITE(0x70001042, 0x02B6),
	S5K4ECGX_REG_WRITE(0x70001044, 0x024E),
	S5K4ECGX_REG_WRITE(0x70001046, 0x02C0),
	S5K4ECGX_REG_WRITE(0x70001048, 0x0240),
	S5K4ECGX_REG_WRITE(0x7000104A, 0x02BE),
	S5K4ECGX_REG_WRITE(0x7000104C, 0x023A),
	S5K4ECGX_REG_WRITE(0x7000104E, 0x02B4),
	S5K4ECGX_REG_WRITE(0x70001050, 0x023A),
	S5K4ECGX_REG_WRITE(0x70001052, 0x02AA),
	S5K4ECGX_REG_WRITE(0x70001054, 0x0240),
	S5K4ECGX_REG_WRITE(0x70001056, 0x029E),
	S5K4ECGX_REG_WRITE(0x70001058, 0x025C),
	S5K4ECGX_REG_WRITE(0x7000105A, 0x0294),
	S5K4ECGX_REG_WRITE(0x7000105C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000105E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001060, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001062, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001064, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001066, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001068, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000106A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000106C, 0x0004),

	S5K4ECGX_REG_WRITE(0x70001070, 0x0008),

	S5K4ECGX_REG_WRITE(0x70001074, 0x01E2),

	S5K4ECGX_REG_WRITE(0x70001078, 0x0350),
	S5K4ECGX_REG_WRITE(0x7000107A, 0x0422),
	S5K4ECGX_REG_WRITE(0x7000107C, 0x02C4),
	S5K4ECGX_REG_WRITE(0x7000107E, 0x0452),
	S5K4ECGX_REG_WRITE(0x70001080, 0x0278),
	S5K4ECGX_REG_WRITE(0x70001082, 0x041C),
	S5K4ECGX_REG_WRITE(0x70001084, 0x0230),
	S5K4ECGX_REG_WRITE(0x70001086, 0x03EE),
	S5K4ECGX_REG_WRITE(0x70001088, 0x01F0),
	S5K4ECGX_REG_WRITE(0x7000108A, 0x0392),
	S5K4ECGX_REG_WRITE(0x7000108C, 0x01C0),
	S5K4ECGX_REG_WRITE(0x7000108E, 0x0340),
	S5K4ECGX_REG_WRITE(0x70001090, 0x0194),
	S5K4ECGX_REG_WRITE(0x70001092, 0x0302),
	S5K4ECGX_REG_WRITE(0x70001094, 0x016E),
	S5K4ECGX_REG_WRITE(0x70001096, 0x02C2),
	S5K4ECGX_REG_WRITE(0x70001098, 0x0148),
	S5K4ECGX_REG_WRITE(0x7000109A, 0x0286),
	S5K4ECGX_REG_WRITE(0x7000109C, 0x018A),
	S5K4ECGX_REG_WRITE(0x7000109E, 0x0242),
	S5K4ECGX_REG_WRITE(0x700010A0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700010A2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700010A4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700010A6, 0x0000),
	S5K4ECGX_REG_WRITE(0x700010A8, 0x0006),

	S5K4ECGX_REG_WRITE(0x700010AC, 0x000A),

	S5K4ECGX_REG_WRITE(0x700010B0, 0x0106),

	S5K4ECGX_REG_WRITE(0x700010B4, 0x0380),
	S5K4ECGX_REG_WRITE(0x700010B6, 0x0000),
	S5K4ECGX_REG_WRITE(0x700010B8, 0x0168),
	S5K4ECGX_REG_WRITE(0x700010BA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700010BC, 0x2D90),
	S5K4ECGX_REG_WRITE(0x700010BE, 0x0000),

	S5K4ECGX_REG_WRITE(0x70001428, 0x0008),
	S5K4ECGX_REG_WRITE(0x7000142A, 0x0190),
	S5K4ECGX_REG_WRITE(0x7000142C, 0x00A0),

	S5K4ECGX_REG_WRITE(0x700011EC, 0x00C0),

	S5K4ECGX_REG_WRITE(0x700011F0, 0x0010),

	S5K4ECGX_REG_WRITE(0x700011EE, 0x0010),

	S5K4ECGX_REG_WRITE(0x700011CE, 0x05D5),

	S5K4ECGX_REG_WRITE(0x700011D2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700011D4, 0x0771),
	S5K4ECGX_REG_WRITE(0x700011D6, 0x03A4),
	S5K4ECGX_REG_WRITE(0x700011D8, 0x0036),
	S5K4ECGX_REG_WRITE(0x700011DA, 0x002A),

	S5K4ECGX_REG_WRITE(0x700008AC, 0x00C0),
	S5K4ECGX_REG_WRITE(0x700008AE, 0x00DF),
	S5K4ECGX_REG_WRITE(0x700008B0, 0x0100),
	S5K4ECGX_REG_WRITE(0x700008B2, 0x0125),
	S5K4ECGX_REG_WRITE(0x700008B4, 0x015F),
	S5K4ECGX_REG_WRITE(0x700008B6, 0x017C),
	S5K4ECGX_REG_WRITE(0x700008B8, 0x0194),

	S5K4ECGX_REG_WRITE(0x7000123C, 0xFEF7),
	S5K4ECGX_REG_WRITE(0x7000123E, 0x0021),
	S5K4ECGX_REG_WRITE(0x70001240, 0x0E74),
	S5K4ECGX_REG_WRITE(0x70001242, 0x0E74),
	S5K4ECGX_REG_WRITE(0x70001244, 0x018F),
	S5K4ECGX_REG_WRITE(0x70001246, 0x0096),
	S5K4ECGX_REG_WRITE(0x70001248, 0x000E),

	S5K4ECGX_REG_WRITE(0x700011E8, 0x0032),
	S5K4ECGX_REG_WRITE(0x700011EA, 0x001E),

	S5K4ECGX_REG_WRITE(0x70002ABC, 0x0006),

	S5K4ECGX_REG_WRITE(0x70001430, 0x0002),

	S5K4ECGX_REG_WRITE(0x7000140A, 0x00AB),
	S5K4ECGX_REG_WRITE(0x7000140C, 0x00BF),
	S5K4ECGX_REG_WRITE(0x7000140E, 0x00D2),
	S5K4ECGX_REG_WRITE(0x70001410, 0x0093),

	S5K4ECGX_REG_WRITE(0x700013F8, 0x0300),
	S5K4ECGX_REG_WRITE(0x700013FA, 0x036E),
	S5K4ECGX_REG_WRITE(0x700013FC, 0x03C2),
	S5K4ECGX_REG_WRITE(0x700013FE, 0x1015),
	S5K4ECGX_REG_WRITE(0x70001400, 0x10E1),
	S5K4ECGX_REG_WRITE(0x70001402, 0x1154),
	S5K4ECGX_REG_WRITE(0x70001404, 0x11A8),
	S5K4ECGX_REG_WRITE(0x70001406, 0x11BB),
	S5K4ECGX_REG_WRITE(0x70001408, 0x123B),

	S5K4ECGX_REG_WRITE(0x70001368, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000136A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000136C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000136E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001370, 0x0008),
	S5K4ECGX_REG_WRITE(0x70001372, 0x0030),
	S5K4ECGX_REG_WRITE(0x70001374, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001376, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001378, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000137A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000137C, 0x0008),
	S5K4ECGX_REG_WRITE(0x7000137E, 0x0030),
	S5K4ECGX_REG_WRITE(0x70001380, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001382, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001384, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001386, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001388, 0x0008),
	S5K4ECGX_REG_WRITE(0x7000138A, 0x0030),
	S5K4ECGX_REG_WRITE(0x7000138C, 0xFFE0),
	S5K4ECGX_REG_WRITE(0x7000138E, 0xFFE0),
	S5K4ECGX_REG_WRITE(0x70001390, 0xFFC0),
	S5K4ECGX_REG_WRITE(0x70001392, 0xFFC0),
	S5K4ECGX_REG_WRITE(0x70001394, 0xFFA0),
	S5K4ECGX_REG_WRITE(0x70001396, 0xFE36),
	S5K4ECGX_REG_WRITE(0x70001398, 0xFFE0),
	S5K4ECGX_REG_WRITE(0x7000139A, 0xFFE0),
	S5K4ECGX_REG_WRITE(0x7000139C, 0xFFC0),
	S5K4ECGX_REG_WRITE(0x7000139E, 0xFFC0),
	S5K4ECGX_REG_WRITE(0x700013A0, 0xFFA0),
	S5K4ECGX_REG_WRITE(0x700013A2, 0xFE36),
	S5K4ECGX_REG_WRITE(0x700013A4, 0xFFE0),
	S5K4ECGX_REG_WRITE(0x700013A6, 0xFFE0),
	S5K4ECGX_REG_WRITE(0x700013A8, 0xFFC0),
	S5K4ECGX_REG_WRITE(0x700013AA, 0xFFC0),
	S5K4ECGX_REG_WRITE(0x700013AC, 0xFFA0),
	S5K4ECGX_REG_WRITE(0x700013AE, 0xFE36),
	S5K4ECGX_REG_WRITE(0x700013B0, 0xFFEA),
	S5K4ECGX_REG_WRITE(0x700013B2, 0xFFEA),
	S5K4ECGX_REG_WRITE(0x700013B4, 0xFFC8),
	S5K4ECGX_REG_WRITE(0x700013B6, 0xFFC8),
	S5K4ECGX_REG_WRITE(0x700013B8, 0xFFC8),
	S5K4ECGX_REG_WRITE(0x700013BA, 0xFFC8),
	S5K4ECGX_REG_WRITE(0x700013BC, 0xFFEA),
	S5K4ECGX_REG_WRITE(0x700013BE, 0xFFEA),
	S5K4ECGX_REG_WRITE(0x700013C0, 0xFFC8),
	S5K4ECGX_REG_WRITE(0x700013C2, 0xFFC8),
	S5K4ECGX_REG_WRITE(0x700013C4, 0xFFC8),
	S5K4ECGX_REG_WRITE(0x700013C6, 0xFFC8),
	S5K4ECGX_REG_WRITE(0x700013C8, 0xFFEA),
	S5K4ECGX_REG_WRITE(0x700013CA, 0xFFEA),
	S5K4ECGX_REG_WRITE(0x700013CC, 0xFFC8),
	S5K4ECGX_REG_WRITE(0x700013CE, 0xFFC8),
	S5K4ECGX_REG_WRITE(0x700013D0, 0xFFC8),
	S5K4ECGX_REG_WRITE(0x700013D2, 0xFFC8),
	S5K4ECGX_REG_WRITE(0x700013D4, 0x0014),
	S5K4ECGX_REG_WRITE(0x700013D6, 0x0014),
	S5K4ECGX_REG_WRITE(0x700013D8, 0x0014),
	S5K4ECGX_REG_WRITE(0x700013DA, 0xFDA0),
	S5K4ECGX_REG_WRITE(0x700013DC, 0xFCF0),
	S5K4ECGX_REG_WRITE(0x700013DE, 0xFCD0),
	S5K4ECGX_REG_WRITE(0x700013E0, 0x0014),
	S5K4ECGX_REG_WRITE(0x700013E2, 0x0014),
	S5K4ECGX_REG_WRITE(0x700013E4, 0x0014),
	S5K4ECGX_REG_WRITE(0x700013E6, 0xFDA0),
	S5K4ECGX_REG_WRITE(0x700013E8, 0xFCF0),
	S5K4ECGX_REG_WRITE(0x700013EA, 0xFCD0),
	S5K4ECGX_REG_WRITE(0x700013EC, 0x0014),
	S5K4ECGX_REG_WRITE(0x700013EE, 0x0014),
	S5K4ECGX_REG_WRITE(0x700013F0, 0x0014),
	S5K4ECGX_REG_WRITE(0x700013F2, 0xFDA0),
	S5K4ECGX_REG_WRITE(0x700013F4, 0xFCF0),
	S5K4ECGX_REG_WRITE(0x700013F6, 0xFCD0),

	S5K4ECGX_REG_WRITE(0x700013FE, 0x1015),
	S5K4ECGX_REG_WRITE(0x70001400, 0x106C),
	S5K4ECGX_REG_WRITE(0x70001402, 0x10CA),
	S5K4ECGX_REG_WRITE(0x70001404, 0x1142),
	S5K4ECGX_REG_WRITE(0x70001406, 0x11BB),
	S5K4ECGX_REG_WRITE(0x70001408, 0x123B),
	S5K4ECGX_REG_WRITE(0x7000140A, 0x00AB),
	S5K4ECGX_REG_WRITE(0x7000140C, 0x00BF),
	S5K4ECGX_REG_WRITE(0x7000140E, 0x00D2),
	S5K4ECGX_REG_WRITE(0x70001410, 0x0093),

	S5K4ECGX_REG_WRITE(0x700011CC, 0x0020),

	S5K4ECGX_REG_WRITE(0x70001412, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001414, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001416, 0x0000),

	S5K4ECGX_REG_WRITE(0x70000724, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000726, 0x0007),
	S5K4ECGX_REG_WRITE(0x70000728, 0x0010),
	S5K4ECGX_REG_WRITE(0x7000072A, 0x0028),
	S5K4ECGX_REG_WRITE(0x7000072C, 0x0062),
	S5K4ECGX_REG_WRITE(0x7000072E, 0x00D3),
	S5K4ECGX_REG_WRITE(0x70000730, 0x0130),
	S5K4ECGX_REG_WRITE(0x70000732, 0x0158),
	S5K4ECGX_REG_WRITE(0x70000734, 0x017D),
	S5K4ECGX_REG_WRITE(0x70000736, 0x01BE),
	S5K4ECGX_REG_WRITE(0x70000738, 0x01F8),
	S5K4ECGX_REG_WRITE(0x7000073A, 0x022C),
	S5K4ECGX_REG_WRITE(0x7000073C, 0x025B),
	S5K4ECGX_REG_WRITE(0x7000073E, 0x02AA),
	S5K4ECGX_REG_WRITE(0x70000740, 0x02EC),
	S5K4ECGX_REG_WRITE(0x70000742, 0x034E),
	S5K4ECGX_REG_WRITE(0x70000744, 0x0396),
	S5K4ECGX_REG_WRITE(0x70000746, 0x03C6),
	S5K4ECGX_REG_WRITE(0x70000748, 0x03E9),
	S5K4ECGX_REG_WRITE(0x7000074A, 0x03F9),
	S5K4ECGX_REG_WRITE(0x7000074C, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000074E, 0x0007),
	S5K4ECGX_REG_WRITE(0x70000750, 0x0010),
	S5K4ECGX_REG_WRITE(0x70000752, 0x0028),
	S5K4ECGX_REG_WRITE(0x70000754, 0x0062),
	S5K4ECGX_REG_WRITE(0x70000756, 0x00D3),
	S5K4ECGX_REG_WRITE(0x70000758, 0x0130),
	S5K4ECGX_REG_WRITE(0x7000075A, 0x0158),
	S5K4ECGX_REG_WRITE(0x7000075C, 0x017D),
	S5K4ECGX_REG_WRITE(0x7000075E, 0x01BE),
	S5K4ECGX_REG_WRITE(0x70000760, 0x01F8),
	S5K4ECGX_REG_WRITE(0x70000762, 0x022C),
	S5K4ECGX_REG_WRITE(0x70000764, 0x025B),
	S5K4ECGX_REG_WRITE(0x70000766, 0x02AA),
	S5K4ECGX_REG_WRITE(0x70000768, 0x02EC),
	S5K4ECGX_REG_WRITE(0x7000076A, 0x034E),
	S5K4ECGX_REG_WRITE(0x7000076C, 0x0396),
	S5K4ECGX_REG_WRITE(0x7000076E, 0x03C6),
	S5K4ECGX_REG_WRITE(0x70000770, 0x03E9),
	S5K4ECGX_REG_WRITE(0x70000772, 0x03F9),
	S5K4ECGX_REG_WRITE(0x70000774, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000776, 0x0007),
	S5K4ECGX_REG_WRITE(0x70000778, 0x0010),
	S5K4ECGX_REG_WRITE(0x7000077A, 0x0028),
	S5K4ECGX_REG_WRITE(0x7000077C, 0x0062),
	S5K4ECGX_REG_WRITE(0x7000077E, 0x00D3),
	S5K4ECGX_REG_WRITE(0x70000780, 0x0130),
	S5K4ECGX_REG_WRITE(0x70000782, 0x0158),
	S5K4ECGX_REG_WRITE(0x70000784, 0x017D),
	S5K4ECGX_REG_WRITE(0x70000786, 0x01BE),
	S5K4ECGX_REG_WRITE(0x70000788, 0x01F8),
	S5K4ECGX_REG_WRITE(0x7000078A, 0x022C),
	S5K4ECGX_REG_WRITE(0x7000078C, 0x025B),
	S5K4ECGX_REG_WRITE(0x7000078E, 0x02AA),
	S5K4ECGX_REG_WRITE(0x70000790, 0x02EC),
	S5K4ECGX_REG_WRITE(0x70000792, 0x034E),
	S5K4ECGX_REG_WRITE(0x70000794, 0x0396),
	S5K4ECGX_REG_WRITE(0x70000796, 0x03C6),
	S5K4ECGX_REG_WRITE(0x70000798, 0x03E9),
	S5K4ECGX_REG_WRITE(0x7000079A, 0x03F9),
	S5K4ECGX_REG_WRITE(0x7000079C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000079E, 0x000F),
	S5K4ECGX_REG_WRITE(0x700007A0, 0x0020),
	S5K4ECGX_REG_WRITE(0x700007A2, 0x0043),
	S5K4ECGX_REG_WRITE(0x700007A4, 0x0086),
	S5K4ECGX_REG_WRITE(0x700007A6, 0x00ED),
	S5K4ECGX_REG_WRITE(0x700007A8, 0x013E),
	S5K4ECGX_REG_WRITE(0x700007AA, 0x0163),
	S5K4ECGX_REG_WRITE(0x700007AC, 0x0185),
	S5K4ECGX_REG_WRITE(0x700007AE, 0x01BF),
	S5K4ECGX_REG_WRITE(0x700007B0, 0x01F2),
	S5K4ECGX_REG_WRITE(0x700007B2, 0x0221),
	S5K4ECGX_REG_WRITE(0x700007B4, 0x024A),
	S5K4ECGX_REG_WRITE(0x700007B6, 0x0294),
	S5K4ECGX_REG_WRITE(0x700007B8, 0x02D0),
	S5K4ECGX_REG_WRITE(0x700007BA, 0x032A),
	S5K4ECGX_REG_WRITE(0x700007BC, 0x036A),
	S5K4ECGX_REG_WRITE(0x700007BE, 0x039F),
	S5K4ECGX_REG_WRITE(0x700007C0, 0x03CC),
	S5K4ECGX_REG_WRITE(0x700007C2, 0x03F9),
	S5K4ECGX_REG_WRITE(0x700007C4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700007C6, 0x000F),
	S5K4ECGX_REG_WRITE(0x700007C8, 0x0020),
	S5K4ECGX_REG_WRITE(0x700007CA, 0x0043),
	S5K4ECGX_REG_WRITE(0x700007CC, 0x0086),
	S5K4ECGX_REG_WRITE(0x700007CE, 0x00ED),
	S5K4ECGX_REG_WRITE(0x700007D0, 0x013E),
	S5K4ECGX_REG_WRITE(0x700007D2, 0x0163),
	S5K4ECGX_REG_WRITE(0x700007D4, 0x0185),
	S5K4ECGX_REG_WRITE(0x700007D6, 0x01BF),
	S5K4ECGX_REG_WRITE(0x700007D8, 0x01F2),
	S5K4ECGX_REG_WRITE(0x700007DA, 0x0221),
	S5K4ECGX_REG_WRITE(0x700007DC, 0x024A),
	S5K4ECGX_REG_WRITE(0x700007DE, 0x0294),
	S5K4ECGX_REG_WRITE(0x700007E0, 0x02D0),
	S5K4ECGX_REG_WRITE(0x700007E2, 0x032A),
	S5K4ECGX_REG_WRITE(0x700007E4, 0x036A),
	S5K4ECGX_REG_WRITE(0x700007E6, 0x039F),
	S5K4ECGX_REG_WRITE(0x700007E8, 0x03CC),
	S5K4ECGX_REG_WRITE(0x700007EA, 0x03F9),
	S5K4ECGX_REG_WRITE(0x700007EC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700007EE, 0x000F),
	S5K4ECGX_REG_WRITE(0x700007F0, 0x0020),
	S5K4ECGX_REG_WRITE(0x700007F2, 0x0043),
	S5K4ECGX_REG_WRITE(0x700007F4, 0x0086),
	S5K4ECGX_REG_WRITE(0x700007F6, 0x00ED),
	S5K4ECGX_REG_WRITE(0x700007F8, 0x013E),
	S5K4ECGX_REG_WRITE(0x700007FA, 0x0163),
	S5K4ECGX_REG_WRITE(0x700007FC, 0x0185),
	S5K4ECGX_REG_WRITE(0x700007FE, 0x01BF),
	S5K4ECGX_REG_WRITE(0x70000800, 0x01F2),
	S5K4ECGX_REG_WRITE(0x70000802, 0x0221),
	S5K4ECGX_REG_WRITE(0x70000804, 0x024A),
	S5K4ECGX_REG_WRITE(0x70000806, 0x0294),
	S5K4ECGX_REG_WRITE(0x70000808, 0x02D0),
	S5K4ECGX_REG_WRITE(0x7000080A, 0x032A),
	S5K4ECGX_REG_WRITE(0x7000080C, 0x036A),
	S5K4ECGX_REG_WRITE(0x7000080E, 0x039F),
	S5K4ECGX_REG_WRITE(0x70000810, 0x03CC),
	S5K4ECGX_REG_WRITE(0x70000812, 0x03F9),

	S5K4ECGX_REG_WRITE(0x70000896, 0x00C0),
	S5K4ECGX_REG_WRITE(0x70000898, 0x0100),
	S5K4ECGX_REG_WRITE(0x7000089A, 0x0125),
	S5K4ECGX_REG_WRITE(0x7000089C, 0x015F),
	S5K4ECGX_REG_WRITE(0x7000089E, 0x017C),
	S5K4ECGX_REG_WRITE(0x700008A0, 0x0194),
	S5K4ECGX_REG_WRITE(0x700008A2, 0x0001),

	S5K4ECGX_REG_WRITE(0x70000888, 0x4800),
	S5K4ECGX_REG_WRITE(0x7000088A, 0x7000),

	S5K4ECGX_REG_WRITE(0x70004800, 0x016C),
	S5K4ECGX_REG_WRITE(0x70004802, 0xFF94),
	S5K4ECGX_REG_WRITE(0x70004804, 0xFFCE),
	S5K4ECGX_REG_WRITE(0x70004806, 0xFF20),
	S5K4ECGX_REG_WRITE(0x70004808, 0x01BF),
	S5K4ECGX_REG_WRITE(0x7000480A, 0xFF53),
	S5K4ECGX_REG_WRITE(0x7000480C, 0x003F),
	S5K4ECGX_REG_WRITE(0x7000480E, 0x0007),
	S5K4ECGX_REG_WRITE(0x70004810, 0x01DF),
	S5K4ECGX_REG_WRITE(0x70004812, 0x0110),
	S5K4ECGX_REG_WRITE(0x70004814, 0x00DF),
	S5K4ECGX_REG_WRITE(0x70004816, 0xFF47),
	S5K4ECGX_REG_WRITE(0x70004818, 0x0206),
	S5K4ECGX_REG_WRITE(0x7000481A, 0xFF7F),
	S5K4ECGX_REG_WRITE(0x7000481C, 0x0191),
	S5K4ECGX_REG_WRITE(0x7000481E, 0xFF06),
	S5K4ECGX_REG_WRITE(0x70004820, 0x01BA),
	S5K4ECGX_REG_WRITE(0x70004822, 0x0108),
	S5K4ECGX_REG_WRITE(0x70004824, 0x016C),
	S5K4ECGX_REG_WRITE(0x70004826, 0xFF94),
	S5K4ECGX_REG_WRITE(0x70004828, 0xFFCE),
	S5K4ECGX_REG_WRITE(0x7000482A, 0xFF20),
	S5K4ECGX_REG_WRITE(0x7000482C, 0x01BF),
	S5K4ECGX_REG_WRITE(0x7000482E, 0xFF53),
	S5K4ECGX_REG_WRITE(0x70004830, 0x003F),
	S5K4ECGX_REG_WRITE(0x70004832, 0x0007),
	S5K4ECGX_REG_WRITE(0x70004834, 0x01DF),
	S5K4ECGX_REG_WRITE(0x70004836, 0x0110),
	S5K4ECGX_REG_WRITE(0x70004838, 0x00DF),
	S5K4ECGX_REG_WRITE(0x7000483A, 0xFF47),
	S5K4ECGX_REG_WRITE(0x7000483C, 0x0206),
	S5K4ECGX_REG_WRITE(0x7000483E, 0xFF7F),
	S5K4ECGX_REG_WRITE(0x70004840, 0x0191),
	S5K4ECGX_REG_WRITE(0x70004842, 0xFF06),
	S5K4ECGX_REG_WRITE(0x70004844, 0x01BA),
	S5K4ECGX_REG_WRITE(0x70004846, 0x0108),
	S5K4ECGX_REG_WRITE(0x70004848, 0x016C),
	S5K4ECGX_REG_WRITE(0x7000484A, 0xFF94),
	S5K4ECGX_REG_WRITE(0x7000484C, 0xFFCE),
	S5K4ECGX_REG_WRITE(0x7000484E, 0xFF20),
	S5K4ECGX_REG_WRITE(0x70004850, 0x01BF),
	S5K4ECGX_REG_WRITE(0x70004852, 0xFF53),
	S5K4ECGX_REG_WRITE(0x70004854, 0x003F),
	S5K4ECGX_REG_WRITE(0x70004856, 0x0007),
	S5K4ECGX_REG_WRITE(0x70004858, 0x01DF),
	S5K4ECGX_REG_WRITE(0x7000485A, 0x0110),
	S5K4ECGX_REG_WRITE(0x7000485C, 0x00DF),
	S5K4ECGX_REG_WRITE(0x7000485E, 0xFF47),
	S5K4ECGX_REG_WRITE(0x70004860, 0x0206),
	S5K4ECGX_REG_WRITE(0x70004862, 0xFF7F),
	S5K4ECGX_REG_WRITE(0x70004864, 0x0191),
	S5K4ECGX_REG_WRITE(0x70004866, 0xFF06),
	S5K4ECGX_REG_WRITE(0x70004868, 0x01BA),
	S5K4ECGX_REG_WRITE(0x7000486A, 0x0108),
	S5K4ECGX_REG_WRITE(0x7000486C, 0x0208),
	S5K4ECGX_REG_WRITE(0x7000486E, 0xFFD3),
	S5K4ECGX_REG_WRITE(0x70004870, 0xFFE9),
	S5K4ECGX_REG_WRITE(0x70004872, 0xFF5B),
	S5K4ECGX_REG_WRITE(0x70004874, 0x025A),
	S5K4ECGX_REG_WRITE(0x70004876, 0xFF80),
	S5K4ECGX_REG_WRITE(0x70004878, 0xFFC8),
	S5K4ECGX_REG_WRITE(0x7000487A, 0xFFC1),
	S5K4ECGX_REG_WRITE(0x7000487C, 0x013A),
	S5K4ECGX_REG_WRITE(0x7000487E, 0x0112),
	S5K4ECGX_REG_WRITE(0x70004880, 0x00EE),
	S5K4ECGX_REG_WRITE(0x70004882, 0xFF99),
	S5K4ECGX_REG_WRITE(0x70004884, 0x009E),
	S5K4ECGX_REG_WRITE(0x70004886, 0xFF5F),
	S5K4ECGX_REG_WRITE(0x70004888, 0x01A8),
	S5K4ECGX_REG_WRITE(0x7000488A, 0xFF75),
	S5K4ECGX_REG_WRITE(0x7000488C, 0x0187),
	S5K4ECGX_REG_WRITE(0x7000488E, 0x01BF),
	S5K4ECGX_REG_WRITE(0x70004890, 0x0208),
	S5K4ECGX_REG_WRITE(0x70004892, 0xFFD3),
	S5K4ECGX_REG_WRITE(0x70004894, 0xFFE9),
	S5K4ECGX_REG_WRITE(0x70004896, 0xFF5B),
	S5K4ECGX_REG_WRITE(0x70004898, 0x025A),
	S5K4ECGX_REG_WRITE(0x7000489A, 0xFF80),
	S5K4ECGX_REG_WRITE(0x7000489C, 0xFFC8),
	S5K4ECGX_REG_WRITE(0x7000489E, 0xFFC1),
	S5K4ECGX_REG_WRITE(0x700048A0, 0x013A),
	S5K4ECGX_REG_WRITE(0x700048A2, 0x0112),
	S5K4ECGX_REG_WRITE(0x700048A4, 0x00EE),
	S5K4ECGX_REG_WRITE(0x700048A6, 0xFF99),
	S5K4ECGX_REG_WRITE(0x700048A8, 0x009E),
	S5K4ECGX_REG_WRITE(0x700048AA, 0xFF5F),
	S5K4ECGX_REG_WRITE(0x700048AC, 0x01A8),
	S5K4ECGX_REG_WRITE(0x700048AE, 0xFF75),
	S5K4ECGX_REG_WRITE(0x700048B0, 0x0187),
	S5K4ECGX_REG_WRITE(0x700048B2, 0x01BF),
	S5K4ECGX_REG_WRITE(0x700048B4, 0x0208),
	S5K4ECGX_REG_WRITE(0x700048B6, 0xFFD3),
	S5K4ECGX_REG_WRITE(0x700048B8, 0xFFE9),
	S5K4ECGX_REG_WRITE(0x700048BA, 0xFF5B),
	S5K4ECGX_REG_WRITE(0x700048BC, 0x025A),
	S5K4ECGX_REG_WRITE(0x700048BE, 0xFF80),
	S5K4ECGX_REG_WRITE(0x700048C0, 0xFFC8),
	S5K4ECGX_REG_WRITE(0x700048C2, 0xFFC1),
	S5K4ECGX_REG_WRITE(0x700048C4, 0x013A),
	S5K4ECGX_REG_WRITE(0x700048C6, 0x0112),
	S5K4ECGX_REG_WRITE(0x700048C8, 0x00EE),
	S5K4ECGX_REG_WRITE(0x700048CA, 0xFF99),
	S5K4ECGX_REG_WRITE(0x700048CC, 0x009E),
	S5K4ECGX_REG_WRITE(0x700048CE, 0xFF5F),
	S5K4ECGX_REG_WRITE(0x700048D0, 0x01A8),
	S5K4ECGX_REG_WRITE(0x700048D2, 0xFF75),
	S5K4ECGX_REG_WRITE(0x700048D4, 0x0187),
	S5K4ECGX_REG_WRITE(0x700048D6, 0x01BF),

	S5K4ECGX_REG_WRITE(0x70000890, 0x48D8),
	S5K4ECGX_REG_WRITE(0x70000892, 0x7000),

	S5K4ECGX_REG_WRITE(0x700048D8, 0x01AA),
	S5K4ECGX_REG_WRITE(0x700048DA, 0xFFB6),
	S5K4ECGX_REG_WRITE(0x700048DC, 0xFFD4),
	S5K4ECGX_REG_WRITE(0x700048DE, 0xFF6C),
	S5K4ECGX_REG_WRITE(0x700048E0, 0x01E8),
	S5K4ECGX_REG_WRITE(0x700048E2, 0xFF79),
	S5K4ECGX_REG_WRITE(0x700048E4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700048E6, 0xFFF5),
	S5K4ECGX_REG_WRITE(0x700048E8, 0x023C),
	S5K4ECGX_REG_WRITE(0x700048EA, 0x00BF),
	S5K4ECGX_REG_WRITE(0x700048EC, 0x00E0),
	S5K4ECGX_REG_WRITE(0x700048EE, 0xFF5B),
	S5K4ECGX_REG_WRITE(0x700048F0, 0x022D),
	S5K4ECGX_REG_WRITE(0x700048F2, 0xFF9B),
	S5K4ECGX_REG_WRITE(0x700048F4, 0x01E1),
	S5K4ECGX_REG_WRITE(0x700048F6, 0xFF34),
	S5K4ECGX_REG_WRITE(0x700048F8, 0x014B),
	S5K4ECGX_REG_WRITE(0x700048FA, 0x01B6),

	S5K4ECGX_REG_WRITE(0x70000924, 0x0050),
	S5K4ECGX_REG_WRITE(0x70000926, 0x00B0),
	S5K4ECGX_REG_WRITE(0x70000928, 0x0196),
	S5K4ECGX_REG_WRITE(0x7000092A, 0x0245),
	S5K4ECGX_REG_WRITE(0x7000092C, 0x0300),

	S5K4ECGX_REG_WRITE(0x70000958, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000095A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000095C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000095E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000960, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000962, 0x00C0),
	S5K4ECGX_REG_WRITE(0x70000964, 0x0064),
	S5K4ECGX_REG_WRITE(0x70000966, 0x0384),
	S5K4ECGX_REG_WRITE(0x70000968, 0x0032),
	S5K4ECGX_REG_WRITE(0x7000096A, 0x01F4),
	S5K4ECGX_REG_WRITE(0x7000096C, 0x0070),
	S5K4ECGX_REG_WRITE(0x7000096E, 0x0040),
	S5K4ECGX_REG_WRITE(0x70000970, 0x00A0),
	S5K4ECGX_REG_WRITE(0x70000972, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000974, 0x0010),
	S5K4ECGX_REG_WRITE(0x70000976, 0x0040),
	S5K4ECGX_REG_WRITE(0x70000978, 0x00A0),
	S5K4ECGX_REG_WRITE(0x7000097A, 0x1430),
	S5K4ECGX_REG_WRITE(0x7000097C, 0x0201),
	S5K4ECGX_REG_WRITE(0x7000097E, 0x0204),
	S5K4ECGX_REG_WRITE(0x70000980, 0x3604),
	S5K4ECGX_REG_WRITE(0x70000982, 0x032A),
	S5K4ECGX_REG_WRITE(0x70000984, 0x0403),
	S5K4ECGX_REG_WRITE(0x70000986, 0x1B06),
	S5K4ECGX_REG_WRITE(0x70000988, 0x6015),
	S5K4ECGX_REG_WRITE(0x7000098A, 0x00C0),
	S5K4ECGX_REG_WRITE(0x7000098C, 0x6080),
	S5K4ECGX_REG_WRITE(0x7000098E, 0x4080),
	S5K4ECGX_REG_WRITE(0x70000990, 0x0640),
	S5K4ECGX_REG_WRITE(0x70000992, 0x0306),
	S5K4ECGX_REG_WRITE(0x70000994, 0x2003),
	S5K4ECGX_REG_WRITE(0x70000996, 0xFF01),
	S5K4ECGX_REG_WRITE(0x70000998, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000099A, 0x0400),
	S5K4ECGX_REG_WRITE(0x7000099C, 0x365A),
	S5K4ECGX_REG_WRITE(0x7000099E, 0x102A),
	S5K4ECGX_REG_WRITE(0x700009A0, 0x000B),
	S5K4ECGX_REG_WRITE(0x700009A2, 0x0600),
	S5K4ECGX_REG_WRITE(0x700009A4, 0x5A0F),
	S5K4ECGX_REG_WRITE(0x700009A6, 0x0505),
	S5K4ECGX_REG_WRITE(0x700009A8, 0x1802),
	S5K4ECGX_REG_WRITE(0x700009AA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700009AC, 0x2006),
	S5K4ECGX_REG_WRITE(0x700009AE, 0x3028),
	S5K4ECGX_REG_WRITE(0x700009B0, 0x0418),
	S5K4ECGX_REG_WRITE(0x700009B2, 0x0101),
	S5K4ECGX_REG_WRITE(0x700009B4, 0x0800),
	S5K4ECGX_REG_WRITE(0x700009B6, 0x1804),
	S5K4ECGX_REG_WRITE(0x700009B8, 0x4008),
	S5K4ECGX_REG_WRITE(0x700009BA, 0x0540),
	S5K4ECGX_REG_WRITE(0x700009BC, 0x8006),
	S5K4ECGX_REG_WRITE(0x700009BE, 0x0020),
	S5K4ECGX_REG_WRITE(0x700009C0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700009C2, 0x1800),
	S5K4ECGX_REG_WRITE(0x700009C4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700009C6, 0x1E10),
	S5K4ECGX_REG_WRITE(0x700009C8, 0x000B),
	S5K4ECGX_REG_WRITE(0x700009CA, 0x0607),
	S5K4ECGX_REG_WRITE(0x700009CC, 0x0005),
	S5K4ECGX_REG_WRITE(0x700009CE, 0x0607),
	S5K4ECGX_REG_WRITE(0x700009D0, 0x0405),
	S5K4ECGX_REG_WRITE(0x700009D2, 0x0205),
	S5K4ECGX_REG_WRITE(0x700009D4, 0x0304),
	S5K4ECGX_REG_WRITE(0x700009D6, 0x0409),
	S5K4ECGX_REG_WRITE(0x700009D8, 0x0306),
	S5K4ECGX_REG_WRITE(0x700009DA, 0x0407),
	S5K4ECGX_REG_WRITE(0x700009DC, 0x1C04),
	S5K4ECGX_REG_WRITE(0x700009DE, 0x0214),
	S5K4ECGX_REG_WRITE(0x700009E0, 0x1002),
	S5K4ECGX_REG_WRITE(0x700009E2, 0x0610),
	S5K4ECGX_REG_WRITE(0x700009E4, 0x0F02),
	S5K4ECGX_REG_WRITE(0x700009E6, 0x4A18),
	S5K4ECGX_REG_WRITE(0x700009E8, 0x0080),
	S5K4ECGX_REG_WRITE(0x700009EA, 0x0040),
	S5K4ECGX_REG_WRITE(0x700009EC, 0x0180),
	S5K4ECGX_REG_WRITE(0x700009EE, 0x0A0A),
	S5K4ECGX_REG_WRITE(0x700009F0, 0x0101),
	S5K4ECGX_REG_WRITE(0x700009F2, 0x2A36),
	S5K4ECGX_REG_WRITE(0x700009F4, 0x6024),
	S5K4ECGX_REG_WRITE(0x700009F6, 0x2A36),
	S5K4ECGX_REG_WRITE(0x700009F8, 0xFFFF),
	S5K4ECGX_REG_WRITE(0x700009FA, 0x0808),
	S5K4ECGX_REG_WRITE(0x700009FC, 0x0A01),
	S5K4ECGX_REG_WRITE(0x700009FE, 0x010A),
	S5K4ECGX_REG_WRITE(0x70000A00, 0x3601),
	S5K4ECGX_REG_WRITE(0x70000A02, 0x242A),
	S5K4ECGX_REG_WRITE(0x70000A04, 0x3660),
	S5K4ECGX_REG_WRITE(0x70000A06, 0xFF2A),
	S5K4ECGX_REG_WRITE(0x70000A08, 0x08FF),
	S5K4ECGX_REG_WRITE(0x70000A0A, 0x0008),
	S5K4ECGX_REG_WRITE(0x70000A0C, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000A0E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000A10, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000A12, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000A14, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000A16, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000A18, 0x00C0),
	S5K4ECGX_REG_WRITE(0x70000A1A, 0x0064),
	S5K4ECGX_REG_WRITE(0x70000A1C, 0x0384),
	S5K4ECGX_REG_WRITE(0x70000A1E, 0x0032),
	S5K4ECGX_REG_WRITE(0x70000A20, 0x01F4),
	S5K4ECGX_REG_WRITE(0x70000A22, 0x0070),
	S5K4ECGX_REG_WRITE(0x70000A24, 0x0040),
	S5K4ECGX_REG_WRITE(0x70000A26, 0x00A0),
	S5K4ECGX_REG_WRITE(0x70000A28, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000A2A, 0x0010),
	S5K4ECGX_REG_WRITE(0x70000A2C, 0x0060),
	S5K4ECGX_REG_WRITE(0x70000A2E, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000A30, 0x1430),
	S5K4ECGX_REG_WRITE(0x70000A32, 0x0201),
	S5K4ECGX_REG_WRITE(0x70000A34, 0x0204),
	S5K4ECGX_REG_WRITE(0x70000A36, 0x2404),
	S5K4ECGX_REG_WRITE(0x70000A38, 0x031B),
	S5K4ECGX_REG_WRITE(0x70000A3A, 0x0103),
	S5K4ECGX_REG_WRITE(0x70000A3C, 0x1205),
	S5K4ECGX_REG_WRITE(0x70000A3E, 0x400D),
	S5K4ECGX_REG_WRITE(0x70000A40, 0x0080),
	S5K4ECGX_REG_WRITE(0x70000A42, 0x2080),
	S5K4ECGX_REG_WRITE(0x70000A44, 0x3040),
	S5K4ECGX_REG_WRITE(0x70000A46, 0x0630),
	S5K4ECGX_REG_WRITE(0x70000A48, 0x0306),
	S5K4ECGX_REG_WRITE(0x70000A4A, 0x2003),
	S5K4ECGX_REG_WRITE(0x70000A4C, 0xFF01),
	S5K4ECGX_REG_WRITE(0x70000A4E, 0x0404),
	S5K4ECGX_REG_WRITE(0x70000A50, 0x0300),
	S5K4ECGX_REG_WRITE(0x70000A52, 0x245A),
	S5K4ECGX_REG_WRITE(0x70000A54, 0x1018),
	S5K4ECGX_REG_WRITE(0x70000A56, 0x000B),
	S5K4ECGX_REG_WRITE(0x70000A58, 0x0B00),
	S5K4ECGX_REG_WRITE(0x70000A5A, 0x5A0F),
	S5K4ECGX_REG_WRITE(0x70000A5C, 0x0505),
	S5K4ECGX_REG_WRITE(0x70000A5E, 0x1802),
	S5K4ECGX_REG_WRITE(0x70000A60, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000A62, 0x2006),
	S5K4ECGX_REG_WRITE(0x70000A64, 0x3428),
	S5K4ECGX_REG_WRITE(0x70000A66, 0x041C),
	S5K4ECGX_REG_WRITE(0x70000A68, 0x0101),
	S5K4ECGX_REG_WRITE(0x70000A6A, 0x0800),
	S5K4ECGX_REG_WRITE(0x70000A6C, 0x1004),
	S5K4ECGX_REG_WRITE(0x70000A6E, 0x4008),
	S5K4ECGX_REG_WRITE(0x70000A70, 0x0540),
	S5K4ECGX_REG_WRITE(0x70000A72, 0x8006),
	S5K4ECGX_REG_WRITE(0x70000A74, 0x0020),
	S5K4ECGX_REG_WRITE(0x70000A76, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000A78, 0x1800),
	S5K4ECGX_REG_WRITE(0x70000A7A, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000A7C, 0x1E10),
	S5K4ECGX_REG_WRITE(0x70000A7E, 0x000B),
	S5K4ECGX_REG_WRITE(0x70000A80, 0x0607),
	S5K4ECGX_REG_WRITE(0x70000A82, 0x0005),
	S5K4ECGX_REG_WRITE(0x70000A84, 0x0607),
	S5K4ECGX_REG_WRITE(0x70000A86, 0x0405),
	S5K4ECGX_REG_WRITE(0x70000A88, 0x0205),
	S5K4ECGX_REG_WRITE(0x70000A8A, 0x0304),
	S5K4ECGX_REG_WRITE(0x70000A8C, 0x0409),
	S5K4ECGX_REG_WRITE(0x70000A8E, 0x0306),
	S5K4ECGX_REG_WRITE(0x70000A90, 0x0407),
	S5K4ECGX_REG_WRITE(0x70000A92, 0x1F04),
	S5K4ECGX_REG_WRITE(0x70000A94, 0x0218),
	S5K4ECGX_REG_WRITE(0x70000A96, 0x1102),
	S5K4ECGX_REG_WRITE(0x70000A98, 0x0611),
	S5K4ECGX_REG_WRITE(0x70000A9A, 0x1002),
	S5K4ECGX_REG_WRITE(0x70000A9C, 0x8018),
	S5K4ECGX_REG_WRITE(0x70000A9E, 0x0080),
	S5K4ECGX_REG_WRITE(0x70000AA0, 0x0080),
	S5K4ECGX_REG_WRITE(0x70000AA2, 0x0180),
	S5K4ECGX_REG_WRITE(0x70000AA4, 0x0A0A),
	S5K4ECGX_REG_WRITE(0x70000AA6, 0x0101),
	S5K4ECGX_REG_WRITE(0x70000AA8, 0x1B24),
	S5K4ECGX_REG_WRITE(0x70000AAA, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000AAC, 0x1010),
	S5K4ECGX_REG_WRITE(0x70000AAE, 0xFFFF),
	S5K4ECGX_REG_WRITE(0x70000AB0, 0x0808),
	S5K4ECGX_REG_WRITE(0x70000AB2, 0x0A01),
	S5K4ECGX_REG_WRITE(0x70000AB4, 0x010A),
	S5K4ECGX_REG_WRITE(0x70000AB6, 0x2401),
	S5K4ECGX_REG_WRITE(0x70000AB8, 0x241B),
	S5K4ECGX_REG_WRITE(0x70000ABA, 0x1E60),
	S5K4ECGX_REG_WRITE(0x70000ABC, 0xFF18),
	S5K4ECGX_REG_WRITE(0x70000ABE, 0x08FF),
	S5K4ECGX_REG_WRITE(0x70000AC0, 0x0008),
	S5K4ECGX_REG_WRITE(0x70000AC2, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000AC4, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000AC6, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000AC8, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000ACA, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000ACC, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000ACE, 0x00C0),
	S5K4ECGX_REG_WRITE(0x70000AD0, 0x0064),
	S5K4ECGX_REG_WRITE(0x70000AD2, 0x0384),
	S5K4ECGX_REG_WRITE(0x70000AD4, 0x0032),
	S5K4ECGX_REG_WRITE(0x70000AD6, 0x01F4),
	S5K4ECGX_REG_WRITE(0x70000AD8, 0x0070),
	S5K4ECGX_REG_WRITE(0x70000ADA, 0x0040),
	S5K4ECGX_REG_WRITE(0x70000ADC, 0x00A0),
	S5K4ECGX_REG_WRITE(0x70000ADE, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000AE0, 0x0010),
	S5K4ECGX_REG_WRITE(0x70000AE2, 0x0060),
	S5K4ECGX_REG_WRITE(0x70000AE4, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000AE6, 0x1430),
	S5K4ECGX_REG_WRITE(0x70000AE8, 0x0201),
	S5K4ECGX_REG_WRITE(0x70000AEA, 0x0204),
	S5K4ECGX_REG_WRITE(0x70000AEC, 0x1B04),
	S5K4ECGX_REG_WRITE(0x70000AEE, 0x0312),
	S5K4ECGX_REG_WRITE(0x70000AF0, 0x0003),
	S5K4ECGX_REG_WRITE(0x70000AF2, 0x0C03),
	S5K4ECGX_REG_WRITE(0x70000AF4, 0x2806),
	S5K4ECGX_REG_WRITE(0x70000AF6, 0x0060),
	S5K4ECGX_REG_WRITE(0x70000AF8, 0x1580),
	S5K4ECGX_REG_WRITE(0x70000AFA, 0x2020),
	S5K4ECGX_REG_WRITE(0x70000AFC, 0x0620),
	S5K4ECGX_REG_WRITE(0x70000AFE, 0x0306),
	S5K4ECGX_REG_WRITE(0x70000B00, 0x2003),
	S5K4ECGX_REG_WRITE(0x70000B02, 0xFF01),
	S5K4ECGX_REG_WRITE(0x70000B04, 0x0404),
	S5K4ECGX_REG_WRITE(0x70000B06, 0x0300),
	S5K4ECGX_REG_WRITE(0x70000B08, 0x145A),
	S5K4ECGX_REG_WRITE(0x70000B0A, 0x1010),
	S5K4ECGX_REG_WRITE(0x70000B0C, 0x000B),
	S5K4ECGX_REG_WRITE(0x70000B0E, 0x0E00),
	S5K4ECGX_REG_WRITE(0x70000B10, 0x5A0F),
	S5K4ECGX_REG_WRITE(0x70000B12, 0x0504),
	S5K4ECGX_REG_WRITE(0x70000B14, 0x1802),
	S5K4ECGX_REG_WRITE(0x70000B16, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000B18, 0x2006),
	S5K4ECGX_REG_WRITE(0x70000B1A, 0x3828),
	S5K4ECGX_REG_WRITE(0x70000B1C, 0x0428),
	S5K4ECGX_REG_WRITE(0x70000B1E, 0x0101),
	S5K4ECGX_REG_WRITE(0x70000B20, 0x8000),
	S5K4ECGX_REG_WRITE(0x70000B22, 0x0A04),
	S5K4ECGX_REG_WRITE(0x70000B24, 0x4008),
	S5K4ECGX_REG_WRITE(0x70000B26, 0x0540),
	S5K4ECGX_REG_WRITE(0x70000B28, 0x8006),
	S5K4ECGX_REG_WRITE(0x70000B2A, 0x0020),
	S5K4ECGX_REG_WRITE(0x70000B2C, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000B2E, 0x1800),
	S5K4ECGX_REG_WRITE(0x70000B30, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000B32, 0x1E10),
	S5K4ECGX_REG_WRITE(0x70000B34, 0x000B),
	S5K4ECGX_REG_WRITE(0x70000B36, 0x0607),
	S5K4ECGX_REG_WRITE(0x70000B38, 0x0005),
	S5K4ECGX_REG_WRITE(0x70000B3A, 0x0607),
	S5K4ECGX_REG_WRITE(0x70000B3C, 0x0405),
	S5K4ECGX_REG_WRITE(0x70000B3E, 0x0207),
	S5K4ECGX_REG_WRITE(0x70000B40, 0x0304),
	S5K4ECGX_REG_WRITE(0x70000B42, 0x0409),
	S5K4ECGX_REG_WRITE(0x70000B44, 0x0306),
	S5K4ECGX_REG_WRITE(0x70000B46, 0x0407),
	S5K4ECGX_REG_WRITE(0x70000B48, 0x2404),
	S5K4ECGX_REG_WRITE(0x70000B4A, 0x0221),
	S5K4ECGX_REG_WRITE(0x70000B4C, 0x1202),
	S5K4ECGX_REG_WRITE(0x70000B4E, 0x0613),
	S5K4ECGX_REG_WRITE(0x70000B50, 0x1202),
	S5K4ECGX_REG_WRITE(0x70000B52, 0x8018),
	S5K4ECGX_REG_WRITE(0x70000B54, 0x0080),
	S5K4ECGX_REG_WRITE(0x70000B56, 0x0080),
	S5K4ECGX_REG_WRITE(0x70000B58, 0x0180),
	S5K4ECGX_REG_WRITE(0x70000B5A, 0x0A0A),
	S5K4ECGX_REG_WRITE(0x70000B5C, 0x0101),
	S5K4ECGX_REG_WRITE(0x70000B5E, 0x121B),
	S5K4ECGX_REG_WRITE(0x70000B60, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000B62, 0x0C0C),
	S5K4ECGX_REG_WRITE(0x70000B64, 0xFFFF),
	S5K4ECGX_REG_WRITE(0x70000B66, 0x0808),
	S5K4ECGX_REG_WRITE(0x70000B68, 0x0A01),
	S5K4ECGX_REG_WRITE(0x70000B6A, 0x010A),
	S5K4ECGX_REG_WRITE(0x70000B6C, 0x1B01),
	S5K4ECGX_REG_WRITE(0x70000B6E, 0x2412),
	S5K4ECGX_REG_WRITE(0x70000B70, 0x0C60),
	S5K4ECGX_REG_WRITE(0x70000B72, 0xFF0C),
	S5K4ECGX_REG_WRITE(0x70000B74, 0x08FF),
	S5K4ECGX_REG_WRITE(0x70000B76, 0x0008),
	S5K4ECGX_REG_WRITE(0x70000B78, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000B7A, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000B7C, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000B7E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000B80, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000B82, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000B84, 0x00C0),
	S5K4ECGX_REG_WRITE(0x70000B86, 0x0064),
	S5K4ECGX_REG_WRITE(0x70000B88, 0x0384),
	S5K4ECGX_REG_WRITE(0x70000B8A, 0x0032),
	S5K4ECGX_REG_WRITE(0x70000B8C, 0x01F4),
	S5K4ECGX_REG_WRITE(0x70000B8E, 0x0070),
	S5K4ECGX_REG_WRITE(0x70000B90, 0x0040),
	S5K4ECGX_REG_WRITE(0x70000B92, 0x00A0),
	S5K4ECGX_REG_WRITE(0x70000B94, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000B96, 0x0010),
	S5K4ECGX_REG_WRITE(0x70000B98, 0x0060),
	S5K4ECGX_REG_WRITE(0x70000B9A, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000B9C, 0x1430),
	S5K4ECGX_REG_WRITE(0x70000B9E, 0x0201),
	S5K4ECGX_REG_WRITE(0x70000BA0, 0x0204),
	S5K4ECGX_REG_WRITE(0x70000BA2, 0x1504),
	S5K4ECGX_REG_WRITE(0x70000BA4, 0x030F),
	S5K4ECGX_REG_WRITE(0x70000BA6, 0x0003),
	S5K4ECGX_REG_WRITE(0x70000BA8, 0x0902),
	S5K4ECGX_REG_WRITE(0x70000BAA, 0x2004),
	S5K4ECGX_REG_WRITE(0x70000BAC, 0x0050),
	S5K4ECGX_REG_WRITE(0x70000BAE, 0x1140),
	S5K4ECGX_REG_WRITE(0x70000BB0, 0x201C),
	S5K4ECGX_REG_WRITE(0x70000BB2, 0x0620),
	S5K4ECGX_REG_WRITE(0x70000BB4, 0x0306),
	S5K4ECGX_REG_WRITE(0x70000BB6, 0x2003),
	S5K4ECGX_REG_WRITE(0x70000BB8, 0xFF01),
	S5K4ECGX_REG_WRITE(0x70000BBA, 0x0404),
	S5K4ECGX_REG_WRITE(0x70000BBC, 0x0300),
	S5K4ECGX_REG_WRITE(0x70000BBE, 0x145A),
	S5K4ECGX_REG_WRITE(0x70000BC0, 0x1010),
	S5K4ECGX_REG_WRITE(0x70000BC2, 0x000B),
	S5K4ECGX_REG_WRITE(0x70000BC4, 0x1000),
	S5K4ECGX_REG_WRITE(0x70000BC6, 0x5A0F),
	S5K4ECGX_REG_WRITE(0x70000BC8, 0x0503),
	S5K4ECGX_REG_WRITE(0x70000BCA, 0x1802),
	S5K4ECGX_REG_WRITE(0x70000BCC, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000BCE, 0x2006),
	S5K4ECGX_REG_WRITE(0x70000BD0, 0x3C28),
	S5K4ECGX_REG_WRITE(0x70000BD2, 0x042C),
	S5K4ECGX_REG_WRITE(0x70000BD4, 0x0101),
	S5K4ECGX_REG_WRITE(0x70000BD6, 0xFF00),
	S5K4ECGX_REG_WRITE(0x70000BD8, 0x0904),
	S5K4ECGX_REG_WRITE(0x70000BDA, 0x4008),
	S5K4ECGX_REG_WRITE(0x70000BDC, 0x0540),
	S5K4ECGX_REG_WRITE(0x70000BDE, 0x8006),
	S5K4ECGX_REG_WRITE(0x70000BE0, 0x0020),
	S5K4ECGX_REG_WRITE(0x70000BE2, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000BE4, 0x1800),
	S5K4ECGX_REG_WRITE(0x70000BE6, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000BE8, 0x1E10),
	S5K4ECGX_REG_WRITE(0x70000BEA, 0x000B),
	S5K4ECGX_REG_WRITE(0x70000BEC, 0x0607),
	S5K4ECGX_REG_WRITE(0x70000BEE, 0x0005),
	S5K4ECGX_REG_WRITE(0x70000BF0, 0x0607),
	S5K4ECGX_REG_WRITE(0x70000BF2, 0x0405),
	S5K4ECGX_REG_WRITE(0x70000BF4, 0x0206),
	S5K4ECGX_REG_WRITE(0x70000BF6, 0x0304),
	S5K4ECGX_REG_WRITE(0x70000BF8, 0x0409),
	S5K4ECGX_REG_WRITE(0x70000BFA, 0x0305),
	S5K4ECGX_REG_WRITE(0x70000BFC, 0x0406),
	S5K4ECGX_REG_WRITE(0x70000BFE, 0x2804),
	S5K4ECGX_REG_WRITE(0x70000C00, 0x0228),
	S5K4ECGX_REG_WRITE(0x70000C02, 0x1402),
	S5K4ECGX_REG_WRITE(0x70000C04, 0x0618),
	S5K4ECGX_REG_WRITE(0x70000C06, 0x1402),
	S5K4ECGX_REG_WRITE(0x70000C08, 0x8018),
	S5K4ECGX_REG_WRITE(0x70000C0A, 0x0080),
	S5K4ECGX_REG_WRITE(0x70000C0C, 0x0080),
	S5K4ECGX_REG_WRITE(0x70000C0E, 0x0180),
	S5K4ECGX_REG_WRITE(0x70000C10, 0x0A0A),
	S5K4ECGX_REG_WRITE(0x70000C12, 0x0101),
	S5K4ECGX_REG_WRITE(0x70000C14, 0x0F15),
	S5K4ECGX_REG_WRITE(0x70000C16, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000C18, 0x0A0A),
	S5K4ECGX_REG_WRITE(0x70000C1A, 0xFFFF),
	S5K4ECGX_REG_WRITE(0x70000C1C, 0x0808),
	S5K4ECGX_REG_WRITE(0x70000C1E, 0x0A01),
	S5K4ECGX_REG_WRITE(0x70000C20, 0x010A),
	S5K4ECGX_REG_WRITE(0x70000C22, 0x1501),
	S5K4ECGX_REG_WRITE(0x70000C24, 0x240F),
	S5K4ECGX_REG_WRITE(0x70000C26, 0x0A60),
	S5K4ECGX_REG_WRITE(0x70000C28, 0xFF0A),
	S5K4ECGX_REG_WRITE(0x70000C2A, 0x08FF),
	S5K4ECGX_REG_WRITE(0x70000C2C, 0x0008),
	S5K4ECGX_REG_WRITE(0x70000C2E, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000C30, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000C32, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000C34, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000C36, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000C38, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000C3A, 0x00C0),
	S5K4ECGX_REG_WRITE(0x70000C3C, 0x0064),
	S5K4ECGX_REG_WRITE(0x70000C3E, 0x0384),
	S5K4ECGX_REG_WRITE(0x70000C40, 0x0032),
	S5K4ECGX_REG_WRITE(0x70000C42, 0x01F4),
	S5K4ECGX_REG_WRITE(0x70000C44, 0x0070),
	S5K4ECGX_REG_WRITE(0x70000C46, 0x0040),
	S5K4ECGX_REG_WRITE(0x70000C48, 0x00A0),
	S5K4ECGX_REG_WRITE(0x70000C4A, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000C4C, 0x0010),
	S5K4ECGX_REG_WRITE(0x70000C4E, 0x0060),
	S5K4ECGX_REG_WRITE(0x70000C50, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000C52, 0x1430),
	S5K4ECGX_REG_WRITE(0x70000C54, 0x0201),
	S5K4ECGX_REG_WRITE(0x70000C56, 0x0204),
	S5K4ECGX_REG_WRITE(0x70000C58, 0x0F04),
	S5K4ECGX_REG_WRITE(0x70000C5A, 0x030C),
	S5K4ECGX_REG_WRITE(0x70000C5C, 0x0003),
	S5K4ECGX_REG_WRITE(0x70000C5E, 0x0602),
	S5K4ECGX_REG_WRITE(0x70000C60, 0x1803),
	S5K4ECGX_REG_WRITE(0x70000C62, 0x0040),
	S5K4ECGX_REG_WRITE(0x70000C64, 0x0E20),
	S5K4ECGX_REG_WRITE(0x70000C66, 0x2018),
	S5K4ECGX_REG_WRITE(0x70000C68, 0x0620),
	S5K4ECGX_REG_WRITE(0x70000C6A, 0x0306),
	S5K4ECGX_REG_WRITE(0x70000C6C, 0x2003),
	S5K4ECGX_REG_WRITE(0x70000C6E, 0xFF01),
	S5K4ECGX_REG_WRITE(0x70000C70, 0x0404),
	S5K4ECGX_REG_WRITE(0x70000C72, 0x0200),
	S5K4ECGX_REG_WRITE(0x70000C74, 0x145A),
	S5K4ECGX_REG_WRITE(0x70000C76, 0x1010),
	S5K4ECGX_REG_WRITE(0x70000C78, 0x000B),
	S5K4ECGX_REG_WRITE(0x70000C7A, 0x1200),
	S5K4ECGX_REG_WRITE(0x70000C7C, 0x5A0F),
	S5K4ECGX_REG_WRITE(0x70000C7E, 0x0502),
	S5K4ECGX_REG_WRITE(0x70000C80, 0x1802),
	S5K4ECGX_REG_WRITE(0x70000C82, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000C84, 0x2006),
	S5K4ECGX_REG_WRITE(0x70000C86, 0x4028),
	S5K4ECGX_REG_WRITE(0x70000C88, 0x0430),
	S5K4ECGX_REG_WRITE(0x70000C8A, 0x0101),
	S5K4ECGX_REG_WRITE(0x70000C8C, 0xFF00),
	S5K4ECGX_REG_WRITE(0x70000C8E, 0x0804),
	S5K4ECGX_REG_WRITE(0x70000C90, 0x4008),
	S5K4ECGX_REG_WRITE(0x70000C92, 0x0540),
	S5K4ECGX_REG_WRITE(0x70000C94, 0x8006),
	S5K4ECGX_REG_WRITE(0x70000C96, 0x0020),
	S5K4ECGX_REG_WRITE(0x70000C98, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000C9A, 0x1800),
	S5K4ECGX_REG_WRITE(0x70000C9C, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000C9E, 0x1E10),
	S5K4ECGX_REG_WRITE(0x70000CA0, 0x000B),
	S5K4ECGX_REG_WRITE(0x70000CA2, 0x0607),
	S5K4ECGX_REG_WRITE(0x70000CA4, 0x0005),
	S5K4ECGX_REG_WRITE(0x70000CA6, 0x0607),
	S5K4ECGX_REG_WRITE(0x70000CA8, 0x0405),
	S5K4ECGX_REG_WRITE(0x70000CAA, 0x0205),
	S5K4ECGX_REG_WRITE(0x70000CAC, 0x0304),
	S5K4ECGX_REG_WRITE(0x70000CAE, 0x0409),
	S5K4ECGX_REG_WRITE(0x70000CB0, 0x0306),
	S5K4ECGX_REG_WRITE(0x70000CB2, 0x0407),
	S5K4ECGX_REG_WRITE(0x70000CB4, 0x2C04),
	S5K4ECGX_REG_WRITE(0x70000CB6, 0x022C),
	S5K4ECGX_REG_WRITE(0x70000CB8, 0x1402),
	S5K4ECGX_REG_WRITE(0x70000CBA, 0x0618),
	S5K4ECGX_REG_WRITE(0x70000CBC, 0x1402),
	S5K4ECGX_REG_WRITE(0x70000CBE, 0x8018),
	S5K4ECGX_REG_WRITE(0x70000CC0, 0x0080),
	S5K4ECGX_REG_WRITE(0x70000CC2, 0x0080),
	S5K4ECGX_REG_WRITE(0x70000CC4, 0x0180),
	S5K4ECGX_REG_WRITE(0x70000CC6, 0x0A0A),
	S5K4ECGX_REG_WRITE(0x70000CC8, 0x0101),
	S5K4ECGX_REG_WRITE(0x70000CCA, 0x0C0F),
	S5K4ECGX_REG_WRITE(0x70000CCC, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000CCE, 0x0808),
	S5K4ECGX_REG_WRITE(0x70000CD0, 0xFFFF),
	S5K4ECGX_REG_WRITE(0x70000CD2, 0x0808),
	S5K4ECGX_REG_WRITE(0x70000CD4, 0x0A01),
	S5K4ECGX_REG_WRITE(0x70000CD6, 0x010A),
	S5K4ECGX_REG_WRITE(0x70000CD8, 0x0F01),
	S5K4ECGX_REG_WRITE(0x70000CDA, 0x240C),
	S5K4ECGX_REG_WRITE(0x70000CDC, 0x0860),
	S5K4ECGX_REG_WRITE(0x70000CDE, 0xFF08),
	S5K4ECGX_REG_WRITE(0x70000CE0, 0x08FF),
	S5K4ECGX_REG_WRITE(0x70000CE2, 0x0008),
	S5K4ECGX_REG_WRITE(0x70000CE4, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000CE6, 0x23CE),
	S5K4ECGX_REG_WRITE(0x70000CE8, 0xFDC8),
	S5K4ECGX_REG_WRITE(0x70000CEA, 0x112E),
	S5K4ECGX_REG_WRITE(0x70000CEC, 0x93A5),
	S5K4ECGX_REG_WRITE(0x70000CEE, 0xFE67),
	S5K4ECGX_REG_WRITE(0x70000CF0, 0x0000),

	S5K4ECGX_CMD_WRITE(0xFCFC, 0xD000),
	S5K4ECGX_REG_WRITE(0x700001A2, 0x0A0A),

	S5K4ECGX_CMD_WRITE(0xFCFC, 0xD000),
	S5K4ECGX_CMD_WRITE(0x0004, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_DTP_init_v1) = {
	S5K4ECGX_REG_WRITE(0xD000B054, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_DTP_stop_v1) = {
	S5K4ECGX_REG_WRITE(0xD000B054, 0x0000),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Effect_Normal_v1) = {
	S5K4ECGX_REG_WRITE(0x70000238, 0x0000),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Effect_Negative_v1) = {
	S5K4ECGX_REG_WRITE(0x70000238, 0x0003),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Effect_Sepia_v1) = {
	S5K4ECGX_REG_WRITE(0x70000238, 0x0004),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Effect_Black_White_v1) = {
	S5K4ECGX_REG_WRITE(0x70000238, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_WB_Auto_v1) = {
	S5K4ECGX_REG_WRITE(0x700004E0, 0x077F),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_WB_Sunny_v1) = {
	S5K4ECGX_REG_WRITE(0x700004E0, 0x0777),
	S5K4ECGX_REG_WRITE(0x700004B4, 0x05E0),
	S5K4ECGX_REG_WRITE(0x700004B6, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004B8, 0x0400),
	S5K4ECGX_REG_WRITE(0x700004BA, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004BC, 0x0530),
	S5K4ECGX_REG_WRITE(0x700004BE, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004C0, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_WB_Cloudy_v1) = {
	S5K4ECGX_REG_WRITE(0x700004E0, 0x0777),
	S5K4ECGX_REG_WRITE(0x700004B4, 0x0710),	/* R */
	S5K4ECGX_REG_WRITE(0x700004B6, 0x0001),	/* Changed */
	S5K4ECGX_REG_WRITE(0x700004B8, 0x0400),	/* G */
	S5K4ECGX_REG_WRITE(0x700004BA, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004BC, 0x0420),	/* B  480-reference */
	S5K4ECGX_REG_WRITE(0x700004BE, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004C0, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_WB_Tungsten_v1) = {
	S5K4ECGX_REG_WRITE(0x700004E0, 0x0777),
	S5K4ECGX_REG_WRITE(0x700004B4, 0x0390),
	S5K4ECGX_REG_WRITE(0x700004B6, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004B8, 0x0400),
	S5K4ECGX_REG_WRITE(0x700004BA, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004BC, 0x0920),
	S5K4ECGX_REG_WRITE(0x700004BE, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004C0, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_WB_Fluorescent_v1) = {
	S5K4ECGX_REG_WRITE(0x700004E0, 0x0777),
	S5K4ECGX_REG_WRITE(0x700004B4, 0x0505),
	S5K4ECGX_REG_WRITE(0x700004B6, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004B8, 0x0400),
	S5K4ECGX_REG_WRITE(0x700004BA, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004BC, 0x0875),
	S5K4ECGX_REG_WRITE(0x700004BE, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004C0, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_WDR_on_v1) = {
	S5K4ECGX_REG_WRITE(0x70001B4A, 0x0000),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_WDR_off_v1) = {
	S5K4ECGX_REG_WRITE(0x70001B4A, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_ISO_Auto_v1) = {
	S5K4ECGX_REG_WRITE(0x70004780, 0x0000),

	S5K4ECGX_REG_WRITE(0x70000EF0, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004E0, 0x077F),
	S5K4ECGX_REG_WRITE(0x700004CA, 0x0000),

	S5K4ECGX_REG_WRITE(0x700004CA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004CC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004CE, 0x0001),
	S5K4ECGX_REG_WRITE(0x700006B6, 0x0200),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_ISO_100_v1) = {
	S5K4ECGX_REG_WRITE(0x700004E0, 0x065F),
	S5K4ECGX_REG_WRITE(0x700004D0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004D2, 0x0001),

	S5K4ECGX_REG_WRITE(0x700004CA, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004CC, 0x01A0),
	S5K4ECGX_REG_WRITE(0x700004CE, 0x0001),
	S5K4ECGX_REG_WRITE(0x700006B6, 0x0100),

	S5K4ECGX_REG_WRITE(0x70004780, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_ISO_200_v1) = {
	S5K4ECGX_REG_WRITE(0x700004E0, 0x065F),
	S5K4ECGX_REG_WRITE(0x700004D0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004D2, 0x0001),

	S5K4ECGX_REG_WRITE(0x700004CA, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004CC, 0x0340),
	S5K4ECGX_REG_WRITE(0x700004CE, 0x0001),
	S5K4ECGX_REG_WRITE(0x700006B6, 0x0100),

	S5K4ECGX_REG_WRITE(0x70004780, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_ISO_400_v1) = {
	S5K4ECGX_REG_WRITE(0x700004E0, 0x065F),
	S5K4ECGX_REG_WRITE(0x700004D0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004D2, 0x0001),

	S5K4ECGX_REG_WRITE(0x700004CA, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004CC, 0x0680),
	S5K4ECGX_REG_WRITE(0x700004CE, 0x0001),
	S5K4ECGX_REG_WRITE(0x700006B6, 0x0100),

	S5K4ECGX_REG_WRITE(0x70004780, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Metering_Matrix_v1) = {
	S5K4ECGX_REG_WRITE(0x70001456, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001458, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000145A, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000145C, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000145E, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001460, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001462, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001464, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001466, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001468, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000146A, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000146C, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000146E, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001470, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001472, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001474, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001476, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001478, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000147A, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000147C, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000147E, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001480, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001482, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001484, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001486, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001488, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000148A, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000148C, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000148E, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001490, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001492, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001494, 0x0101),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Metering_Center_v1) = {
	S5K4ECGX_REG_WRITE(0x70001456, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001458, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000145A, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000145C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000145E, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001460, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001462, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001464, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001466, 0x0201),
	S5K4ECGX_REG_WRITE(0x70001468, 0x0303),
	S5K4ECGX_REG_WRITE(0x7000146A, 0x0303),
	S5K4ECGX_REG_WRITE(0x7000146C, 0x0102),
	S5K4ECGX_REG_WRITE(0x7000146E, 0x0201),
	S5K4ECGX_REG_WRITE(0x70001470, 0x0403),
	S5K4ECGX_REG_WRITE(0x70001472, 0x0304),
	S5K4ECGX_REG_WRITE(0x70001474, 0x0102),
	S5K4ECGX_REG_WRITE(0x70001476, 0x0201),
	S5K4ECGX_REG_WRITE(0x70001478, 0x0403),
	S5K4ECGX_REG_WRITE(0x7000147A, 0x0304),
	S5K4ECGX_REG_WRITE(0x7000147C, 0x0102),
	S5K4ECGX_REG_WRITE(0x7000147E, 0x0201),
	S5K4ECGX_REG_WRITE(0x70001480, 0x0403),
	S5K4ECGX_REG_WRITE(0x70001482, 0x0304),
	S5K4ECGX_REG_WRITE(0x70001484, 0x0102),
	S5K4ECGX_REG_WRITE(0x70001486, 0x0201),
	S5K4ECGX_REG_WRITE(0x70001488, 0x0303),
	S5K4ECGX_REG_WRITE(0x7000148A, 0x0303),
	S5K4ECGX_REG_WRITE(0x7000148C, 0x0102),
	S5K4ECGX_REG_WRITE(0x7000148E, 0x0201),
	S5K4ECGX_REG_WRITE(0x70001490, 0x0202),
	S5K4ECGX_REG_WRITE(0x70001492, 0x0202),
	S5K4ECGX_REG_WRITE(0x70001494, 0x0102),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Metering_Spot_v1) = {
	S5K4ECGX_REG_WRITE(0x70001456, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001458, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000145A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000145C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000145E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001460, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001462, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001464, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001466, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001468, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000146A, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000146C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000146E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001470, 0x010F),
	S5K4ECGX_REG_WRITE(0x70001472, 0x0F01),
	S5K4ECGX_REG_WRITE(0x70001474, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001476, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001478, 0x010F),
	S5K4ECGX_REG_WRITE(0x7000147A, 0x0F01),
	S5K4ECGX_REG_WRITE(0x7000147C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000147E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001480, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001482, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001484, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001486, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001488, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000148A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000148C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000148E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001490, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001492, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001494, 0x0000),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_EV_Minus_4_v1) = {
	S5K4ECGX_REG_WRITE(0x7000022C, 0xFF30),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_EV_Minus_3_v1) = {
	S5K4ECGX_REG_WRITE(0x7000022C, 0xFFA0),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_EV_Minus_2_v1) = {
	S5K4ECGX_REG_WRITE(0x7000022C, 0xFFC8),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_EV_Minus_1_v1) = {
	S5K4ECGX_REG_WRITE(0x7000022C, 0xFFE0),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_EV_Default_v1) = {
	S5K4ECGX_REG_WRITE(0x7000022C, 0x0000),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_EV_Plus_1_v1) = {
	S5K4ECGX_REG_WRITE(0x7000022C, 0x0020),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_EV_Plus_2_v1) = {
	S5K4ECGX_REG_WRITE(0x7000022C, 0x0038),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_EV_Plus_3_v1) = {
	S5K4ECGX_REG_WRITE(0x7000022C, 0x0060),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_EV_Plus_4_v1) = {
	S5K4ECGX_REG_WRITE(0x7000022C, 0x007F),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Contrast_Minus_4_v1) = {
	S5K4ECGX_REG_WRITE(0x7000022E, 0xFF81),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Contrast_Minus_3_v1) = {
	S5K4ECGX_REG_WRITE(0x7000022E, 0xFFA0),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Contrast_Minus_2_v1) = {
	S5K4ECGX_REG_WRITE(0x7000022E, 0xFFC0),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Contrast_Minus_1_v1) = {
	S5K4ECGX_REG_WRITE(0x7000022E, 0xFFE0),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Contrast_Default_v1) = {
	S5K4ECGX_REG_WRITE(0x7000022E, 0x0000),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Contrast_Plus_1_v1) = {
	S5K4ECGX_REG_WRITE(0x7000022E, 0x0020),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Contrast_Plus_2_v1) = {
	S5K4ECGX_REG_WRITE(0x7000022E, 0x0040),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Contrast_Plus_3_v1) = {
	S5K4ECGX_REG_WRITE(0x7000022E, 0x0060),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Contrast_Plus_4_v1) = {
	S5K4ECGX_REG_WRITE(0x7000022E, 0x007F),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Sharpness_Minus_3_v1) = {
	S5K4ECGX_REG_WRITE(0x700009F4, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000AAA, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000B60, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000C16, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000CCC, 0x0000),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Sharpness_Minus_2_v1) = {
	S5K4ECGX_REG_WRITE(0x700009F4, 0x2010),
	S5K4ECGX_REG_WRITE(0x70000AAA, 0x2010),
	S5K4ECGX_REG_WRITE(0x70000B60, 0x2010),
	S5K4ECGX_REG_WRITE(0x70000C16, 0x2010),
	S5K4ECGX_REG_WRITE(0x70000CCC, 0x2010),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Sharpness_Minus_1_v1) = {
	S5K4ECGX_REG_WRITE(0x700009F4, 0x4020),
	S5K4ECGX_REG_WRITE(0x70000AAA, 0x4020),
	S5K4ECGX_REG_WRITE(0x70000B60, 0x4020),
	S5K4ECGX_REG_WRITE(0x70000C16, 0x4020),
	S5K4ECGX_REG_WRITE(0x70000CCC, 0x4020),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Sharpness_Default_v1) = {
	S5K4ECGX_REG_WRITE(0x700009F4, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000AAA, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000B60, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000C16, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000CCC, 0x6024),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Sharpness_Plus_1_v1) = {
	S5K4ECGX_REG_WRITE(0x700009F4, 0x8040),
	S5K4ECGX_REG_WRITE(0x70000AAA, 0x8040),
	S5K4ECGX_REG_WRITE(0x70000B60, 0x8040),
	S5K4ECGX_REG_WRITE(0x70000C16, 0x8040),
	S5K4ECGX_REG_WRITE(0x70000CCC, 0x8040),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Sharpness_Plus_2_v1) = {
	S5K4ECGX_REG_WRITE(0x700009F4, 0xA060),
	S5K4ECGX_REG_WRITE(0x70000AAA, 0xA060),
	S5K4ECGX_REG_WRITE(0x70000B60, 0xA060),
	S5K4ECGX_REG_WRITE(0x70000C16, 0xA060),
	S5K4ECGX_REG_WRITE(0x70000CCC, 0xA060),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Sharpness_Plus_3_v1) = {
	S5K4ECGX_REG_WRITE(0x700009F4, 0xC080),
	S5K4ECGX_REG_WRITE(0x70000AAA, 0xC080),
	S5K4ECGX_REG_WRITE(0x70000B60, 0xC080),
	S5K4ECGX_REG_WRITE(0x70000C16, 0xC080),
	S5K4ECGX_REG_WRITE(0x70000CCC, 0xC080),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Saturation_Minus_2_v1) = {
	S5K4ECGX_REG_WRITE(0x70000230, 0xFF81),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Saturation_Minus_1_v1) = {
	S5K4ECGX_REG_WRITE(0x70000230, 0xFFC0),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Saturation_Default_v1) = {
	S5K4ECGX_REG_WRITE(0x70000230, 0x0000),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Saturation_Plus_1_v1) = {
	S5K4ECGX_REG_WRITE(0x70000230, 0x0040),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Saturation_Plus_2_v1) = {
	S5K4ECGX_REG_WRITE(0x70000230, 0x007F),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Jpeg_Quality_High_v1) = {
	S5K4ECGX_REG_WRITE(0x70000472, 0x005F),
	S5K4ECGX_REG_WRITE(0x70000474, 0x005F),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Jpeg_Quality_Normal_v1) = {
	S5K4ECGX_REG_WRITE(0x70000472, 0x0050),
	S5K4ECGX_REG_WRITE(0x70000474, 0x0050),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Jpeg_Quality_Low_v1) = {
	S5K4ECGX_REG_WRITE(0x70000472, 0x004B),
	S5K4ECGX_REG_WRITE(0x70000474, 0x004B),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Default_v1) = {
	S5K4ECGX_REG_WRITE(0x70001456, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001458, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000145A, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000145C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000145E, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001460, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001462, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001464, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001466, 0x0201),
	S5K4ECGX_REG_WRITE(0x70001468, 0x0303),
	S5K4ECGX_REG_WRITE(0x7000146A, 0x0303),
	S5K4ECGX_REG_WRITE(0x7000146C, 0x0102),
	S5K4ECGX_REG_WRITE(0x7000146E, 0x0201),
	S5K4ECGX_REG_WRITE(0x70001470, 0x0403),
	S5K4ECGX_REG_WRITE(0x70001472, 0x0304),
	S5K4ECGX_REG_WRITE(0x70001474, 0x0102),
	S5K4ECGX_REG_WRITE(0x70001476, 0x0201),
	S5K4ECGX_REG_WRITE(0x70001478, 0x0403),
	S5K4ECGX_REG_WRITE(0x7000147A, 0x0304),
	S5K4ECGX_REG_WRITE(0x7000147C, 0x0102),
	S5K4ECGX_REG_WRITE(0x7000147E, 0x0201),
	S5K4ECGX_REG_WRITE(0x70001480, 0x0403),
	S5K4ECGX_REG_WRITE(0x70001482, 0x0304),
	S5K4ECGX_REG_WRITE(0x70001484, 0x0102),
	S5K4ECGX_REG_WRITE(0x70001486, 0x0201),
	S5K4ECGX_REG_WRITE(0x70001488, 0x0303),
	S5K4ECGX_REG_WRITE(0x7000148A, 0x0303),
	S5K4ECGX_REG_WRITE(0x7000148C, 0x0102),
	S5K4ECGX_REG_WRITE(0x7000148E, 0x0201),
	S5K4ECGX_REG_WRITE(0x70001490, 0x0202),
	S5K4ECGX_REG_WRITE(0x70001492, 0x0202),
	S5K4ECGX_REG_WRITE(0x70001494, 0x0102),

	S5K4ECGX_REG_WRITE(0x70004780, 0x0000),

	S5K4ECGX_REG_WRITE(0x700006AC, 0x452C),
	S5K4ECGX_REG_WRITE(0x700006AE, 0x0004),

	S5K4ECGX_REG_WRITE(0x70000EF0, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000EF6, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004E0, 0x077F),
	S5K4ECGX_REG_WRITE(0x700004CA, 0x0000),

	S5K4ECGX_REG_WRITE(0x700004CA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004CC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004CE, 0x0001),
	S5K4ECGX_REG_WRITE(0x700006B6, 0x0200),

	S5K4ECGX_REG_WRITE(0x70002B7E, 0x0001),

	S5K4ECGX_REG_WRITE(0x70001448, 0x003C),
	S5K4ECGX_REG_WRITE(0x7000144E, 0x000F),
	S5K4ECGX_REG_WRITE(0x70000580, 0x3520),
	S5K4ECGX_REG_WRITE(0x70000582, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000584, 0xC350),
	S5K4ECGX_REG_WRITE(0x70000586, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000588, 0x3520),
	S5K4ECGX_REG_WRITE(0x7000058A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000058C, 0xC350),
	S5K4ECGX_REG_WRITE(0x7000058E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000590, 0x0470),
	S5K4ECGX_REG_WRITE(0x70000592, 0x0C00),
	S5K4ECGX_REG_WRITE(0x70000594, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000596, 0x1000),

	S5K4ECGX_REG_WRITE(0x70000538, 0x0111),
	S5K4ECGX_REG_WRITE(0x7000053A, 0x00EF),

	S5K4ECGX_REG_WRITE(0x700005FC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700005FE, 0x0001),

	S5K4ECGX_REG_WRITE(0x700009F4, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000AAA, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000B60, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000C16, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000CCC, 0x6024),

	S5K4ECGX_REG_WRITE(0x70000230, 0x0000),

	S5K4ECGX_REG_WRITE(0x7000062C, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000062E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000630, 0x0A3C),
	S5K4ECGX_REG_WRITE(0x70000632, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000634, 0x0D05),
	S5K4ECGX_REG_WRITE(0x70000636, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000638, 0x3408),
	S5K4ECGX_REG_WRITE(0x7000063A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000063C, 0x3408),
	S5K4ECGX_REG_WRITE(0x7000063E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000640, 0x6810),
	S5K4ECGX_REG_WRITE(0x70000642, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000644, 0x8214),
	S5K4ECGX_REG_WRITE(0x70000646, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000648, 0xC350),
	S5K4ECGX_REG_WRITE(0x7000064A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000064C, 0xC350),
	S5K4ECGX_REG_WRITE(0x7000064E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000650, 0xC350),
	S5K4ECGX_REG_WRITE(0x70000652, 0x0000),

	S5K4ECGX_REG_WRITE(0x700003AE, 0x0535),
	S5K4ECGX_REG_WRITE(0x700003B0, 0x029A),

	S5K4ECGX_REG_WRITE(0x70000262, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000266, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000024A, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000264, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000026C, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000023A, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000023C, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Portrait_v1) = {
	S5K4ECGX_REG_WRITE(0x700009F4, 0x4020),
	S5K4ECGX_REG_WRITE(0x70000AAA, 0x4020),
	S5K4ECGX_REG_WRITE(0x70000B60, 0x4020),
	S5K4ECGX_REG_WRITE(0x70000C16, 0x4020),
	S5K4ECGX_REG_WRITE(0x70000CCC, 0x4020),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Nightshot_v1) = {
	S5K4ECGX_REG_WRITE(0x700006AC, 0xFFFF),
	S5K4ECGX_REG_WRITE(0x700006AE, 0x00FF),

	S5K4ECGX_REG_WRITE(0x700005FC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700005FE, 0x0000),

	S5K4ECGX_REG_WRITE(0x70000580, 0xF424),
	S5K4ECGX_REG_WRITE(0x70000582, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000584, 0xF424),
	S5K4ECGX_REG_WRITE(0x70000586, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000588, 0xF424),
	S5K4ECGX_REG_WRITE(0x7000058A, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000058C, 0xF424),
	S5K4ECGX_REG_WRITE(0x7000058E, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000590, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000592, 0x0700),
	S5K4ECGX_REG_WRITE(0x70000594, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000596, 0x2000),

	S5K4ECGX_REG_WRITE(0x700003AE, 0x1388),
	S5K4ECGX_REG_WRITE(0x700003B0, 0x1388),

	S5K4ECGX_REG_WRITE(0x700002BC, 0x09C4),
	S5K4ECGX_REG_WRITE(0x700002BE, 0x014D),

	S5K4ECGX_REG_WRITE(0x70000262, 0x0000),

	S5K4ECGX_REG_WRITE(0x70000266, 0x0001),

	S5K4ECGX_REG_WRITE(0x7000024A, 0x0001),

	S5K4ECGX_REG_WRITE(0x70000264, 0x0001),

	S5K4ECGX_REG_WRITE(0x7000026C, 0x0001),

	S5K4ECGX_REG_WRITE(0x7000023A, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000023C, 0x0001),

	S5K4ECGX_REG_WRITE(0x700009EA, 0x1580),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Landscape_v1) = {
	S5K4ECGX_REG_WRITE(0x70001456, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001458, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000145A, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000145C, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000145E, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001460, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001462, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001464, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001466, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001468, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000146A, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000146C, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000146E, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001470, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001472, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001474, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001476, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001478, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000147A, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000147C, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000147E, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001480, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001482, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001484, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001486, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001488, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000148A, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000148C, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000148E, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001490, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001492, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001494, 0x0101),
	S5K4ECGX_REG_WRITE(0x700009F4, 0x8040),
	S5K4ECGX_REG_WRITE(0x70000AAA, 0x8040),
	S5K4ECGX_REG_WRITE(0x70000B60, 0x8040),
	S5K4ECGX_REG_WRITE(0x70000C16, 0x8040),
	S5K4ECGX_REG_WRITE(0x70000CCC, 0x8040),
	S5K4ECGX_REG_WRITE(0x70000230, 0x0040),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Sports_v1) = {

	S5K4ECGX_REG_WRITE(0x700005FC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700005FE, 0x0000),

	S5K4ECGX_REG_WRITE(0x70000580, 0x3520),
	S5K4ECGX_REG_WRITE(0x70000582, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000584, 0x3520),
	S5K4ECGX_REG_WRITE(0x70000586, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000588, 0x3520),
	S5K4ECGX_REG_WRITE(0x7000058A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000058C, 0x3520),
	S5K4ECGX_REG_WRITE(0x7000058E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000590, 0x0200),
	S5K4ECGX_REG_WRITE(0x70000592, 0x0200),
	S5K4ECGX_REG_WRITE(0x70000594, 0x0200),
	S5K4ECGX_REG_WRITE(0x70000596, 0x0200),

	S5K4ECGX_REG_WRITE(0x70000262, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000266, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000024A, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000264, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000026C, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000023A, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000023C, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Party_Indoor_v1) = {
	S5K4ECGX_REG_WRITE(0x700004E0, 0x065F),
	S5K4ECGX_REG_WRITE(0x700004D0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004D2, 0x0001),

	S5K4ECGX_REG_WRITE(0x700004CA, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004CC, 0x0340),
	S5K4ECGX_REG_WRITE(0x700004CE, 0x0001),
	S5K4ECGX_REG_WRITE(0x700006B6, 0x0100),

	S5K4ECGX_REG_WRITE(0x70004780, 0x0001),

	S5K4ECGX_REG_WRITE(0x70000230, 0x0031),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Beach_Snow_v1) = {
	S5K4ECGX_REG_WRITE(0x700004E0, 0x065F),
	S5K4ECGX_REG_WRITE(0x700004D0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004D2, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004CA, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004CC, 0x00D0),
	S5K4ECGX_REG_WRITE(0x700004CE, 0x0001),
	S5K4ECGX_REG_WRITE(0x700006B6, 0x0100),

	S5K4ECGX_REG_WRITE(0x70004780, 0x0001),

	S5K4ECGX_REG_WRITE(0x70000230, 0x0031),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Sunset_v1) = {
	S5K4ECGX_REG_WRITE(0x70002B7E, 0x0000),

	S5K4ECGX_REG_WRITE(0x700004B4, 0x05E0),
	S5K4ECGX_REG_WRITE(0x700004B6, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004B8, 0x0400),
	S5K4ECGX_REG_WRITE(0x700004BA, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004BC, 0x0520),
	S5K4ECGX_REG_WRITE(0x700004BE, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Duskdawn_v1) = {
	S5K4ECGX_REG_WRITE(0x70002B7E, 0x0000),

	S5K4ECGX_REG_WRITE(0x700004B4, 0x0575),
	S5K4ECGX_REG_WRITE(0x700004B6, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004B8, 0x0400),
	S5K4ECGX_REG_WRITE(0x700004BA, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004BC, 0x0835),
	S5K4ECGX_REG_WRITE(0x700004BE, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Fireworks_v1) = {
	S5K4ECGX_REG_WRITE(0x7000062C, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000062E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000630, 0x1478),
	S5K4ECGX_REG_WRITE(0x70000632, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000634, 0x1A0A),
	S5K4ECGX_REG_WRITE(0x70000636, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000638, 0x6810),
	S5K4ECGX_REG_WRITE(0x7000063A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000063C, 0x6810),
	S5K4ECGX_REG_WRITE(0x7000063E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000640, 0xD020),
	S5K4ECGX_REG_WRITE(0x70000642, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000644, 0x0428),
	S5K4ECGX_REG_WRITE(0x70000646, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000648, 0x1A80),
	S5K4ECGX_REG_WRITE(0x7000064A, 0x0006),
	S5K4ECGX_REG_WRITE(0x7000064C, 0x1A80),
	S5K4ECGX_REG_WRITE(0x7000064E, 0x0006),
	S5K4ECGX_REG_WRITE(0x70000650, 0x1A80),
	S5K4ECGX_REG_WRITE(0x70000652, 0x0006),

	S5K4ECGX_REG_WRITE(0x700003AE, 0x2710),
	S5K4ECGX_REG_WRITE(0x700003B0, 0x2710),

	S5K4ECGX_REG_WRITE(0x70000262, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000266, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000024A, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000264, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000026C, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000023A, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000023C, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Candle_Light_v1) = {
	S5K4ECGX_REG_WRITE(0x700004E0, 0x0777),
	S5K4ECGX_REG_WRITE(0x700004B4, 0x05E0),
	S5K4ECGX_REG_WRITE(0x700004B6, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004B8, 0x0400),
	S5K4ECGX_REG_WRITE(0x700004BA, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004BC, 0x0530),
	S5K4ECGX_REG_WRITE(0x700004BE, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Night_Capture_v1) = {
	S5K4ECGX_REG_WRITE(0x700009EA, 0x0AAA),
	S5K4ECGX_REG_WRITE(0x70000AA0, 0x0AAA),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_AF_Return_Macro_pos_v1) = {
	S5K4ECGX_REG_WRITE(0x700015AC, 0x0018),
	S5K4ECGX_REG_WRITE(0x700015AE, 0x002A),
	S5K4ECGX_REG_WRITE(0x700015B0, 0x0030),
	S5K4ECGX_REG_WRITE(0x700015B2, 0x0036),
	S5K4ECGX_REG_WRITE(0x700015B4, 0x003C),
	S5K4ECGX_REG_WRITE(0x700015B6, 0x0042),
	S5K4ECGX_REG_WRITE(0x700015B8, 0x0048),
	S5K4ECGX_REG_WRITE(0x700015BA, 0x004E),
	S5K4ECGX_REG_WRITE(0x700015BC, 0x0054),
	S5K4ECGX_REG_WRITE(0x700015BE, 0x005A),
	S5K4ECGX_REG_WRITE(0x700015C0, 0x0060),
	S5K4ECGX_REG_WRITE(0x700015C2, 0x0066),
	S5K4ECGX_REG_WRITE(0x700015C4, 0x006C),
	S5K4ECGX_REG_WRITE(0x700015C6, 0x0072),
	S5K4ECGX_REG_WRITE(0x700015C8, 0x0078),
	S5K4ECGX_REG_WRITE(0x700015CA, 0x007E),
	S5K4ECGX_REG_WRITE(0x700015CC, 0x0084),
	S5K4ECGX_REG_WRITE(0x700015CE, 0x008A),
	S5K4ECGX_REG_WRITE(0x700015D0, 0x0090),
	S5K4ECGX_REG_WRITE(0x700015D2, 0x0096),
	S5K4ECGX_REG_WRITE(0x700015D4, 0x009C),
	S5K4ECGX_REG_WRITE(0x700015D6, 0x00A2),
	S5K4ECGX_REG_WRITE(0x700015D8, 0x00A8),
	S5K4ECGX_REG_WRITE(0x700015DA, 0x00AE),
	S5K4ECGX_REG_WRITE(0x700015DC, 0x00B4),
	S5K4ECGX_REG_WRITE(0x700015DE, 0x00BA),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_AF_Normal_mode_v1) = {
	S5K4ECGX_REG_WRITE(0x70000288, 0x002A),
	S5K4ECGX_MDELAY(100),
	S5K4ECGX_REG_WRITE(0x70000286, 0x0004),
	S5K4ECGX_MDELAY(200),
	S5K4ECGX_REG_WRITE(0x7000160C, 0x9002),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_AF_Macro_mode_v1) = {
	S5K4ECGX_REG_WRITE(0x70000288, 0x00D0),
	S5K4ECGX_MDELAY(100),
	S5K4ECGX_REG_WRITE(0x70000286, 0x0004),
	S5K4ECGX_MDELAY(200),
	S5K4ECGX_REG_WRITE(0x7000160C, 0x9042),
	S5K4ECGX_REG_WRITE(0x7000159E, 0x1800),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_AF_Low_Light_Mode_On_v1) = {
	S5K4ECGX_REG_WRITE(0x70001616, 0x0003),

	S5K4ECGX_REG_WRITE(0x700015A4, 0x0902),

	S5K4ECGX_REG_WRITE(0x7000159E, 0x0C00),

	S5K4ECGX_REG_WRITE(0x700015AC, 0x002A),
	S5K4ECGX_REG_WRITE(0x700015AE, 0x0033),
	S5K4ECGX_REG_WRITE(0x700015B0, 0x003C),
	S5K4ECGX_REG_WRITE(0x700015B2, 0x0045),
	S5K4ECGX_REG_WRITE(0x700015B4, 0x004E),
	S5K4ECGX_REG_WRITE(0x700015B6, 0x0057),
	S5K4ECGX_REG_WRITE(0x700015B8, 0x0063),
	S5K4ECGX_REG_WRITE(0x700015BA, 0x006F),
	S5K4ECGX_REG_WRITE(0x700015BC, 0x007B),
	S5K4ECGX_REG_WRITE(0x700015BE, 0x0087),
	S5K4ECGX_REG_WRITE(0x700015C0, 0x0093),
	S5K4ECGX_REG_WRITE(0x700015C2, 0x00A2),
	S5K4ECGX_REG_WRITE(0x700015C4, 0x00B1),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_AF_Low_Light_Mode_Off_v1) = {
	S5K4ECGX_REG_WRITE(0x70001616, 0x0003),

	S5K4ECGX_REG_WRITE(0x700015A4, 0x0902),

	S5K4ECGX_REG_WRITE(0x7000159E, 0x1800),

	S5K4ECGX_REG_WRITE(0x700015AC, 0x0018),
	S5K4ECGX_REG_WRITE(0x700015AE, 0x002A),
	S5K4ECGX_REG_WRITE(0x700015B0, 0x0030),
	S5K4ECGX_REG_WRITE(0x700015B2, 0x0036),
	S5K4ECGX_REG_WRITE(0x700015B4, 0x003C),
	S5K4ECGX_REG_WRITE(0x700015B6, 0x0042),
	S5K4ECGX_REG_WRITE(0x700015B8, 0x0048),
	S5K4ECGX_REG_WRITE(0x700015BA, 0x004E),
	S5K4ECGX_REG_WRITE(0x700015BC, 0x0054),
	S5K4ECGX_REG_WRITE(0x700015BE, 0x005A),
	S5K4ECGX_REG_WRITE(0x700015C0, 0x0060),
	S5K4ECGX_REG_WRITE(0x700015C2, 0x0066),
	S5K4ECGX_REG_WRITE(0x700015C4, 0x006C),
	S5K4ECGX_REG_WRITE(0x700015C6, 0x0072),
	S5K4ECGX_REG_WRITE(0x700015C8, 0x0078),
	S5K4ECGX_REG_WRITE(0x700015CA, 0x007E),
	S5K4ECGX_REG_WRITE(0x700015CC, 0x0084),
	S5K4ECGX_REG_WRITE(0x700015CE, 0x008A),
	S5K4ECGX_REG_WRITE(0x700015D0, 0x0090),
	S5K4ECGX_REG_WRITE(0x700015D2, 0x0096),
	S5K4ECGX_REG_WRITE(0x700015D4, 0x009C),
	S5K4ECGX_REG_WRITE(0x700015D6, 0x00A2),
	S5K4ECGX_REG_WRITE(0x700015D8, 0x00A8),
	S5K4ECGX_REG_WRITE(0x700015DA, 0x00AE),
	S5K4ECGX_REG_WRITE(0x700015DC, 0x00B4),
	S5K4ECGX_REG_WRITE(0x700015DE, 0x00BA),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Single_AF_Start_v1) = {
	S5K4ECGX_REG_WRITE(0x70000286, 0x0005),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Single_AF_Off_1_v1) = {
	S5K4ECGX_REG_WRITE(0x70000288, 0x0000),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Single_AF_Off_2_v1) = {
	S5K4ECGX_REG_WRITE(0x70000286, 0x0004),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Face_Detection_On_v1) = {
	S5K4ECGX_REG_WRITE(0x7000028E, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000290, 0x00E3),
	S5K4ECGX_REG_WRITE(0x70000292, 0x0200),
	S5K4ECGX_REG_WRITE(0x70000294, 0x0238),
	S5K4ECGX_REG_WRITE(0x70000296, 0x01C6),
	S5K4ECGX_REG_WRITE(0x70000298, 0x0166),
	S5K4ECGX_REG_WRITE(0x7000029A, 0x0074),
	S5K4ECGX_REG_WRITE(0x7000029C, 0x0132),
	S5K4ECGX_REG_WRITE(0x7000029E, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Face_Detection_Off_v1) = {
	S5K4ECGX_REG_WRITE(0x7000028E, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000290, 0x00E3),
	S5K4ECGX_REG_WRITE(0x70000292, 0x0200),
	S5K4ECGX_REG_WRITE(0x70000294, 0x0238),
	S5K4ECGX_REG_WRITE(0x70000296, 0x01C6),
	S5K4ECGX_REG_WRITE(0x70000298, 0x0166),
	S5K4ECGX_REG_WRITE(0x7000029A, 0x0074),
	S5K4ECGX_REG_WRITE(0x7000029C, 0x0132),
	S5K4ECGX_REG_WRITE(0x7000029E, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Low_Cap_On_v1) = {
	S5K4ECGX_REG_WRITE(0x700009EA, 0x0D58),
	S5K4ECGX_REG_WRITE(0x70000AA0, 0x0A53),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Low_Cap_Off_v1) = {
	S5K4ECGX_REG_WRITE(0x700009EA, 0x0040),
	S5K4ECGX_REG_WRITE(0x70000AA0, 0x0080),
	S5K4ECGX_REGSET_END
};

/* restores crop settings to full resolution */
S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Reset_Crop_v1) = {
	S5K4ECGX_REG_WRITE(0x7000024C, 0x0A00),
	S5K4ECGX_REG_WRITE(0x7000024E, 0x0780),
	S5K4ECGX_REG_WRITE(0x70000250, 0x0010),
	S5K4ECGX_REG_WRITE(0x70000252, 0x000C),
	S5K4ECGX_REG_WRITE(0x70000254, 0x0A00),
	S5K4ECGX_REG_WRITE(0x70000256, 0x0780),
	S5K4ECGX_REG_WRITE(0x70000258, 0x0010),
	S5K4ECGX_REG_WRITE(0x7000025A, 0x000C),
	S5K4ECGX_REG_WRITE(0x7000048E, 0x0A00),
	S5K4ECGX_REG_WRITE(0x70000490, 0x0780),
	S5K4ECGX_REG_WRITE(0x70000492, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000494, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000496, 0x0A00),
	S5K4ECGX_REG_WRITE(0x70000498, 0x0780),
	S5K4ECGX_REG_WRITE(0x7000049A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000049C, 0x0000),

	S5K4ECGX_REG_WRITE(0x7000025E, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000260, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Capture_Start_v1) = {
	S5K4ECGX_REG_WRITE(0x70001A00, 0x185C),
	S5K4ECGX_REG_WRITE(0x70001A02, 0x7000),
	S5K4ECGX_REG_WRITE(0x7000023E, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000024A, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000240, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Preview_Return_v1) = {
	S5K4ECGX_REG_WRITE(0x700005C4, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A00, 0x192E),
	S5K4ECGX_REG_WRITE(0x70001A02, 0x7000),
	S5K4ECGX_REG_WRITE(0x70000952, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000023E, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000024A, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000240, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Flash_init_v1) = {
	S5K4ECGX_REG_WRITE(0x700017DC, 0x0001),	/* one frame AE */

	S5K4ECGX_REG_WRITE(0x700017AE, 0x0270),	/* AWB R point */

	S5K4ECGX_REG_WRITE(0x700017B0, 0x0210),	/* AWB B point */

	S5K4ECGX_REG_WRITE(0x700017E2, 0x0001),	/* Flash AE tune start */
	S5K4ECGX_REG_WRITE(0x700017E4, 0x0030),	/* 0x100 for Rin output */
	S5K4ECGX_REG_WRITE(0x700017E6, 0x0040),
	S5K4ECGX_REG_WRITE(0x700017E8, 0x0050),
	S5K4ECGX_REG_WRITE(0x700017EA, 0x0060),
	S5K4ECGX_REG_WRITE(0x700017EC, 0x0070),
	S5K4ECGX_REG_WRITE(0x700017EE, 0x0080),
	S5K4ECGX_REG_WRITE(0x700017F0, 0x0090),
	S5K4ECGX_REG_WRITE(0x700017F2, 0x00A0),
	S5K4ECGX_REG_WRITE(0x700017F4, 0x0050),	/* 0x100 for Rout output-20 */
	S5K4ECGX_REG_WRITE(0x700017F6, 0x0014),
	S5K4ECGX_REG_WRITE(0x700017F8, 0x000A),
	S5K4ECGX_REG_WRITE(0x700017FA, 0x0008),
	S5K4ECGX_REG_WRITE(0x700017FC, 0x0005),
	S5K4ECGX_REG_WRITE(0x700017FE, 0x0004),
	S5K4ECGX_REG_WRITE(0x70001800, 0x0002),
	S5K4ECGX_REG_WRITE(0x70001802, 0x0001),

	S5K4ECGX_REG_WRITE(0x70001824, 0x0100),	/* 0x100 for NB output */
	S5K4ECGX_REG_WRITE(0x70001826, 0x0100),
	S5K4ECGX_REG_WRITE(0x70001828, 0x0100),
	S5K4ECGX_REG_WRITE(0x7000182A, 0x0100),
	S5K4ECGX_REG_WRITE(0x7000182C, 0x0100),
	S5K4ECGX_REG_WRITE(0x7000182E, 0x0100),
	S5K4ECGX_REG_WRITE(0x70001830, 0x0100),
	S5K4ECGX_REG_WRITE(0x70001832, 0x0100),

	S5K4ECGX_REG_WRITE(0x700017B4, 0x0100),
	S5K4ECGX_REG_WRITE(0x700017B6, 0x00A0),
	S5K4ECGX_REG_WRITE(0x700017B8, 0x0080),
	S5K4ECGX_REG_WRITE(0x700017BA, 0x0020),
	S5K4ECGX_REG_WRITE(0x700017BC, 0x0001),

	S5K4ECGX_REG_WRITE(0x700017C8, 0x0025),
	S5K4ECGX_REG_WRITE(0x700017CA, 0x0030),
	S5K4ECGX_REG_WRITE(0x700017CC, 0x0050),
	S5K4ECGX_REG_WRITE(0x700017CE, 0x0070),
	S5K4ECGX_REG_WRITE(0x700017D0, 0x0080),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Pre_Flash_Start_v1) = {
	S5K4ECGX_REG_WRITE(0x7000057C, 0x0000),

	S5K4ECGX_REG_WRITE(0x70001F06, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Pre_Flash_End_v1) = {
	S5K4ECGX_REG_WRITE(0x7000057C, 0x0002),

	S5K4ECGX_REG_WRITE(0x70001F08, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Flash_Start_v1) = {
	S5K4ECGX_REG_WRITE(0x700017A8, 0x0001),

	S5K4ECGX_REG_WRITE(0x7000047E, 0x0002),

	S5K4ECGX_REG_WRITE(0x70001448, 0x0027),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Flash_End_v1) = {
	S5K4ECGX_REG_WRITE(0x700017A8, 0x0000),

	S5K4ECGX_REG_WRITE(0x7000047E, 0x0000),

	S5K4ECGX_REG_WRITE(0x70001448, 0x003C),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_5M_Capture_v1) = {
	S5K4ECGX_REG_WRITE(0x70000392, 0x0A00),
	S5K4ECGX_REG_WRITE(0x70000394, 0x0780),
	S5K4ECGX_REG_WRITE(0x70000396, 0x0009),

	S5K4ECGX_REG_WRITE(0x700003AC, 0x0002),

	S5K4ECGX_REG_WRITE(0x700003AA, 0x0000),

	S5K4ECGX_REG_WRITE(0x7000026C, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_3M_Capture_v1) = {
	S5K4ECGX_REG_WRITE(0x70000392, 0x0800),
	S5K4ECGX_REG_WRITE(0x70000394, 0x0600),
	S5K4ECGX_REG_WRITE(0x70000396, 0x0009),

	S5K4ECGX_REG_WRITE(0x700003AC, 0x0002),

	S5K4ECGX_REG_WRITE(0x700003AA, 0x0000),

	S5K4ECGX_REG_WRITE(0x7000024A, 0x0001),

	S5K4ECGX_REG_WRITE(0x7000026C, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_2M_Capture_v1) = {
	S5K4ECGX_REG_WRITE(0x70000392, 0x0640),
	S5K4ECGX_REG_WRITE(0x70000394, 0x04B0),
	S5K4ECGX_REG_WRITE(0x70000396, 0x0009),

	S5K4ECGX_REG_WRITE(0x700003AC, 0x0002),

	S5K4ECGX_REG_WRITE(0x700003AA, 0x0000),

	S5K4ECGX_REG_WRITE(0x7000024A, 0x0001),

	S5K4ECGX_REG_WRITE(0x7000026C, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_1M_Capture_v1) = {
	S5K4ECGX_REG_WRITE(0x70000392, 0x0500),
	S5K4ECGX_REG_WRITE(0x70000394, 0x03C0),
	S5K4ECGX_REG_WRITE(0x70000396, 0x0009),

	S5K4ECGX_REG_WRITE(0x700003AC, 0x0002),

	S5K4ECGX_REG_WRITE(0x700003AA, 0x0000),

	S5K4ECGX_REG_WRITE(0x7000024A, 0x0001),

	S5K4ECGX_REG_WRITE(0x7000026C, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_VGA_Capture_v1) = {
	S5K4ECGX_REG_WRITE(0x70000392, 0x0280),
	S5K4ECGX_REG_WRITE(0x70000394, 0x01E0),
	S5K4ECGX_REG_WRITE(0x70000396, 0x0009),

	S5K4ECGX_REG_WRITE(0x700003AC, 0x0002),

	S5K4ECGX_REG_WRITE(0x700003AA, 0x0000),

	S5K4ECGX_REG_WRITE(0x7000024A, 0x0001),

	S5K4ECGX_REG_WRITE(0x7000026C, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_720_Preview_v1) = {
	S5K4ECGX_REG_WRITE(0x700002A0, 0x02D0),
	S5K4ECGX_REG_WRITE(0x700002A2, 0x01E0),
	S5K4ECGX_REG_WRITE(0x700002A4, 0x0005),
	S5K4ECGX_REG_WRITE(0x700002AE, 0x0052),
	S5K4ECGX_REG_WRITE(0x700002B8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002BA, 0x0001),
	S5K4ECGX_REG_WRITE(0x700002BC, 0x029A),
	S5K4ECGX_REG_WRITE(0x700002BE, 0x014D),
	S5K4ECGX_REG_WRITE(0x700002CA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002CC, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000262, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000266, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000024A, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000264, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_640_Preview_v1) = {
	S5K4ECGX_REG_WRITE(0x700002A0, 0x0280),
	S5K4ECGX_REG_WRITE(0x700002A2, 0x01E0),
	S5K4ECGX_REG_WRITE(0x700002A4, 0x0005),
	S5K4ECGX_REG_WRITE(0x700002AE, 0x0052),
	S5K4ECGX_REG_WRITE(0x700002B8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002BA, 0x0001),
	S5K4ECGX_REG_WRITE(0x700002BC, 0x029A),
	S5K4ECGX_REG_WRITE(0x700002BE, 0x014D),
	S5K4ECGX_REG_WRITE(0x700002CA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002CC, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000262, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000266, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000024A, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000264, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_352_Preview_v1) = {
	S5K4ECGX_REG_WRITE(0x700002A0, 0x0160),
	S5K4ECGX_REG_WRITE(0x700002A2, 0x0120),
	S5K4ECGX_REG_WRITE(0x700002A4, 0x0005),
	S5K4ECGX_REG_WRITE(0x700002AE, 0x0052),
	S5K4ECGX_REG_WRITE(0x700002B8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002BA, 0x0001),
	S5K4ECGX_REG_WRITE(0x700002BC, 0x029A),
	S5K4ECGX_REG_WRITE(0x700002BE, 0x014D),
	S5K4ECGX_REG_WRITE(0x700002CA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002CC, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000262, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000266, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000024A, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000264, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_176_Preview_v1) = {
	S5K4ECGX_REG_WRITE(0x700002A0, 0x00B0),
	S5K4ECGX_REG_WRITE(0x700002A2, 0x0090),
	S5K4ECGX_REG_WRITE(0x700002A4, 0x0005),
	S5K4ECGX_REG_WRITE(0x700002AE, 0x0052),
	S5K4ECGX_REG_WRITE(0x700002B8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002BA, 0x0001),
	S5K4ECGX_REG_WRITE(0x700002BC, 0x029A),
	S5K4ECGX_REG_WRITE(0x700002BE, 0x014D),
	S5K4ECGX_REG_WRITE(0x700002CA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002CC, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000262, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000266, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000024A, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000264, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_AE_AWB_Lock_On_v1) = {
	S5K4ECGX_REG_WRITE(0x70002B76, 0x0000),
	S5K4ECGX_REG_WRITE(0x70002B7E, 0x0000),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_AE_AWB_Lock_Off_v1) = {
	S5K4ECGX_REG_WRITE(0x70002B76, 0x0001),
	S5K4ECGX_REG_WRITE(0x70002B7E, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Get_AE_Stable_Status_v1) = {
	S5K4ECGX_REG_READ(0x70002B8C),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Get_Light_Level_v1) = {
	S5K4ECGX_REG_READ(0x70002B30),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_get_1st_af_search_status_v1) = {
	S5K4ECGX_REG_READ(0x70002E06),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_get_2nd_af_search_status_v1) = {
	S5K4ECGX_REG_READ(0x70002167),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_get_capture_status_v1) = {
	S5K4ECGX_REG_READ(0x70001F02),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_get_esd_status_v1) = {
	S5K4ECGX_CMD_WRITE(0xFCFC, 0xD000),
	S5K4ECGX_REG_READ(0xD0000060),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_get_iso_reg_v1) = {
	S5K4ECGX_REG_READ(0x70002ADC),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_get_shutterspeed_reg_v1) = {
	S5K4ECGX_REG_READ(0x70002AD8),
	S5K4ECGX_REGSET_END
};

#undef S5K4ECGX_DEFINE_REGSET
#undef S5K4ECGX_REGSET_END
#undef S5K4ECGX_CMD_WRITE
#undef S5K4ECGX_REG_WRITE
#undef S5K4ECGX_REG_READ
#undef S5K4ECGX_MDELAY
#undef _SWAB16
#undef _DUMMY

#endif

#if !defined(__S5K4ECGX_V1_0_DEFINE_REGSET__)
#define __S5K4ECGX_V1_0_DEFINE_REGSET__
#elif !defined(__S5K4ECGX_V1_0_DEFINE_REGSET_DATA__)
#define __S5K4ECGX_V1_0_DEFINE_REGSET_DATA__
#endif
