/* drivers/media/video/s5k4ecgx_regs_1_1.h
 *
 * Driver for s5k4ecgx (5MP Camera) from SEC(LSI), firmware EVT1.1
 *
 * Copyright (C) 2010, SAMSUNG ELECTRONICS
 * Copyright (C) 2012, Insignal Co,. Ltd
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 */

#include "s5k4ecgx_regset.h"

#if !defined(__S5K4ECGX_V1_1_DEFINE_REGSET__)

#define S5K4ECGX_DEFINE_REGSET(NAME) static const struct s5k4ecgx_reg NAME[]
#define S5K4ECGX_REGSET_END \
	{ .type = S5K4ECGX_REGTYPE_END, .data_len = 0 }
#define S5K4ECGX_CMD_WRITE(ADDR, DATA) \
	{ .type = S5K4ECGX_REGTYPE_CMD, .data_len = 4 }
#define S5K4ECGX_REG_WRITE(ADDR, DATA) \
	{ .type = S5K4ECGX_REGTYPE_WRITE, .data_len = 2, { .addr = ADDR } }
#define S5K4ECGX_REG_READ(ADDR) \
	{ .type = S5K4ECGX_REGTYPE_READ, .data_len = 1, { .addr = ADDR } }
#define S5K4ECGX_MDELAY(MSEC) \
	{ .type = S5K4ECGX_REGTYPE_DELAY, .data_len = 1, { .msec = MSEC } }

#elif !defined(__S5K4ECGX_V1_1_DEFINE_REGSET_DATA__)

#define _SWAB16(X) ((X >> 8) & 0xFF), (X & 0xFF)
#define _DUMMY 0
#define S5K4ECGX_DEFINE_REGSET(NAME) static const u8 NAME##_data[]
#define S5K4ECGX_REGSET_END
#define S5K4ECGX_CMD_WRITE(ADDR, DATA) _SWAB16(ADDR), _SWAB16(DATA)
#define S5K4ECGX_REG_WRITE(ADDR, DATA) _SWAB16(DATA)
#define S5K4ECGX_REG_READ(ADDR) _DUMMY
#define S5K4ECGX_MDELAY(MSEC) _DUMMY

#endif

#if !defined(__S5K4ECGX_V1_1_DEFINE_REGSET__) \
	|| !defined(__S5K4ECGX_V1_1_DEFINE_REGSET_DATA__)
S5K4ECGX_DEFINE_REGSET(s5k4ecgx_init_reg) = {
	S5K4ECGX_CMD_WRITE(0xFCFC, 0xD000),
	S5K4ECGX_CMD_WRITE(0x0010, 0x0001),
	S5K4ECGX_CMD_WRITE(0x1030, 0x0000),
	S5K4ECGX_CMD_WRITE(0x0014, 0x0001),

	S5K4ECGX_MDELAY(10),

	/* Drive current setting */
	S5K4ECGX_REG_WRITE(0xD0001082, 0x0155),	/* d0_d4_cd10, d0_d4_cd10 9:0 */
	S5K4ECGX_REG_WRITE(0xD0001084, 0x0155),	/* d5_d9_cd10, d5_d9_cd10 9:0 */
	S5K4ECGX_REG_WRITE(0xD0001086, 0x0055),	/* gpio_cd10, gpio_cd10 */
	S5K4ECGX_REG_WRITE(0xD0001088, 0x0555),	/* clks_output_cd10, clks_output_cd10 11:0 */
	S5K4ECGX_REG_WRITE(0xD000100E, 0x0000),	/* pclk_delay_r */

	S5K4ECGX_REG_WRITE(0xD000007A, 0x0000),

	/* ISP FE(ADLC) */
	S5K4ECGX_REG_WRITE(0xD000E406, 0x0092),
	S5K4ECGX_REG_WRITE(0xD000E410, 0x3804),
	S5K4ECGX_REG_WRITE(0xD000E41A, 0x0010),	/* 101022 ADD adlcptune_total */
	S5K4ECGX_REG_WRITE(0xD000E420, 0x0003),
	S5K4ECGX_REG_WRITE(0xD000E422, 0x0060),
	S5K4ECGX_REG_WRITE(0xD000E42E, 0x0004),
	S5K4ECGX_REG_WRITE(0xD000F400, 0x5A3C),
	S5K4ECGX_REG_WRITE(0xD000F402, 0x0023),
	S5K4ECGX_REG_WRITE(0xD000F404, 0x8080),
	S5K4ECGX_REG_WRITE(0xD000F406, 0x03AF),
	S5K4ECGX_REG_WRITE(0xD000F408, 0x000A),
	S5K4ECGX_REG_WRITE(0xD000F40A, 0xAA54),
	S5K4ECGX_REG_WRITE(0xD000F40C, 0x0040),
	S5K4ECGX_REG_WRITE(0xD000F40E, 0x464E),
	S5K4ECGX_REG_WRITE(0xD000F410, 0x0240),
	S5K4ECGX_REG_WRITE(0xD000F412, 0x0240),
	S5K4ECGX_REG_WRITE(0xD000F414, 0x0040),
	S5K4ECGX_REG_WRITE(0xD000F416, 0x1000),
	S5K4ECGX_REG_WRITE(0xD000F418, 0x555C),
	S5K4ECGX_REG_WRITE(0xD000F41A, 0xD000),
	S5K4ECGX_REG_WRITE(0xD000F41C, 0x0010),
	S5K4ECGX_REG_WRITE(0xD000F41E, 0x0202),
	S5K4ECGX_REG_WRITE(0xD000F420, 0x0401),
	S5K4ECGX_REG_WRITE(0xD000F422, 0x0022),
	S5K4ECGX_REG_WRITE(0xD000F424, 0x0088),
	S5K4ECGX_REG_WRITE(0xD000F426, 0x009F),
	S5K4ECGX_REG_WRITE(0xD000F428, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F42A, 0x1800),
	S5K4ECGX_REG_WRITE(0xD000F42C, 0x0088),
	S5K4ECGX_REG_WRITE(0xD000F42E, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F430, 0x2428),
	S5K4ECGX_REG_WRITE(0xD000F432, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F434, 0x03EE),
	S5K4ECGX_REG_WRITE(0xD000F436, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F438, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F43A, 0x0000),
	S5K4ECGX_REG_WRITE(0xD000F552, 0x0708),
	S5K4ECGX_REG_WRITE(0xD000F554, 0x080C),

	/* For subsampling Size */
	S5K4ECGX_REG_WRITE(0x700018BC, 0x0004),
	S5K4ECGX_REG_WRITE(0x700018BE, 0x05B6),
	S5K4ECGX_REG_WRITE(0x700018C0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018C2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018C4, 0x0001),
	S5K4ECGX_REG_WRITE(0x700018C6, 0x05BA),
	S5K4ECGX_REG_WRITE(0x700018C8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018CA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018CC, 0x0007),
	S5K4ECGX_REG_WRITE(0x700018CE, 0x05BA),
	S5K4ECGX_REG_WRITE(0x700018D0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018D2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018D4, 0x01F4),
	S5K4ECGX_REG_WRITE(0x700018D6, 0x024E),
	S5K4ECGX_REG_WRITE(0x700018D8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018DA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018DC, 0x01F4),
	S5K4ECGX_REG_WRITE(0x700018DE, 0x05B6),
	S5K4ECGX_REG_WRITE(0x700018E0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018E2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018E4, 0x01F4),
	S5K4ECGX_REG_WRITE(0x700018E6, 0x05BA),
	S5K4ECGX_REG_WRITE(0x700018E8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018EA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018EC, 0x01F4),
	S5K4ECGX_REG_WRITE(0x700018EE, 0x024F),
	S5K4ECGX_REG_WRITE(0x700018F0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018F2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018F4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018F6, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018F8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018FA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700018FC, 0x0075),
	S5K4ECGX_REG_WRITE(0x700018FE, 0x00CF),
	S5K4ECGX_REG_WRITE(0x70001900, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001902, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001904, 0x0075),
	S5K4ECGX_REG_WRITE(0x70001906, 0x00D6),
	S5K4ECGX_REG_WRITE(0x70001908, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000190A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000190C, 0x0004),
	S5K4ECGX_REG_WRITE(0x7000190E, 0x01F4),
	S5K4ECGX_REG_WRITE(0x70001910, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001912, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001914, 0x00F0),
	S5K4ECGX_REG_WRITE(0x70001916, 0x01F4),
	S5K4ECGX_REG_WRITE(0x70001918, 0x029E),
	S5K4ECGX_REG_WRITE(0x7000191A, 0x05B2),
	S5K4ECGX_REG_WRITE(0x7000191C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000191E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001920, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001922, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001924, 0x01F8),
	S5K4ECGX_REG_WRITE(0x70001926, 0x0228),
	S5K4ECGX_REG_WRITE(0x70001928, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000192A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000192C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000192E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001930, 0x0208),
	S5K4ECGX_REG_WRITE(0x70001932, 0x0238),
	S5K4ECGX_REG_WRITE(0x70001934, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001936, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001938, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000193A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000193C, 0x0218),
	S5K4ECGX_REG_WRITE(0x7000193E, 0x0238),
	S5K4ECGX_REG_WRITE(0x70001940, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001942, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001944, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001946, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001948, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000194A, 0x0009),
	S5K4ECGX_REG_WRITE(0x7000194C, 0x00DE),
	S5K4ECGX_REG_WRITE(0x7000194E, 0x05C0),
	S5K4ECGX_REG_WRITE(0x70001950, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001952, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001954, 0x00DF),
	S5K4ECGX_REG_WRITE(0x70001956, 0x00E4),
	S5K4ECGX_REG_WRITE(0x70001958, 0x01F8),
	S5K4ECGX_REG_WRITE(0x7000195A, 0x01FD),
	S5K4ECGX_REG_WRITE(0x7000195C, 0x05B6),
	S5K4ECGX_REG_WRITE(0x7000195E, 0x05BB),
	S5K4ECGX_REG_WRITE(0x70001960, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001962, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001964, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001966, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001968, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000196A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000196C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000196E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001970, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001972, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001974, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001976, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001978, 0x01F8),
	S5K4ECGX_REG_WRITE(0x7000197A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000197C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000197E, 0x0077),
	S5K4ECGX_REG_WRITE(0x70001980, 0x007E),
	S5K4ECGX_REG_WRITE(0x70001982, 0x024F),
	S5K4ECGX_REG_WRITE(0x70001984, 0x025E),
	S5K4ECGX_REG_WRITE(0x70001986, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001988, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000198A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000198C, 0x0000),

	/* For Capture */
	S5K4ECGX_REG_WRITE(0x7000198E, 0x0004),
	S5K4ECGX_REG_WRITE(0x70001990, 0x09D1),
	S5K4ECGX_REG_WRITE(0x70001992, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001994, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001996, 0x0001),
	S5K4ECGX_REG_WRITE(0x70001998, 0x09D5),
	S5K4ECGX_REG_WRITE(0x7000199A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000199C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000199E, 0x0008),
	S5K4ECGX_REG_WRITE(0x700019A0, 0x09D5),
	S5K4ECGX_REG_WRITE(0x700019A2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019A4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019A6, 0x02AA),
	S5K4ECGX_REG_WRITE(0x700019A8, 0x0326),
	S5K4ECGX_REG_WRITE(0x700019AA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019AC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019AE, 0x02AA),
	S5K4ECGX_REG_WRITE(0x700019B0, 0x09D1),
	S5K4ECGX_REG_WRITE(0x700019B2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019B4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019B6, 0x02AA),
	S5K4ECGX_REG_WRITE(0x700019B8, 0x09D5),
	S5K4ECGX_REG_WRITE(0x700019BA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019BC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019BE, 0x02AA),
	S5K4ECGX_REG_WRITE(0x700019C0, 0x0327),
	S5K4ECGX_REG_WRITE(0x700019C2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019C4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019C6, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019C8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019CA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019CC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019CE, 0x0008),
	S5K4ECGX_REG_WRITE(0x700019D0, 0x0084),
	S5K4ECGX_REG_WRITE(0x700019D2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019D4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019D6, 0x0008),
	S5K4ECGX_REG_WRITE(0x700019D8, 0x008D),
	S5K4ECGX_REG_WRITE(0x700019DA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019DC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019DE, 0x0008),
	S5K4ECGX_REG_WRITE(0x700019E0, 0x02AA),
	S5K4ECGX_REG_WRITE(0x700019E2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019E4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019E6, 0x00AA),
	S5K4ECGX_REG_WRITE(0x700019E8, 0x02AA),
	S5K4ECGX_REG_WRITE(0x700019EA, 0x03AD),
	S5K4ECGX_REG_WRITE(0x700019EC, 0x09CD),
	S5K4ECGX_REG_WRITE(0x700019EE, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019F0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019F2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019F4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019F6, 0x02AE),
	S5K4ECGX_REG_WRITE(0x700019F8, 0x02DE),
	S5K4ECGX_REG_WRITE(0x700019FA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019FC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700019FE, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A00, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A02, 0x02BE),
	S5K4ECGX_REG_WRITE(0x70001A04, 0x02EE),
	S5K4ECGX_REG_WRITE(0x70001A06, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A08, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A0A, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A0C, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A0E, 0x02CE),
	S5K4ECGX_REG_WRITE(0x70001A10, 0x02EE),
	S5K4ECGX_REG_WRITE(0x70001A12, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A14, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A16, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A18, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A1A, 0x0001),
	S5K4ECGX_REG_WRITE(0x70001A1C, 0x0009),
	S5K4ECGX_REG_WRITE(0x70001A1E, 0x0095),
	S5K4ECGX_REG_WRITE(0x70001A20, 0x09DB),
	S5K4ECGX_REG_WRITE(0x70001A22, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A24, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A26, 0x0096),
	S5K4ECGX_REG_WRITE(0x70001A28, 0x009B),
	S5K4ECGX_REG_WRITE(0x70001A2A, 0x02AE),
	S5K4ECGX_REG_WRITE(0x70001A2C, 0x02B3),
	S5K4ECGX_REG_WRITE(0x70001A2E, 0x09D1),
	S5K4ECGX_REG_WRITE(0x70001A30, 0x09D6),
	S5K4ECGX_REG_WRITE(0x70001A32, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A34, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A36, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A38, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A3A, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A3C, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A3E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A40, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A42, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A44, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A46, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A48, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A4A, 0x02AE),
	S5K4ECGX_REG_WRITE(0x70001A4C, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A4E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A50, 0x0009),
	S5K4ECGX_REG_WRITE(0x70001A52, 0x0010),
	S5K4ECGX_REG_WRITE(0x70001A54, 0x0327),
	S5K4ECGX_REG_WRITE(0x70001A56, 0x0336),
	S5K4ECGX_REG_WRITE(0x70001A58, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A5A, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A5C, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001A5E, 0x0000),

	S5K4ECGX_REG_WRITE(0x70001AF8, 0x5A3C),	/* #senHal_TuneStr_AngTuneData1_2_D000F400
						   register at subsampling*/

	S5K4ECGX_REG_WRITE(0x70001896, 0x0002),	/* #senHal_SamplingType	0002 03EE: PLA setting */
	S5K4ECGX_REG_WRITE(0x70001898, 0x0000),	/* #senHal_SamplingMode 0 : 2 PLA / 1 : 4PLA */
	S5K4ECGX_REG_WRITE(0x7000189A, 0x0003),	/* #senHal_PLAOption
						   [0] VPLA enable , [1] HPLA enable*/

	S5K4ECGX_REG_WRITE(0x7000189E, 0x0FB0),	/* #senHal_ExpMinPixels */

	S5K4ECGX_REG_WRITE(0x700018AC, 0x0060),	/* #senHal_uAddColsBin */
	S5K4ECGX_REG_WRITE(0x700018AE, 0x0060),	/* #senHal_uAddColsNoBin */
	S5K4ECGX_REG_WRITE(0x700018B0, 0x05C0),	/* #senHal_uMinColsBin */
	S5K4ECGX_REG_WRITE(0x700018B2, 0x05C0),	/* #senHal_uMinColsNoBin */

	S5K4ECGX_REG_WRITE(0x70001AEA, 0x8080),	/* #senHal_SubF404Tune */
	S5K4ECGX_REG_WRITE(0x70001AEC, 0x0080),	/* #senHal_FullF404Tune */
	S5K4ECGX_REG_WRITE(0x70001AE0, 0x0000),	/* #senHal_bSenAAC */

	S5K4ECGX_REG_WRITE(0x70001A72, 0x0000),	/* #senHal_bSRX	SRX off */
	S5K4ECGX_REG_WRITE(0x700018A2, 0x0004),	/* #senHal_NExpLinesCheckFine,
						   extend Forbidden area line*/
	S5K4ECGX_REG_WRITE(0x70001A6A, 0x009A),	/* #senHal_usForbiddenRightOfs,
						   extend right Forbidden area line*/
	S5K4ECGX_REG_WRITE(0x7000385E, 0x024C),	/* #Mon_Sen_uExpPixelsOfs */

	S5K4ECGX_REG_WRITE(0x70000EE6, 0x0000),	/* #setot_bUseDigitalHbin */
	S5K4ECGX_REG_WRITE(0x70001B2A, 0x0300),	/* #senHal_TuneStr2_usAngTuneGainTh  2   70001B2A */
	S5K4ECGX_REG_WRITE(0x70001B2C, 0x00D6),	/* #senHal_TuneStr2_AngTuneF4CA_0_   2   70001B2C */
	S5K4ECGX_REG_WRITE(0x70001B2E, 0x008D),	/* #senHal_TuneStr2_AngTuneF4CA_1_   2   70001B2E */
	S5K4ECGX_REG_WRITE(0x70001B30, 0x00CF),	/* #senHal_TuneStr2_AngTuneF4C2_0_   2   70001B30 */
	S5K4ECGX_REG_WRITE(0x70001B32, 0x0084),	/* #senHal_TuneStr2_AngTuneF4C2_1_   2   70001B32 */

	/* OTP setting */

	S5K4ECGX_REG_WRITE(0x70000722, 0x0100),	/* #skl_OTP_usWaitTime,
						   This register should be positioned in
						   front of D0001000*/
	S5K4ECGX_REG_WRITE(0x70000726, 0x0001),	/* #skl_bUseOTPfunc, This is OTP on/off function */
	S5K4ECGX_REG_WRITE(0x700008D6, 0x0001),	/* #ash_bUseOTPData */
	S5K4ECGX_REG_WRITE(0x7000146E, 0x0000),	/* #awbb_otp_disable */
	S5K4ECGX_REG_WRITE(0x700008DC, 0x0001),	/* #ash_bUseGasAlphaOTP */

	/* TnP setting */
	/* Start of Patch data */
	S5K4ECGX_REG_WRITE(0x70003AF8, 0xB570),	/* 70003AF8 */
	S5K4ECGX_REG_WRITE(0x70003AFA, 0x4B36),	/* 70003AFA */
	S5K4ECGX_REG_WRITE(0x70003AFC, 0x216F),	/* 70003AFC */
	S5K4ECGX_REG_WRITE(0x70003AFE, 0x4836),	/* 70003AFE */
	S5K4ECGX_REG_WRITE(0x70003B00, 0x8C80),	/* 70003B00 */
	S5K4ECGX_REG_WRITE(0x70003B02, 0x2200),	/* 70003B02 */
	S5K4ECGX_REG_WRITE(0x70003B04, 0xC008),	/* 70003B04 */
	S5K4ECGX_REG_WRITE(0x70003B06, 0x6001),	/* 70003B06 */
	S5K4ECGX_REG_WRITE(0x70003B08, 0x4934),	/* 70003B08 */
	S5K4ECGX_REG_WRITE(0x70003B0A, 0x4835),	/* 70003B0A */
	S5K4ECGX_REG_WRITE(0x70003B0C, 0x2501),	/* 70003B0C */
	S5K4ECGX_REG_WRITE(0x70003B0E, 0xF000),	/* 70003B0E */
	S5K4ECGX_REG_WRITE(0x70003B10, 0xFB77),	/* 70003B10 */
	S5K4ECGX_REG_WRITE(0x70003B12, 0x4934),	/* 70003B12 */
	S5K4ECGX_REG_WRITE(0x70003B14, 0x4834),	/* 70003B14 */
	S5K4ECGX_REG_WRITE(0x70003B16, 0x2402),	/* 70003B16 */
	S5K4ECGX_REG_WRITE(0x70003B18, 0x002A),	/* 70003B18 */
	S5K4ECGX_REG_WRITE(0x70003B1A, 0xF000),	/* 70003B1A */
	S5K4ECGX_REG_WRITE(0x70003B1C, 0xFB71),	/* 70003B1C */
	S5K4ECGX_REG_WRITE(0x70003B1E, 0x4833),	/* 70003B1E */
	S5K4ECGX_REG_WRITE(0x70003B20, 0x0221),	/* 70003B20 */
	S5K4ECGX_REG_WRITE(0x70003B22, 0x8001),	/* 70003B22 */
	S5K4ECGX_REG_WRITE(0x70003B24, 0x2100),	/* 70003B24 */
	S5K4ECGX_REG_WRITE(0x70003B26, 0x8041),	/* 70003B26 */
	S5K4ECGX_REG_WRITE(0x70003B28, 0x4931),	/* 70003B28 */
	S5K4ECGX_REG_WRITE(0x70003B2A, 0x4832),	/* 70003B2A */
	S5K4ECGX_REG_WRITE(0x70003B2C, 0x6041),	/* 70003B2C */
	S5K4ECGX_REG_WRITE(0x70003B2E, 0x4932),	/* 70003B2E */
	S5K4ECGX_REG_WRITE(0x70003B30, 0x4832),	/* 70003B30 */
	S5K4ECGX_REG_WRITE(0x70003B32, 0x0022),	/* 70003B32 */
	S5K4ECGX_REG_WRITE(0x70003B34, 0x2503),	/* 70003B34 */
	S5K4ECGX_REG_WRITE(0x70003B36, 0xF000),	/* 70003B36 */
	S5K4ECGX_REG_WRITE(0x70003B38, 0xFB63),	/* 70003B38 */
	S5K4ECGX_REG_WRITE(0x70003B3A, 0x482E),	/* 70003B3A */
	S5K4ECGX_REG_WRITE(0x70003B3C, 0x4930),	/* 70003B3C */
	S5K4ECGX_REG_WRITE(0x70003B3E, 0x30C0),	/* 70003B3E */
	S5K4ECGX_REG_WRITE(0x70003B40, 0x63C1),	/* 70003B40 */
	S5K4ECGX_REG_WRITE(0x70003B42, 0x492C),	/* 70003B42 */
	S5K4ECGX_REG_WRITE(0x70003B44, 0x482F),	/* 70003B44 */
	S5K4ECGX_REG_WRITE(0x70003B46, 0x3980),	/* 70003B46 */
	S5K4ECGX_REG_WRITE(0x70003B48, 0x6408),	/* 70003B48 */
	S5K4ECGX_REG_WRITE(0x70003B4A, 0x482F),	/* 70003B4A */
	S5K4ECGX_REG_WRITE(0x70003B4C, 0x492F),	/* 70003B4C */
	S5K4ECGX_REG_WRITE(0x70003B4E, 0x6388),	/* 70003B4E */
	S5K4ECGX_REG_WRITE(0x70003B50, 0x492F),	/* 70003B50 */
	S5K4ECGX_REG_WRITE(0x70003B52, 0x4830),	/* 70003B52 */
	S5K4ECGX_REG_WRITE(0x70003B54, 0x2404),	/* 70003B54 */
	S5K4ECGX_REG_WRITE(0x70003B56, 0x002A),	/* 70003B56 */
	S5K4ECGX_REG_WRITE(0x70003B58, 0xF000),	/* 70003B58 */
	S5K4ECGX_REG_WRITE(0x70003B5A, 0xFB52),	/* 70003B5A */
	S5K4ECGX_REG_WRITE(0x70003B5C, 0x492E),	/* 70003B5C */
	S5K4ECGX_REG_WRITE(0x70003B5E, 0x482F),	/* 70003B5E */
	S5K4ECGX_REG_WRITE(0x70003B60, 0x0022),	/* 70003B60 */
	S5K4ECGX_REG_WRITE(0x70003B62, 0x2505),	/* 70003B62 */
	S5K4ECGX_REG_WRITE(0x70003B64, 0xF000),	/* 70003B64 */
	S5K4ECGX_REG_WRITE(0x70003B66, 0xF876),	/* 70003B66 */
	S5K4ECGX_REG_WRITE(0x70003B68, 0x482C),	/* 70003B68 */
	S5K4ECGX_REG_WRITE(0x70003B6A, 0x492D),	/* 70003B6A */
	S5K4ECGX_REG_WRITE(0x70003B6C, 0x2406),	/* 70003B6C */
	S5K4ECGX_REG_WRITE(0x70003B6E, 0x002A),	/* 70003B6E */
	S5K4ECGX_REG_WRITE(0x70003B70, 0x1D80),	/* 70003B70 */
	S5K4ECGX_REG_WRITE(0x70003B72, 0xF000),	/* 70003B72 */
	S5K4ECGX_REG_WRITE(0x70003B74, 0xF86F),	/* 70003B74 */
	S5K4ECGX_REG_WRITE(0x70003B76, 0x4829),	/* 70003B76 */
	S5K4ECGX_REG_WRITE(0x70003B78, 0x492A),	/* 70003B78 */
	S5K4ECGX_REG_WRITE(0x70003B7A, 0x0022),	/* 70003B7A */
	S5K4ECGX_REG_WRITE(0x70003B7C, 0x2507),	/* 70003B7C */
	S5K4ECGX_REG_WRITE(0x70003B7E, 0x300C),	/* 70003B7E */
	S5K4ECGX_REG_WRITE(0x70003B80, 0xF000),	/* 70003B80 */
	S5K4ECGX_REG_WRITE(0x70003B82, 0xF868),	/* 70003B82 */
	S5K4ECGX_REG_WRITE(0x70003B84, 0x4825),	/* 70003B84 */
	S5K4ECGX_REG_WRITE(0x70003B86, 0x4928),	/* 70003B86 */
	S5K4ECGX_REG_WRITE(0x70003B88, 0x2408),	/* 70003B88 */
	S5K4ECGX_REG_WRITE(0x70003B8A, 0x002A),	/* 70003B8A */
	S5K4ECGX_REG_WRITE(0x70003B8C, 0x3010),	/* 70003B8C */
	S5K4ECGX_REG_WRITE(0x70003B8E, 0xF000),	/* 70003B8E */
	S5K4ECGX_REG_WRITE(0x70003B90, 0xF861),	/* 70003B90 */
	S5K4ECGX_REG_WRITE(0x70003B92, 0x4926),	/* 70003B92 */
	S5K4ECGX_REG_WRITE(0x70003B94, 0x4826),	/* 70003B94 */
	S5K4ECGX_REG_WRITE(0x70003B96, 0x0022),	/* 70003B96 */
	S5K4ECGX_REG_WRITE(0x70003B98, 0x2509),	/* 70003B98 */
	S5K4ECGX_REG_WRITE(0x70003B9A, 0xF000),	/* 70003B9A */
	S5K4ECGX_REG_WRITE(0x70003B9C, 0xFB31),	/* 70003B9C */
	S5K4ECGX_REG_WRITE(0x70003B9E, 0x4925),	/* 70003B9E */
	S5K4ECGX_REG_WRITE(0x70003BA0, 0x4825),	/* 70003BA0 */
	S5K4ECGX_REG_WRITE(0x70003BA2, 0x240A),	/* 70003BA2 */
	S5K4ECGX_REG_WRITE(0x70003BA4, 0x002A),	/* 70003BA4 */
	S5K4ECGX_REG_WRITE(0x70003BA6, 0xF000),	/* 70003BA6 */
	S5K4ECGX_REG_WRITE(0x70003BA8, 0xFB2B),	/* 70003BA8 */
	S5K4ECGX_REG_WRITE(0x70003BAA, 0x4924),	/* 70003BAA */
	S5K4ECGX_REG_WRITE(0x70003BAC, 0x4824),	/* 70003BAC */
	S5K4ECGX_REG_WRITE(0x70003BAE, 0x250B),	/* 70003BAE */
	S5K4ECGX_REG_WRITE(0x70003BB0, 0x0022),	/* 70003BB0 */
	S5K4ECGX_REG_WRITE(0x70003BB2, 0xF000),	/* 70003BB2 */
	S5K4ECGX_REG_WRITE(0x70003BB4, 0xFB25),	/* 70003BB4 */
	S5K4ECGX_REG_WRITE(0x70003BB6, 0x4923),	/* 70003BB6 */
	S5K4ECGX_REG_WRITE(0x70003BB8, 0x4823),	/* 70003BB8 */
	S5K4ECGX_REG_WRITE(0x70003BBA, 0x002A),	/* 70003BBA */
	S5K4ECGX_REG_WRITE(0x70003BBC, 0x240C),	/* 70003BBC */
	S5K4ECGX_REG_WRITE(0x70003BBE, 0xF000),	/* 70003BBE */
	S5K4ECGX_REG_WRITE(0x70003BC0, 0xFB1F),	/* 70003BC0 */
	S5K4ECGX_REG_WRITE(0x70003BC2, 0x4922),	/* 70003BC2 */
	S5K4ECGX_REG_WRITE(0x70003BC4, 0x4822),	/* 70003BC4 */
	S5K4ECGX_REG_WRITE(0x70003BC6, 0x0022),	/* 70003BC6 */
	S5K4ECGX_REG_WRITE(0x70003BC8, 0xF000),	/* 70003BC8 */
	S5K4ECGX_REG_WRITE(0x70003BCA, 0xFB1A),	/* 70003BCA */
	S5K4ECGX_REG_WRITE(0x70003BCC, 0xBC70),	/* 70003BCC */
	S5K4ECGX_REG_WRITE(0x70003BCE, 0xBC08),	/* 70003BCE */
	S5K4ECGX_REG_WRITE(0x70003BD0, 0x4718),	/* 70003BD0 */
	S5K4ECGX_REG_WRITE(0x70003BD2, 0x0000),	/* 70003BD2 */
	S5K4ECGX_REG_WRITE(0x70003BD4, 0x0185),	/* 70003BD4 */
	S5K4ECGX_REG_WRITE(0x70003BD6, 0x4EC2),	/* 70003BD6 */
	S5K4ECGX_REG_WRITE(0x70003BD8, 0x1F6C),	/* 70003BD8 */
	S5K4ECGX_REG_WRITE(0x70003BDA, 0x7000),	/* 70003BDA */
	S5K4ECGX_REG_WRITE(0x70003BDC, 0x3C6D),	/* 70003BDC */
	S5K4ECGX_REG_WRITE(0x70003BDE, 0x7000),	/* 70003BDE */
	S5K4ECGX_REG_WRITE(0x70003BE0, 0xE38B),	/* 70003BE0 */
	S5K4ECGX_REG_WRITE(0x70003BE2, 0x0000),	/* 70003BE2 */
	S5K4ECGX_REG_WRITE(0x70003BE4, 0x3CA5),	/* 70003BE4 */
	S5K4ECGX_REG_WRITE(0x70003BE6, 0x7000),	/* 70003BE6 */
	S5K4ECGX_REG_WRITE(0x70003BE8, 0xC3B1),	/* 70003BE8 */
	S5K4ECGX_REG_WRITE(0x70003BEA, 0x0000),	/* 70003BEA */
	S5K4ECGX_REG_WRITE(0x70003BEC, 0x4780),	/* 70003BEC */
	S5K4ECGX_REG_WRITE(0x70003BEE, 0x7000),	/* 70003BEE */
	S5K4ECGX_REG_WRITE(0x70003BF0, 0x3D03),	/* 70003BF0 */
	S5K4ECGX_REG_WRITE(0x70003BF2, 0x7000),	/* 70003BF2 */
	S5K4ECGX_REG_WRITE(0x70003BF4, 0x0080),	/* 70003BF4 */
	S5K4ECGX_REG_WRITE(0x70003BF6, 0x7000),	/* 70003BF6 */
	S5K4ECGX_REG_WRITE(0x70003BF8, 0x3D3F),	/* 70003BF8 */
	S5K4ECGX_REG_WRITE(0x70003BFA, 0x7000),	/* 70003BFA */
	S5K4ECGX_REG_WRITE(0x70003BFC, 0xB49D),	/* 70003BFC */
	S5K4ECGX_REG_WRITE(0x70003BFE, 0x0000),	/* 70003BFE */
	S5K4ECGX_REG_WRITE(0x70003C00, 0x3DEB),	/* 70003C00 */
	S5K4ECGX_REG_WRITE(0x70003C02, 0x7000),	/* 70003C02 */
	S5K4ECGX_REG_WRITE(0x70003C04, 0x3D9F),	/* 70003C04 */
	S5K4ECGX_REG_WRITE(0x70003C06, 0x7000),	/* 70003C06 */
	S5K4ECGX_REG_WRITE(0x70003C08, 0xFFFF),	/* 70003C08 */
	S5K4ECGX_REG_WRITE(0x70003C0A, 0x00FF),	/* 70003C0A */
	S5K4ECGX_REG_WRITE(0x70003C0C, 0x17E0),	/* 70003C0C */
	S5K4ECGX_REG_WRITE(0x70003C0E, 0x7000),	/* 70003C0E */
	S5K4ECGX_REG_WRITE(0x70003C10, 0x3F67),	/* 70003C10 */
	S5K4ECGX_REG_WRITE(0x70003C12, 0x7000),	/* 70003C12 */
	S5K4ECGX_REG_WRITE(0x70003C14, 0x053D),	/* 70003C14 */
	S5K4ECGX_REG_WRITE(0x70003C16, 0x0000),	/* 70003C16 */
	S5K4ECGX_REG_WRITE(0x70003C18, 0x0000),	/* 70003C18 */
	S5K4ECGX_REG_WRITE(0x70003C1A, 0x0A89),	/* 70003C1A */
	S5K4ECGX_REG_WRITE(0x70003C1C, 0x6CD2),	/* 70003C1C */
	S5K4ECGX_REG_WRITE(0x70003C1E, 0x0000),	/* 70003C1E */
	S5K4ECGX_REG_WRITE(0x70003C20, 0x02C9),	/* 70003C20 */
	S5K4ECGX_REG_WRITE(0x70003C22, 0x0000),	/* 70003C22 */
	S5K4ECGX_REG_WRITE(0x70003C24, 0x0000),	/* 70003C24 */
	S5K4ECGX_REG_WRITE(0x70003C26, 0x0A9A),	/* 70003C26 */
	S5K4ECGX_REG_WRITE(0x70003C28, 0x0000),	/* 70003C28 */
	S5K4ECGX_REG_WRITE(0x70003C2A, 0x02D2),	/* 70003C2A */
	S5K4ECGX_REG_WRITE(0x70003C2C, 0x3FB5),	/* 70003C2C */
	S5K4ECGX_REG_WRITE(0x70003C2E, 0x7000),	/* 70003C2E */
	S5K4ECGX_REG_WRITE(0x70003C30, 0x9E65),	/* 70003C30 */
	S5K4ECGX_REG_WRITE(0x70003C32, 0x0000),	/* 70003C32 */
	S5K4ECGX_REG_WRITE(0x70003C34, 0x4029),	/* 70003C34 */
	S5K4ECGX_REG_WRITE(0x70003C36, 0x7000),	/* 70003C36 */
	S5K4ECGX_REG_WRITE(0x70003C38, 0x7C49),	/* 70003C38 */
	S5K4ECGX_REG_WRITE(0x70003C3A, 0x0000),	/* 70003C3A */
	S5K4ECGX_REG_WRITE(0x70003C3C, 0x409D),	/* 70003C3C */
	S5K4ECGX_REG_WRITE(0x70003C3E, 0x7000),	/* 70003C3E */
	S5K4ECGX_REG_WRITE(0x70003C40, 0x7C63),	/* 70003C40 */
	S5K4ECGX_REG_WRITE(0x70003C42, 0x0000),	/* 70003C42 */
	S5K4ECGX_REG_WRITE(0x70003C44, 0x40B9),	/* 70003C44 */
	S5K4ECGX_REG_WRITE(0x70003C46, 0x7000),	/* 70003C46 */
	S5K4ECGX_REG_WRITE(0x70003C48, 0x8F01),	/* 70003C48 */
	S5K4ECGX_REG_WRITE(0x70003C4A, 0x0000),	/* 70003C4A */
	S5K4ECGX_REG_WRITE(0x70003C4C, 0x415B),	/* 70003C4C */
	S5K4ECGX_REG_WRITE(0x70003C4E, 0x7000),	/* 70003C4E */
	S5K4ECGX_REG_WRITE(0x70003C50, 0x7F3F),	/* 70003C50 */
	S5K4ECGX_REG_WRITE(0x70003C52, 0x0000),	/* 70003C52 */
	S5K4ECGX_REG_WRITE(0x70003C54, 0xB570),	/* 70003C54 */
	S5K4ECGX_REG_WRITE(0x70003C56, 0x000C),	/* 70003C56 */
	S5K4ECGX_REG_WRITE(0x70003C58, 0x0015),	/* 70003C58 */
	S5K4ECGX_REG_WRITE(0x70003C5A, 0x0029),	/* 70003C5A */
	S5K4ECGX_REG_WRITE(0x70003C5C, 0xF000),	/* 70003C5C */
	S5K4ECGX_REG_WRITE(0x70003C5E, 0xFAD8),	/* 70003C5E */
	S5K4ECGX_REG_WRITE(0x70003C60, 0x49F8),	/* 70003C60 */
	S5K4ECGX_REG_WRITE(0x70003C62, 0x00A8),	/* 70003C62 */
	S5K4ECGX_REG_WRITE(0x70003C64, 0x500C),	/* 70003C64 */
	S5K4ECGX_REG_WRITE(0x70003C66, 0xBC70),	/* 70003C66 */
	S5K4ECGX_REG_WRITE(0x70003C68, 0xBC08),	/* 70003C68 */
	S5K4ECGX_REG_WRITE(0x70003C6A, 0x4718),	/* 70003C6A */
	S5K4ECGX_REG_WRITE(0x70003C6C, 0x6808),	/* 70003C6C */
	S5K4ECGX_REG_WRITE(0x70003C6E, 0x0400),	/* 70003C6E */
	S5K4ECGX_REG_WRITE(0x70003C70, 0x0C00),	/* 70003C70 */
	S5K4ECGX_REG_WRITE(0x70003C72, 0x6849),	/* 70003C72 */
	S5K4ECGX_REG_WRITE(0x70003C74, 0x0409),	/* 70003C74 */
	S5K4ECGX_REG_WRITE(0x70003C76, 0x0C09),	/* 70003C76 */
	S5K4ECGX_REG_WRITE(0x70003C78, 0x4AF3),	/* 70003C78 */
	S5K4ECGX_REG_WRITE(0x70003C7A, 0x8992),	/* 70003C7A */
	S5K4ECGX_REG_WRITE(0x70003C7C, 0x2A00),	/* 70003C7C */
	S5K4ECGX_REG_WRITE(0x70003C7E, 0xD00D),	/* 70003C7E */
	S5K4ECGX_REG_WRITE(0x70003C80, 0x2300),	/* 70003C80 */
	S5K4ECGX_REG_WRITE(0x70003C82, 0x1A89),	/* 70003C82 */
	S5K4ECGX_REG_WRITE(0x70003C84, 0xD400),	/* 70003C84 */
	S5K4ECGX_REG_WRITE(0x70003C86, 0x000B),	/* 70003C86 */
	S5K4ECGX_REG_WRITE(0x70003C88, 0x0419),	/* 70003C88 */
	S5K4ECGX_REG_WRITE(0x70003C8A, 0x0C09),	/* 70003C8A */
	S5K4ECGX_REG_WRITE(0x70003C8C, 0x23FF),	/* 70003C8C */
	S5K4ECGX_REG_WRITE(0x70003C8E, 0x33C1),	/* 70003C8E */
	S5K4ECGX_REG_WRITE(0x70003C90, 0x1810),	/* 70003C90 */
	S5K4ECGX_REG_WRITE(0x70003C92, 0x4298),	/* 70003C92 */
	S5K4ECGX_REG_WRITE(0x70003C94, 0xD800),	/* 70003C94 */
	S5K4ECGX_REG_WRITE(0x70003C96, 0x0003),	/* 70003C96 */
	S5K4ECGX_REG_WRITE(0x70003C98, 0x0418),	/* 70003C98 */
	S5K4ECGX_REG_WRITE(0x70003C9A, 0x0C00),	/* 70003C9A */
	S5K4ECGX_REG_WRITE(0x70003C9C, 0x4AEB),	/* 70003C9C */
	S5K4ECGX_REG_WRITE(0x70003C9E, 0x8150),	/* 70003C9E */
	S5K4ECGX_REG_WRITE(0x70003CA0, 0x8191),	/* 70003CA0 */
	S5K4ECGX_REG_WRITE(0x70003CA2, 0x4770),	/* 70003CA2 */
	S5K4ECGX_REG_WRITE(0x70003CA4, 0xB5F3),	/* 70003CA4 */
	S5K4ECGX_REG_WRITE(0x70003CA6, 0x0004),	/* 70003CA6 */
	S5K4ECGX_REG_WRITE(0x70003CA8, 0xB081),	/* 70003CA8 */
	S5K4ECGX_REG_WRITE(0x70003CAA, 0x9802),	/* 70003CAA */
	S5K4ECGX_REG_WRITE(0x70003CAC, 0x6800),	/* 70003CAC */
	S5K4ECGX_REG_WRITE(0x70003CAE, 0x0600),	/* 70003CAE */
	S5K4ECGX_REG_WRITE(0x70003CB0, 0x0E00),	/* 70003CB0 */
	S5K4ECGX_REG_WRITE(0x70003CB2, 0x2201),	/* 70003CB2 */
	S5K4ECGX_REG_WRITE(0x70003CB4, 0x0015),	/* 70003CB4 */
	S5K4ECGX_REG_WRITE(0x70003CB6, 0x0021),	/* 70003CB6 */
	S5K4ECGX_REG_WRITE(0x70003CB8, 0x3910),	/* 70003CB8 */
	S5K4ECGX_REG_WRITE(0x70003CBA, 0x408A),	/* 70003CBA */
	S5K4ECGX_REG_WRITE(0x70003CBC, 0x40A5),	/* 70003CBC */
	S5K4ECGX_REG_WRITE(0x70003CBE, 0x4FE4),	/* 70003CBE */
	S5K4ECGX_REG_WRITE(0x70003CC0, 0x0016),	/* 70003CC0 */
	S5K4ECGX_REG_WRITE(0x70003CC2, 0x2C10),	/* 70003CC2 */
	S5K4ECGX_REG_WRITE(0x70003CC4, 0xDA03),	/* 70003CC4 */
	S5K4ECGX_REG_WRITE(0x70003CC6, 0x8839),	/* 70003CC6 */
	S5K4ECGX_REG_WRITE(0x70003CC8, 0x43A9),	/* 70003CC8 */
	S5K4ECGX_REG_WRITE(0x70003CCA, 0x8039),	/* 70003CCA */
	S5K4ECGX_REG_WRITE(0x70003CCC, 0xE002),	/* 70003CCC */
	S5K4ECGX_REG_WRITE(0x70003CCE, 0x8879),	/* 70003CCE */
	S5K4ECGX_REG_WRITE(0x70003CD0, 0x43B1),	/* 70003CD0 */
	S5K4ECGX_REG_WRITE(0x70003CD2, 0x8079),	/* 70003CD2 */
	S5K4ECGX_REG_WRITE(0x70003CD4, 0xF000),	/* 70003CD4 */
	S5K4ECGX_REG_WRITE(0x70003CD6, 0xFAA4),	/* 70003CD6 */
	S5K4ECGX_REG_WRITE(0x70003CD8, 0x2C10),	/* 70003CD8 */
	S5K4ECGX_REG_WRITE(0x70003CDA, 0xDA03),	/* 70003CDA */
	S5K4ECGX_REG_WRITE(0x70003CDC, 0x8839),	/* 70003CDC */
	S5K4ECGX_REG_WRITE(0x70003CDE, 0x4329),	/* 70003CDE */
	S5K4ECGX_REG_WRITE(0x70003CE0, 0x8039),	/* 70003CE0 */
	S5K4ECGX_REG_WRITE(0x70003CE2, 0xE002),	/* 70003CE2 */
	S5K4ECGX_REG_WRITE(0x70003CE4, 0x8879),	/* 70003CE4 */
	S5K4ECGX_REG_WRITE(0x70003CE6, 0x4331),	/* 70003CE6 */
	S5K4ECGX_REG_WRITE(0x70003CE8, 0x8079),	/* 70003CE8 */
	S5K4ECGX_REG_WRITE(0x70003CEA, 0x49DA),	/* 70003CEA */
	S5K4ECGX_REG_WRITE(0x70003CEC, 0x8809),	/* 70003CEC */
	S5K4ECGX_REG_WRITE(0x70003CEE, 0x2900),	/* 70003CEE */
	S5K4ECGX_REG_WRITE(0x70003CF0, 0xD102),	/* 70003CF0 */
	S5K4ECGX_REG_WRITE(0x70003CF2, 0xF000),	/* 70003CF2 */
	S5K4ECGX_REG_WRITE(0x70003CF4, 0xFA9D),	/* 70003CF4 */
	S5K4ECGX_REG_WRITE(0x70003CF6, 0x2000),	/* 70003CF6 */
	S5K4ECGX_REG_WRITE(0x70003CF8, 0x9902),	/* 70003CF8 */
	S5K4ECGX_REG_WRITE(0x70003CFA, 0x6008),	/* 70003CFA */
	S5K4ECGX_REG_WRITE(0x70003CFC, 0xBCFE),	/* 70003CFC */
	S5K4ECGX_REG_WRITE(0x70003CFE, 0xBC08),	/* 70003CFE */
	S5K4ECGX_REG_WRITE(0x70003D00, 0x4718),	/* 70003D00 */
	S5K4ECGX_REG_WRITE(0x70003D02, 0xB538),	/* 70003D02 */
	S5K4ECGX_REG_WRITE(0x70003D04, 0x9C04),	/* 70003D04 */
	S5K4ECGX_REG_WRITE(0x70003D06, 0x0015),	/* 70003D06 */
	S5K4ECGX_REG_WRITE(0x70003D08, 0x002A),	/* 70003D08 */
	S5K4ECGX_REG_WRITE(0x70003D0A, 0x9400),	/* 70003D0A */
	S5K4ECGX_REG_WRITE(0x70003D0C, 0xF000),	/* 70003D0C */
	S5K4ECGX_REG_WRITE(0x70003D0E, 0xFA98),	/* 70003D0E */
	S5K4ECGX_REG_WRITE(0x70003D10, 0x4AD1),	/* 70003D10 */
	S5K4ECGX_REG_WRITE(0x70003D12, 0x8811),	/* 70003D12 */
	S5K4ECGX_REG_WRITE(0x70003D14, 0x2900),	/* 70003D14 */
	S5K4ECGX_REG_WRITE(0x70003D16, 0xD00F),	/* 70003D16 */
	S5K4ECGX_REG_WRITE(0x70003D18, 0x8820),	/* 70003D18 */
	S5K4ECGX_REG_WRITE(0x70003D1A, 0x4281),	/* 70003D1A */
	S5K4ECGX_REG_WRITE(0x70003D1C, 0xD20C),	/* 70003D1C */
	S5K4ECGX_REG_WRITE(0x70003D1E, 0x8861),	/* 70003D1E */
	S5K4ECGX_REG_WRITE(0x70003D20, 0x8853),	/* 70003D20 */
	S5K4ECGX_REG_WRITE(0x70003D22, 0x4299),	/* 70003D22 */
	S5K4ECGX_REG_WRITE(0x70003D24, 0xD200),	/* 70003D24 */
	S5K4ECGX_REG_WRITE(0x70003D26, 0x1E40),	/* 70003D26 */
	S5K4ECGX_REG_WRITE(0x70003D28, 0x0400),	/* 70003D28 */
	S5K4ECGX_REG_WRITE(0x70003D2A, 0x0C00),	/* 70003D2A */
	S5K4ECGX_REG_WRITE(0x70003D2C, 0x8020),	/* 70003D2C */
	S5K4ECGX_REG_WRITE(0x70003D2E, 0x8851),	/* 70003D2E */
	S5K4ECGX_REG_WRITE(0x70003D30, 0x8061),	/* 70003D30 */
	S5K4ECGX_REG_WRITE(0x70003D32, 0x4368),	/* 70003D32 */
	S5K4ECGX_REG_WRITE(0x70003D34, 0x1840),	/* 70003D34 */
	S5K4ECGX_REG_WRITE(0x70003D36, 0x6060),	/* 70003D36 */
	S5K4ECGX_REG_WRITE(0x70003D38, 0xBC38),	/* 70003D38 */
	S5K4ECGX_REG_WRITE(0x70003D3A, 0xBC08),	/* 70003D3A */
	S5K4ECGX_REG_WRITE(0x70003D3C, 0x4718),	/* 70003D3C */
	S5K4ECGX_REG_WRITE(0x70003D3E, 0xB5F8),	/* 70003D3E */
	S5K4ECGX_REG_WRITE(0x70003D40, 0x0004),	/* 70003D40 */
	S5K4ECGX_REG_WRITE(0x70003D42, 0x6808),	/* 70003D42 */
	S5K4ECGX_REG_WRITE(0x70003D44, 0x0400),	/* 70003D44 */
	S5K4ECGX_REG_WRITE(0x70003D46, 0x0C00),	/* 70003D46 */
	S5K4ECGX_REG_WRITE(0x70003D48, 0x2201),	/* 70003D48 */
	S5K4ECGX_REG_WRITE(0x70003D4A, 0x0015),	/* 70003D4A */
	S5K4ECGX_REG_WRITE(0x70003D4C, 0x0021),	/* 70003D4C */
	S5K4ECGX_REG_WRITE(0x70003D4E, 0x3910),	/* 70003D4E */
	S5K4ECGX_REG_WRITE(0x70003D50, 0x408A),	/* 70003D50 */
	S5K4ECGX_REG_WRITE(0x70003D52, 0x40A5),	/* 70003D52 */
	S5K4ECGX_REG_WRITE(0x70003D54, 0x4FBE),	/* 70003D54 */
	S5K4ECGX_REG_WRITE(0x70003D56, 0x0016),	/* 70003D56 */
	S5K4ECGX_REG_WRITE(0x70003D58, 0x2C10),	/* 70003D58 */
	S5K4ECGX_REG_WRITE(0x70003D5A, 0xDA03),	/* 70003D5A */
	S5K4ECGX_REG_WRITE(0x70003D5C, 0x8839),	/* 70003D5C */
	S5K4ECGX_REG_WRITE(0x70003D5E, 0x43A9),	/* 70003D5E */
	S5K4ECGX_REG_WRITE(0x70003D60, 0x8039),	/* 70003D60 */
	S5K4ECGX_REG_WRITE(0x70003D62, 0xE002),	/* 70003D62 */
	S5K4ECGX_REG_WRITE(0x70003D64, 0x8879),	/* 70003D64 */
	S5K4ECGX_REG_WRITE(0x70003D66, 0x43B1),	/* 70003D66 */
	S5K4ECGX_REG_WRITE(0x70003D68, 0x8079),	/* 70003D68 */
	S5K4ECGX_REG_WRITE(0x70003D6A, 0xF000),	/* 70003D6A */
	S5K4ECGX_REG_WRITE(0x70003D6C, 0xFA71),	/* 70003D6C */
	S5K4ECGX_REG_WRITE(0x70003D6E, 0x2C10),	/* 70003D6E */
	S5K4ECGX_REG_WRITE(0x70003D70, 0xDA03),	/* 70003D70 */
	S5K4ECGX_REG_WRITE(0x70003D72, 0x8838),	/* 70003D72 */
	S5K4ECGX_REG_WRITE(0x70003D74, 0x4328),	/* 70003D74 */
	S5K4ECGX_REG_WRITE(0x70003D76, 0x8038),	/* 70003D76 */
	S5K4ECGX_REG_WRITE(0x70003D78, 0xE002),	/* 70003D78 */
	S5K4ECGX_REG_WRITE(0x70003D7A, 0x8878),	/* 70003D7A */
	S5K4ECGX_REG_WRITE(0x70003D7C, 0x4330),	/* 70003D7C */
	S5K4ECGX_REG_WRITE(0x70003D7E, 0x8078),	/* 70003D7E */
	S5K4ECGX_REG_WRITE(0x70003D80, 0x48B6),	/* 70003D80 */
	S5K4ECGX_REG_WRITE(0x70003D82, 0x8800),	/* 70003D82 */
	S5K4ECGX_REG_WRITE(0x70003D84, 0x0400),	/* 70003D84 */
	S5K4ECGX_REG_WRITE(0x70003D86, 0xD507),	/* 70003D86 */
	S5K4ECGX_REG_WRITE(0x70003D88, 0x4BB5),	/* 70003D88 */
	S5K4ECGX_REG_WRITE(0x70003D8A, 0x7819),	/* 70003D8A */
	S5K4ECGX_REG_WRITE(0x70003D8C, 0x4AB5),	/* 70003D8C */
	S5K4ECGX_REG_WRITE(0x70003D8E, 0x7810),	/* 70003D8E */
	S5K4ECGX_REG_WRITE(0x70003D90, 0x7018),	/* 70003D90 */
	S5K4ECGX_REG_WRITE(0x70003D92, 0x7011),	/* 70003D92 */
	S5K4ECGX_REG_WRITE(0x70003D94, 0x49B4),	/* 70003D94 */
	S5K4ECGX_REG_WRITE(0x70003D96, 0x8188),	/* 70003D96 */
	S5K4ECGX_REG_WRITE(0x70003D98, 0xBCF8),	/* 70003D98 */
	S5K4ECGX_REG_WRITE(0x70003D9A, 0xBC08),	/* 70003D9A */
	S5K4ECGX_REG_WRITE(0x70003D9C, 0x4718),	/* 70003D9C */
	S5K4ECGX_REG_WRITE(0x70003D9E, 0xB538),	/* 70003D9E */
	S5K4ECGX_REG_WRITE(0x70003DA0, 0x48B2),	/* 70003DA0 */
	S5K4ECGX_REG_WRITE(0x70003DA2, 0x4669),	/* 70003DA2 */
	S5K4ECGX_REG_WRITE(0x70003DA4, 0xF000),	/* 70003DA4 */
	S5K4ECGX_REG_WRITE(0x70003DA6, 0xFA5C),	/* 70003DA6 */
	S5K4ECGX_REG_WRITE(0x70003DA8, 0x48B1),	/* 70003DA8 */
	S5K4ECGX_REG_WRITE(0x70003DAA, 0x49B0),	/* 70003DAA */
	S5K4ECGX_REG_WRITE(0x70003DAC, 0x69C2),	/* 70003DAC */
	S5K4ECGX_REG_WRITE(0x70003DAE, 0x2400),	/* 70003DAE */
	S5K4ECGX_REG_WRITE(0x70003DB0, 0x31A8),	/* 70003DB0 */
	S5K4ECGX_REG_WRITE(0x70003DB2, 0x2A00),	/* 70003DB2 */
	S5K4ECGX_REG_WRITE(0x70003DB4, 0xD008),	/* 70003DB4 */
	S5K4ECGX_REG_WRITE(0x70003DB6, 0x61C4),	/* 70003DB6 */
	S5K4ECGX_REG_WRITE(0x70003DB8, 0x684A),	/* 70003DB8 */
	S5K4ECGX_REG_WRITE(0x70003DBA, 0x6242),	/* 70003DBA */
	S5K4ECGX_REG_WRITE(0x70003DBC, 0x6282),	/* 70003DBC */
	S5K4ECGX_REG_WRITE(0x70003DBE, 0x466B),	/* 70003DBE */
	S5K4ECGX_REG_WRITE(0x70003DC0, 0x881A),	/* 70003DC0 */
	S5K4ECGX_REG_WRITE(0x70003DC2, 0x6302),	/* 70003DC2 */
	S5K4ECGX_REG_WRITE(0x70003DC4, 0x885A),	/* 70003DC4 */
	S5K4ECGX_REG_WRITE(0x70003DC6, 0x6342),	/* 70003DC6 */
	S5K4ECGX_REG_WRITE(0x70003DC8, 0x6A02),	/* 70003DC8 */
	S5K4ECGX_REG_WRITE(0x70003DCA, 0x2A00),	/* 70003DCA */
	S5K4ECGX_REG_WRITE(0x70003DCC, 0xD00A),	/* 70003DCC */
	S5K4ECGX_REG_WRITE(0x70003DCE, 0x6204),	/* 70003DCE */
	S5K4ECGX_REG_WRITE(0x70003DD0, 0x6849),	/* 70003DD0 */
	S5K4ECGX_REG_WRITE(0x70003DD2, 0x6281),	/* 70003DD2 */
	S5K4ECGX_REG_WRITE(0x70003DD4, 0x466B),	/* 70003DD4 */
	S5K4ECGX_REG_WRITE(0x70003DD6, 0x8819),	/* 70003DD6 */
	S5K4ECGX_REG_WRITE(0x70003DD8, 0x6301),	/* 70003DD8 */
	S5K4ECGX_REG_WRITE(0x70003DDA, 0x8859),	/* 70003DDA */
	S5K4ECGX_REG_WRITE(0x70003DDC, 0x6341),	/* 70003DDC */
	S5K4ECGX_REG_WRITE(0x70003DDE, 0x49A5),	/* 70003DDE */
	S5K4ECGX_REG_WRITE(0x70003DE0, 0x88C9),	/* 70003DE0 */
	S5K4ECGX_REG_WRITE(0x70003DE2, 0x63C1),	/* 70003DE2 */
	S5K4ECGX_REG_WRITE(0x70003DE4, 0xF000),	/* 70003DE4 */
	S5K4ECGX_REG_WRITE(0x70003DE6, 0xFA44),	/* 70003DE6 */
	S5K4ECGX_REG_WRITE(0x70003DE8, 0xE7A6),	/* 70003DE8 */
	S5K4ECGX_REG_WRITE(0x70003DEA, 0xB5F0),	/* 70003DEA */
	S5K4ECGX_REG_WRITE(0x70003DEC, 0xB08B),	/* 70003DEC */
	S5K4ECGX_REG_WRITE(0x70003DEE, 0x20FF),	/* 70003DEE */
	S5K4ECGX_REG_WRITE(0x70003DF0, 0x1C40),	/* 70003DF0 */
	S5K4ECGX_REG_WRITE(0x70003DF2, 0x49A1),	/* 70003DF2 */
	S5K4ECGX_REG_WRITE(0x70003DF4, 0x89CC),	/* 70003DF4 */
	S5K4ECGX_REG_WRITE(0x70003DF6, 0x4E9E),	/* 70003DF6 */
	S5K4ECGX_REG_WRITE(0x70003DF8, 0x6AB1),	/* 70003DF8 */
	S5K4ECGX_REG_WRITE(0x70003DFA, 0x4284),	/* 70003DFA */
	S5K4ECGX_REG_WRITE(0x70003DFC, 0xD101),	/* 70003DFC */
	S5K4ECGX_REG_WRITE(0x70003DFE, 0x489F),	/* 70003DFE */
	S5K4ECGX_REG_WRITE(0x70003E00, 0x6081),	/* 70003E00 */
	S5K4ECGX_REG_WRITE(0x70003E02, 0x6A70),	/* 70003E02 */
	S5K4ECGX_REG_WRITE(0x70003E04, 0x0200),	/* 70003E04 */
	S5K4ECGX_REG_WRITE(0x70003E06, 0xF000),	/* 70003E06 */
	S5K4ECGX_REG_WRITE(0x70003E08, 0xFA3B),	/* 70003E08 */
	S5K4ECGX_REG_WRITE(0x70003E0A, 0x0400),	/* 70003E0A */
	S5K4ECGX_REG_WRITE(0x70003E0C, 0x0C00),	/* 70003E0C */
	S5K4ECGX_REG_WRITE(0x70003E0E, 0x4A96),	/* 70003E0E */
	S5K4ECGX_REG_WRITE(0x70003E10, 0x8A11),	/* 70003E10 */
	S5K4ECGX_REG_WRITE(0x70003E12, 0x9109),	/* 70003E12 */
	S5K4ECGX_REG_WRITE(0x70003E14, 0x2101),	/* 70003E14 */
	S5K4ECGX_REG_WRITE(0x70003E16, 0x0349),	/* 70003E16 */
	S5K4ECGX_REG_WRITE(0x70003E18, 0x4288),	/* 70003E18 */
	S5K4ECGX_REG_WRITE(0x70003E1A, 0xD200),	/* 70003E1A */
	S5K4ECGX_REG_WRITE(0x70003E1C, 0x0001),	/* 70003E1C */
	S5K4ECGX_REG_WRITE(0x70003E1E, 0x4A92),	/* 70003E1E */
	S5K4ECGX_REG_WRITE(0x70003E20, 0x8211),	/* 70003E20 */
	S5K4ECGX_REG_WRITE(0x70003E22, 0x4D97),	/* 70003E22 */
	S5K4ECGX_REG_WRITE(0x70003E24, 0x8829),	/* 70003E24 */
	S5K4ECGX_REG_WRITE(0x70003E26, 0x9108),	/* 70003E26 */
	S5K4ECGX_REG_WRITE(0x70003E28, 0x4A8B),	/* 70003E28 */
	S5K4ECGX_REG_WRITE(0x70003E2A, 0x2303),	/* 70003E2A */
	S5K4ECGX_REG_WRITE(0x70003E2C, 0x3222),	/* 70003E2C */
	S5K4ECGX_REG_WRITE(0x70003E2E, 0x1F91),	/* 70003E2E */
	S5K4ECGX_REG_WRITE(0x70003E30, 0xF000),	/* 70003E30 */
	S5K4ECGX_REG_WRITE(0x70003E32, 0xFA2C),	/* 70003E32 */
	S5K4ECGX_REG_WRITE(0x70003E34, 0x8028),	/* 70003E34 */
	S5K4ECGX_REG_WRITE(0x70003E36, 0x488E),	/* 70003E36 */
	S5K4ECGX_REG_WRITE(0x70003E38, 0x4987),	/* 70003E38 */
	S5K4ECGX_REG_WRITE(0x70003E3A, 0x6BC2),	/* 70003E3A */
	S5K4ECGX_REG_WRITE(0x70003E3C, 0x6AC0),	/* 70003E3C */
	S5K4ECGX_REG_WRITE(0x70003E3E, 0x4282),	/* 70003E3E */
	S5K4ECGX_REG_WRITE(0x70003E40, 0xD201),	/* 70003E40 */
	S5K4ECGX_REG_WRITE(0x70003E42, 0x8CC8),	/* 70003E42 */
	S5K4ECGX_REG_WRITE(0x70003E44, 0x8028),	/* 70003E44 */
	S5K4ECGX_REG_WRITE(0x70003E46, 0x88E8),	/* 70003E46 */
	S5K4ECGX_REG_WRITE(0x70003E48, 0x9007),	/* 70003E48 */
	S5K4ECGX_REG_WRITE(0x70003E4A, 0x2240),	/* 70003E4A */
	S5K4ECGX_REG_WRITE(0x70003E4C, 0x4310),	/* 70003E4C */
	S5K4ECGX_REG_WRITE(0x70003E4E, 0x80E8),	/* 70003E4E */
	S5K4ECGX_REG_WRITE(0x70003E50, 0x2000),	/* 70003E50 */
	S5K4ECGX_REG_WRITE(0x70003E52, 0x0041),	/* 70003E52 */
	S5K4ECGX_REG_WRITE(0x70003E54, 0x194B),	/* 70003E54 */
	S5K4ECGX_REG_WRITE(0x70003E56, 0x001E),	/* 70003E56 */
	S5K4ECGX_REG_WRITE(0x70003E58, 0x3680),	/* 70003E58 */
	S5K4ECGX_REG_WRITE(0x70003E5A, 0x8BB2),	/* 70003E5A */
	S5K4ECGX_REG_WRITE(0x70003E5C, 0xAF04),	/* 70003E5C */
	S5K4ECGX_REG_WRITE(0x70003E5E, 0x527A),	/* 70003E5E */
	S5K4ECGX_REG_WRITE(0x70003E60, 0x4A7D),	/* 70003E60 */
	S5K4ECGX_REG_WRITE(0x70003E62, 0x188A),	/* 70003E62 */
	S5K4ECGX_REG_WRITE(0x70003E64, 0x8897),	/* 70003E64 */
	S5K4ECGX_REG_WRITE(0x70003E66, 0x83B7),	/* 70003E66 */
	S5K4ECGX_REG_WRITE(0x70003E68, 0x33A0),	/* 70003E68 */
	S5K4ECGX_REG_WRITE(0x70003E6A, 0x891F),	/* 70003E6A */
	S5K4ECGX_REG_WRITE(0x70003E6C, 0xAE01),	/* 70003E6C */
	S5K4ECGX_REG_WRITE(0x70003E6E, 0x5277),	/* 70003E6E */
	S5K4ECGX_REG_WRITE(0x70003E70, 0x8A11),	/* 70003E70 */
	S5K4ECGX_REG_WRITE(0x70003E72, 0x8119),	/* 70003E72 */
	S5K4ECGX_REG_WRITE(0x70003E74, 0x1C40),	/* 70003E74 */
	S5K4ECGX_REG_WRITE(0x70003E76, 0x0400),	/* 70003E76 */
	S5K4ECGX_REG_WRITE(0x70003E78, 0x0C00),	/* 70003E78 */
	S5K4ECGX_REG_WRITE(0x70003E7A, 0x2806),	/* 70003E7A */
	S5K4ECGX_REG_WRITE(0x70003E7C, 0xD3E9),	/* 70003E7C */
	S5K4ECGX_REG_WRITE(0x70003E7E, 0xF000),	/* 70003E7E */
	S5K4ECGX_REG_WRITE(0x70003E80, 0xFA0D),	/* 70003E80 */
	S5K4ECGX_REG_WRITE(0x70003E82, 0xF000),	/* 70003E82 */
	S5K4ECGX_REG_WRITE(0x70003E84, 0xFA13),	/* 70003E84 */
	S5K4ECGX_REG_WRITE(0x70003E86, 0x4F79),	/* 70003E86 */
	S5K4ECGX_REG_WRITE(0x70003E88, 0x37A8),	/* 70003E88 */
	S5K4ECGX_REG_WRITE(0x70003E8A, 0x2800),	/* 70003E8A */
	S5K4ECGX_REG_WRITE(0x70003E8C, 0xD10A),	/* 70003E8C */
	S5K4ECGX_REG_WRITE(0x70003E8E, 0x1FE0),	/* 70003E8E */
	S5K4ECGX_REG_WRITE(0x70003E90, 0x38FD),	/* 70003E90 */
	S5K4ECGX_REG_WRITE(0x70003E92, 0xD001),	/* 70003E92 */
	S5K4ECGX_REG_WRITE(0x70003E94, 0x1CC0),	/* 70003E94 */
	S5K4ECGX_REG_WRITE(0x70003E96, 0xD105),	/* 70003E96 */
	S5K4ECGX_REG_WRITE(0x70003E98, 0x4874),	/* 70003E98 */
	S5K4ECGX_REG_WRITE(0x70003E9A, 0x8829),	/* 70003E9A */
	S5K4ECGX_REG_WRITE(0x70003E9C, 0x3818),	/* 70003E9C */
	S5K4ECGX_REG_WRITE(0x70003E9E, 0x6840),	/* 70003E9E */
	S5K4ECGX_REG_WRITE(0x70003EA0, 0x4348),	/* 70003EA0 */
	S5K4ECGX_REG_WRITE(0x70003EA2, 0x6078),	/* 70003EA2 */
	S5K4ECGX_REG_WRITE(0x70003EA4, 0x4972),	/* 70003EA4 */
	S5K4ECGX_REG_WRITE(0x70003EA6, 0x6878),	/* 70003EA6 */
	S5K4ECGX_REG_WRITE(0x70003EA8, 0x6B89),	/* 70003EA8 */
	S5K4ECGX_REG_WRITE(0x70003EAA, 0x4288),	/* 70003EAA */
	S5K4ECGX_REG_WRITE(0x70003EAC, 0xD300),	/* 70003EAC */
	S5K4ECGX_REG_WRITE(0x70003EAE, 0x0008),	/* 70003EAE */
	S5K4ECGX_REG_WRITE(0x70003EB0, 0x6078),	/* 70003EB0 */
	S5K4ECGX_REG_WRITE(0x70003EB2, 0x2000),	/* 70003EB2 */
	S5K4ECGX_REG_WRITE(0x70003EB4, 0x0041),	/* 70003EB4 */
	S5K4ECGX_REG_WRITE(0x70003EB6, 0xAA04),	/* 70003EB6 */
	S5K4ECGX_REG_WRITE(0x70003EB8, 0x5A53),	/* 70003EB8 */
	S5K4ECGX_REG_WRITE(0x70003EBA, 0x194A),	/* 70003EBA */
	S5K4ECGX_REG_WRITE(0x70003EBC, 0x269C),	/* 70003EBC */
	S5K4ECGX_REG_WRITE(0x70003EBE, 0x52B3),	/* 70003EBE */
	S5K4ECGX_REG_WRITE(0x70003EC0, 0xAB01),	/* 70003EC0 */
	S5K4ECGX_REG_WRITE(0x70003EC2, 0x5A59),	/* 70003EC2 */
	S5K4ECGX_REG_WRITE(0x70003EC4, 0x32A0),	/* 70003EC4 */
	S5K4ECGX_REG_WRITE(0x70003EC6, 0x8111),	/* 70003EC6 */
	S5K4ECGX_REG_WRITE(0x70003EC8, 0x1C40),	/* 70003EC8 */
	S5K4ECGX_REG_WRITE(0x70003ECA, 0x0400),	/* 70003ECA */
	S5K4ECGX_REG_WRITE(0x70003ECC, 0x0C00),	/* 70003ECC */
	S5K4ECGX_REG_WRITE(0x70003ECE, 0x2806),	/* 70003ECE */
	S5K4ECGX_REG_WRITE(0x70003ED0, 0xD3F0),	/* 70003ED0 */
	S5K4ECGX_REG_WRITE(0x70003ED2, 0x4965),	/* 70003ED2 */
	S5K4ECGX_REG_WRITE(0x70003ED4, 0x9809),	/* 70003ED4 */
	S5K4ECGX_REG_WRITE(0x70003ED6, 0x8208),	/* 70003ED6 */
	S5K4ECGX_REG_WRITE(0x70003ED8, 0x9808),	/* 70003ED8 */
	S5K4ECGX_REG_WRITE(0x70003EDA, 0x8028),	/* 70003EDA */
	S5K4ECGX_REG_WRITE(0x70003EDC, 0x9807),	/* 70003EDC */
	S5K4ECGX_REG_WRITE(0x70003EDE, 0x80E8),	/* 70003EDE */
	S5K4ECGX_REG_WRITE(0x70003EE0, 0x1FE0),	/* 70003EE0 */
	S5K4ECGX_REG_WRITE(0x70003EE2, 0x38FD),	/* 70003EE2 */
	S5K4ECGX_REG_WRITE(0x70003EE4, 0xD13B),	/* 70003EE4 */
	S5K4ECGX_REG_WRITE(0x70003EE6, 0x4D64),	/* 70003EE6 */
	S5K4ECGX_REG_WRITE(0x70003EE8, 0x89E8),	/* 70003EE8 */
	S5K4ECGX_REG_WRITE(0x70003EEA, 0x1FC1),	/* 70003EEA */
	S5K4ECGX_REG_WRITE(0x70003EEC, 0x39FF),	/* 70003EEC */
	S5K4ECGX_REG_WRITE(0x70003EEE, 0xD136),	/* 70003EEE */
	S5K4ECGX_REG_WRITE(0x70003EF0, 0x4C5F),	/* 70003EF0 */
	S5K4ECGX_REG_WRITE(0x70003EF2, 0x8AE0),	/* 70003EF2 */
	S5K4ECGX_REG_WRITE(0x70003EF4, 0xF000),	/* 70003EF4 */
	S5K4ECGX_REG_WRITE(0x70003EF6, 0xF9E2),	/* 70003EF6 */
	S5K4ECGX_REG_WRITE(0x70003EF8, 0x0006),	/* 70003EF8 */
	S5K4ECGX_REG_WRITE(0x70003EFA, 0x8B20),	/* 70003EFA */
	S5K4ECGX_REG_WRITE(0x70003EFC, 0xF000),	/* 70003EFC */
	S5K4ECGX_REG_WRITE(0x70003EFE, 0xF9E6),	/* 70003EFE */
	S5K4ECGX_REG_WRITE(0x70003F00, 0x9000),	/* 70003F00 */
	S5K4ECGX_REG_WRITE(0x70003F02, 0x6AA1),	/* 70003F02 */
	S5K4ECGX_REG_WRITE(0x70003F04, 0x6878),	/* 70003F04 */
	S5K4ECGX_REG_WRITE(0x70003F06, 0x1809),	/* 70003F06 */
	S5K4ECGX_REG_WRITE(0x70003F08, 0x0200),	/* 70003F08 */
	S5K4ECGX_REG_WRITE(0x70003F0A, 0xF000),	/* 70003F0A */
	S5K4ECGX_REG_WRITE(0x70003F0C, 0xF9B9),	/* 70003F0C */
	S5K4ECGX_REG_WRITE(0x70003F0E, 0x0400),	/* 70003F0E */
	S5K4ECGX_REG_WRITE(0x70003F10, 0x0C00),	/* 70003F10 */
	S5K4ECGX_REG_WRITE(0x70003F12, 0x0022),	/* 70003F12 */
	S5K4ECGX_REG_WRITE(0x70003F14, 0x3246),	/* 70003F14 */
	S5K4ECGX_REG_WRITE(0x70003F16, 0x0011),	/* 70003F16 */
	S5K4ECGX_REG_WRITE(0x70003F18, 0x310A),	/* 70003F18 */
	S5K4ECGX_REG_WRITE(0x70003F1A, 0x2305),	/* 70003F1A */
	S5K4ECGX_REG_WRITE(0x70003F1C, 0xF000),	/* 70003F1C */
	S5K4ECGX_REG_WRITE(0x70003F1E, 0xF9B6),	/* 70003F1E */
	S5K4ECGX_REG_WRITE(0x70003F20, 0x66E8),	/* 70003F20 */
	S5K4ECGX_REG_WRITE(0x70003F22, 0x6B23),	/* 70003F22 */
	S5K4ECGX_REG_WRITE(0x70003F24, 0x0002),	/* 70003F24 */
	S5K4ECGX_REG_WRITE(0x70003F26, 0x0031),	/* 70003F26 */
	S5K4ECGX_REG_WRITE(0x70003F28, 0x0018),	/* 70003F28 */
	S5K4ECGX_REG_WRITE(0x70003F2A, 0xF000),	/* 70003F2A */
	S5K4ECGX_REG_WRITE(0x70003F2C, 0xF9D7),	/* 70003F2C */
	S5K4ECGX_REG_WRITE(0x70003F2E, 0x466B),	/* 70003F2E */
	S5K4ECGX_REG_WRITE(0x70003F30, 0x8518),	/* 70003F30 */
	S5K4ECGX_REG_WRITE(0x70003F32, 0x6EEA),	/* 70003F32 */
	S5K4ECGX_REG_WRITE(0x70003F34, 0x6B60),	/* 70003F34 */
	S5K4ECGX_REG_WRITE(0x70003F36, 0x9900),	/* 70003F36 */
	S5K4ECGX_REG_WRITE(0x70003F38, 0xF000),	/* 70003F38 */
	S5K4ECGX_REG_WRITE(0x70003F3A, 0xF9D0),	/* 70003F3A */
	S5K4ECGX_REG_WRITE(0x70003F3C, 0x466B),	/* 70003F3C */
	S5K4ECGX_REG_WRITE(0x70003F3E, 0x8558),	/* 70003F3E */
	S5K4ECGX_REG_WRITE(0x70003F40, 0x0029),	/* 70003F40 */
	S5K4ECGX_REG_WRITE(0x70003F42, 0x980A),	/* 70003F42 */
	S5K4ECGX_REG_WRITE(0x70003F44, 0x3170),	/* 70003F44 */
	S5K4ECGX_REG_WRITE(0x70003F46, 0xF000),	/* 70003F46 */
	S5K4ECGX_REG_WRITE(0x70003F48, 0xF9D1),	/* 70003F48 */
	S5K4ECGX_REG_WRITE(0x70003F4A, 0x0028),	/* 70003F4A */
	S5K4ECGX_REG_WRITE(0x70003F4C, 0x3060),	/* 70003F4C */
	S5K4ECGX_REG_WRITE(0x70003F4E, 0x8A02),	/* 70003F4E */
	S5K4ECGX_REG_WRITE(0x70003F50, 0x4946),	/* 70003F50 */
	S5K4ECGX_REG_WRITE(0x70003F52, 0x3128),	/* 70003F52 */
	S5K4ECGX_REG_WRITE(0x70003F54, 0x808A),	/* 70003F54 */
	S5K4ECGX_REG_WRITE(0x70003F56, 0x8A42),	/* 70003F56 */
	S5K4ECGX_REG_WRITE(0x70003F58, 0x80CA),	/* 70003F58 */
	S5K4ECGX_REG_WRITE(0x70003F5A, 0x8A80),	/* 70003F5A */
	S5K4ECGX_REG_WRITE(0x70003F5C, 0x8108),	/* 70003F5C */
	S5K4ECGX_REG_WRITE(0x70003F5E, 0xB00B),	/* 70003F5E */
	S5K4ECGX_REG_WRITE(0x70003F60, 0xBCF0),	/* 70003F60 */
	S5K4ECGX_REG_WRITE(0x70003F62, 0xBC08),	/* 70003F62 */
	S5K4ECGX_REG_WRITE(0x70003F64, 0x4718),	/* 70003F64 */
	S5K4ECGX_REG_WRITE(0x70003F66, 0xB570),	/* 70003F66 */
	S5K4ECGX_REG_WRITE(0x70003F68, 0x2400),	/* 70003F68 */
	S5K4ECGX_REG_WRITE(0x70003F6A, 0x4D46),	/* 70003F6A */
	S5K4ECGX_REG_WRITE(0x70003F6C, 0x4846),	/* 70003F6C */
	S5K4ECGX_REG_WRITE(0x70003F6E, 0x8881),	/* 70003F6E */
	S5K4ECGX_REG_WRITE(0x70003F70, 0x4846),	/* 70003F70 */
	S5K4ECGX_REG_WRITE(0x70003F72, 0x8041),	/* 70003F72 */
	S5K4ECGX_REG_WRITE(0x70003F74, 0x2101),	/* 70003F74 */
	S5K4ECGX_REG_WRITE(0x70003F76, 0x8001),	/* 70003F76 */
	S5K4ECGX_REG_WRITE(0x70003F78, 0xF000),	/* 70003F78 */
	S5K4ECGX_REG_WRITE(0x70003F7A, 0xF9C0),	/* 70003F7A */
	S5K4ECGX_REG_WRITE(0x70003F7C, 0x4842),	/* 70003F7C */
	S5K4ECGX_REG_WRITE(0x70003F7E, 0x3820),	/* 70003F7E */
	S5K4ECGX_REG_WRITE(0x70003F80, 0x8BC0),	/* 70003F80 */
	S5K4ECGX_REG_WRITE(0x70003F82, 0xF000),	/* 70003F82 */
	S5K4ECGX_REG_WRITE(0x70003F84, 0xF9C3),	/* 70003F84 */
	S5K4ECGX_REG_WRITE(0x70003F86, 0x4B42),	/* 70003F86 */
	S5K4ECGX_REG_WRITE(0x70003F88, 0x220D),	/* 70003F88 */
	S5K4ECGX_REG_WRITE(0x70003F8A, 0x0712),	/* 70003F8A */
	S5K4ECGX_REG_WRITE(0x70003F8C, 0x18A8),	/* 70003F8C */
	S5K4ECGX_REG_WRITE(0x70003F8E, 0x8806),	/* 70003F8E */
	S5K4ECGX_REG_WRITE(0x70003F90, 0x00E1),	/* 70003F90 */
	S5K4ECGX_REG_WRITE(0x70003F92, 0x18C9),	/* 70003F92 */
	S5K4ECGX_REG_WRITE(0x70003F94, 0x81CE),	/* 70003F94 */
	S5K4ECGX_REG_WRITE(0x70003F96, 0x8846),	/* 70003F96 */
	S5K4ECGX_REG_WRITE(0x70003F98, 0x818E),	/* 70003F98 */
	S5K4ECGX_REG_WRITE(0x70003F9A, 0x8886),	/* 70003F9A */
	S5K4ECGX_REG_WRITE(0x70003F9C, 0x824E),	/* 70003F9C */
	S5K4ECGX_REG_WRITE(0x70003F9E, 0x88C0),	/* 70003F9E */
	S5K4ECGX_REG_WRITE(0x70003FA0, 0x8208),	/* 70003FA0 */
	S5K4ECGX_REG_WRITE(0x70003FA2, 0x3508),	/* 70003FA2 */
	S5K4ECGX_REG_WRITE(0x70003FA4, 0x042D),	/* 70003FA4 */
	S5K4ECGX_REG_WRITE(0x70003FA6, 0x0C2D),	/* 70003FA6 */
	S5K4ECGX_REG_WRITE(0x70003FA8, 0x1C64),	/* 70003FA8 */
	S5K4ECGX_REG_WRITE(0x70003FAA, 0x0424),	/* 70003FAA */
	S5K4ECGX_REG_WRITE(0x70003FAC, 0x0C24),	/* 70003FAC */
	S5K4ECGX_REG_WRITE(0x70003FAE, 0x2C07),	/* 70003FAE */
	S5K4ECGX_REG_WRITE(0x70003FB0, 0xD3EC),	/* 70003FB0 */
	S5K4ECGX_REG_WRITE(0x70003FB2, 0xE658),	/* 70003FB2 */
	S5K4ECGX_REG_WRITE(0x70003FB4, 0xB510),	/* 70003FB4 */
	S5K4ECGX_REG_WRITE(0x70003FB6, 0x4834),	/* 70003FB6 */
	S5K4ECGX_REG_WRITE(0x70003FB8, 0x4C34),	/* 70003FB8 */
	S5K4ECGX_REG_WRITE(0x70003FBA, 0x88C0),	/* 70003FBA */
	S5K4ECGX_REG_WRITE(0x70003FBC, 0x8060),	/* 70003FBC */
	S5K4ECGX_REG_WRITE(0x70003FBE, 0x2001),	/* 70003FBE */
	S5K4ECGX_REG_WRITE(0x70003FC0, 0x8020),	/* 70003FC0 */
	S5K4ECGX_REG_WRITE(0x70003FC2, 0x4831),	/* 70003FC2 */
	S5K4ECGX_REG_WRITE(0x70003FC4, 0x3820),	/* 70003FC4 */
	S5K4ECGX_REG_WRITE(0x70003FC6, 0x8BC0),	/* 70003FC6 */
	S5K4ECGX_REG_WRITE(0x70003FC8, 0xF000),	/* 70003FC8 */
	S5K4ECGX_REG_WRITE(0x70003FCA, 0xF9A0),	/* 70003FCA */
	S5K4ECGX_REG_WRITE(0x70003FCC, 0x88E0),	/* 70003FCC */
	S5K4ECGX_REG_WRITE(0x70003FCE, 0x4A31),	/* 70003FCE */
	S5K4ECGX_REG_WRITE(0x70003FD0, 0x2800),	/* 70003FD0 */
	S5K4ECGX_REG_WRITE(0x70003FD2, 0xD003),	/* 70003FD2 */
	S5K4ECGX_REG_WRITE(0x70003FD4, 0x4930),	/* 70003FD4 */
	S5K4ECGX_REG_WRITE(0x70003FD6, 0x8849),	/* 70003FD6 */
	S5K4ECGX_REG_WRITE(0x70003FD8, 0x2900),	/* 70003FD8 */
	S5K4ECGX_REG_WRITE(0x70003FDA, 0xD009),	/* 70003FDA */
	S5K4ECGX_REG_WRITE(0x70003FDC, 0x2001),	/* 70003FDC */
	S5K4ECGX_REG_WRITE(0x70003FDE, 0x03C0),	/* 70003FDE */
	S5K4ECGX_REG_WRITE(0x70003FE0, 0x8050),	/* 70003FE0 */
	S5K4ECGX_REG_WRITE(0x70003FE2, 0x80D0),	/* 70003FE2 */
	S5K4ECGX_REG_WRITE(0x70003FE4, 0x2000),	/* 70003FE4 */
	S5K4ECGX_REG_WRITE(0x70003FE6, 0x8090),	/* 70003FE6 */
	S5K4ECGX_REG_WRITE(0x70003FE8, 0x8110),	/* 70003FE8 */
	S5K4ECGX_REG_WRITE(0x70003FEA, 0xBC10),	/* 70003FEA */
	S5K4ECGX_REG_WRITE(0x70003FEC, 0xBC08),	/* 70003FEC */
	S5K4ECGX_REG_WRITE(0x70003FEE, 0x4718),	/* 70003FEE */
	S5K4ECGX_REG_WRITE(0x70003FF0, 0x8050),	/* 70003FF0 */
	S5K4ECGX_REG_WRITE(0x70003FF2, 0x8920),	/* 70003FF2 */
	S5K4ECGX_REG_WRITE(0x70003FF4, 0x80D0),	/* 70003FF4 */
	S5K4ECGX_REG_WRITE(0x70003FF6, 0x8960),	/* 70003FF6 */
	S5K4ECGX_REG_WRITE(0x70003FF8, 0x0400),	/* 70003FF8 */
	S5K4ECGX_REG_WRITE(0x70003FFA, 0x1400),	/* 70003FFA */
	S5K4ECGX_REG_WRITE(0x70003FFC, 0x8090),	/* 70003FFC */
	S5K4ECGX_REG_WRITE(0x70003FFE, 0x89A1),	/* 70003FFE */
	S5K4ECGX_REG_WRITE(0x70004000, 0x0409),	/* 70004000 */
	S5K4ECGX_REG_WRITE(0x70004002, 0x1409),	/* 70004002 */
	S5K4ECGX_REG_WRITE(0x70004004, 0x8111),	/* 70004004 */
	S5K4ECGX_REG_WRITE(0x70004006, 0x89E3),	/* 70004006 */
	S5K4ECGX_REG_WRITE(0x70004008, 0x8A24),	/* 70004008 */
	S5K4ECGX_REG_WRITE(0x7000400A, 0x2B00),	/* 7000400A */
	S5K4ECGX_REG_WRITE(0x7000400C, 0xD104),	/* 7000400C */
	S5K4ECGX_REG_WRITE(0x7000400E, 0x17C3),	/* 7000400E */
	S5K4ECGX_REG_WRITE(0x70004010, 0x0F5B),	/* 70004010 */
	S5K4ECGX_REG_WRITE(0x70004012, 0x1818),	/* 70004012 */
	S5K4ECGX_REG_WRITE(0x70004014, 0x10C0),	/* 70004014 */
	S5K4ECGX_REG_WRITE(0x70004016, 0x8090),	/* 70004016 */
	S5K4ECGX_REG_WRITE(0x70004018, 0x2C00),	/* 70004018 */
	S5K4ECGX_REG_WRITE(0x7000401A, 0xD1E6),	/* 7000401A */
	S5K4ECGX_REG_WRITE(0x7000401C, 0x17C8),	/* 7000401C */
	S5K4ECGX_REG_WRITE(0x7000401E, 0x0F40),	/* 7000401E */
	S5K4ECGX_REG_WRITE(0x70004020, 0x1840),	/* 70004020 */
	S5K4ECGX_REG_WRITE(0x70004022, 0x10C0),	/* 70004022 */
	S5K4ECGX_REG_WRITE(0x70004024, 0x8110),	/* 70004024 */
	S5K4ECGX_REG_WRITE(0x70004026, 0xE7E0),	/* 70004026 */
	S5K4ECGX_REG_WRITE(0x70004028, 0xB510),	/* 70004028 */
	S5K4ECGX_REG_WRITE(0x7000402A, 0x000C),	/* 7000402A */
	S5K4ECGX_REG_WRITE(0x7000402C, 0x4919),	/* 7000402C */
	S5K4ECGX_REG_WRITE(0x7000402E, 0x2204),	/* 7000402E */
	S5K4ECGX_REG_WRITE(0x70004030, 0x6820),	/* 70004030 */
	S5K4ECGX_REG_WRITE(0x70004032, 0x5E8A),	/* 70004032 */
	S5K4ECGX_REG_WRITE(0x70004034, 0x0140),	/* 70004034 */
	S5K4ECGX_REG_WRITE(0x70004036, 0x1A80),	/* 70004036 */
	S5K4ECGX_REG_WRITE(0x70004038, 0x0280),	/* 70004038 */
	S5K4ECGX_REG_WRITE(0x7000403A, 0x8849),	/* 7000403A */
	S5K4ECGX_REG_WRITE(0x7000403C, 0xF000),	/* 7000403C */
	S5K4ECGX_REG_WRITE(0x7000403E, 0xF96E),	/* 7000403E */
	S5K4ECGX_REG_WRITE(0x70004040, 0x6020),	/* 70004040 */
	S5K4ECGX_REG_WRITE(0x70004042, 0xE7D2),	/* 70004042 */
	S5K4ECGX_REG_WRITE(0x70004044, 0x38D4),	/* 70004044 */
	S5K4ECGX_REG_WRITE(0x70004046, 0x7000),	/* 70004046 */
	S5K4ECGX_REG_WRITE(0x70004048, 0x17D0),	/* 70004048 */
	S5K4ECGX_REG_WRITE(0x7000404A, 0x7000),	/* 7000404A */
	S5K4ECGX_REG_WRITE(0x7000404C, 0x5000),	/* 7000404C */
	S5K4ECGX_REG_WRITE(0x7000404E, 0xD000),	/* 7000404E */
	S5K4ECGX_REG_WRITE(0x70004050, 0x1100),	/* 70004050 */
	S5K4ECGX_REG_WRITE(0x70004052, 0xD000),	/* 70004052 */
	S5K4ECGX_REG_WRITE(0x70004054, 0x171A),	/* 70004054 */
	S5K4ECGX_REG_WRITE(0x70004056, 0x7000),	/* 70004056 */
	S5K4ECGX_REG_WRITE(0x70004058, 0x4780),	/* 70004058 */
	S5K4ECGX_REG_WRITE(0x7000405A, 0x7000),	/* 7000405A */
	S5K4ECGX_REG_WRITE(0x7000405C, 0x2FCA),	/* 7000405C */
	S5K4ECGX_REG_WRITE(0x7000405E, 0x7000),	/* 7000405E */
	S5K4ECGX_REG_WRITE(0x70004060, 0x2FC5),	/* 70004060 */
	S5K4ECGX_REG_WRITE(0x70004062, 0x7000),	/* 70004062 */
	S5K4ECGX_REG_WRITE(0x70004064, 0x2FC6),	/* 70004064 */
	S5K4ECGX_REG_WRITE(0x70004066, 0x7000),	/* 70004066 */
	S5K4ECGX_REG_WRITE(0x70004068, 0x2ED8),	/* 70004068 */
	S5K4ECGX_REG_WRITE(0x7000406A, 0x7000),	/* 7000406A */
	S5K4ECGX_REG_WRITE(0x7000406C, 0x2BD0),	/* 7000406C */
	S5K4ECGX_REG_WRITE(0x7000406E, 0x7000),	/* 7000406E */
	S5K4ECGX_REG_WRITE(0x70004070, 0x17E0),	/* 70004070 */
	S5K4ECGX_REG_WRITE(0x70004072, 0x7000),	/* 70004072 */
	S5K4ECGX_REG_WRITE(0x70004074, 0x2DE8),	/* 70004074 */
	S5K4ECGX_REG_WRITE(0x70004076, 0x7000),	/* 70004076 */
	S5K4ECGX_REG_WRITE(0x70004078, 0x37E0),	/* 70004078 */
	S5K4ECGX_REG_WRITE(0x7000407A, 0x7000),	/* 7000407A */
	S5K4ECGX_REG_WRITE(0x7000407C, 0x210C),	/* 7000407C */
	S5K4ECGX_REG_WRITE(0x7000407E, 0x7000),	/* 7000407E */
	S5K4ECGX_REG_WRITE(0x70004080, 0x1484),	/* 70004080 */
	S5K4ECGX_REG_WRITE(0x70004082, 0x7000),	/* 70004082 */
	S5K4ECGX_REG_WRITE(0x70004084, 0xA006),	/* 70004084 */
	S5K4ECGX_REG_WRITE(0x70004086, 0x0000),	/* 70004086 */
	S5K4ECGX_REG_WRITE(0x70004088, 0x0724),	/* 70004088 */
	S5K4ECGX_REG_WRITE(0x7000408A, 0x7000),	/* 7000408A */
	S5K4ECGX_REG_WRITE(0x7000408C, 0xA000),	/* 7000408C */
	S5K4ECGX_REG_WRITE(0x7000408E, 0xD000),	/* 7000408E */
	S5K4ECGX_REG_WRITE(0x70004090, 0x2270),	/* 70004090 */
	S5K4ECGX_REG_WRITE(0x70004092, 0x7000),	/* 70004092 */
	S5K4ECGX_REG_WRITE(0x70004094, 0x2558),	/* 70004094 */
	S5K4ECGX_REG_WRITE(0x70004096, 0x7000),	/* 70004096 */
	S5K4ECGX_REG_WRITE(0x70004098, 0x146C),	/* 70004098 */
	S5K4ECGX_REG_WRITE(0x7000409A, 0x7000),	/* 7000409A */
	S5K4ECGX_REG_WRITE(0x7000409C, 0xB510),	/* 7000409C */
	S5K4ECGX_REG_WRITE(0x7000409E, 0x000C),	/* 7000409E */
	S5K4ECGX_REG_WRITE(0x700040A0, 0x4951),	/* 700040A0 */
	S5K4ECGX_REG_WRITE(0x700040A2, 0x2208),	/* 700040A2 */
	S5K4ECGX_REG_WRITE(0x700040A4, 0x6820),	/* 700040A4 */
	S5K4ECGX_REG_WRITE(0x700040A6, 0x5E8A),	/* 700040A6 */
	S5K4ECGX_REG_WRITE(0x700040A8, 0x0140),	/* 700040A8 */
	S5K4ECGX_REG_WRITE(0x700040AA, 0x1A80),	/* 700040AA */
	S5K4ECGX_REG_WRITE(0x700040AC, 0x0280),	/* 700040AC */
	S5K4ECGX_REG_WRITE(0x700040AE, 0x88C9),	/* 700040AE */
	S5K4ECGX_REG_WRITE(0x700040B0, 0xF000),	/* 700040B0 */
	S5K4ECGX_REG_WRITE(0x700040B2, 0xF934),	/* 700040B2 */
	S5K4ECGX_REG_WRITE(0x700040B4, 0x6020),	/* 700040B4 */
	S5K4ECGX_REG_WRITE(0x700040B6, 0xE798),	/* 700040B6 */
	S5K4ECGX_REG_WRITE(0x700040B8, 0xB5FE),	/* 700040B8 */
	S5K4ECGX_REG_WRITE(0x700040BA, 0x000C),	/* 700040BA */
	S5K4ECGX_REG_WRITE(0x700040BC, 0x6825),	/* 700040BC */
	S5K4ECGX_REG_WRITE(0x700040BE, 0x6866),	/* 700040BE */
	S5K4ECGX_REG_WRITE(0x700040C0, 0x68A0),	/* 700040C0 */
	S5K4ECGX_REG_WRITE(0x700040C2, 0x9001),	/* 700040C2 */
	S5K4ECGX_REG_WRITE(0x700040C4, 0x68E7),	/* 700040C4 */
	S5K4ECGX_REG_WRITE(0x700040C6, 0x1BA8),	/* 700040C6 */
	S5K4ECGX_REG_WRITE(0x700040C8, 0x42B5),	/* 700040C8 */
	S5K4ECGX_REG_WRITE(0x700040CA, 0xDA00),	/* 700040CA */
	S5K4ECGX_REG_WRITE(0x700040CC, 0x1B70),	/* 700040CC */
	S5K4ECGX_REG_WRITE(0x700040CE, 0x9000),	/* 700040CE */
	S5K4ECGX_REG_WRITE(0x700040D0, 0x4945),	/* 700040D0 */
	S5K4ECGX_REG_WRITE(0x700040D2, 0x4846),	/* 700040D2 */
	S5K4ECGX_REG_WRITE(0x700040D4, 0x884A),	/* 700040D4 */
	S5K4ECGX_REG_WRITE(0x700040D6, 0x8843),	/* 700040D6 */
	S5K4ECGX_REG_WRITE(0x700040D8, 0x435A),	/* 700040D8 */
	S5K4ECGX_REG_WRITE(0x700040DA, 0x2304),	/* 700040DA */
	S5K4ECGX_REG_WRITE(0x700040DC, 0x5ECB),	/* 700040DC */
	S5K4ECGX_REG_WRITE(0x700040DE, 0x0A92),	/* 700040DE */
	S5K4ECGX_REG_WRITE(0x700040E0, 0x18D2),	/* 700040E0 */
	S5K4ECGX_REG_WRITE(0x700040E2, 0x02D2),	/* 700040E2 */
	S5K4ECGX_REG_WRITE(0x700040E4, 0x0C12),	/* 700040E4 */
	S5K4ECGX_REG_WRITE(0x700040E6, 0x88CB),	/* 700040E6 */
	S5K4ECGX_REG_WRITE(0x700040E8, 0x8880),	/* 700040E8 */
	S5K4ECGX_REG_WRITE(0x700040EA, 0x4343),	/* 700040EA */
	S5K4ECGX_REG_WRITE(0x700040EC, 0x0A98),	/* 700040EC */
	S5K4ECGX_REG_WRITE(0x700040EE, 0x2308),	/* 700040EE */
	S5K4ECGX_REG_WRITE(0x700040F0, 0x5ECB),	/* 700040F0 */
	S5K4ECGX_REG_WRITE(0x700040F2, 0x18C0),	/* 700040F2 */
	S5K4ECGX_REG_WRITE(0x700040F4, 0x02C0),	/* 700040F4 */
	S5K4ECGX_REG_WRITE(0x700040F6, 0x0C00),	/* 700040F6 */
	S5K4ECGX_REG_WRITE(0x700040F8, 0x0411),	/* 700040F8 */
	S5K4ECGX_REG_WRITE(0x700040FA, 0x0400),	/* 700040FA */
	S5K4ECGX_REG_WRITE(0x700040FC, 0x1409),	/* 700040FC */
	S5K4ECGX_REG_WRITE(0x700040FE, 0x1400),	/* 700040FE */
	S5K4ECGX_REG_WRITE(0x70004100, 0x1A08),	/* 70004100 */
	S5K4ECGX_REG_WRITE(0x70004102, 0x493A),	/* 70004102 */
	S5K4ECGX_REG_WRITE(0x70004104, 0x39E0),	/* 70004104 */
	S5K4ECGX_REG_WRITE(0x70004106, 0x6148),	/* 70004106 */
	S5K4ECGX_REG_WRITE(0x70004108, 0x9801),	/* 70004108 */
	S5K4ECGX_REG_WRITE(0x7000410A, 0x3040),	/* 7000410A */
	S5K4ECGX_REG_WRITE(0x7000410C, 0x7880),	/* 7000410C */
	S5K4ECGX_REG_WRITE(0x7000410E, 0x2800),	/* 7000410E */
	S5K4ECGX_REG_WRITE(0x70004110, 0xD103),	/* 70004110 */
	S5K4ECGX_REG_WRITE(0x70004112, 0x9801),	/* 70004112 */
	S5K4ECGX_REG_WRITE(0x70004114, 0x0029),	/* 70004114 */
	S5K4ECGX_REG_WRITE(0x70004116, 0xF000),	/* 70004116 */
	S5K4ECGX_REG_WRITE(0x70004118, 0xF907),	/* 70004118 */
	S5K4ECGX_REG_WRITE(0x7000411A, 0x8839),	/* 7000411A */
	S5K4ECGX_REG_WRITE(0x7000411C, 0x9800),	/* 7000411C */
	S5K4ECGX_REG_WRITE(0x7000411E, 0x4281),	/* 7000411E */
	S5K4ECGX_REG_WRITE(0x70004120, 0xD814),	/* 70004120 */
	S5K4ECGX_REG_WRITE(0x70004122, 0x8879),	/* 70004122 */
	S5K4ECGX_REG_WRITE(0x70004124, 0x9800),	/* 70004124 */
	S5K4ECGX_REG_WRITE(0x70004126, 0x4281),	/* 70004126 */
	S5K4ECGX_REG_WRITE(0x70004128, 0xD20C),	/* 70004128 */
	S5K4ECGX_REG_WRITE(0x7000412A, 0x9801),	/* 7000412A */
	S5K4ECGX_REG_WRITE(0x7000412C, 0x0029),	/* 7000412C */
	S5K4ECGX_REG_WRITE(0x7000412E, 0xF000),	/* 7000412E */
	S5K4ECGX_REG_WRITE(0x70004130, 0xF903),	/* 70004130 */
	S5K4ECGX_REG_WRITE(0x70004132, 0x9801),	/* 70004132 */
	S5K4ECGX_REG_WRITE(0x70004134, 0x0029),	/* 70004134 */
	S5K4ECGX_REG_WRITE(0x70004136, 0xF000),	/* 70004136 */
	S5K4ECGX_REG_WRITE(0x70004138, 0xF8FF),	/* 70004138 */
	S5K4ECGX_REG_WRITE(0x7000413A, 0x9801),	/* 7000413A */
	S5K4ECGX_REG_WRITE(0x7000413C, 0x0029),	/* 7000413C */
	S5K4ECGX_REG_WRITE(0x7000413E, 0xF000),	/* 7000413E */
	S5K4ECGX_REG_WRITE(0x70004140, 0xF8FB),	/* 70004140 */
	S5K4ECGX_REG_WRITE(0x70004142, 0xE003),	/* 70004142 */
	S5K4ECGX_REG_WRITE(0x70004144, 0x9801),	/* 70004144 */
	S5K4ECGX_REG_WRITE(0x70004146, 0x0029),	/* 70004146 */
	S5K4ECGX_REG_WRITE(0x70004148, 0xF000),	/* 70004148 */
	S5K4ECGX_REG_WRITE(0x7000414A, 0xF8F6),	/* 7000414A */
	S5K4ECGX_REG_WRITE(0x7000414C, 0x9801),	/* 7000414C */
	S5K4ECGX_REG_WRITE(0x7000414E, 0x0032),	/* 7000414E */
	S5K4ECGX_REG_WRITE(0x70004150, 0x0039),	/* 70004150 */
	S5K4ECGX_REG_WRITE(0x70004152, 0xF000),	/* 70004152 */
	S5K4ECGX_REG_WRITE(0x70004154, 0xF8F9),	/* 70004154 */
	S5K4ECGX_REG_WRITE(0x70004156, 0x6020),	/* 70004156 */
	S5K4ECGX_REG_WRITE(0x70004158, 0xE5D0),	/* 70004158 */
	S5K4ECGX_REG_WRITE(0x7000415A, 0xB57C),	/* 7000415A */
	S5K4ECGX_REG_WRITE(0x7000415C, 0x4824),	/* 7000415C */
	S5K4ECGX_REG_WRITE(0x7000415E, 0xA901),	/* 7000415E */
	S5K4ECGX_REG_WRITE(0x70004160, 0x0004),	/* 70004160 */
	S5K4ECGX_REG_WRITE(0x70004162, 0xF000),	/* 70004162 */
	S5K4ECGX_REG_WRITE(0x70004164, 0xF87D),	/* 70004164 */
	S5K4ECGX_REG_WRITE(0x70004166, 0x466B),	/* 70004166 */
	S5K4ECGX_REG_WRITE(0x70004168, 0x88D9),	/* 70004168 */
	S5K4ECGX_REG_WRITE(0x7000416A, 0x8898),	/* 7000416A */
	S5K4ECGX_REG_WRITE(0x7000416C, 0x4B1F),	/* 7000416C */
	S5K4ECGX_REG_WRITE(0x7000416E, 0x3346),	/* 7000416E */
	S5K4ECGX_REG_WRITE(0x70004170, 0x1E9A),	/* 70004170 */
	S5K4ECGX_REG_WRITE(0x70004172, 0xF000),	/* 70004172 */
	S5K4ECGX_REG_WRITE(0x70004174, 0xF8F1),	/* 70004174 */
	S5K4ECGX_REG_WRITE(0x70004176, 0x481E),	/* 70004176 */
	S5K4ECGX_REG_WRITE(0x70004178, 0x491C),	/* 70004178 */
	S5K4ECGX_REG_WRITE(0x7000417A, 0x3812),	/* 7000417A */
	S5K4ECGX_REG_WRITE(0x7000417C, 0x3140),	/* 7000417C */
	S5K4ECGX_REG_WRITE(0x7000417E, 0x8A42),	/* 7000417E */
	S5K4ECGX_REG_WRITE(0x70004180, 0x888B),	/* 70004180 */
	S5K4ECGX_REG_WRITE(0x70004182, 0x18D2),	/* 70004182 */
	S5K4ECGX_REG_WRITE(0x70004184, 0x8242),	/* 70004184 */
	S5K4ECGX_REG_WRITE(0x70004186, 0x8AC2),	/* 70004186 */
	S5K4ECGX_REG_WRITE(0x70004188, 0x88C9),	/* 70004188 */
	S5K4ECGX_REG_WRITE(0x7000418A, 0x1851),	/* 7000418A */
	S5K4ECGX_REG_WRITE(0x7000418C, 0x82C1),	/* 7000418C */
	S5K4ECGX_REG_WRITE(0x7000418E, 0x0020),	/* 7000418E */
	S5K4ECGX_REG_WRITE(0x70004190, 0x4669),	/* 70004190 */
	S5K4ECGX_REG_WRITE(0x70004192, 0xF000),	/* 70004192 */
	S5K4ECGX_REG_WRITE(0x70004194, 0xF865),	/* 70004194 */
	S5K4ECGX_REG_WRITE(0x70004196, 0x4817),	/* 70004196 */
	S5K4ECGX_REG_WRITE(0x70004198, 0x214D),	/* 70004198 */
	S5K4ECGX_REG_WRITE(0x7000419A, 0x8301),	/* 7000419A */
	S5K4ECGX_REG_WRITE(0x7000419C, 0x2196),	/* 7000419C */
	S5K4ECGX_REG_WRITE(0x7000419E, 0x8381),	/* 7000419E */
	S5K4ECGX_REG_WRITE(0x700041A0, 0x211D),	/* 700041A0 */
	S5K4ECGX_REG_WRITE(0x700041A2, 0x3020),	/* 700041A2 */
	S5K4ECGX_REG_WRITE(0x700041A4, 0x8001),	/* 700041A4 */
	S5K4ECGX_REG_WRITE(0x700041A6, 0xF000),	/* 700041A6 */
	S5K4ECGX_REG_WRITE(0x700041A8, 0xF8DF),	/* 700041A8 */
	S5K4ECGX_REG_WRITE(0x700041AA, 0xF000),	/* 700041AA */
	S5K4ECGX_REG_WRITE(0x700041AC, 0xF8E5),	/* 700041AC */
	S5K4ECGX_REG_WRITE(0x700041AE, 0x4812),	/* 700041AE */
	S5K4ECGX_REG_WRITE(0x700041B0, 0x4C12),	/* 700041B0 */
	S5K4ECGX_REG_WRITE(0x700041B2, 0x6E00),	/* 700041B2 */
	S5K4ECGX_REG_WRITE(0x700041B4, 0x60E0),	/* 700041B4 */
	S5K4ECGX_REG_WRITE(0x700041B6, 0x466B),	/* 700041B6 */
	S5K4ECGX_REG_WRITE(0x700041B8, 0x8818),	/* 700041B8 */
	S5K4ECGX_REG_WRITE(0x700041BA, 0x8859),	/* 700041BA */
	S5K4ECGX_REG_WRITE(0x700041BC, 0x0025),	/* 700041BC */
	S5K4ECGX_REG_WRITE(0x700041BE, 0x1A40),	/* 700041BE */
	S5K4ECGX_REG_WRITE(0x700041C0, 0x3540),	/* 700041C0 */
	S5K4ECGX_REG_WRITE(0x700041C2, 0x61A8),	/* 700041C2 */
	S5K4ECGX_REG_WRITE(0x700041C4, 0x4809),	/* 700041C4 */
	S5K4ECGX_REG_WRITE(0x700041C6, 0x9900),	/* 700041C6 */
	S5K4ECGX_REG_WRITE(0x700041C8, 0x3060),	/* 700041C8 */
	S5K4ECGX_REG_WRITE(0x700041CA, 0xF000),	/* 700041CA */
	S5K4ECGX_REG_WRITE(0x700041CC, 0xF8DD),	/* 700041CC */
	S5K4ECGX_REG_WRITE(0x700041CE, 0x466B),	/* 700041CE */
	S5K4ECGX_REG_WRITE(0x700041D0, 0x8819),	/* 700041D0 */
	S5K4ECGX_REG_WRITE(0x700041D2, 0x1DE0),	/* 700041D2 */
	S5K4ECGX_REG_WRITE(0x700041D4, 0x30F9),	/* 700041D4 */
	S5K4ECGX_REG_WRITE(0x700041D6, 0x8741),	/* 700041D6 */
	S5K4ECGX_REG_WRITE(0x700041D8, 0x8859),	/* 700041D8 */
	S5K4ECGX_REG_WRITE(0x700041DA, 0x8781),	/* 700041DA */
	S5K4ECGX_REG_WRITE(0x700041DC, 0x2000),	/* 700041DC */
	S5K4ECGX_REG_WRITE(0x700041DE, 0x71A0),	/* 700041DE */
	S5K4ECGX_REG_WRITE(0x700041E0, 0x74A8),	/* 700041E0 */
	S5K4ECGX_REG_WRITE(0x700041E2, 0xBC7C),	/* 700041E2 */
	S5K4ECGX_REG_WRITE(0x700041E4, 0xBC08),	/* 700041E4 */
	S5K4ECGX_REG_WRITE(0x700041E6, 0x4718),	/* 700041E6 */
	S5K4ECGX_REG_WRITE(0x700041E8, 0x2558),	/* 700041E8 */
	S5K4ECGX_REG_WRITE(0x700041EA, 0x7000),	/* 700041EA */
	S5K4ECGX_REG_WRITE(0x700041EC, 0x2AB8),	/* 700041EC */
	S5K4ECGX_REG_WRITE(0x700041EE, 0x7000),	/* 700041EE */
	S5K4ECGX_REG_WRITE(0x700041F0, 0x145E),	/* 700041F0 */
	S5K4ECGX_REG_WRITE(0x700041F2, 0x7000),	/* 700041F2 */
	S5K4ECGX_REG_WRITE(0x700041F4, 0x2698),	/* 700041F4 */
	S5K4ECGX_REG_WRITE(0x700041F6, 0x7000),	/* 700041F6 */
	S5K4ECGX_REG_WRITE(0x700041F8, 0x2BB8),	/* 700041F8 */
	S5K4ECGX_REG_WRITE(0x700041FA, 0x7000),	/* 700041FA */
	S5K4ECGX_REG_WRITE(0x700041FC, 0x2998),	/* 700041FC */
	S5K4ECGX_REG_WRITE(0x700041FE, 0x7000),	/* 700041FE */
	S5K4ECGX_REG_WRITE(0x70004200, 0x4778),	/* 70004200 */
	S5K4ECGX_REG_WRITE(0x70004202, 0x46C0),	/* 70004202 */
	S5K4ECGX_REG_WRITE(0x70004204, 0xC000),	/* 70004204 */
	S5K4ECGX_REG_WRITE(0x70004206, 0xE59F),	/* 70004206 */
	S5K4ECGX_REG_WRITE(0x70004208, 0xFF1C),	/* 70004208 */
	S5K4ECGX_REG_WRITE(0x7000420A, 0xE12F),	/* 7000420A */
	S5K4ECGX_REG_WRITE(0x7000420C, 0x1789),	/* 7000420C */
	S5K4ECGX_REG_WRITE(0x7000420E, 0x0001),	/* 7000420E */
	S5K4ECGX_REG_WRITE(0x70004210, 0x4778),	/* 70004210 */
	S5K4ECGX_REG_WRITE(0x70004212, 0x46C0),	/* 70004212 */
	S5K4ECGX_REG_WRITE(0x70004214, 0xC000),	/* 70004214 */
	S5K4ECGX_REG_WRITE(0x70004216, 0xE59F),	/* 70004216 */
	S5K4ECGX_REG_WRITE(0x70004218, 0xFF1C),	/* 70004218 */
	S5K4ECGX_REG_WRITE(0x7000421A, 0xE12F),	/* 7000421A */
	S5K4ECGX_REG_WRITE(0x7000421C, 0x16F1),	/* 7000421C */
	S5K4ECGX_REG_WRITE(0x7000421E, 0x0001),	/* 7000421E */
	S5K4ECGX_REG_WRITE(0x70004220, 0x4778),	/* 70004220 */
	S5K4ECGX_REG_WRITE(0x70004222, 0x46C0),	/* 70004222 */
	S5K4ECGX_REG_WRITE(0x70004224, 0xC000),	/* 70004224 */
	S5K4ECGX_REG_WRITE(0x70004226, 0xE59F),	/* 70004226 */
	S5K4ECGX_REG_WRITE(0x70004228, 0xFF1C),	/* 70004228 */
	S5K4ECGX_REG_WRITE(0x7000422A, 0xE12F),	/* 7000422A */
	S5K4ECGX_REG_WRITE(0x7000422C, 0xC3B1),	/* 7000422C */
	S5K4ECGX_REG_WRITE(0x7000422E, 0x0000),	/* 7000422E */
	S5K4ECGX_REG_WRITE(0x70004230, 0x4778),	/* 70004230 */
	S5K4ECGX_REG_WRITE(0x70004232, 0x46C0),	/* 70004232 */
	S5K4ECGX_REG_WRITE(0x70004234, 0xC000),	/* 70004234 */
	S5K4ECGX_REG_WRITE(0x70004236, 0xE59F),	/* 70004236 */
	S5K4ECGX_REG_WRITE(0x70004238, 0xFF1C),	/* 70004238 */
	S5K4ECGX_REG_WRITE(0x7000423A, 0xE12F),	/* 7000423A */
	S5K4ECGX_REG_WRITE(0x7000423C, 0xC36D),	/* 7000423C */
	S5K4ECGX_REG_WRITE(0x7000423E, 0x0000),	/* 7000423E */
	S5K4ECGX_REG_WRITE(0x70004240, 0x4778),	/* 70004240 */
	S5K4ECGX_REG_WRITE(0x70004242, 0x46C0),	/* 70004242 */
	S5K4ECGX_REG_WRITE(0x70004244, 0xC000),	/* 70004244 */
	S5K4ECGX_REG_WRITE(0x70004246, 0xE59F),	/* 70004246 */
	S5K4ECGX_REG_WRITE(0x70004248, 0xFF1C),	/* 70004248 */
	S5K4ECGX_REG_WRITE(0x7000424A, 0xE12F),	/* 7000424A */
	S5K4ECGX_REG_WRITE(0x7000424C, 0xF6D7),	/* 7000424C */
	S5K4ECGX_REG_WRITE(0x7000424E, 0x0000),	/* 7000424E */
	S5K4ECGX_REG_WRITE(0x70004250, 0x4778),	/* 70004250 */
	S5K4ECGX_REG_WRITE(0x70004252, 0x46C0),	/* 70004252 */
	S5K4ECGX_REG_WRITE(0x70004254, 0xC000),	/* 70004254 */
	S5K4ECGX_REG_WRITE(0x70004256, 0xE59F),	/* 70004256 */
	S5K4ECGX_REG_WRITE(0x70004258, 0xFF1C),	/* 70004258 */
	S5K4ECGX_REG_WRITE(0x7000425A, 0xE12F),	/* 7000425A */
	S5K4ECGX_REG_WRITE(0x7000425C, 0xB49D),	/* 7000425C */
	S5K4ECGX_REG_WRITE(0x7000425E, 0x0000),	/* 7000425E */
	S5K4ECGX_REG_WRITE(0x70004260, 0x4778),	/* 70004260 */
	S5K4ECGX_REG_WRITE(0x70004262, 0x46C0),	/* 70004262 */
	S5K4ECGX_REG_WRITE(0x70004264, 0xC000),	/* 70004264 */
	S5K4ECGX_REG_WRITE(0x70004266, 0xE59F),	/* 70004266 */
	S5K4ECGX_REG_WRITE(0x70004268, 0xFF1C),	/* 70004268 */
	S5K4ECGX_REG_WRITE(0x7000426A, 0xE12F),	/* 7000426A */
	S5K4ECGX_REG_WRITE(0x7000426C, 0x7EDF),	/* 7000426C */
	S5K4ECGX_REG_WRITE(0x7000426E, 0x0000),	/* 7000426E */
	S5K4ECGX_REG_WRITE(0x70004270, 0x4778),	/* 70004270 */
	S5K4ECGX_REG_WRITE(0x70004272, 0x46C0),	/* 70004272 */
	S5K4ECGX_REG_WRITE(0x70004274, 0xC000),	/* 70004274 */
	S5K4ECGX_REG_WRITE(0x70004276, 0xE59F),	/* 70004276 */
	S5K4ECGX_REG_WRITE(0x70004278, 0xFF1C),	/* 70004278 */
	S5K4ECGX_REG_WRITE(0x7000427A, 0xE12F),	/* 7000427A */
	S5K4ECGX_REG_WRITE(0x7000427C, 0x448D),	/* 7000427C */
	S5K4ECGX_REG_WRITE(0x7000427E, 0x0000),	/* 7000427E */
	S5K4ECGX_REG_WRITE(0x70004280, 0x4778),	/* 70004280 */
	S5K4ECGX_REG_WRITE(0x70004282, 0x46C0),	/* 70004282 */
	S5K4ECGX_REG_WRITE(0x70004284, 0xF004),	/* 70004284 */
	S5K4ECGX_REG_WRITE(0x70004286, 0xE51F),	/* 70004286 */
	S5K4ECGX_REG_WRITE(0x70004288, 0x29EC),	/* 70004288 */
	S5K4ECGX_REG_WRITE(0x7000428A, 0x0001),	/* 7000428A */
	S5K4ECGX_REG_WRITE(0x7000428C, 0x4778),	/* 7000428C */
	S5K4ECGX_REG_WRITE(0x7000428E, 0x46C0),	/* 7000428E */
	S5K4ECGX_REG_WRITE(0x70004290, 0xC000),	/* 70004290 */
	S5K4ECGX_REG_WRITE(0x70004292, 0xE59F),	/* 70004292 */
	S5K4ECGX_REG_WRITE(0x70004294, 0xFF1C),	/* 70004294 */
	S5K4ECGX_REG_WRITE(0x70004296, 0xE12F),	/* 70004296 */
	S5K4ECGX_REG_WRITE(0x70004298, 0x2EF1),	/* 70004298 */
	S5K4ECGX_REG_WRITE(0x7000429A, 0x0000),	/* 7000429A */
	S5K4ECGX_REG_WRITE(0x7000429C, 0x4778),	/* 7000429C */
	S5K4ECGX_REG_WRITE(0x7000429E, 0x46C0),	/* 7000429E */
	S5K4ECGX_REG_WRITE(0x700042A0, 0xC000),	/* 700042A0 */
	S5K4ECGX_REG_WRITE(0x700042A2, 0xE59F),	/* 700042A2 */
	S5K4ECGX_REG_WRITE(0x700042A4, 0xFF1C),	/* 700042A4 */
	S5K4ECGX_REG_WRITE(0x700042A6, 0xE12F),	/* 700042A6 */
	S5K4ECGX_REG_WRITE(0x700042A8, 0xEE03),	/* 700042A8 */
	S5K4ECGX_REG_WRITE(0x700042AA, 0x0000),	/* 700042AA */
	S5K4ECGX_REG_WRITE(0x700042AC, 0x4778),	/* 700042AC */
	S5K4ECGX_REG_WRITE(0x700042AE, 0x46C0),	/* 700042AE */
	S5K4ECGX_REG_WRITE(0x700042B0, 0xC000),	/* 700042B0 */
	S5K4ECGX_REG_WRITE(0x700042B2, 0xE59F),	/* 700042B2 */
	S5K4ECGX_REG_WRITE(0x700042B4, 0xFF1C),	/* 700042B4 */
	S5K4ECGX_REG_WRITE(0x700042B6, 0xE12F),	/* 700042B6 */
	S5K4ECGX_REG_WRITE(0x700042B8, 0xA58B),	/* 700042B8 */
	S5K4ECGX_REG_WRITE(0x700042BA, 0x0000),	/* 700042BA */
	S5K4ECGX_REG_WRITE(0x700042BC, 0x4778),	/* 700042BC */
	S5K4ECGX_REG_WRITE(0x700042BE, 0x46C0),	/* 700042BE */
	S5K4ECGX_REG_WRITE(0x700042C0, 0xC000),	/* 700042C0 */
	S5K4ECGX_REG_WRITE(0x700042C2, 0xE59F),	/* 700042C2 */
	S5K4ECGX_REG_WRITE(0x700042C4, 0xFF1C),	/* 700042C4 */
	S5K4ECGX_REG_WRITE(0x700042C6, 0xE12F),	/* 700042C6 */
	S5K4ECGX_REG_WRITE(0x700042C8, 0x7C49),	/* 700042C8 */
	S5K4ECGX_REG_WRITE(0x700042CA, 0x0000),	/* 700042CA */
	S5K4ECGX_REG_WRITE(0x700042CC, 0x4778),	/* 700042CC */
	S5K4ECGX_REG_WRITE(0x700042CE, 0x46C0),	/* 700042CE */
	S5K4ECGX_REG_WRITE(0x700042D0, 0xC000),	/* 700042D0 */
	S5K4ECGX_REG_WRITE(0x700042D2, 0xE59F),	/* 700042D2 */
	S5K4ECGX_REG_WRITE(0x700042D4, 0xFF1C),	/* 700042D4 */
	S5K4ECGX_REG_WRITE(0x700042D6, 0xE12F),	/* 700042D6 */
	S5K4ECGX_REG_WRITE(0x700042D8, 0x7C63),	/* 700042D8 */
	S5K4ECGX_REG_WRITE(0x700042DA, 0x0000),	/* 700042DA */
	S5K4ECGX_REG_WRITE(0x700042DC, 0x4778),	/* 700042DC */
	S5K4ECGX_REG_WRITE(0x700042DE, 0x46C0),	/* 700042DE */
	S5K4ECGX_REG_WRITE(0x700042E0, 0xC000),	/* 700042E0 */
	S5K4ECGX_REG_WRITE(0x700042E2, 0xE59F),	/* 700042E2 */
	S5K4ECGX_REG_WRITE(0x700042E4, 0xFF1C),	/* 700042E4 */
	S5K4ECGX_REG_WRITE(0x700042E6, 0xE12F),	/* 700042E6 */
	S5K4ECGX_REG_WRITE(0x700042E8, 0x2DB7),	/* 700042E8 */
	S5K4ECGX_REG_WRITE(0x700042EA, 0x0000),	/* 700042EA */
	S5K4ECGX_REG_WRITE(0x700042EC, 0x4778),	/* 700042EC */
	S5K4ECGX_REG_WRITE(0x700042EE, 0x46C0),	/* 700042EE */
	S5K4ECGX_REG_WRITE(0x700042F0, 0xC000),	/* 700042F0 */
	S5K4ECGX_REG_WRITE(0x700042F2, 0xE59F),	/* 700042F2 */
	S5K4ECGX_REG_WRITE(0x700042F4, 0xFF1C),	/* 700042F4 */
	S5K4ECGX_REG_WRITE(0x700042F6, 0xE12F),	/* 700042F6 */
	S5K4ECGX_REG_WRITE(0x700042F8, 0xEB3D),	/* 700042F8 */
	S5K4ECGX_REG_WRITE(0x700042FA, 0x0000),	/* 700042FA */
	S5K4ECGX_REG_WRITE(0x700042FC, 0x4778),	/* 700042FC */
	S5K4ECGX_REG_WRITE(0x700042FE, 0x46C0),	/* 700042FE */
	S5K4ECGX_REG_WRITE(0x70004300, 0xC000),	/* 70004300 */
	S5K4ECGX_REG_WRITE(0x70004302, 0xE59F),	/* 70004302 */
	S5K4ECGX_REG_WRITE(0x70004304, 0xFF1C),	/* 70004304 */
	S5K4ECGX_REG_WRITE(0x70004306, 0xE12F),	/* 70004306 */
	S5K4ECGX_REG_WRITE(0x70004308, 0xF061),	/* 70004308 */
	S5K4ECGX_REG_WRITE(0x7000430A, 0x0000),	/* 7000430A */
	S5K4ECGX_REG_WRITE(0x7000430C, 0x4778),	/* 7000430C */
	S5K4ECGX_REG_WRITE(0x7000430E, 0x46C0),	/* 7000430E */
	S5K4ECGX_REG_WRITE(0x70004310, 0xC000),	/* 70004310 */
	S5K4ECGX_REG_WRITE(0x70004312, 0xE59F),	/* 70004312 */
	S5K4ECGX_REG_WRITE(0x70004314, 0xFF1C),	/* 70004314 */
	S5K4ECGX_REG_WRITE(0x70004316, 0xE12F),	/* 70004316 */
	S5K4ECGX_REG_WRITE(0x70004318, 0xF0EF),	/* 70004318 */
	S5K4ECGX_REG_WRITE(0x7000431A, 0x0000),	/* 7000431A */
	S5K4ECGX_REG_WRITE(0x7000431C, 0x4778),	/* 7000431C */
	S5K4ECGX_REG_WRITE(0x7000431E, 0x46C0),	/* 7000431E */
	S5K4ECGX_REG_WRITE(0x70004320, 0xF004),	/* 70004320 */
	S5K4ECGX_REG_WRITE(0x70004322, 0xE51F),	/* 70004322 */
	S5K4ECGX_REG_WRITE(0x70004324, 0x2824),	/* 70004324 */
	S5K4ECGX_REG_WRITE(0x70004326, 0x0001),	/* 70004326 */
	S5K4ECGX_REG_WRITE(0x70004328, 0x4778),	/* 70004328 */
	S5K4ECGX_REG_WRITE(0x7000432A, 0x46C0),	/* 7000432A */
	S5K4ECGX_REG_WRITE(0x7000432C, 0xC000),	/* 7000432C */
	S5K4ECGX_REG_WRITE(0x7000432E, 0xE59F),	/* 7000432E */
	S5K4ECGX_REG_WRITE(0x70004330, 0xFF1C),	/* 70004330 */
	S5K4ECGX_REG_WRITE(0x70004332, 0xE12F),	/* 70004332 */
	S5K4ECGX_REG_WRITE(0x70004334, 0x8EDD),	/* 70004334 */
	S5K4ECGX_REG_WRITE(0x70004336, 0x0000),	/* 70004336 */
	S5K4ECGX_REG_WRITE(0x70004338, 0x4778),	/* 70004338 */
	S5K4ECGX_REG_WRITE(0x7000433A, 0x46C0),	/* 7000433A */
	S5K4ECGX_REG_WRITE(0x7000433C, 0xC000),	/* 7000433C */
	S5K4ECGX_REG_WRITE(0x7000433E, 0xE59F),	/* 7000433E */
	S5K4ECGX_REG_WRITE(0x70004340, 0xFF1C),	/* 70004340 */
	S5K4ECGX_REG_WRITE(0x70004342, 0xE12F),	/* 70004342 */
	S5K4ECGX_REG_WRITE(0x70004344, 0x8DCB),	/* 70004344 */
	S5K4ECGX_REG_WRITE(0x70004346, 0x0000),	/* 70004346 */
	S5K4ECGX_REG_WRITE(0x70004348, 0x4778),	/* 70004348 */
	S5K4ECGX_REG_WRITE(0x7000434A, 0x46C0),	/* 7000434A */
	S5K4ECGX_REG_WRITE(0x7000434C, 0xC000),	/* 7000434C */
	S5K4ECGX_REG_WRITE(0x7000434E, 0xE59F),	/* 7000434E */
	S5K4ECGX_REG_WRITE(0x70004350, 0xFF1C),	/* 70004350 */
	S5K4ECGX_REG_WRITE(0x70004352, 0xE12F),	/* 70004352 */
	S5K4ECGX_REG_WRITE(0x70004354, 0x8E17),	/* 70004354 */
	S5K4ECGX_REG_WRITE(0x70004356, 0x0000),	/* 70004356 */
	S5K4ECGX_REG_WRITE(0x70004358, 0x4778),	/* 70004358 */
	S5K4ECGX_REG_WRITE(0x7000435A, 0x46C0),	/* 7000435A */
	S5K4ECGX_REG_WRITE(0x7000435C, 0xC000),	/* 7000435C */
	S5K4ECGX_REG_WRITE(0x7000435E, 0xE59F),	/* 7000435E */
	S5K4ECGX_REG_WRITE(0x70004360, 0xFF1C),	/* 70004360 */
	S5K4ECGX_REG_WRITE(0x70004362, 0xE12F),	/* 70004362 */
	S5K4ECGX_REG_WRITE(0x70004364, 0x98C5),	/* 70004364 */
	S5K4ECGX_REG_WRITE(0x70004366, 0x0000),	/* 70004366 */
	S5K4ECGX_REG_WRITE(0x70004368, 0x4778),	/* 70004368 */
	S5K4ECGX_REG_WRITE(0x7000436A, 0x46C0),	/* 7000436A */
	S5K4ECGX_REG_WRITE(0x7000436C, 0xC000),	/* 7000436C */
	S5K4ECGX_REG_WRITE(0x7000436E, 0xE59F),	/* 7000436E */
	S5K4ECGX_REG_WRITE(0x70004370, 0xFF1C),	/* 70004370 */
	S5K4ECGX_REG_WRITE(0x70004372, 0xE12F),	/* 70004372 */
	S5K4ECGX_REG_WRITE(0x70004374, 0x7C7D),	/* 70004374 */
	S5K4ECGX_REG_WRITE(0x70004376, 0x0000),	/* 70004376 */
	S5K4ECGX_REG_WRITE(0x70004378, 0x4778),	/* 70004378 */
	S5K4ECGX_REG_WRITE(0x7000437A, 0x46C0),	/* 7000437A */
	S5K4ECGX_REG_WRITE(0x7000437C, 0xC000),	/* 7000437C */
	S5K4ECGX_REG_WRITE(0x7000437E, 0xE59F),	/* 7000437E */
	S5K4ECGX_REG_WRITE(0x70004380, 0xFF1C),	/* 70004380 */
	S5K4ECGX_REG_WRITE(0x70004382, 0xE12F),	/* 70004382 */
	S5K4ECGX_REG_WRITE(0x70004384, 0x7E31),	/* 70004384 */
	S5K4ECGX_REG_WRITE(0x70004386, 0x0000),	/* 70004386 */
	S5K4ECGX_REG_WRITE(0x70004388, 0x4778),	/* 70004388 */
	S5K4ECGX_REG_WRITE(0x7000438A, 0x46C0),	/* 7000438A */
	S5K4ECGX_REG_WRITE(0x7000438C, 0xC000),	/* 7000438C */
	S5K4ECGX_REG_WRITE(0x7000438E, 0xE59F),	/* 7000438E */
	S5K4ECGX_REG_WRITE(0x70004390, 0xFF1C),	/* 70004390 */
	S5K4ECGX_REG_WRITE(0x70004392, 0xE12F),	/* 70004392 */
	S5K4ECGX_REG_WRITE(0x70004394, 0x7EAB),	/* 70004394 */
	S5K4ECGX_REG_WRITE(0x70004396, 0x0000),	/* 70004396 */
	/* End of Patch Data(Last : 70004396h) */
	/* Total Size 2208 (08A0) */
	/* Addr : 3AF8 , Size : 2206(89Eh) */

	/* #define	TNP_USER_MBCV_CONTROL */
	/* #define TNP_4EC_MBR_TUNE */
	/* #define TNP_4EC_FORBIDDEN_TUNE */
	/* #define TNP_AF_FINESEARCH_DRIVEBACK */
	/* #define TNP_FLASH_ALG */
	/* #define TNP_GAS_ALPHA_OTP */
	/* #define	TNP_AWB_MODUL_COMP */
	/* #define	TNP_AWB_INIT_QUEUE */

	/* TNP_Regs_usCintrTh         2   70004780 */
	/* TNP_Regs_usFixedCintc      2   70004782 */
	/* TNP_Regs_FlsWeightRIn_0_   2   70004784 */
	/* TNP_Regs_FlsWeightRIn_1_   2   70004786 */
	/* TNP_Regs_FlsWeightRIn_2_   2   70004788 */
	/* TNP_Regs_FlsWeightRIn_3_   2   7000478A */
	/* TNP_Regs_FlsWeightRIn_4_   2   7000478C */
	/* TNP_Regs_FlsWeightRIn_5_   2   7000478E */
	/* TNP_Regs_FlsWeightROut_0_  2   70004790 */
	/* TNP_Regs_FlsWeightROut_1_  2   70004792 */
	/* TNP_Regs_FlsWeightROut_2_  2   70004794 */
	/* TNP_Regs_FlsWeightROut_3_  2   70004796 */
	/* TNP_Regs_FlsWeightROut_4_  2   70004798 */
	/* TNP_Regs_FlsWeightROut_5_  2   7000479A */

	/* TNP_Regs_FlBRIn_0_         2   7000479C */
	/* TNP_Regs_FlBRIn_1_         2   7000479E */
	/* TNP_Regs_FlBRIn_2_         2   700047A0 */
	/* TNP_Regs_FlBRInOut_0_      2   700047A2 */
	/* TNP_Regs_FlBRInOut_1_      2   700047A4 */
	/* TNP_Regs_FlBRInOut_2_      2   700047A6 */

	S5K4ECGX_REG_WRITE(0xD0001000, 0x0001),

	/* AF setting */
	S5K4ECGX_REG_WRITE(0x700001FC, 0x0001),	/* #REG_TC_IPRM_LedGpio */
	S5K4ECGX_REG_WRITE(0x70001720, 0x0100),
	S5K4ECGX_REG_WRITE(0x700001FE, 0x0003),
	S5K4ECGX_REG_WRITE(0x70000200, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000204, 0x0061),
	S5K4ECGX_REG_WRITE(0x7000020C, 0x2F0C),
	S5K4ECGX_REG_WRITE(0x7000020E, 0x0190),
	S5K4ECGX_REG_WRITE(0x70000294, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000296, 0x00E3),
	S5K4ECGX_REG_WRITE(0x70000298, 0x0200),
	S5K4ECGX_REG_WRITE(0x7000029A, 0x0238),
	S5K4ECGX_REG_WRITE(0x7000029C, 0x01C6),
	S5K4ECGX_REG_WRITE(0x7000029E, 0x0166),
	S5K4ECGX_REG_WRITE(0x700002A0, 0x0074),
	S5K4ECGX_REG_WRITE(0x700002A2, 0x0132),
	S5K4ECGX_REG_WRITE(0x700002A4, 0x0001),

	S5K4ECGX_REG_WRITE(0x7000070E, 0x00C0),
	S5K4ECGX_REG_WRITE(0x7000071E, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000163C, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001648, 0x9002),
	S5K4ECGX_REG_WRITE(0x70001652, 0x0002),
	S5K4ECGX_REG_WRITE(0x70001654, 0x0000),
	S5K4ECGX_REG_WRITE(0x700015E0, 0x0902),

	S5K4ECGX_REG_WRITE(0x7000164C, 0x0003),
	S5K4ECGX_REG_WRITE(0x7000163E, 0x00D5),
	S5K4ECGX_REG_WRITE(0x70001640, 0x0098),
	S5K4ECGX_REG_WRITE(0x700015D4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700015D6, 0xD000),
	S5K4ECGX_REG_WRITE(0x7000169A, 0xFF95),
	S5K4ECGX_REG_WRITE(0x7000166A, 0x0280),
	S5K4ECGX_REG_WRITE(0x70001676, 0x03A0),
	S5K4ECGX_REG_WRITE(0x70001678, 0x0320),
	S5K4ECGX_REG_WRITE(0x700016BC, 0x0030),
	S5K4ECGX_REG_WRITE(0x700016E0, 0x0060),
	S5K4ECGX_REG_WRITE(0x700016D4, 0x0010),
	S5K4ECGX_REG_WRITE(0x70001656, 0x0000),
	S5K4ECGX_REG_WRITE(0x700015E6, 0x003C),

	S5K4ECGX_REG_WRITE(0x700015E8, 0x0018),	/* #af_pos_usTableLastInd */
	S5K4ECGX_REG_WRITE(0x700015EA, 0x002A),
	S5K4ECGX_REG_WRITE(0x700015EC, 0x0030),
	S5K4ECGX_REG_WRITE(0x700015EE, 0x0036),
	S5K4ECGX_REG_WRITE(0x700015F0, 0x003C),
	S5K4ECGX_REG_WRITE(0x700015F2, 0x0042),
	S5K4ECGX_REG_WRITE(0x700015F4, 0x0048),
	S5K4ECGX_REG_WRITE(0x700015F6, 0x004E),
	S5K4ECGX_REG_WRITE(0x700015F8, 0x0054),
	S5K4ECGX_REG_WRITE(0x700015FA, 0x005A),
	S5K4ECGX_REG_WRITE(0x700015FC, 0x0060),
	S5K4ECGX_REG_WRITE(0x700015FE, 0x0066),
	S5K4ECGX_REG_WRITE(0x70001600, 0x006C),
	S5K4ECGX_REG_WRITE(0x70001602, 0x0072),
	S5K4ECGX_REG_WRITE(0x70001604, 0x0078),
	S5K4ECGX_REG_WRITE(0x70001606, 0x007E),
	S5K4ECGX_REG_WRITE(0x70001608, 0x0084),
	S5K4ECGX_REG_WRITE(0x7000160A, 0x008A),
	S5K4ECGX_REG_WRITE(0x7000160C, 0x0090),
	S5K4ECGX_REG_WRITE(0x7000160E, 0x0096),
	S5K4ECGX_REG_WRITE(0x70001610, 0x009C),
	S5K4ECGX_REG_WRITE(0x70001612, 0x00A2),
	S5K4ECGX_REG_WRITE(0x70001614, 0x00A8),
	S5K4ECGX_REG_WRITE(0x70001616, 0x00AE),
	S5K4ECGX_REG_WRITE(0x70001618, 0x00B4),
	S5K4ECGX_REG_WRITE(0x7000161A, 0x00BA),	/* #af_pos_usTable_24_ */

	S5K4ECGX_REG_WRITE(0x70001722, 0x8000),
	S5K4ECGX_REG_WRITE(0x70001724, 0x0006),
	S5K4ECGX_REG_WRITE(0x70001726, 0x3FF0),
	S5K4ECGX_REG_WRITE(0x70001728, 0x03E8),
	S5K4ECGX_REG_WRITE(0x7000172A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000172C, 0x0020),
	S5K4ECGX_REG_WRITE(0x7000172E, 0x0010),
	S5K4ECGX_REG_WRITE(0x70001730, 0x0008),
	S5K4ECGX_REG_WRITE(0x70001732, 0x0040),
	S5K4ECGX_REG_WRITE(0x70001734, 0x0080),
	S5K4ECGX_REG_WRITE(0x70001736, 0x00C0),
	S5K4ECGX_REG_WRITE(0x70001738, 0x00E0),

	S5K4ECGX_REG_WRITE(0x7000028C, 0x0003),	/* #REG_TC_AF_AfCmd */

	/* GAS TBL setting */
	S5K4ECGX_REG_WRITE(0x700008B4, 0x0001),	/* #wbt_bUseOutdoorASH */

	/* TVAR_ash_AwbAshCord, Refer Mon_AWB_RotGain */
	S5K4ECGX_REG_WRITE(0x700008BC, 0x00C0),	/* #TVAR_ash_AwbAshCord_0_ 2300K */
	S5K4ECGX_REG_WRITE(0x700008BE, 0x00DF),	/* #TVAR_ash_AwbAshCord_1_ 2750K */
	S5K4ECGX_REG_WRITE(0x700008C0, 0x0100),	/* #TVAR_ash_AwbAshCord_2_ 3300K */
	S5K4ECGX_REG_WRITE(0x700008C2, 0x0125),	/* #TVAR_ash_AwbAshCord_3_ 4150K */
	S5K4ECGX_REG_WRITE(0x700008C4, 0x015F),	/* #TVAR_ash_AwbAshCord_4_ 5250K */
	S5K4ECGX_REG_WRITE(0x700008C6, 0x017C),	/* #TVAR_ash_AwbAshCord_5_ 6400K */
	S5K4ECGX_REG_WRITE(0x700008C8, 0x0194),	/* #TVAR_ash_AwbAshCord_6_ 7500K */

	S5K4ECGX_REG_WRITE(0x700008F6, 0x4000),
	S5K4ECGX_REG_WRITE(0x700008F8, 0x4000),
	S5K4ECGX_REG_WRITE(0x700008FA, 0x4000),
	S5K4ECGX_REG_WRITE(0x700008FC, 0x4000),

	S5K4ECGX_REG_WRITE(0x700008FE, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000900, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000902, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000904, 0x4000),

	S5K4ECGX_REG_WRITE(0x70000906, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000908, 0x4000),
	S5K4ECGX_REG_WRITE(0x7000090A, 0x4000),
	S5K4ECGX_REG_WRITE(0x7000090C, 0x4000),

	S5K4ECGX_REG_WRITE(0x7000090E, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000910, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000912, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000914, 0x4000),

	S5K4ECGX_REG_WRITE(0x70000916, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000918, 0x4000),
	S5K4ECGX_REG_WRITE(0x7000091A, 0x4000),
	S5K4ECGX_REG_WRITE(0x7000091C, 0x4000),

	S5K4ECGX_REG_WRITE(0x7000091E, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000920, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000922, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000924, 0x4000),

	S5K4ECGX_REG_WRITE(0x70000926, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000928, 0x4000),
	S5K4ECGX_REG_WRITE(0x7000092A, 0x4000),
	S5K4ECGX_REG_WRITE(0x7000092C, 0x4000),

	S5K4ECGX_REG_WRITE(0x7000092E, 0x4500),
	S5K4ECGX_REG_WRITE(0x70000930, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000932, 0x4000),
	S5K4ECGX_REG_WRITE(0x70000934, 0x4000),

	S5K4ECGX_REG_WRITE(0x700008F4, 0x0001),	/* #ash_bUseGasAlpha */

	/* AE START */

	/* AE WEIGHT */
	S5K4ECGX_REG_WRITE(0x70001492, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001494, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001496, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001498, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000149A, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000149C, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000149E, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014A0, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014A2, 0x0201),
	S5K4ECGX_REG_WRITE(0x700014A4, 0x0303),
	S5K4ECGX_REG_WRITE(0x700014A6, 0x0303),
	S5K4ECGX_REG_WRITE(0x700014A8, 0x0102),
	S5K4ECGX_REG_WRITE(0x700014AA, 0x0201),
	S5K4ECGX_REG_WRITE(0x700014AC, 0x0403),
	S5K4ECGX_REG_WRITE(0x700014AE, 0x0304),
	S5K4ECGX_REG_WRITE(0x700014B0, 0x0102),
	S5K4ECGX_REG_WRITE(0x700014B2, 0x0201),
	S5K4ECGX_REG_WRITE(0x700014B4, 0x0403),
	S5K4ECGX_REG_WRITE(0x700014B6, 0x0304),
	S5K4ECGX_REG_WRITE(0x700014B8, 0x0102),
	S5K4ECGX_REG_WRITE(0x700014BA, 0x0201),
	S5K4ECGX_REG_WRITE(0x700014BC, 0x0403),
	S5K4ECGX_REG_WRITE(0x700014BE, 0x0304),
	S5K4ECGX_REG_WRITE(0x700014C0, 0x0102),
	S5K4ECGX_REG_WRITE(0x700014C2, 0x0201),
	S5K4ECGX_REG_WRITE(0x700014C4, 0x0303),
	S5K4ECGX_REG_WRITE(0x700014C6, 0x0303),
	S5K4ECGX_REG_WRITE(0x700014C8, 0x0102),
	S5K4ECGX_REG_WRITE(0x700014CA, 0x0201),
	S5K4ECGX_REG_WRITE(0x700014CC, 0x0202),
	S5K4ECGX_REG_WRITE(0x700014CE, 0x0202),
	S5K4ECGX_REG_WRITE(0x700014D0, 0x0102),

	S5K4ECGX_REG_WRITE(0x70001484, 0x003C),	/* #TVAR_ae_BrAve */
	S5K4ECGX_REG_WRITE(0x7000148A, 0x000F),	/* #ae_StatMode */
	S5K4ECGX_REG_WRITE(0x7000058C, 0x3520),
	S5K4ECGX_REG_WRITE(0x7000058E, 0x0000),	/* #lt_uMaxExp1 */
	S5K4ECGX_REG_WRITE(0x70000590, 0xC350),
	S5K4ECGX_REG_WRITE(0x70000592, 0x0000),	/* #lt_uMaxExp2 */
	S5K4ECGX_REG_WRITE(0x70000594, 0x3520),
	S5K4ECGX_REG_WRITE(0x70000596, 0x0000),	/* #lt_uCapMaxExp1 */
	S5K4ECGX_REG_WRITE(0x70000598, 0xC350),
	S5K4ECGX_REG_WRITE(0x7000059A, 0x0000),	/* #lt_uCapMaxExp2 */
	S5K4ECGX_REG_WRITE(0x7000059C, 0x0470),	/* #lt_uMaxAnGain1 */
	S5K4ECGX_REG_WRITE(0x7000059E, 0x0C00),	/* #lt_uMaxAnGain2 */
	S5K4ECGX_REG_WRITE(0x700005A0, 0x0100),	/* #lt_uMaxDigGain */
	S5K4ECGX_REG_WRITE(0x700005A2, 0x1000),	/* #lt_uMaxTotGain */

	S5K4ECGX_REG_WRITE(0x70000544, 0x0111),	/* #lt_uLimitHigh */
	S5K4ECGX_REG_WRITE(0x70000546, 0x00EF),	/* #lt_uLimitLow */

	S5K4ECGX_REG_WRITE(0x70000F2A, 0x0001),	/* #AFC_Default60Hz */
	S5K4ECGX_REG_WRITE(0x70000F30, 0x0002),	/* #AFC_D_ConvAccelerPower */

	S5K4ECGX_REG_WRITE(0x70000588, 0x0000),	/* AE Speed-up */

	S5K4ECGX_REG_WRITE(0x70000600, 0xD000),

	S5K4ECGX_REG_WRITE(0x70000608, 0x0001),	/* #lt_ExpGain_uSubsamplingmode */
	S5K4ECGX_REG_WRITE(0x7000060A, 0x0001),	/* #lt_ExpGain_uNonSubsampling */
	S5K4ECGX_REG_WRITE(0x7000060C, 0x0C00),	/* #lt_ExpGain_ExpCurveGainMaxStr */
	S5K4ECGX_REG_WRITE(0x7000060E, 0x0100),	/* #lt_ExpGain_ExpCurveGainMaxStr_0__uMaxDigGain */
	S5K4ECGX_REG_WRITE(0x70000610, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000612, 0x0000),	/* #lt_ExpGain_ExpCurveGainMaxStr_0__ulExpIn_0_ */
	S5K4ECGX_REG_WRITE(0x70000614, 0x0A3C),
	S5K4ECGX_REG_WRITE(0x70000616, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000618, 0x0D04),
	S5K4ECGX_REG_WRITE(0x7000061A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000061C, 0x4008),
	S5K4ECGX_REG_WRITE(0x7000061E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000620, 0x7000),
	S5K4ECGX_REG_WRITE(0x70000622, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000624, 0x9C00),
	S5K4ECGX_REG_WRITE(0x70000626, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000628, 0xAD00),
	S5K4ECGX_REG_WRITE(0x7000062A, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000062C, 0xF1D4),
	S5K4ECGX_REG_WRITE(0x7000062E, 0x0002),
	S5K4ECGX_REG_WRITE(0x70000630, 0xDC00),
	S5K4ECGX_REG_WRITE(0x70000632, 0x0005),
	S5K4ECGX_REG_WRITE(0x70000634, 0xDC00),
	S5K4ECGX_REG_WRITE(0x70000636, 0x0005),
	S5K4ECGX_REG_WRITE(0x70000638, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000063A, 0x0000),	/* #lt_ExpGain_ExpCurveGainMaxStr_0__ulExpOut_0_ */
	S5K4ECGX_REG_WRITE(0x7000063C, 0x0A3C),
	S5K4ECGX_REG_WRITE(0x7000063E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000640, 0x0D05),
	S5K4ECGX_REG_WRITE(0x70000642, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000644, 0x3408),
	S5K4ECGX_REG_WRITE(0x70000646, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000648, 0x3408),
	S5K4ECGX_REG_WRITE(0x7000064A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000064C, 0x6810),
	S5K4ECGX_REG_WRITE(0x7000064E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000650, 0x8214),
	S5K4ECGX_REG_WRITE(0x70000652, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000654, 0xC350),
	S5K4ECGX_REG_WRITE(0x70000656, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000658, 0xC350),
	S5K4ECGX_REG_WRITE(0x7000065A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000065C, 0xC350),
	S5K4ECGX_REG_WRITE(0x7000065E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000660, 0x0650),	/* #lt_ExpGain_ExpCurveGainMaxStr_1_ */
	S5K4ECGX_REG_WRITE(0x70000662, 0x0100),	/* #lt_ExpGain_ExpCurveGainMaxStr_1__uMaxDigGain */

	S5K4ECGX_REG_WRITE(0x700006B8, 0x452C),
	S5K4ECGX_REG_WRITE(0x700006BA, 0x000C),	/* #lt_uMaxLei */

	S5K4ECGX_REG_WRITE(0x700005D0, 0x0000),	/* #lt_mbr_Peak_behind */

	/* AWB init Start point */
	S5K4ECGX_REG_WRITE(0x7000145E, 0x0470),	/* 0400 */
	S5K4ECGX_REG_WRITE(0x70001460, 0x0400),	/* 0428 */
	S5K4ECGX_REG_WRITE(0x70001462, 0x09F0),	/* 9B3 */

	/* AWB Init */
	/* White Locus */
	S5K4ECGX_REG_WRITE(0x700011F0, 0x012C),	/* #awbb_IntcR */
	S5K4ECGX_REG_WRITE(0x700011F2, 0x0121),	/* #awbb_IntcB */

	/* IndoorZone */
	S5K4ECGX_REG_WRITE(0x7000101C, 0x039A),
	S5K4ECGX_REG_WRITE(0x7000101E, 0x03E8),
	S5K4ECGX_REG_WRITE(0x70001020, 0x033C),
	S5K4ECGX_REG_WRITE(0x70001022, 0x03AE),
	S5K4ECGX_REG_WRITE(0x70001024, 0x02DE),
	S5K4ECGX_REG_WRITE(0x70001026, 0x0376),
	S5K4ECGX_REG_WRITE(0x70001028, 0x029C),
	S5K4ECGX_REG_WRITE(0x7000102A, 0x033C),
	S5K4ECGX_REG_WRITE(0x7000102C, 0x027E),
	S5K4ECGX_REG_WRITE(0x7000102E, 0x0312),
	S5K4ECGX_REG_WRITE(0x70001030, 0x025E),
	S5K4ECGX_REG_WRITE(0x70001032, 0x02F6),
	S5K4ECGX_REG_WRITE(0x70001034, 0x023E),
	S5K4ECGX_REG_WRITE(0x70001036, 0x02DA),
	S5K4ECGX_REG_WRITE(0x70001038, 0x022A),
	S5K4ECGX_REG_WRITE(0x7000103A, 0x02BC),
	S5K4ECGX_REG_WRITE(0x7000103C, 0x0214),
	S5K4ECGX_REG_WRITE(0x7000103E, 0x02A2),
	S5K4ECGX_REG_WRITE(0x70001040, 0x01FE),
	S5K4ECGX_REG_WRITE(0x70001042, 0x0292),
	S5K4ECGX_REG_WRITE(0x70001044, 0x01F0),
	S5K4ECGX_REG_WRITE(0x70001046, 0x0284),
	S5K4ECGX_REG_WRITE(0x70001048, 0x01E0),
	S5K4ECGX_REG_WRITE(0x7000104A, 0x0276),
	S5K4ECGX_REG_WRITE(0x7000104C, 0x01D2),
	S5K4ECGX_REG_WRITE(0x7000104E, 0x0266),
	S5K4ECGX_REG_WRITE(0x70001050, 0x01C4),
	S5K4ECGX_REG_WRITE(0x70001052, 0x0258),
	S5K4ECGX_REG_WRITE(0x70001054, 0x01D8),
	S5K4ECGX_REG_WRITE(0x70001056, 0x0216),
	S5K4ECGX_REG_WRITE(0x70001058, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000105A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000105C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000105E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001060, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001062, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001064, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001066, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001068, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000106A, 0x0000),

	S5K4ECGX_REG_WRITE(0x7000106C, 0x0005),	/* #awbb_IndoorGrZones_m_GridStep */
	S5K4ECGX_REG_WRITE(0x70001070, 0x000F),	/* #awbb_IndoorGrZones_ZInfo_m_GridSz */
	S5K4ECGX_REG_WRITE(0x70001074, 0x013C),	/* #awbb_IndoorGrZones_m_Boffs */

	/* Outdoor Zone */
	S5K4ECGX_REG_WRITE(0x70001078, 0x0254),
	S5K4ECGX_REG_WRITE(0x7000107A, 0x0296),
	S5K4ECGX_REG_WRITE(0x7000107C, 0x0246),
	S5K4ECGX_REG_WRITE(0x7000107E, 0x02B4),
	S5K4ECGX_REG_WRITE(0x70001080, 0x0238),
	S5K4ECGX_REG_WRITE(0x70001082, 0x02B8),
	S5K4ECGX_REG_WRITE(0x70001084, 0x022A),
	S5K4ECGX_REG_WRITE(0x70001086, 0x02B0),
	S5K4ECGX_REG_WRITE(0x70001088, 0x021C),
	S5K4ECGX_REG_WRITE(0x7000108A, 0x02A6),
	S5K4ECGX_REG_WRITE(0x7000108C, 0x021A),
	S5K4ECGX_REG_WRITE(0x7000108E, 0x029C),
	S5K4ECGX_REG_WRITE(0x70001090, 0x021A),
	S5K4ECGX_REG_WRITE(0x70001092, 0x0292),
	S5K4ECGX_REG_WRITE(0x70001094, 0x0220),
	S5K4ECGX_REG_WRITE(0x70001096, 0x0288),
	S5K4ECGX_REG_WRITE(0x70001098, 0x0226),
	S5K4ECGX_REG_WRITE(0x7000109A, 0x027E),
	S5K4ECGX_REG_WRITE(0x7000109C, 0x0244),
	S5K4ECGX_REG_WRITE(0x7000109E, 0x0274),
	S5K4ECGX_REG_WRITE(0x700010A0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700010A2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700010A4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700010A6, 0x0000),

	S5K4ECGX_REG_WRITE(0x700010A8, 0x0004),	/* #awbb_OutdoorGrZones_m_GridStep */
	S5K4ECGX_REG_WRITE(0x700010AC, 0x000A),	/* #awbb_OutdoorGrZones_ZInfo_m_GridSz */
	S5K4ECGX_REG_WRITE(0x700010B0, 0x01EE),	/* #awbb_OutdoorGrZones_m_Boffs */

	/* LowBR Zone */
	S5K4ECGX_REG_WRITE(0x700010B4, 0x0350),
	S5K4ECGX_REG_WRITE(0x700010B6, 0x0422),
	S5K4ECGX_REG_WRITE(0x700010B8, 0x02C4),
	S5K4ECGX_REG_WRITE(0x700010BA, 0x0452),
	S5K4ECGX_REG_WRITE(0x700010BC, 0x0278),
	S5K4ECGX_REG_WRITE(0x700010BE, 0x041C),
	S5K4ECGX_REG_WRITE(0x700010C0, 0x0230),
	S5K4ECGX_REG_WRITE(0x700010C2, 0x03EE),
	S5K4ECGX_REG_WRITE(0x700010C4, 0x01F0),
	S5K4ECGX_REG_WRITE(0x700010C6, 0x0392),
	S5K4ECGX_REG_WRITE(0x700010C8, 0x01C0),
	S5K4ECGX_REG_WRITE(0x700010CA, 0x0340),
	S5K4ECGX_REG_WRITE(0x700010CC, 0x0194),
	S5K4ECGX_REG_WRITE(0x700010CE, 0x0302),
	S5K4ECGX_REG_WRITE(0x700010D0, 0x016E),
	S5K4ECGX_REG_WRITE(0x700010D2, 0x02C2),
	S5K4ECGX_REG_WRITE(0x700010D4, 0x0148),
	S5K4ECGX_REG_WRITE(0x700010D6, 0x0286),
	S5K4ECGX_REG_WRITE(0x700010D8, 0x018A),
	S5K4ECGX_REG_WRITE(0x700010DA, 0x0242),
	S5K4ECGX_REG_WRITE(0x700010DC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700010DE, 0x0000),
	S5K4ECGX_REG_WRITE(0x700010E0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700010E2, 0x0000),

	S5K4ECGX_REG_WRITE(0x700010E4, 0x0006),	/* #awbb_LowBrGrZones_m_GridStep */
	S5K4ECGX_REG_WRITE(0x700010E8, 0x000A),	/* #awbb_LowBrGrZones_ZInfo_m_GridSz */
	S5K4ECGX_REG_WRITE(0x700010EC, 0x0106),	/* #awbb_LowBrGrZones_m_Boffs */

	/* LowTemp Zone */
	S5K4ECGX_REG_WRITE(0x700010F0, 0x0380),
	S5K4ECGX_REG_WRITE(0x700010F2, 0x0000),	/* #awbb_CrclLowT_R_c */
	S5K4ECGX_REG_WRITE(0x700010F4, 0x0168),
	S5K4ECGX_REG_WRITE(0x700010F6, 0x0000),	/* #awbb_CrclLowT_B_c */
	S5K4ECGX_REG_WRITE(0x700010F8, 0x2D90),
	S5K4ECGX_REG_WRITE(0x700010FA, 0x0000),	/* #awbb_CrclLowT_Rad_c */

	/* AWB Convergence Speed */
	S5K4ECGX_REG_WRITE(0x70001464, 0x0008),
	S5K4ECGX_REG_WRITE(0x70001466, 0x0190),
	S5K4ECGX_REG_WRITE(0x70001468, 0x00A0),

	S5K4ECGX_REG_WRITE(0x70001228, 0x00C0),
	S5K4ECGX_REG_WRITE(0x7000122C, 0x0010),
	S5K4ECGX_REG_WRITE(0x7000122A, 0x0010),

	S5K4ECGX_REG_WRITE(0x7000120A, 0x05D5),	/* #awbb_MvEq_RBthresh */
	S5K4ECGX_REG_WRITE(0x7000120E, 0x0000),

	S5K4ECGX_REG_WRITE(0x70001210, 0x0771),
	S5K4ECGX_REG_WRITE(0x70001212, 0x03A4),
	S5K4ECGX_REG_WRITE(0x70001214, 0x0036),
	S5K4ECGX_REG_WRITE(0x70001216, 0x002A),

	S5K4ECGX_REG_WRITE(0x70001278, 0xFEF7),
	S5K4ECGX_REG_WRITE(0x7000127A, 0x0021),
	S5K4ECGX_REG_WRITE(0x7000127C, 0x0E74),
	S5K4ECGX_REG_WRITE(0x7000127E, 0x0E74),
	S5K4ECGX_REG_WRITE(0x70001280, 0x018F),
	S5K4ECGX_REG_WRITE(0x70001282, 0x0096),
	S5K4ECGX_REG_WRITE(0x70001284, 0x000E),
	S5K4ECGX_REG_WRITE(0x70001224, 0x0032),
	S5K4ECGX_REG_WRITE(0x70001226, 0x001E),
	S5K4ECGX_REG_WRITE(0x70001228, 0x00C0),
	S5K4ECGX_REG_WRITE(0x7000122A, 0x0010),
	S5K4ECGX_REG_WRITE(0x7000122C, 0x0002),	/* awbb_YThreshLow_Low */
	S5K4ECGX_REG_WRITE(0x70002BA4, 0x0006),	/* #Mon_AWB_ByPassMode */

	S5K4ECGX_REG_WRITE(0x7000146C, 0x0002),	/* #awbb_GridEnable */

	/* Grid */
	S5K4ECGX_REG_WRITE(0x70001434, 0x0300),	/* awbb_GridConst_1 */
	S5K4ECGX_REG_WRITE(0x70001436, 0x036E),	/* awbb_GridConst_1_1_ */
	S5K4ECGX_REG_WRITE(0x70001438, 0x03C2),	/* awbb_GridConst_1_2_ */
	S5K4ECGX_REG_WRITE(0x7000143A, 0x1074),	/* awbb_GridConst_2 */
	S5K4ECGX_REG_WRITE(0x7000143C, 0x10C2),	/* awbb_GridConst_2_1_ */
	S5K4ECGX_REG_WRITE(0x7000143E, 0x1104),	/* awbb_GridConst_2_2_ */
	S5K4ECGX_REG_WRITE(0x70001440, 0x1142),	/* awbb_GridConst_2_3_ */
	S5K4ECGX_REG_WRITE(0x70001442, 0x11BB),	/* awbb_GridConst_2_4_ */
	S5K4ECGX_REG_WRITE(0x70001444, 0x123B),	/* awbb_GridConst_2_5_ */
	S5K4ECGX_REG_WRITE(0x70001446, 0x00AB),	/* awbb_GridCoeff_R_1 */
	S5K4ECGX_REG_WRITE(0x70001448, 0x00BF),	/* awbb_GridCoeff_B_1 */
	S5K4ECGX_REG_WRITE(0x7000144A, 0x00D2),	/* awbb_GridCoeff_R_2 */
	S5K4ECGX_REG_WRITE(0x7000144C, 0x0093),	/* awbb_GridCoeff_B_2 */

	/* Indoor Grid Offset */
	S5K4ECGX_REG_WRITE(0x700013A4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700013A6, 0xFFD0),
	S5K4ECGX_REG_WRITE(0x700013A8, 0xFFD0),
	S5K4ECGX_REG_WRITE(0x700013AA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700013AC, 0x0008),
	S5K4ECGX_REG_WRITE(0x700013AE, 0x0018),
	S5K4ECGX_REG_WRITE(0x700013B0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700013B2, 0xFFD0),
	S5K4ECGX_REG_WRITE(0x700013B4, 0xFFD0),
	S5K4ECGX_REG_WRITE(0x700013B6, 0x0000),
	S5K4ECGX_REG_WRITE(0x700013B8, 0x0008),
	S5K4ECGX_REG_WRITE(0x700013BA, 0x0018),
	S5K4ECGX_REG_WRITE(0x700013BC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700013BE, 0xFFD0),
	S5K4ECGX_REG_WRITE(0x700013C0, 0xFFD0),
	S5K4ECGX_REG_WRITE(0x700013C2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700013C4, 0x0008),
	S5K4ECGX_REG_WRITE(0x700013C6, 0x0018),
	S5K4ECGX_REG_WRITE(0x700013C8, 0xFFE0),
	S5K4ECGX_REG_WRITE(0x700013CA, 0xFFE0),
	S5K4ECGX_REG_WRITE(0x700013CC, 0xFFC0),
	S5K4ECGX_REG_WRITE(0x700013CE, 0xFFC0),
	S5K4ECGX_REG_WRITE(0x700013D0, 0xFFB0),
	S5K4ECGX_REG_WRITE(0x700013D2, 0xFFB0),
	S5K4ECGX_REG_WRITE(0x700013D4, 0xFFE0),
	S5K4ECGX_REG_WRITE(0x700013D6, 0xFFE0),
	S5K4ECGX_REG_WRITE(0x700013D8, 0xFFC0),
	S5K4ECGX_REG_WRITE(0x700013DA, 0xFFC0),
	S5K4ECGX_REG_WRITE(0x700013DC, 0xFFB0),
	S5K4ECGX_REG_WRITE(0x700013DE, 0xFFB0),
	S5K4ECGX_REG_WRITE(0x700013E0, 0xFFE0),
	S5K4ECGX_REG_WRITE(0x700013E2, 0xFFE0),
	S5K4ECGX_REG_WRITE(0x700013E4, 0xFFC0),
	S5K4ECGX_REG_WRITE(0x700013E6, 0xFFC0),
	S5K4ECGX_REG_WRITE(0x700013E8, 0xFFB0),
	S5K4ECGX_REG_WRITE(0x700013EA, 0xFFB0),

	/* Outdoor Grid Offset */
	S5K4ECGX_REG_WRITE(0x700013EC, 0xFFB0),
	S5K4ECGX_REG_WRITE(0x700013EE, 0xFFD0),
	S5K4ECGX_REG_WRITE(0x700013F0, 0xFFD0),
	S5K4ECGX_REG_WRITE(0x700013F2, 0xFFD0),
	S5K4ECGX_REG_WRITE(0x700013F4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700013F6, 0x0000),
	S5K4ECGX_REG_WRITE(0x700013F8, 0xFFB0),
	S5K4ECGX_REG_WRITE(0x700013FA, 0xFFD0),
	S5K4ECGX_REG_WRITE(0x700013FC, 0xFFD0),
	S5K4ECGX_REG_WRITE(0x700013FE, 0xFFD0),
	S5K4ECGX_REG_WRITE(0x70001400, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001402, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001404, 0xFFB0),
	S5K4ECGX_REG_WRITE(0x70001406, 0xFFD0),
	S5K4ECGX_REG_WRITE(0x70001408, 0xFFD0),
	S5K4ECGX_REG_WRITE(0x7000140A, 0xFFD0),
	S5K4ECGX_REG_WRITE(0x7000140C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000140E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001410, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001412, 0xFFC8),
	S5K4ECGX_REG_WRITE(0x70001414, 0xFFB8),
	S5K4ECGX_REG_WRITE(0x70001416, 0xFFB8),
	S5K4ECGX_REG_WRITE(0x70001418, 0xFFB8),
	S5K4ECGX_REG_WRITE(0x7000141A, 0xFFB8),
	S5K4ECGX_REG_WRITE(0x7000141C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000141E, 0xFFC8),
	S5K4ECGX_REG_WRITE(0x70001420, 0xFFB8),
	S5K4ECGX_REG_WRITE(0x70001422, 0xFFB8),
	S5K4ECGX_REG_WRITE(0x70001424, 0xFFB8),
	S5K4ECGX_REG_WRITE(0x70001426, 0xFFB8),
	S5K4ECGX_REG_WRITE(0x70001428, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000142A, 0xFFC8),
	S5K4ECGX_REG_WRITE(0x7000142C, 0xFFB8),
	S5K4ECGX_REG_WRITE(0x7000142E, 0xFFB8),
	S5K4ECGX_REG_WRITE(0x70001430, 0xFFB8),
	S5K4ECGX_REG_WRITE(0x70001432, 0xFFB8),

	S5K4ECGX_REG_WRITE(0x70001208, 0x0020),

	S5K4ECGX_REG_WRITE(0x7000144E, 0x0000),	/* #awbb_RGainOff */
	S5K4ECGX_REG_WRITE(0x70001450, 0x0000),	/* #awbb_BGainOff */
	S5K4ECGX_REG_WRITE(0x70001452, 0x0000),	/* #awbb_GGainOff */

	/* RGB Indoor Gamma */
	S5K4ECGX_REG_WRITE(0x70000734, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000736, 0x0007),
	S5K4ECGX_REG_WRITE(0x70000738, 0x0011),
	S5K4ECGX_REG_WRITE(0x7000073A, 0x002D),
	S5K4ECGX_REG_WRITE(0x7000073C, 0x006B),
	S5K4ECGX_REG_WRITE(0x7000073E, 0x00DC),
	S5K4ECGX_REG_WRITE(0x70000740, 0x013B),
	S5K4ECGX_REG_WRITE(0x70000742, 0x0166),
	S5K4ECGX_REG_WRITE(0x70000744, 0x018D),
	S5K4ECGX_REG_WRITE(0x70000746, 0x01CD),
	S5K4ECGX_REG_WRITE(0x70000748, 0x0204),
	S5K4ECGX_REG_WRITE(0x7000074A, 0x0235),
	S5K4ECGX_REG_WRITE(0x7000074C, 0x0260),
	S5K4ECGX_REG_WRITE(0x7000074E, 0x02AA),
	S5K4ECGX_REG_WRITE(0x70000750, 0x02EC),
	S5K4ECGX_REG_WRITE(0x70000752, 0x034E),
	S5K4ECGX_REG_WRITE(0x70000754, 0x0396),
	S5K4ECGX_REG_WRITE(0x70000756, 0x03C6),
	S5K4ECGX_REG_WRITE(0x70000758, 0x03E9),
	S5K4ECGX_REG_WRITE(0x7000075A, 0x03F9),
	S5K4ECGX_REG_WRITE(0x7000075C, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000075E, 0x0007),
	S5K4ECGX_REG_WRITE(0x70000760, 0x0011),
	S5K4ECGX_REG_WRITE(0x70000762, 0x002D),
	S5K4ECGX_REG_WRITE(0x70000764, 0x006B),
	S5K4ECGX_REG_WRITE(0x70000766, 0x00DC),
	S5K4ECGX_REG_WRITE(0x70000768, 0x013B),
	S5K4ECGX_REG_WRITE(0x7000076A, 0x0166),
	S5K4ECGX_REG_WRITE(0x7000076C, 0x018D),
	S5K4ECGX_REG_WRITE(0x7000076E, 0x01CD),
	S5K4ECGX_REG_WRITE(0x70000770, 0x0204),
	S5K4ECGX_REG_WRITE(0x70000772, 0x0235),
	S5K4ECGX_REG_WRITE(0x70000774, 0x0260),
	S5K4ECGX_REG_WRITE(0x70000776, 0x02AA),
	S5K4ECGX_REG_WRITE(0x70000778, 0x02EC),
	S5K4ECGX_REG_WRITE(0x7000077A, 0x034E),
	S5K4ECGX_REG_WRITE(0x7000077C, 0x0396),
	S5K4ECGX_REG_WRITE(0x7000077E, 0x03C6),
	S5K4ECGX_REG_WRITE(0x70000780, 0x03E9),
	S5K4ECGX_REG_WRITE(0x70000782, 0x03F9),
	S5K4ECGX_REG_WRITE(0x70000784, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000786, 0x0007),
	S5K4ECGX_REG_WRITE(0x70000788, 0x0011),
	S5K4ECGX_REG_WRITE(0x7000078A, 0x002D),
	S5K4ECGX_REG_WRITE(0x7000078C, 0x006B),
	S5K4ECGX_REG_WRITE(0x7000078E, 0x00DC),
	S5K4ECGX_REG_WRITE(0x70000790, 0x013B),
	S5K4ECGX_REG_WRITE(0x70000792, 0x0166),
	S5K4ECGX_REG_WRITE(0x70000794, 0x018D),
	S5K4ECGX_REG_WRITE(0x70000796, 0x01CD),
	S5K4ECGX_REG_WRITE(0x70000798, 0x0204),
	S5K4ECGX_REG_WRITE(0x7000079A, 0x0235),
	S5K4ECGX_REG_WRITE(0x7000079C, 0x0260),
	S5K4ECGX_REG_WRITE(0x7000079E, 0x02AA),
	S5K4ECGX_REG_WRITE(0x700007A0, 0x02EC),
	S5K4ECGX_REG_WRITE(0x700007A2, 0x034E),
	S5K4ECGX_REG_WRITE(0x700007A4, 0x0396),
	S5K4ECGX_REG_WRITE(0x700007A6, 0x03C6),
	S5K4ECGX_REG_WRITE(0x700007A8, 0x03E9),
	S5K4ECGX_REG_WRITE(0x700007AA, 0x03F9),

	/* RGB Outdoor Gamma */
	S5K4ECGX_REG_WRITE(0x700007AC, 0x0001),
	S5K4ECGX_REG_WRITE(0x700007AE, 0x0007),
	S5K4ECGX_REG_WRITE(0x700007B0, 0x0011),
	S5K4ECGX_REG_WRITE(0x700007B2, 0x002D),
	S5K4ECGX_REG_WRITE(0x700007B4, 0x006B),
	S5K4ECGX_REG_WRITE(0x700007B6, 0x00DC),
	S5K4ECGX_REG_WRITE(0x700007B8, 0x013B),
	S5K4ECGX_REG_WRITE(0x700007BA, 0x0166),
	S5K4ECGX_REG_WRITE(0x700007BC, 0x018D),
	S5K4ECGX_REG_WRITE(0x700007BE, 0x01CD),
	S5K4ECGX_REG_WRITE(0x700007C0, 0x0204),
	S5K4ECGX_REG_WRITE(0x700007C2, 0x0235),
	S5K4ECGX_REG_WRITE(0x700007C4, 0x0260),
	S5K4ECGX_REG_WRITE(0x700007C6, 0x02AA),
	S5K4ECGX_REG_WRITE(0x700007C8, 0x02EC),
	S5K4ECGX_REG_WRITE(0x700007CA, 0x034E),
	S5K4ECGX_REG_WRITE(0x700007CC, 0x0396),
	S5K4ECGX_REG_WRITE(0x700007CE, 0x03C6),
	S5K4ECGX_REG_WRITE(0x700007D0, 0x03E9),
	S5K4ECGX_REG_WRITE(0x700007D2, 0x03F9),
	S5K4ECGX_REG_WRITE(0x700007D4, 0x0001),
	S5K4ECGX_REG_WRITE(0x700007D6, 0x0007),
	S5K4ECGX_REG_WRITE(0x700007D8, 0x0011),
	S5K4ECGX_REG_WRITE(0x700007DA, 0x002D),
	S5K4ECGX_REG_WRITE(0x700007DC, 0x006B),
	S5K4ECGX_REG_WRITE(0x700007DE, 0x00DC),
	S5K4ECGX_REG_WRITE(0x700007E0, 0x013B),
	S5K4ECGX_REG_WRITE(0x700007E2, 0x0166),
	S5K4ECGX_REG_WRITE(0x700007E4, 0x018D),
	S5K4ECGX_REG_WRITE(0x700007E6, 0x01CD),
	S5K4ECGX_REG_WRITE(0x700007E8, 0x0204),
	S5K4ECGX_REG_WRITE(0x700007EA, 0x0235),
	S5K4ECGX_REG_WRITE(0x700007EC, 0x0260),
	S5K4ECGX_REG_WRITE(0x700007EE, 0x02AA),
	S5K4ECGX_REG_WRITE(0x700007F0, 0x02EC),
	S5K4ECGX_REG_WRITE(0x700007F2, 0x034E),
	S5K4ECGX_REG_WRITE(0x700007F4, 0x0396),
	S5K4ECGX_REG_WRITE(0x700007F6, 0x03C6),
	S5K4ECGX_REG_WRITE(0x700007F8, 0x03E9),
	S5K4ECGX_REG_WRITE(0x700007FA, 0x03F9),
	S5K4ECGX_REG_WRITE(0x700007FC, 0x0001),
	S5K4ECGX_REG_WRITE(0x700007FE, 0x0007),
	S5K4ECGX_REG_WRITE(0x70000800, 0x0011),
	S5K4ECGX_REG_WRITE(0x70000802, 0x002D),
	S5K4ECGX_REG_WRITE(0x70000804, 0x006B),
	S5K4ECGX_REG_WRITE(0x70000806, 0x00DC),
	S5K4ECGX_REG_WRITE(0x70000808, 0x013B),
	S5K4ECGX_REG_WRITE(0x7000080A, 0x0166),
	S5K4ECGX_REG_WRITE(0x7000080C, 0x018D),
	S5K4ECGX_REG_WRITE(0x7000080E, 0x01CD),
	S5K4ECGX_REG_WRITE(0x70000810, 0x0204),
	S5K4ECGX_REG_WRITE(0x70000812, 0x0235),
	S5K4ECGX_REG_WRITE(0x70000814, 0x0260),
	S5K4ECGX_REG_WRITE(0x70000816, 0x02AA),
	S5K4ECGX_REG_WRITE(0x70000818, 0x02EC),
	S5K4ECGX_REG_WRITE(0x7000081A, 0x034E),
	S5K4ECGX_REG_WRITE(0x7000081C, 0x0396),
	S5K4ECGX_REG_WRITE(0x7000081E, 0x03C6),
	S5K4ECGX_REG_WRITE(0x70000820, 0x03E9),
	S5K4ECGX_REG_WRITE(0x70000822, 0x03F9),

	/* CCM */
	S5K4ECGX_REG_WRITE(0x700008A6, 0x00C0),
	S5K4ECGX_REG_WRITE(0x700008A8, 0x00D0),
	S5K4ECGX_REG_WRITE(0x700008AA, 0x00E0),
	S5K4ECGX_REG_WRITE(0x700008AC, 0x0110),
	S5K4ECGX_REG_WRITE(0x700008AE, 0x017C),
	S5K4ECGX_REG_WRITE(0x700008B0, 0x0194),

	S5K4ECGX_REG_WRITE(0x700008B2, 0x0001),

	S5K4ECGX_REG_WRITE(0x70000898, 0x4800),
	S5K4ECGX_REG_WRITE(0x7000089A, 0x7000),
	S5K4ECGX_REG_WRITE(0x700008A0, 0x48D8),
	S5K4ECGX_REG_WRITE(0x700008A2, 0x7000),

	S5K4ECGX_REG_WRITE(0x70004800, 0x010F),	/* hor */
	S5K4ECGX_REG_WRITE(0x70004802, 0xFF90),
	S5K4ECGX_REG_WRITE(0x70004804, 0xFF7D),
	S5K4ECGX_REG_WRITE(0x70004806, 0xFEF1),
	S5K4ECGX_REG_WRITE(0x70004808, 0x0137),
	S5K4ECGX_REG_WRITE(0x7000480A, 0xFF68),
	S5K4ECGX_REG_WRITE(0x7000480C, 0xFFEE),
	S5K4ECGX_REG_WRITE(0x7000480E, 0xFF8A),
	S5K4ECGX_REG_WRITE(0x70004810, 0x013A),
	S5K4ECGX_REG_WRITE(0x70004812, 0x006E),
	S5K4ECGX_REG_WRITE(0x70004814, 0x0089),
	S5K4ECGX_REG_WRITE(0x70004816, 0xFEFE),
	S5K4ECGX_REG_WRITE(0x70004818, 0x0175),
	S5K4ECGX_REG_WRITE(0x7000481A, 0xFF4A),
	S5K4ECGX_REG_WRITE(0x7000481C, 0x00D6),
	S5K4ECGX_REG_WRITE(0x7000481E, 0xFEFE),
	S5K4ECGX_REG_WRITE(0x70004820, 0x0113),
	S5K4ECGX_REG_WRITE(0x70004822, 0x00E6),
	S5K4ECGX_REG_WRITE(0x70004824, 0x010F),	/* incaA */
	S5K4ECGX_REG_WRITE(0x70004826, 0xFF90),
	S5K4ECGX_REG_WRITE(0x70004828, 0xFF7D),
	S5K4ECGX_REG_WRITE(0x7000482A, 0xFEF1),
	S5K4ECGX_REG_WRITE(0x7000482C, 0x0137),
	S5K4ECGX_REG_WRITE(0x7000482E, 0xFF68),
	S5K4ECGX_REG_WRITE(0x70004830, 0xFFEE),
	S5K4ECGX_REG_WRITE(0x70004832, 0xFF8A),
	S5K4ECGX_REG_WRITE(0x70004834, 0x013A),
	S5K4ECGX_REG_WRITE(0x70004836, 0x006E),
	S5K4ECGX_REG_WRITE(0x70004838, 0x0089),
	S5K4ECGX_REG_WRITE(0x7000483A, 0xFEFE),
	S5K4ECGX_REG_WRITE(0x7000483C, 0x0175),
	S5K4ECGX_REG_WRITE(0x7000483E, 0xFF4A),
	S5K4ECGX_REG_WRITE(0x70004840, 0x00D6),
	S5K4ECGX_REG_WRITE(0x70004842, 0xFEFE),
	S5K4ECGX_REG_WRITE(0x70004844, 0x0113),
	S5K4ECGX_REG_WRITE(0x70004846, 0x00E6),
	S5K4ECGX_REG_WRITE(0x70004848, 0x010F),	/* WW */
	S5K4ECGX_REG_WRITE(0x7000484A, 0xFF90),
	S5K4ECGX_REG_WRITE(0x7000484C, 0xFF7D),
	S5K4ECGX_REG_WRITE(0x7000484E, 0xFEF1),
	S5K4ECGX_REG_WRITE(0x70004850, 0x0137),
	S5K4ECGX_REG_WRITE(0x70004852, 0xFF68),
	S5K4ECGX_REG_WRITE(0x70004854, 0xFFEE),
	S5K4ECGX_REG_WRITE(0x70004856, 0xFF8A),
	S5K4ECGX_REG_WRITE(0x70004858, 0x013A),
	S5K4ECGX_REG_WRITE(0x7000485A, 0x006E),
	S5K4ECGX_REG_WRITE(0x7000485C, 0x0089),
	S5K4ECGX_REG_WRITE(0x7000485E, 0xFEFE),
	S5K4ECGX_REG_WRITE(0x70004860, 0x0175),
	S5K4ECGX_REG_WRITE(0x70004862, 0xFF4A),
	S5K4ECGX_REG_WRITE(0x70004864, 0x00D6),
	S5K4ECGX_REG_WRITE(0x70004866, 0xFEFE),
	S5K4ECGX_REG_WRITE(0x70004868, 0x0113),
	S5K4ECGX_REG_WRITE(0x7000486A, 0x00E6),
	S5K4ECGX_REG_WRITE(0x7000486C, 0x017B),	/* CW */
	S5K4ECGX_REG_WRITE(0x7000486E, 0xFFB5),
	S5K4ECGX_REG_WRITE(0x70004870, 0xFFF9),
	S5K4ECGX_REG_WRITE(0x70004872, 0xFF5E),
	S5K4ECGX_REG_WRITE(0x70004874, 0x019D),
	S5K4ECGX_REG_WRITE(0x70004876, 0xFFA2),
	S5K4ECGX_REG_WRITE(0x70004878, 0xFFD9),
	S5K4ECGX_REG_WRITE(0x7000487A, 0xFFCB),
	S5K4ECGX_REG_WRITE(0x7000487C, 0x012C),
	S5K4ECGX_REG_WRITE(0x7000487E, 0x00C9),
	S5K4ECGX_REG_WRITE(0x70004880, 0x00B0),
	S5K4ECGX_REG_WRITE(0x70004882, 0xFF2F),
	S5K4ECGX_REG_WRITE(0x70004884, 0x00CA),
	S5K4ECGX_REG_WRITE(0x70004886, 0xFF91),
	S5K4ECGX_REG_WRITE(0x70004888, 0x015E),
	S5K4ECGX_REG_WRITE(0x7000488A, 0xFF47),
	S5K4ECGX_REG_WRITE(0x7000488C, 0x0129),
	S5K4ECGX_REG_WRITE(0x7000488E, 0x0125),
	S5K4ECGX_REG_WRITE(0x70004890, 0x01AF),	/* D50 */
	S5K4ECGX_REG_WRITE(0x70004892, 0xFFBA),
	S5K4ECGX_REG_WRITE(0x70004894, 0xFFF1),
	S5K4ECGX_REG_WRITE(0x70004896, 0xFF27),
	S5K4ECGX_REG_WRITE(0x70004898, 0x01DE),
	S5K4ECGX_REG_WRITE(0x7000489A, 0xFF77),
	S5K4ECGX_REG_WRITE(0x7000489C, 0xFFCB),
	S5K4ECGX_REG_WRITE(0x7000489E, 0xFFC5),
	S5K4ECGX_REG_WRITE(0x700048A0, 0x0136),
	S5K4ECGX_REG_WRITE(0x700048A2, 0x0110),
	S5K4ECGX_REG_WRITE(0x700048A4, 0x00EF),
	S5K4ECGX_REG_WRITE(0x700048A6, 0xFFA0),
	S5K4ECGX_REG_WRITE(0x700048A8, 0x00A3),
	S5K4ECGX_REG_WRITE(0x700048AA, 0xFF7B),
	S5K4ECGX_REG_WRITE(0x700048AC, 0x018C),
	S5K4ECGX_REG_WRITE(0x700048AE, 0xFF1D),
	S5K4ECGX_REG_WRITE(0x700048B0, 0x0138),
	S5K4ECGX_REG_WRITE(0x700048B2, 0x0138),
	S5K4ECGX_REG_WRITE(0x700048B4, 0x01AF),	/* D65 */
	S5K4ECGX_REG_WRITE(0x700048B6, 0xFFBA),
	S5K4ECGX_REG_WRITE(0x700048B8, 0xFFF1),
	S5K4ECGX_REG_WRITE(0x700048BA, 0xFF27),
	S5K4ECGX_REG_WRITE(0x700048BC, 0x01DE),
	S5K4ECGX_REG_WRITE(0x700048BE, 0xFF77),
	S5K4ECGX_REG_WRITE(0x700048C0, 0xFFCB),
	S5K4ECGX_REG_WRITE(0x700048C2, 0xFFC5),
	S5K4ECGX_REG_WRITE(0x700048C4, 0x0136),
	S5K4ECGX_REG_WRITE(0x700048C6, 0x0110),
	S5K4ECGX_REG_WRITE(0x700048C8, 0x00EF),
	S5K4ECGX_REG_WRITE(0x700048CA, 0xFFA0),
	S5K4ECGX_REG_WRITE(0x700048CC, 0x00A3),
	S5K4ECGX_REG_WRITE(0x700048CE, 0xFF7B),
	S5K4ECGX_REG_WRITE(0x700048D0, 0x018C),
	S5K4ECGX_REG_WRITE(0x700048D2, 0xFF1D),
	S5K4ECGX_REG_WRITE(0x700048D4, 0x0138),
	S5K4ECGX_REG_WRITE(0x700048D6, 0x0138),

	S5K4ECGX_REG_WRITE(0x700048D8, 0x019F),	/* #TVAR_wbt_pOutdoorCcm[0] */
	S5K4ECGX_REG_WRITE(0x700048DA, 0xFFBF),
	S5K4ECGX_REG_WRITE(0x700048DC, 0xFFFD),
	S5K4ECGX_REG_WRITE(0x700048DE, 0xFF10),
	S5K4ECGX_REG_WRITE(0x700048E0, 0x01D4),
	S5K4ECGX_REG_WRITE(0x700048E2, 0xFFA4),
	S5K4ECGX_REG_WRITE(0x700048E4, 0xFFE8),
	S5K4ECGX_REG_WRITE(0x700048E6, 0xFFE0),
	S5K4ECGX_REG_WRITE(0x700048E8, 0x01C2),
	S5K4ECGX_REG_WRITE(0x700048EA, 0x0087),
	S5K4ECGX_REG_WRITE(0x700048EC, 0x00A5),
	S5K4ECGX_REG_WRITE(0x700048EE, 0xFF17),
	S5K4ECGX_REG_WRITE(0x700048F0, 0x01DD),
	S5K4ECGX_REG_WRITE(0x700048F2, 0xFF0E),
	S5K4ECGX_REG_WRITE(0x700048F4, 0x010B),
	S5K4ECGX_REG_WRITE(0x700048F6, 0xFF24),
	S5K4ECGX_REG_WRITE(0x700048F8, 0x00F0),
	S5K4ECGX_REG_WRITE(0x700048FA, 0x01DB),

	/* System Setting */
	S5K4ECGX_REG_WRITE(0x700001F8, 0x5DC0),	/* #REG_TC_IPRM_InClockLSBs, MCLK: 24Mhz */
	S5K4ECGX_REG_WRITE(0x70000212, 0x0002),	/* #REG_TC_IPRM_UseNPviClocks */
	S5K4ECGX_REG_WRITE(0x70000214, 0x0000),	/* #REG_TC_IPRM_UseNMipiClocks */
	S5K4ECGX_REG_WRITE(0x70000216, 0x0000),	/* #REG_TC_IPRM_NumberOfMipiLanes */
	S5K4ECGX_REG_WRITE(0x7000021A, 0x3A98),	/* #REG_TC_IPRM_OpClk4KHz_0, SCLK: 60Mhz */
	S5K4ECGX_REG_WRITE(0x7000021C, 0x4F1A),	/* #REG_TC_IPRM_MinOutRate4KHz_0	PCLK Min : 81Mhz */
	S5K4ECGX_REG_WRITE(0x7000021E, 0x4F1A),	/* #REG_TC_IPRM_MaxOutRate4KHz_0	PCLK Max : 81Mhz */
	S5K4ECGX_REG_WRITE(0x70000220, 0x4F1A),	/* #REG_TC_IPRM_OpClk4KHz_1	SCLK	 : 81Mhz */
	S5K4ECGX_REG_WRITE(0x70000222, 0x4F1A),	/* #REG_TC_IPRM_MinOutRate4KHz_1	PCLK Min : 81Mhz */
	S5K4ECGX_REG_WRITE(0x70000224, 0x4F1A),	/* #REG_TC_IPRM_MaxOutRate4KHz_1 PCLK Max : 81Mhz */
	S5K4ECGX_REG_WRITE(0x7000022C, 0x0001),	/* #REG_TC_IPRM_InitParamsUpdated */

	/* ETC.. Setting */
	S5K4ECGX_REG_WRITE(0x70000478, 0x005F),	/* #REG_TC_BRC_usPrevQuality */
	S5K4ECGX_REG_WRITE(0x7000047A, 0x005F),	/* #REG_TC_BRC_usCaptureQuality */

	S5K4ECGX_REG_WRITE(0x7000047C, 0x0001),	/* #REG_TC_THUMB_Thumb_bActive */
	S5K4ECGX_REG_WRITE(0x7000047E, 0x0280),	/* #REG_TC_THUMB_Thumb_uWidth */
	S5K4ECGX_REG_WRITE(0x70000480, 0x01E0),	/* #REG_TC_THUMB_Thumb_uHeight */
	S5K4ECGX_REG_WRITE(0x70000482, 0x0005),	/* #REG_TC_THUMB_Thumb_Format */

	S5K4ECGX_REG_WRITE(0x700017DC, 0x0054),	/* #jpeg_ManualMBCV */
	S5K4ECGX_REG_WRITE(0x70001AE4, 0x001C),	/* #senHal_bExtraAddLine */
	S5K4ECGX_REG_WRITE(0x70000284, 0x0001),	/* #REG_TC_GP_bBypassScalerJpg */
	S5K4ECGX_REG_WRITE(0x7000028A, 0x0001),	/* #REG_TC_GP_bUse1FrameCaptureMode */
	/* 0 : Continuous mode,1 : Single frame mode */

	/* Configuration Setting */
	S5K4ECGX_REG_WRITE(0x700002A6, 0x0280),	/* #REG_0TC_PCFG_usWidth	   : 640 */
	S5K4ECGX_REG_WRITE(0x700002A8, 0x01E0),	/* #REG_0TC_PCFG_usHeight   : 480 */
	S5K4ECGX_REG_WRITE(0x700002AA, 0x0005),	/* #REG_0TC_PCFG_Format	5 : YUV	7 : Raw	9 : JPG */
	S5K4ECGX_REG_WRITE(0x700002AC, 0x4F1A),	/* #REG_0TC_PCFG_usMaxOut4KHzRate */
	S5K4ECGX_REG_WRITE(0x700002AE, 0x4F1A),	/* #REG_0TC_PCFG_usMinOut4KHzRate */
	S5K4ECGX_REG_WRITE(0x700002B0, 0x0100),	/* #REG_0TC_PCFG_OutClkPerPix88 */
	S5K4ECGX_REG_WRITE(0x700002B2, 0x0300),	/* #REG_0TC_PCFG_uBpp88 */
	S5K4ECGX_REG_WRITE(0x700002B4, 0x0052),	/* #REG_0TC_PCFG_PVIMask */
	S5K4ECGX_REG_WRITE(0x700002B6, 0x0000),	/* #REG_0TC_PCFG_OIFMask */
	S5K4ECGX_REG_WRITE(0x700002B8, 0x01E0),	/* #REG_0TC_PCFG_usJpegPacketSize */
	S5K4ECGX_REG_WRITE(0x700002BA, 0x0000),	/* #REG_0TC_PCFG_usJpegTotalPackets */
	S5K4ECGX_REG_WRITE(0x700002BC, 0x0000),	/* #REG_0TC_PCFG_uClockInd */
	S5K4ECGX_REG_WRITE(0x700002BE, 0x0000),	/* #REG_0TC_PCFG_usFrTimeType */
	S5K4ECGX_REG_WRITE(0x700002C0, 0x0001),	/* #REG_0TC_PCFG_FrRateQualityType */
	S5K4ECGX_REG_WRITE(0x700002C2, 0x029A),	/* #REG_0TC_PCFG_usMaxFrTimeMsecMult10 */
	S5K4ECGX_REG_WRITE(0x700002C4, 0x014A),	/* #REG_0TC_PCFG_usMinFrTimeMsecMult10 */
	S5K4ECGX_REG_WRITE(0x700002D0, 0x0000),	/* #REG_0TC_PCFG_uPrevMirror */
	S5K4ECGX_REG_WRITE(0x700002D2, 0x0000),	/* #REG_0TC_PCFG_uCaptureMirror */
	S5K4ECGX_REG_WRITE(0x700002D4, 0x0000),	/* #REG_0TC_PCFG_uRotation */

	S5K4ECGX_REG_WRITE(0x70000396, 0x0000),	/* #REG_0TC_CCFG_uCaptureMode */
	S5K4ECGX_REG_WRITE(0x70000398, 0x0A00),	/* #REG_0TC_CCFG_usWidth */
	S5K4ECGX_REG_WRITE(0x7000039A, 0x0780),	/* #REG_0TC_CCFG_usHeight */
	S5K4ECGX_REG_WRITE(0x7000039C, 0x0009),	/* #REG_0TC_CCFG_Format */
	S5K4ECGX_REG_WRITE(0x7000039E, 0x4F1A),	/* #REG_0TC_CCFG_usMaxOut4KHzRate */
	S5K4ECGX_REG_WRITE(0x700003A0, 0x4F1A),	/* #REG_0TC_CCFG_usMinOut4KHzRate */
	S5K4ECGX_REG_WRITE(0x700003A2, 0x0100),	/* #REG_0TC_CCFG_OutClkPerPix88 */
	S5K4ECGX_REG_WRITE(0x700003A4, 0x0300),	/* #REG_0TC_CCFG_uBpp88 */
	S5K4ECGX_REG_WRITE(0x700003A6, 0x0042),	/* #REG_0TC_CCFG_PVIMask */
	S5K4ECGX_REG_WRITE(0x700003A8, 0x0000),	/* #REG_0TC_CCFG_OIFMask */
	S5K4ECGX_REG_WRITE(0x700003AA, 0x01E0),	/* #REG_0TC_CCFG_usJpegPacketSize */
	S5K4ECGX_REG_WRITE(0x700003AC, 0x0000),	/* #REG_0TC_CCFG_usJpegTotalPackets */
	S5K4ECGX_REG_WRITE(0x700003AE, 0x0001),	/* #REG_0TC_CCFG_uClockInd */
	S5K4ECGX_REG_WRITE(0x700003B0, 0x0000),	/* #REG_0TC_CCFG_usFrTimeType */
	S5K4ECGX_REG_WRITE(0x700003B2, 0x0002),	/* #REG_0TC_CCFG_FrRateQualityType */
	S5K4ECGX_REG_WRITE(0x700003B4, 0x0535),	/* #REG_0TC_CCFG_usMaxFrTimeMsecMult10 */
	S5K4ECGX_REG_WRITE(0x700003B6, 0x029A),	/* #REG_0TC_CCFG_usMinFrTimeMsecMult10 */

	S5K4ECGX_REG_WRITE(0x70000250, 0x0A00),
	S5K4ECGX_REG_WRITE(0x70000252, 0x0780),
	S5K4ECGX_REG_WRITE(0x70000254, 0x0010),
	S5K4ECGX_REG_WRITE(0x70000256, 0x000C),
	S5K4ECGX_REG_WRITE(0x70000258, 0x0A00),
	S5K4ECGX_REG_WRITE(0x7000025A, 0x0780),
	S5K4ECGX_REG_WRITE(0x7000025C, 0x0010),
	S5K4ECGX_REG_WRITE(0x7000025E, 0x000C),
	S5K4ECGX_REG_WRITE(0x70000494, 0x0A00),
	S5K4ECGX_REG_WRITE(0x70000496, 0x0780),
	S5K4ECGX_REG_WRITE(0x70000498, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000049A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000049C, 0x0A00),
	S5K4ECGX_REG_WRITE(0x7000049E, 0x0780),
	S5K4ECGX_REG_WRITE(0x700004A0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004A2, 0x0000),

	S5K4ECGX_REG_WRITE(0x70000262, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000264, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000266, 0x0000),	/* #REG_TC_GP_ActivePrevConfig */
	S5K4ECGX_REG_WRITE(0x7000026A, 0x0001),	/* #REG_TC_GP_PrevOpenAfterChange */
	S5K4ECGX_REG_WRITE(0x7000024E, 0x0001),	/* #REG_TC_GP_NewConfigSync */
	S5K4ECGX_REG_WRITE(0x70000268, 0x0001),	/* #REG_TC_GP_PrevConfigChanged */
	S5K4ECGX_REG_WRITE(0x70000270, 0x0001),	/* #REG_TC_GP_CapConfigChanged */
	S5K4ECGX_REG_WRITE(0x7000023E, 0x0001),	/* #REG_TC_GP_EnablePreview */
	S5K4ECGX_REG_WRITE(0x70000240, 0x0001),	/* #REG_TC_GP_EnablePreviewChanged */

	/* AFIT */
	S5K4ECGX_REG_WRITE(0x70000944, 0x0050),	/* #afit_uNoiseIndInDoor_0_ */
	S5K4ECGX_REG_WRITE(0x70000946, 0x0103),	/* #afit_uNoiseIndInDoor_1_ */
	S5K4ECGX_REG_WRITE(0x70000948, 0x0196),	/* #afit_uNoiseIndInDoor_2_ */
	S5K4ECGX_REG_WRITE(0x7000094A, 0x0245),	/* #afit_uNoiseIndInDoor_3_ */
	S5K4ECGX_REG_WRITE(0x7000094C, 0x0300),	/* #afit_uNoiseIndInDoor_4_ */

	S5K4ECGX_REG_WRITE(0x7000097A, 0x0001),	/* #afit_bUseSenBpr */
	S5K4ECGX_REG_WRITE(0x7000097C, 0x01CC),	/* #afit_usBprThr_0_ */
	S5K4ECGX_REG_WRITE(0x7000097E, 0x01CC),	/* #afit_usBprThr_1_ */
	S5K4ECGX_REG_WRITE(0x70000980, 0x01CC),	/* #afit_usBprThr_2_ */
	S5K4ECGX_REG_WRITE(0x70000982, 0x01CC),	/* #afit_usBprThr_3_ */
	S5K4ECGX_REG_WRITE(0x70000984, 0x01CC),	/* #afit_usBprThr_4_ */
	S5K4ECGX_REG_WRITE(0x70000986, 0x0180),	/* #afit_NIContrastAFITValue */
	S5K4ECGX_REG_WRITE(0x70000988, 0x0196),	/* #afit_NIContrastTh */

	S5K4ECGX_REG_WRITE(0x70000976, 0x0070),
	S5K4ECGX_REG_WRITE(0x70000978, 0x0005),

	S5K4ECGX_REG_WRITE(0x70000938, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000093A, 0x0014),	/* #SARR_uNormBrInDoor_0_ */
	S5K4ECGX_REG_WRITE(0x7000093C, 0x00D2),	/* #SARR_uNormBrInDoor_1_ */
	S5K4ECGX_REG_WRITE(0x7000093E, 0x0384),	/* #SARR_uNormBrInDoor_2_ */
	S5K4ECGX_REG_WRITE(0x70000940, 0x07D0),	/* #SARR_uNormBrInDoor_3_ */
	S5K4ECGX_REG_WRITE(0x70000942, 0x1388),	/* #SARR_uNormBrInDoor_4_ */

	S5K4ECGX_REG_WRITE(0x7000098C, 0x0000),	/* AFIT 0 */
	S5K4ECGX_REG_WRITE(0x7000098E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000990, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000992, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000994, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000996, 0x00C0),
	S5K4ECGX_REG_WRITE(0x70000998, 0x0064),
	S5K4ECGX_REG_WRITE(0x7000099A, 0x0384),
	S5K4ECGX_REG_WRITE(0x7000099C, 0x005F),
	S5K4ECGX_REG_WRITE(0x7000099E, 0x01F4),
	S5K4ECGX_REG_WRITE(0x700009A0, 0x0070),
	S5K4ECGX_REG_WRITE(0x700009A2, 0x0040),
	S5K4ECGX_REG_WRITE(0x700009A4, 0x00A0),
	S5K4ECGX_REG_WRITE(0x700009A6, 0x0100),
	S5K4ECGX_REG_WRITE(0x700009A8, 0x0010),
	S5K4ECGX_REG_WRITE(0x700009AA, 0x0040),
	S5K4ECGX_REG_WRITE(0x700009AC, 0x00A0),
	S5K4ECGX_REG_WRITE(0x700009AE, 0x1430),
	S5K4ECGX_REG_WRITE(0x700009B0, 0x0201),
	S5K4ECGX_REG_WRITE(0x700009B2, 0x0204),
	S5K4ECGX_REG_WRITE(0x700009B4, 0x3604),
	S5K4ECGX_REG_WRITE(0x700009B6, 0x032A),
	S5K4ECGX_REG_WRITE(0x700009B8, 0x0403),
	S5K4ECGX_REG_WRITE(0x700009BA, 0x1B06),
	S5K4ECGX_REG_WRITE(0x700009BC, 0x6015),
	S5K4ECGX_REG_WRITE(0x700009BE, 0x00C0),
	S5K4ECGX_REG_WRITE(0x700009C0, 0x6080),
	S5K4ECGX_REG_WRITE(0x700009C2, 0x4080),
	S5K4ECGX_REG_WRITE(0x700009C4, 0x0640),
	S5K4ECGX_REG_WRITE(0x700009C6, 0x0306),
	S5K4ECGX_REG_WRITE(0x700009C8, 0x2003),
	S5K4ECGX_REG_WRITE(0x700009CA, 0xFF01),
	S5K4ECGX_REG_WRITE(0x700009CC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700009CE, 0x0400),
	S5K4ECGX_REG_WRITE(0x700009D0, 0x365A),
	S5K4ECGX_REG_WRITE(0x700009D2, 0x102A),
	S5K4ECGX_REG_WRITE(0x700009D4, 0x000B),
	S5K4ECGX_REG_WRITE(0x700009D6, 0x0600),
	S5K4ECGX_REG_WRITE(0x700009D8, 0x5A0F),
	S5K4ECGX_REG_WRITE(0x700009DA, 0x0505),
	S5K4ECGX_REG_WRITE(0x700009DC, 0x1802),
	S5K4ECGX_REG_WRITE(0x700009DE, 0x0000),
	S5K4ECGX_REG_WRITE(0x700009E0, 0x2006),
	S5K4ECGX_REG_WRITE(0x700009E2, 0x3028),
	S5K4ECGX_REG_WRITE(0x700009E4, 0x0418),
	S5K4ECGX_REG_WRITE(0x700009E6, 0x0101),
	S5K4ECGX_REG_WRITE(0x700009E8, 0x0800),
	S5K4ECGX_REG_WRITE(0x700009EA, 0x1804),
	S5K4ECGX_REG_WRITE(0x700009EC, 0x4008),
	S5K4ECGX_REG_WRITE(0x700009EE, 0x0540),
	S5K4ECGX_REG_WRITE(0x700009F0, 0x8006),
	S5K4ECGX_REG_WRITE(0x700009F2, 0x0020),
	S5K4ECGX_REG_WRITE(0x700009F4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700009F6, 0x1800),
	S5K4ECGX_REG_WRITE(0x700009F8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700009FA, 0x1E10),
	S5K4ECGX_REG_WRITE(0x700009FC, 0x000B),
	S5K4ECGX_REG_WRITE(0x700009FE, 0x0607),
	S5K4ECGX_REG_WRITE(0x70000A00, 0x0005),
	S5K4ECGX_REG_WRITE(0x70000A02, 0x0607),
	S5K4ECGX_REG_WRITE(0x70000A04, 0x0705),
	S5K4ECGX_REG_WRITE(0x70000A06, 0x0206),
	S5K4ECGX_REG_WRITE(0x70000A08, 0x0304),
	S5K4ECGX_REG_WRITE(0x70000A0A, 0x0309),
	S5K4ECGX_REG_WRITE(0x70000A0C, 0x0305),
	S5K4ECGX_REG_WRITE(0x70000A0E, 0x2006),
	S5K4ECGX_REG_WRITE(0x70000A10, 0x1320),
	S5K4ECGX_REG_WRITE(0x70000A12, 0x1014),
	S5K4ECGX_REG_WRITE(0x70000A14, 0x1010),
	S5K4ECGX_REG_WRITE(0x70000A16, 0x0C10),
	S5K4ECGX_REG_WRITE(0x70000A18, 0x1A0C),
	S5K4ECGX_REG_WRITE(0x70000A1A, 0x4A18),
	S5K4ECGX_REG_WRITE(0x70000A1C, 0x0080),
	S5K4ECGX_REG_WRITE(0x70000A1E, 0x0050),
	S5K4ECGX_REG_WRITE(0x70000A20, 0x0180),
	S5K4ECGX_REG_WRITE(0x70000A22, 0x0A0A),
	S5K4ECGX_REG_WRITE(0x70000A24, 0x0101),
	S5K4ECGX_REG_WRITE(0x70000A26, 0x2A36),
	S5K4ECGX_REG_WRITE(0x70000A28, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000A2A, 0x2A36),
	S5K4ECGX_REG_WRITE(0x70000A2C, 0xFFFF),
	S5K4ECGX_REG_WRITE(0x70000A2E, 0x0808),
	S5K4ECGX_REG_WRITE(0x70000A30, 0x0A01),
	S5K4ECGX_REG_WRITE(0x70000A32, 0x010A),
	S5K4ECGX_REG_WRITE(0x70000A34, 0x3601),
	S5K4ECGX_REG_WRITE(0x70000A36, 0x242A),
	S5K4ECGX_REG_WRITE(0x70000A38, 0x3660),
	S5K4ECGX_REG_WRITE(0x70000A3A, 0xFF2A),
	S5K4ECGX_REG_WRITE(0x70000A3C, 0x08FF),
	S5K4ECGX_REG_WRITE(0x70000A3E, 0x0008),
	S5K4ECGX_REG_WRITE(0x70000A40, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000A42, 0x0000),	/* AFIT 1 */
	S5K4ECGX_REG_WRITE(0x70000A44, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000A46, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000A48, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000A4A, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000A4C, 0x00C0),
	S5K4ECGX_REG_WRITE(0x70000A4E, 0x0064),
	S5K4ECGX_REG_WRITE(0x70000A50, 0x0384),
	S5K4ECGX_REG_WRITE(0x70000A52, 0x0051),
	S5K4ECGX_REG_WRITE(0x70000A54, 0x01F4),
	S5K4ECGX_REG_WRITE(0x70000A56, 0x0070),
	S5K4ECGX_REG_WRITE(0x70000A58, 0x0040),
	S5K4ECGX_REG_WRITE(0x70000A5A, 0x00A0),
	S5K4ECGX_REG_WRITE(0x70000A5C, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000A5E, 0x0010),
	S5K4ECGX_REG_WRITE(0x70000A60, 0x0060),
	S5K4ECGX_REG_WRITE(0x70000A62, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000A64, 0x1430),
	S5K4ECGX_REG_WRITE(0x70000A66, 0x0201),
	S5K4ECGX_REG_WRITE(0x70000A68, 0x0204),
	S5K4ECGX_REG_WRITE(0x70000A6A, 0x2404),
	S5K4ECGX_REG_WRITE(0x70000A6C, 0x031B),
	S5K4ECGX_REG_WRITE(0x70000A6E, 0x0103),
	S5K4ECGX_REG_WRITE(0x70000A70, 0x1205),
	S5K4ECGX_REG_WRITE(0x70000A72, 0x400D),
	S5K4ECGX_REG_WRITE(0x70000A74, 0x0080),
	S5K4ECGX_REG_WRITE(0x70000A76, 0x1980),
	S5K4ECGX_REG_WRITE(0x70000A78, 0x272E),
	S5K4ECGX_REG_WRITE(0x70000A7A, 0x0629),
	S5K4ECGX_REG_WRITE(0x70000A7C, 0x0306),
	S5K4ECGX_REG_WRITE(0x70000A7E, 0x2003),
	S5K4ECGX_REG_WRITE(0x70000A80, 0xFF01),
	S5K4ECGX_REG_WRITE(0x70000A82, 0x0404),
	S5K4ECGX_REG_WRITE(0x70000A84, 0x0300),
	S5K4ECGX_REG_WRITE(0x70000A86, 0x245A),
	S5K4ECGX_REG_WRITE(0x70000A88, 0x1018),
	S5K4ECGX_REG_WRITE(0x70000A8A, 0x000B),
	S5K4ECGX_REG_WRITE(0x70000A8C, 0x0B00),
	S5K4ECGX_REG_WRITE(0x70000A8E, 0x5A0F),
	S5K4ECGX_REG_WRITE(0x70000A90, 0x0505),
	S5K4ECGX_REG_WRITE(0x70000A92, 0x1802),
	S5K4ECGX_REG_WRITE(0x70000A94, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000A96, 0x2006),
	S5K4ECGX_REG_WRITE(0x70000A98, 0x3828),
	S5K4ECGX_REG_WRITE(0x70000A9A, 0x0425),
	S5K4ECGX_REG_WRITE(0x70000A9C, 0x0101),
	S5K4ECGX_REG_WRITE(0x70000A9E, 0x0800),
	S5K4ECGX_REG_WRITE(0x70000AA0, 0x1004),
	S5K4ECGX_REG_WRITE(0x70000AA2, 0x4008),
	S5K4ECGX_REG_WRITE(0x70000AA4, 0x0540),
	S5K4ECGX_REG_WRITE(0x70000AA6, 0x8006),
	S5K4ECGX_REG_WRITE(0x70000AA8, 0x0020),
	S5K4ECGX_REG_WRITE(0x70000AAA, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000AAC, 0x1800),
	S5K4ECGX_REG_WRITE(0x70000AAE, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000AB0, 0x1E10),
	S5K4ECGX_REG_WRITE(0x70000AB2, 0x000B),
	S5K4ECGX_REG_WRITE(0x70000AB4, 0x0607),
	S5K4ECGX_REG_WRITE(0x70000AB6, 0x0005),
	S5K4ECGX_REG_WRITE(0x70000AB8, 0x0607),
	S5K4ECGX_REG_WRITE(0x70000ABA, 0x0405),
	S5K4ECGX_REG_WRITE(0x70000ABC, 0x0205),
	S5K4ECGX_REG_WRITE(0x70000ABE, 0x0304),
	S5K4ECGX_REG_WRITE(0x70000AC0, 0x0409),
	S5K4ECGX_REG_WRITE(0x70000AC2, 0x0306),
	S5K4ECGX_REG_WRITE(0x70000AC4, 0x0407),
	S5K4ECGX_REG_WRITE(0x70000AC6, 0x2204),
	S5K4ECGX_REG_WRITE(0x70000AC8, 0x021C),
	S5K4ECGX_REG_WRITE(0x70000ACA, 0x1102),
	S5K4ECGX_REG_WRITE(0x70000ACC, 0x0611),
	S5K4ECGX_REG_WRITE(0x70000ACE, 0x1A02),
	S5K4ECGX_REG_WRITE(0x70000AD0, 0x8018),
	S5K4ECGX_REG_WRITE(0x70000AD2, 0x0080),
	S5K4ECGX_REG_WRITE(0x70000AD4, 0x0074),
	S5K4ECGX_REG_WRITE(0x70000AD6, 0x0180),
	S5K4ECGX_REG_WRITE(0x70000AD8, 0x0A0A),
	S5K4ECGX_REG_WRITE(0x70000ADA, 0x0101),
	S5K4ECGX_REG_WRITE(0x70000ADC, 0x141D),
	S5K4ECGX_REG_WRITE(0x70000ADE, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000AE0, 0x1217),
	S5K4ECGX_REG_WRITE(0x70000AE2, 0xFFFF),
	S5K4ECGX_REG_WRITE(0x70000AE4, 0x0808),
	S5K4ECGX_REG_WRITE(0x70000AE6, 0x0A01),
	S5K4ECGX_REG_WRITE(0x70000AE8, 0x010A),
	S5K4ECGX_REG_WRITE(0x70000AEA, 0x2401),
	S5K4ECGX_REG_WRITE(0x70000AEC, 0x241B),
	S5K4ECGX_REG_WRITE(0x70000AEE, 0x1E60),
	S5K4ECGX_REG_WRITE(0x70000AF0, 0xFF18),
	S5K4ECGX_REG_WRITE(0x70000AF2, 0x08FF),
	S5K4ECGX_REG_WRITE(0x70000AF4, 0x0008),
	S5K4ECGX_REG_WRITE(0x70000AF6, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000AF8, 0x0000),	/* AFIT 2 */
	S5K4ECGX_REG_WRITE(0x70000AFA, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000AFC, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000AFE, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000B00, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000B02, 0x00C0),
	S5K4ECGX_REG_WRITE(0x70000B04, 0x0064),
	S5K4ECGX_REG_WRITE(0x70000B06, 0x0384),
	S5K4ECGX_REG_WRITE(0x70000B08, 0x0043),
	S5K4ECGX_REG_WRITE(0x70000B0A, 0x01F4),
	S5K4ECGX_REG_WRITE(0x70000B0C, 0x0070),
	S5K4ECGX_REG_WRITE(0x70000B0E, 0x0040),
	S5K4ECGX_REG_WRITE(0x70000B10, 0x00A0),
	S5K4ECGX_REG_WRITE(0x70000B12, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000B14, 0x0010),
	S5K4ECGX_REG_WRITE(0x70000B16, 0x0060),
	S5K4ECGX_REG_WRITE(0x70000B18, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000B1A, 0x1430),
	S5K4ECGX_REG_WRITE(0x70000B1C, 0x0201),
	S5K4ECGX_REG_WRITE(0x70000B1E, 0x0204),
	S5K4ECGX_REG_WRITE(0x70000B20, 0x1B04),
	S5K4ECGX_REG_WRITE(0x70000B22, 0x0312),
	S5K4ECGX_REG_WRITE(0x70000B24, 0x0003),
	S5K4ECGX_REG_WRITE(0x70000B26, 0x0C03),
	S5K4ECGX_REG_WRITE(0x70000B28, 0x2806),
	S5K4ECGX_REG_WRITE(0x70000B2A, 0x0060),
	S5K4ECGX_REG_WRITE(0x70000B2C, 0x1580),
	S5K4ECGX_REG_WRITE(0x70000B2E, 0x2020),
	S5K4ECGX_REG_WRITE(0x70000B30, 0x0620),
	S5K4ECGX_REG_WRITE(0x70000B32, 0x0306),
	S5K4ECGX_REG_WRITE(0x70000B34, 0x2003),
	S5K4ECGX_REG_WRITE(0x70000B36, 0xFF01),
	S5K4ECGX_REG_WRITE(0x70000B38, 0x0404),
	S5K4ECGX_REG_WRITE(0x70000B3A, 0x0300),
	S5K4ECGX_REG_WRITE(0x70000B3C, 0x145A),
	S5K4ECGX_REG_WRITE(0x70000B3E, 0x1010),
	S5K4ECGX_REG_WRITE(0x70000B40, 0x000B),
	S5K4ECGX_REG_WRITE(0x70000B42, 0x0E00),
	S5K4ECGX_REG_WRITE(0x70000B44, 0x5A0F),
	S5K4ECGX_REG_WRITE(0x70000B46, 0x0504),
	S5K4ECGX_REG_WRITE(0x70000B48, 0x1802),
	S5K4ECGX_REG_WRITE(0x70000B4A, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000B4C, 0x2006),
	S5K4ECGX_REG_WRITE(0x70000B4E, 0x3828),
	S5K4ECGX_REG_WRITE(0x70000B50, 0x0428),
	S5K4ECGX_REG_WRITE(0x70000B52, 0x0101),
	S5K4ECGX_REG_WRITE(0x70000B54, 0x8000),
	S5K4ECGX_REG_WRITE(0x70000B56, 0x0A04),
	S5K4ECGX_REG_WRITE(0x70000B58, 0x4008),
	S5K4ECGX_REG_WRITE(0x70000B5A, 0x0540),
	S5K4ECGX_REG_WRITE(0x70000B5C, 0x8006),
	S5K4ECGX_REG_WRITE(0x70000B5E, 0x0020),
	S5K4ECGX_REG_WRITE(0x70000B60, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000B62, 0x1800),
	S5K4ECGX_REG_WRITE(0x70000B64, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000B66, 0x1E10),
	S5K4ECGX_REG_WRITE(0x70000B68, 0x000B),
	S5K4ECGX_REG_WRITE(0x70000B6A, 0x0607),
	S5K4ECGX_REG_WRITE(0x70000B6C, 0x0005),
	S5K4ECGX_REG_WRITE(0x70000B6E, 0x0607),
	S5K4ECGX_REG_WRITE(0x70000B70, 0x0405),
	S5K4ECGX_REG_WRITE(0x70000B72, 0x0207),
	S5K4ECGX_REG_WRITE(0x70000B74, 0x0304),
	S5K4ECGX_REG_WRITE(0x70000B76, 0x0409),
	S5K4ECGX_REG_WRITE(0x70000B78, 0x0306),
	S5K4ECGX_REG_WRITE(0x70000B7A, 0x0407),
	S5K4ECGX_REG_WRITE(0x70000B7C, 0x2404),
	S5K4ECGX_REG_WRITE(0x70000B7E, 0x0221),
	S5K4ECGX_REG_WRITE(0x70000B80, 0x1202),
	S5K4ECGX_REG_WRITE(0x70000B82, 0x0613),
	S5K4ECGX_REG_WRITE(0x70000B84, 0x1A02),
	S5K4ECGX_REG_WRITE(0x70000B86, 0x8018),
	S5K4ECGX_REG_WRITE(0x70000B88, 0x0080),
	S5K4ECGX_REG_WRITE(0x70000B8A, 0x0080),
	S5K4ECGX_REG_WRITE(0x70000B8C, 0x0180),
	S5K4ECGX_REG_WRITE(0x70000B8E, 0x0A0A),
	S5K4ECGX_REG_WRITE(0x70000B90, 0x0101),
	S5K4ECGX_REG_WRITE(0x70000B92, 0x121B),
	S5K4ECGX_REG_WRITE(0x70000B94, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000B96, 0x0C0C),
	S5K4ECGX_REG_WRITE(0x70000B98, 0xFFFF),
	S5K4ECGX_REG_WRITE(0x70000B9A, 0x0808),
	S5K4ECGX_REG_WRITE(0x70000B9C, 0x0A01),
	S5K4ECGX_REG_WRITE(0x70000B9E, 0x010A),
	S5K4ECGX_REG_WRITE(0x70000BA0, 0x1B01),
	S5K4ECGX_REG_WRITE(0x70000BA2, 0x2412),
	S5K4ECGX_REG_WRITE(0x70000BA4, 0x0C60),
	S5K4ECGX_REG_WRITE(0x70000BA6, 0xFF0C),
	S5K4ECGX_REG_WRITE(0x70000BA8, 0x08FF),
	S5K4ECGX_REG_WRITE(0x70000BAA, 0x0008),
	S5K4ECGX_REG_WRITE(0x70000BAC, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000BAE, 0x0000),	/* AFIT 3 */
	S5K4ECGX_REG_WRITE(0x70000BB0, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000BB2, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000BB4, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000BB6, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000BB8, 0x00C0),
	S5K4ECGX_REG_WRITE(0x70000BBA, 0x0064),
	S5K4ECGX_REG_WRITE(0x70000BBC, 0x0384),
	S5K4ECGX_REG_WRITE(0x70000BBE, 0x0032),
	S5K4ECGX_REG_WRITE(0x70000BC0, 0x01F4),
	S5K4ECGX_REG_WRITE(0x70000BC2, 0x0070),
	S5K4ECGX_REG_WRITE(0x70000BC4, 0x0040),
	S5K4ECGX_REG_WRITE(0x70000BC6, 0x00A0),
	S5K4ECGX_REG_WRITE(0x70000BC8, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000BCA, 0x0010),
	S5K4ECGX_REG_WRITE(0x70000BCC, 0x0060),
	S5K4ECGX_REG_WRITE(0x70000BCE, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000BD0, 0x1430),
	S5K4ECGX_REG_WRITE(0x70000BD2, 0x0201),
	S5K4ECGX_REG_WRITE(0x70000BD4, 0x0204),
	S5K4ECGX_REG_WRITE(0x70000BD6, 0x1504),
	S5K4ECGX_REG_WRITE(0x70000BD8, 0x030F),
	S5K4ECGX_REG_WRITE(0x70000BDA, 0x0003),
	S5K4ECGX_REG_WRITE(0x70000BDC, 0x0902),
	S5K4ECGX_REG_WRITE(0x70000BDE, 0x2004),
	S5K4ECGX_REG_WRITE(0x70000BE0, 0x0050),
	S5K4ECGX_REG_WRITE(0x70000BE2, 0x1140),
	S5K4ECGX_REG_WRITE(0x70000BE4, 0x201C),
	S5K4ECGX_REG_WRITE(0x70000BE6, 0x0620),
	S5K4ECGX_REG_WRITE(0x70000BE8, 0x0306),
	S5K4ECGX_REG_WRITE(0x70000BEA, 0x2003),
	S5K4ECGX_REG_WRITE(0x70000BEC, 0xFF01),
	S5K4ECGX_REG_WRITE(0x70000BEE, 0x0404),
	S5K4ECGX_REG_WRITE(0x70000BF0, 0x0300),
	S5K4ECGX_REG_WRITE(0x70000BF2, 0x145A),
	S5K4ECGX_REG_WRITE(0x70000BF4, 0x1010),
	S5K4ECGX_REG_WRITE(0x70000BF6, 0x000B),
	S5K4ECGX_REG_WRITE(0x70000BF8, 0x1000),
	S5K4ECGX_REG_WRITE(0x70000BFA, 0x5A0F),
	S5K4ECGX_REG_WRITE(0x70000BFC, 0x0503),
	S5K4ECGX_REG_WRITE(0x70000BFE, 0x1802),
	S5K4ECGX_REG_WRITE(0x70000C00, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000C02, 0x2006),
	S5K4ECGX_REG_WRITE(0x70000C04, 0x3C28),
	S5K4ECGX_REG_WRITE(0x70000C06, 0x042C),
	S5K4ECGX_REG_WRITE(0x70000C08, 0x0101),
	S5K4ECGX_REG_WRITE(0x70000C0A, 0xFF00),
	S5K4ECGX_REG_WRITE(0x70000C0C, 0x0904),
	S5K4ECGX_REG_WRITE(0x70000C0E, 0x4008),
	S5K4ECGX_REG_WRITE(0x70000C10, 0x0540),
	S5K4ECGX_REG_WRITE(0x70000C12, 0x8006),
	S5K4ECGX_REG_WRITE(0x70000C14, 0x0020),
	S5K4ECGX_REG_WRITE(0x70000C16, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000C18, 0x1800),
	S5K4ECGX_REG_WRITE(0x70000C1A, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000C1C, 0x1E10),
	S5K4ECGX_REG_WRITE(0x70000C1E, 0x000B),
	S5K4ECGX_REG_WRITE(0x70000C20, 0x0607),
	S5K4ECGX_REG_WRITE(0x70000C22, 0x0005),
	S5K4ECGX_REG_WRITE(0x70000C24, 0x0607),
	S5K4ECGX_REG_WRITE(0x70000C26, 0x0405),
	S5K4ECGX_REG_WRITE(0x70000C28, 0x0206),
	S5K4ECGX_REG_WRITE(0x70000C2A, 0x0304),
	S5K4ECGX_REG_WRITE(0x70000C2C, 0x0409),
	S5K4ECGX_REG_WRITE(0x70000C2E, 0x0305),
	S5K4ECGX_REG_WRITE(0x70000C30, 0x0406),
	S5K4ECGX_REG_WRITE(0x70000C32, 0x2804),
	S5K4ECGX_REG_WRITE(0x70000C34, 0x0228),
	S5K4ECGX_REG_WRITE(0x70000C36, 0x1402),
	S5K4ECGX_REG_WRITE(0x70000C38, 0x0618),
	S5K4ECGX_REG_WRITE(0x70000C3A, 0x1A02),
	S5K4ECGX_REG_WRITE(0x70000C3C, 0x8018),
	S5K4ECGX_REG_WRITE(0x70000C3E, 0x0080),
	S5K4ECGX_REG_WRITE(0x70000C40, 0x0080),
	S5K4ECGX_REG_WRITE(0x70000C42, 0x0180),
	S5K4ECGX_REG_WRITE(0x70000C44, 0x0A0A),
	S5K4ECGX_REG_WRITE(0x70000C46, 0x0101),
	S5K4ECGX_REG_WRITE(0x70000C48, 0x0F15),
	S5K4ECGX_REG_WRITE(0x70000C4A, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000C4C, 0x0A0A),
	S5K4ECGX_REG_WRITE(0x70000C4E, 0xFFFF),
	S5K4ECGX_REG_WRITE(0x70000C50, 0x0808),
	S5K4ECGX_REG_WRITE(0x70000C52, 0x0A01),
	S5K4ECGX_REG_WRITE(0x70000C54, 0x010A),
	S5K4ECGX_REG_WRITE(0x70000C56, 0x1501),
	S5K4ECGX_REG_WRITE(0x70000C58, 0x240F),
	S5K4ECGX_REG_WRITE(0x70000C5A, 0x0A60),
	S5K4ECGX_REG_WRITE(0x70000C5C, 0xFF0A),
	S5K4ECGX_REG_WRITE(0x70000C5E, 0x08FF),
	S5K4ECGX_REG_WRITE(0x70000C60, 0x0008),
	S5K4ECGX_REG_WRITE(0x70000C62, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000C64, 0x0000),	/* AFIT 4 */
	S5K4ECGX_REG_WRITE(0x70000C66, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000C68, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000C6A, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000C6C, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000C6E, 0x00C0),
	S5K4ECGX_REG_WRITE(0x70000C70, 0x0064),
	S5K4ECGX_REG_WRITE(0x70000C72, 0x0384),
	S5K4ECGX_REG_WRITE(0x70000C74, 0x0032),
	S5K4ECGX_REG_WRITE(0x70000C76, 0x01F4),
	S5K4ECGX_REG_WRITE(0x70000C78, 0x0070),
	S5K4ECGX_REG_WRITE(0x70000C7A, 0x0040),
	S5K4ECGX_REG_WRITE(0x70000C7C, 0x00A0),
	S5K4ECGX_REG_WRITE(0x70000C7E, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000C80, 0x0010),
	S5K4ECGX_REG_WRITE(0x70000C82, 0x0060),
	S5K4ECGX_REG_WRITE(0x70000C84, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000C86, 0x1430),
	S5K4ECGX_REG_WRITE(0x70000C88, 0x0201),
	S5K4ECGX_REG_WRITE(0x70000C8A, 0x0204),
	S5K4ECGX_REG_WRITE(0x70000C8C, 0x0F04),
	S5K4ECGX_REG_WRITE(0x70000C8E, 0x030C),
	S5K4ECGX_REG_WRITE(0x70000C90, 0x0003),
	S5K4ECGX_REG_WRITE(0x70000C92, 0x0602),
	S5K4ECGX_REG_WRITE(0x70000C94, 0x1803),
	S5K4ECGX_REG_WRITE(0x70000C96, 0x0040),
	S5K4ECGX_REG_WRITE(0x70000C98, 0x0E20),
	S5K4ECGX_REG_WRITE(0x70000C9A, 0x2018),
	S5K4ECGX_REG_WRITE(0x70000C9C, 0x0620),
	S5K4ECGX_REG_WRITE(0x70000C9E, 0x0306),
	S5K4ECGX_REG_WRITE(0x70000CA0, 0x2003),
	S5K4ECGX_REG_WRITE(0x70000CA2, 0xFF01),
	S5K4ECGX_REG_WRITE(0x70000CA4, 0x0404),
	S5K4ECGX_REG_WRITE(0x70000CA6, 0x0200),
	S5K4ECGX_REG_WRITE(0x70000CA8, 0x145A),
	S5K4ECGX_REG_WRITE(0x70000CAA, 0x1010),
	S5K4ECGX_REG_WRITE(0x70000CAC, 0x000B),
	S5K4ECGX_REG_WRITE(0x70000CAE, 0x1200),
	S5K4ECGX_REG_WRITE(0x70000CB0, 0x5A0F),
	S5K4ECGX_REG_WRITE(0x70000CB2, 0x0502),
	S5K4ECGX_REG_WRITE(0x70000CB4, 0x1802),
	S5K4ECGX_REG_WRITE(0x70000CB6, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000CB8, 0x2006),
	S5K4ECGX_REG_WRITE(0x70000CBA, 0x4028),
	S5K4ECGX_REG_WRITE(0x70000CBC, 0x0430),
	S5K4ECGX_REG_WRITE(0x70000CBE, 0x0101),
	S5K4ECGX_REG_WRITE(0x70000CC0, 0xFF00),
	S5K4ECGX_REG_WRITE(0x70000CC2, 0x0804),
	S5K4ECGX_REG_WRITE(0x70000CC4, 0x4008),
	S5K4ECGX_REG_WRITE(0x70000CC6, 0x0540),
	S5K4ECGX_REG_WRITE(0x70000CC8, 0x8006),
	S5K4ECGX_REG_WRITE(0x70000CCA, 0x0020),
	S5K4ECGX_REG_WRITE(0x70000CCC, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000CCE, 0x1800),
	S5K4ECGX_REG_WRITE(0x70000CD0, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000CD2, 0x1E10),
	S5K4ECGX_REG_WRITE(0x70000CD4, 0x000B),
	S5K4ECGX_REG_WRITE(0x70000CD6, 0x0607),
	S5K4ECGX_REG_WRITE(0x70000CD8, 0x0005),
	S5K4ECGX_REG_WRITE(0x70000CDA, 0x0607),
	S5K4ECGX_REG_WRITE(0x70000CDC, 0x0405),
	S5K4ECGX_REG_WRITE(0x70000CDE, 0x0205),
	S5K4ECGX_REG_WRITE(0x70000CE0, 0x0304),
	S5K4ECGX_REG_WRITE(0x70000CE2, 0x0409),
	S5K4ECGX_REG_WRITE(0x70000CE4, 0x0306),
	S5K4ECGX_REG_WRITE(0x70000CE6, 0x0407),
	S5K4ECGX_REG_WRITE(0x70000CE8, 0x2C04),
	S5K4ECGX_REG_WRITE(0x70000CEA, 0x022C),
	S5K4ECGX_REG_WRITE(0x70000CEC, 0x1402),
	S5K4ECGX_REG_WRITE(0x70000CEE, 0x0618),
	S5K4ECGX_REG_WRITE(0x70000CF0, 0x1A02),
	S5K4ECGX_REG_WRITE(0x70000CF2, 0x8018),
	S5K4ECGX_REG_WRITE(0x70000CF4, 0x0080),
	S5K4ECGX_REG_WRITE(0x70000CF6, 0x0080),
	S5K4ECGX_REG_WRITE(0x70000CF8, 0x0180),
	S5K4ECGX_REG_WRITE(0x70000CFA, 0x0A0A),
	S5K4ECGX_REG_WRITE(0x70000CFC, 0x0101),
	S5K4ECGX_REG_WRITE(0x70000CFE, 0x0C0F),
	S5K4ECGX_REG_WRITE(0x70000D00, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000D02, 0x0808),
	S5K4ECGX_REG_WRITE(0x70000D04, 0xFFFF),
	S5K4ECGX_REG_WRITE(0x70000D06, 0x0808),
	S5K4ECGX_REG_WRITE(0x70000D08, 0x0A01),
	S5K4ECGX_REG_WRITE(0x70000D0A, 0x010A),
	S5K4ECGX_REG_WRITE(0x70000D0C, 0x0F01),
	S5K4ECGX_REG_WRITE(0x70000D0E, 0x240C),
	S5K4ECGX_REG_WRITE(0x70000D10, 0x0860),
	S5K4ECGX_REG_WRITE(0x70000D12, 0xFF08),
	S5K4ECGX_REG_WRITE(0x70000D14, 0x08FF),
	S5K4ECGX_REG_WRITE(0x70000D16, 0x0008),
	S5K4ECGX_REG_WRITE(0x70000D18, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000D1A, 0x23CE),
	S5K4ECGX_REG_WRITE(0x70000D1C, 0xFDC8),
	S5K4ECGX_REG_WRITE(0x70000D1E, 0x112E),
	S5K4ECGX_REG_WRITE(0x70000D20, 0x83A5),
	S5K4ECGX_REG_WRITE(0x70000D22, 0xFE67),
	S5K4ECGX_REG_WRITE(0x70000D24, 0x0000),

	S5K4ECGX_REG_WRITE(0x70000588, 0x0002),	/* AE Speed Normal */

	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_DTP_init) = {
	S5K4ECGX_REG_WRITE(0xD000B054, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_DTP_stop) = {
	S5K4ECGX_REG_WRITE(0xD000B054, 0x0000),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_FPS_Auto) = {
	S5K4ECGX_REG_WRITE(0x700002B4, 0x0052),
	S5K4ECGX_REG_WRITE(0x700002BE, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002C0, 0x0001),
	S5K4ECGX_REG_WRITE(0x700002C2, 0x029A),
	S5K4ECGX_REG_WRITE(0x700002C4, 0x014A),
	S5K4ECGX_REG_WRITE(0x700002D0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002D2, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000266, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000026A, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000024E, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000268, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_FPS_7) = {
	S5K4ECGX_REG_WRITE(0x700002B4, 0x0052),
	S5K4ECGX_REG_WRITE(0x700002BE, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002C0, 0x0001),
	S5K4ECGX_REG_WRITE(0x700002C2, 0x0535),
	S5K4ECGX_REG_WRITE(0x700002C4, 0x0535),
	S5K4ECGX_REG_WRITE(0x700002D0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002D2, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000266, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000026A, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000024E, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000268, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_FPS_15) = {
	S5K4ECGX_REG_WRITE(0x700002B4, 0x0052),
	S5K4ECGX_REG_WRITE(0x700002BE, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002C0, 0x0001),
	S5K4ECGX_REG_WRITE(0x700002C2, 0x029A),
	S5K4ECGX_REG_WRITE(0x700002C4, 0x029A),
	S5K4ECGX_REG_WRITE(0x700002D0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002D2, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000266, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000026A, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000024E, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000268, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_FPS_30) = {
	S5K4ECGX_REG_WRITE(0x700002B4, 0x0052),
	S5K4ECGX_REG_WRITE(0x700002BE, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002C0, 0x0001),
	S5K4ECGX_REG_WRITE(0x700002C2, 0x014D),
	S5K4ECGX_REG_WRITE(0x700002C4, 0x014D),
	S5K4ECGX_REG_WRITE(0x700002D0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002D2, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000266, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000026A, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000024E, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000268, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Effect_Normal) = {
	S5K4ECGX_REG_WRITE(0x7000023C, 0x0000),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Effect_Solarization) = {
	S5K4ECGX_REG_WRITE(0x7000023C, 0x0002),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Effect_Negative) = {
	S5K4ECGX_REG_WRITE(0x7000023C, 0x0003),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Effect_Sepia) = {
	S5K4ECGX_REG_WRITE(0x7000023C, 0x0004),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Effect_Black_White) = {
	S5K4ECGX_REG_WRITE(0x7000023C, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_WB_Auto) = {
	S5K4ECGX_REG_WRITE(0x700004E6, 0x077F),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_WB_Sunny) = {
	S5K4ECGX_REG_WRITE(0x700004E6, 0x0777),
	S5K4ECGX_REG_WRITE(0x700004BA, 0x05E0),
	S5K4ECGX_REG_WRITE(0x700004BC, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004BE, 0x0400),
	S5K4ECGX_REG_WRITE(0x700004C0, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004C2, 0x0530),
	S5K4ECGX_REG_WRITE(0x700004C4, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004C6, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_WB_Cloudy) = {
	S5K4ECGX_REG_WRITE(0x700004E6, 0x0777),
	S5K4ECGX_REG_WRITE(0x700004BA, 0x0710),
	S5K4ECGX_REG_WRITE(0x700004BC, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004BE, 0x0400),
	S5K4ECGX_REG_WRITE(0x700004C0, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004C2, 0x0420),
	S5K4ECGX_REG_WRITE(0x700004C4, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004C6, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_WB_Tungsten) = {
	S5K4ECGX_REG_WRITE(0x700004E6, 0x0777),
	S5K4ECGX_REG_WRITE(0x700004BA, 0x0390),
	S5K4ECGX_REG_WRITE(0x700004BC, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004BE, 0x0400),
	S5K4ECGX_REG_WRITE(0x700004C0, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004C2, 0x0920),
	S5K4ECGX_REG_WRITE(0x700004C4, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004C6, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_WB_Fluorescent) = {
	S5K4ECGX_REG_WRITE(0x700004E6, 0x0777),
	S5K4ECGX_REG_WRITE(0x700004BA, 0x0505),
	S5K4ECGX_REG_WRITE(0x700004BC, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004BE, 0x0400),
	S5K4ECGX_REG_WRITE(0x700004C0, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004C2, 0x0875),
	S5K4ECGX_REG_WRITE(0x700004C4, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004C6, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_WDR_on) = {
	S5K4ECGX_REG_WRITE(0x70001BEA, 0x0000),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_WDR_off) = {
	S5K4ECGX_REG_WRITE(0x70001BEA, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_ISO_Auto) = {
	S5K4ECGX_REG_WRITE(0x70000938, 0x0000),

	S5K4ECGX_REG_WRITE(0x70000F2A, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004E6, 0x077F),

	S5K4ECGX_REG_WRITE(0x700004D0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004D2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004D4, 0x0001),
	S5K4ECGX_REG_WRITE(0x700006C2, 0x0200),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_ISO_100) = {
	S5K4ECGX_REG_WRITE(0x700004E6, 0x065F),
	S5K4ECGX_REG_WRITE(0x700004D6, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004D8, 0x0001),

	S5K4ECGX_REG_WRITE(0x700004D0, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004D2, 0x01A0),
	S5K4ECGX_REG_WRITE(0x700004D4, 0x0001),
	S5K4ECGX_REG_WRITE(0x700006C2, 0x0100),

	S5K4ECGX_REG_WRITE(0x70000938, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_ISO_200) = {
	S5K4ECGX_REG_WRITE(0x700004E6, 0x065F),
	S5K4ECGX_REG_WRITE(0x700004D6, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004D8, 0x0001),

	S5K4ECGX_REG_WRITE(0x700004D0, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004D2, 0x0340),
	S5K4ECGX_REG_WRITE(0x700004D4, 0x0001),
	S5K4ECGX_REG_WRITE(0x700006C2, 0x0100),

	S5K4ECGX_REG_WRITE(0x70000938, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_ISO_400) = {
	S5K4ECGX_REG_WRITE(0x700004E6, 0x065F),
	S5K4ECGX_REG_WRITE(0x700004D6, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004D8, 0x0001),

	S5K4ECGX_REG_WRITE(0x700004D0, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004D2, 0x0680),
	S5K4ECGX_REG_WRITE(0x700004D4, 0x0001),
	S5K4ECGX_REG_WRITE(0x700006C2, 0x0100),

	S5K4ECGX_REG_WRITE(0x70000938, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Metering_Matrix) = {
	S5K4ECGX_REG_WRITE(0x70001492, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001494, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001496, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001498, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000149A, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000149C, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000149E, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014A0, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014A2, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014A4, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014A6, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014A8, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014AA, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014AC, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014AE, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014B0, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014B2, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014B4, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014B6, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014B8, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014BA, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014BC, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014BE, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014C0, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014C2, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014C4, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014C6, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014C8, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014CA, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014CC, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014CE, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014D0, 0x0101),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Metering_Center) = {
	S5K4ECGX_REG_WRITE(0x70001492, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001494, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001496, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001498, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000149A, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000149C, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000149E, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014A0, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014A2, 0x0201),
	S5K4ECGX_REG_WRITE(0x700014A4, 0x0303),
	S5K4ECGX_REG_WRITE(0x700014A6, 0x0303),
	S5K4ECGX_REG_WRITE(0x700014A8, 0x0102),
	S5K4ECGX_REG_WRITE(0x700014AA, 0x0201),
	S5K4ECGX_REG_WRITE(0x700014AC, 0x0403),
	S5K4ECGX_REG_WRITE(0x700014AE, 0x0304),
	S5K4ECGX_REG_WRITE(0x700014B0, 0x0102),
	S5K4ECGX_REG_WRITE(0x700014B2, 0x0201),
	S5K4ECGX_REG_WRITE(0x700014B4, 0x0403),
	S5K4ECGX_REG_WRITE(0x700014B6, 0x0304),
	S5K4ECGX_REG_WRITE(0x700014B8, 0x0102),
	S5K4ECGX_REG_WRITE(0x700014BA, 0x0201),
	S5K4ECGX_REG_WRITE(0x700014BC, 0x0403),
	S5K4ECGX_REG_WRITE(0x700014BE, 0x0304),
	S5K4ECGX_REG_WRITE(0x700014C0, 0x0102),
	S5K4ECGX_REG_WRITE(0x700014C2, 0x0201),
	S5K4ECGX_REG_WRITE(0x700014C4, 0x0303),
	S5K4ECGX_REG_WRITE(0x700014C6, 0x0303),
	S5K4ECGX_REG_WRITE(0x700014C8, 0x0102),
	S5K4ECGX_REG_WRITE(0x700014CA, 0x0201),
	S5K4ECGX_REG_WRITE(0x700014CC, 0x0202),
	S5K4ECGX_REG_WRITE(0x700014CE, 0x0202),
	S5K4ECGX_REG_WRITE(0x700014D0, 0x0102),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Metering_Spot) = {
	S5K4ECGX_REG_WRITE(0x70001492, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001494, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001496, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001498, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000149A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000149C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000149E, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014A0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014A2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014A4, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014A6, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014A8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014AA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014AC, 0x010F),
	S5K4ECGX_REG_WRITE(0x700014AE, 0x0F01),
	S5K4ECGX_REG_WRITE(0x700014B0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014B2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014B4, 0x010F),
	S5K4ECGX_REG_WRITE(0x700014B6, 0x0F01),
	S5K4ECGX_REG_WRITE(0x700014B8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014BA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014BC, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014BE, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014C0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014C2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014C4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014C6, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014C8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014CA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014CC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014CE, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014D0, 0x0000),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_EV_Minus_4) = {
	S5K4ECGX_REG_WRITE(0x70000230, 0xFF30),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_EV_Minus_3) = {
	S5K4ECGX_REG_WRITE(0x70000230, 0xFFA0),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_EV_Minus_2) = {
	S5K4ECGX_REG_WRITE(0x70000230, 0xFFC8),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_EV_Minus_1) = {
	S5K4ECGX_REG_WRITE(0x70000230, 0xFFE0),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_EV_Default) = {
	S5K4ECGX_REG_WRITE(0x70000230, 0x0000),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_EV_Plus_1) = {
	S5K4ECGX_REG_WRITE(0x70000230, 0x0020),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_EV_Plus_2) = {
	S5K4ECGX_REG_WRITE(0x70000230, 0x0038),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_EV_Plus_3) = {
	S5K4ECGX_REG_WRITE(0x70000230, 0x0060),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_EV_Plus_4) = {
	S5K4ECGX_REG_WRITE(0x70000230, 0x007F),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Contrast_Minus_4) = {
	S5K4ECGX_REG_WRITE(0x70000232, 0xFF81),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Contrast_Minus_3) = {
	S5K4ECGX_REG_WRITE(0x70000232, 0xFFA0),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Contrast_Minus_2) = {
	S5K4ECGX_REG_WRITE(0x70000232, 0xFFC0),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Contrast_Minus_1) = {
	S5K4ECGX_REG_WRITE(0x70000232, 0xFFE0),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Contrast_Default) = {
	S5K4ECGX_REG_WRITE(0x70000232, 0x0000),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Contrast_Plus_1) = {
	S5K4ECGX_REG_WRITE(0x70000232, 0x0020),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Contrast_Plus_2) = {
	S5K4ECGX_REG_WRITE(0x70000232, 0x0040),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Contrast_Plus_3) = {
	S5K4ECGX_REG_WRITE(0x70000232, 0x0060),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Contrast_Plus_4) = {
	S5K4ECGX_REG_WRITE(0x70000232, 0x007F),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Sharpness_Minus_3) = {
	S5K4ECGX_REG_WRITE(0x70000A28, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000ADE, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000B94, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000C4A, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000D00, 0x0000),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Sharpness_Minus_2) = {
	S5K4ECGX_REG_WRITE(0x70000A28, 0x2010),
	S5K4ECGX_REG_WRITE(0x70000ADE, 0x2010),
	S5K4ECGX_REG_WRITE(0x70000B94, 0x2010),
	S5K4ECGX_REG_WRITE(0x70000C4A, 0x2010),
	S5K4ECGX_REG_WRITE(0x70000D00, 0x2010),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Sharpness_Minus_1) = {
	S5K4ECGX_REG_WRITE(0x70000A28, 0x4020),
	S5K4ECGX_REG_WRITE(0x70000ADE, 0x4020),
	S5K4ECGX_REG_WRITE(0x70000B94, 0x4020),
	S5K4ECGX_REG_WRITE(0x70000C4A, 0x4020),
	S5K4ECGX_REG_WRITE(0x70000D00, 0x4020),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Sharpness_Default) = {
	S5K4ECGX_REG_WRITE(0x70000A28, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000ADE, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000B94, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000C4A, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000D00, 0x6024),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Sharpness_Plus_1) = {
	S5K4ECGX_REG_WRITE(0x70000A28, 0x8040),
	S5K4ECGX_REG_WRITE(0x70000ADE, 0x8040),
	S5K4ECGX_REG_WRITE(0x70000B94, 0x8040),
	S5K4ECGX_REG_WRITE(0x70000C4A, 0x8040),
	S5K4ECGX_REG_WRITE(0x70000D00, 0x8040),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Sharpness_Plus_2) = {
	S5K4ECGX_REG_WRITE(0x70000A28, 0xA060),
	S5K4ECGX_REG_WRITE(0x70000ADE, 0xA060),
	S5K4ECGX_REG_WRITE(0x70000B94, 0xA060),
	S5K4ECGX_REG_WRITE(0x70000C4A, 0xA060),
	S5K4ECGX_REG_WRITE(0x70000D00, 0xA060),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Sharpness_Plus_3) = {
	S5K4ECGX_REG_WRITE(0x70000A28, 0xC080),
	S5K4ECGX_REG_WRITE(0x70000ADE, 0xC080),
	S5K4ECGX_REG_WRITE(0x70000B94, 0xC080),
	S5K4ECGX_REG_WRITE(0x70000C4A, 0xC080),
	S5K4ECGX_REG_WRITE(0x70000D00, 0xC080),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Saturation_Minus_2) = {
	S5K4ECGX_REG_WRITE(0x70000234, 0xFF81),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Saturation_Minus_1) = {
	S5K4ECGX_REG_WRITE(0x70000234, 0xFFC0),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Saturation_Default) = {
	S5K4ECGX_REG_WRITE(0x70000234, 0x0000),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Saturation_Plus_1) = {
	S5K4ECGX_REG_WRITE(0x70000234, 0x0040),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Saturation_Plus_2) = {
	S5K4ECGX_REG_WRITE(0x70000234, 0x007F),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Jpeg_Quality_High) = {
	S5K4ECGX_REG_WRITE(0x70000478, 0x005F),
	S5K4ECGX_REG_WRITE(0x7000047A, 0x005F),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Jpeg_Quality_Normal) = {
	S5K4ECGX_REG_WRITE(0x70000478, 0x005A),
	S5K4ECGX_REG_WRITE(0x7000047A, 0x005A),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Jpeg_Quality_Low) = {
	S5K4ECGX_REG_WRITE(0x70000478, 0x0054),
	S5K4ECGX_REG_WRITE(0x7000047A, 0x0054),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Default) = {
	S5K4ECGX_REG_WRITE(0x70001492, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001494, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001496, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001498, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000149A, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000149C, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000149E, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014A0, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014A2, 0x0201),
	S5K4ECGX_REG_WRITE(0x700014A4, 0x0303),
	S5K4ECGX_REG_WRITE(0x700014A6, 0x0303),
	S5K4ECGX_REG_WRITE(0x700014A8, 0x0102),
	S5K4ECGX_REG_WRITE(0x700014AA, 0x0201),
	S5K4ECGX_REG_WRITE(0x700014AC, 0x0403),
	S5K4ECGX_REG_WRITE(0x700014AE, 0x0304),
	S5K4ECGX_REG_WRITE(0x700014B0, 0x0102),
	S5K4ECGX_REG_WRITE(0x700014B2, 0x0201),
	S5K4ECGX_REG_WRITE(0x700014B4, 0x0403),
	S5K4ECGX_REG_WRITE(0x700014B6, 0x0304),
	S5K4ECGX_REG_WRITE(0x700014B8, 0x0102),
	S5K4ECGX_REG_WRITE(0x700014BA, 0x0201),
	S5K4ECGX_REG_WRITE(0x700014BC, 0x0403),
	S5K4ECGX_REG_WRITE(0x700014BE, 0x0304),
	S5K4ECGX_REG_WRITE(0x700014C0, 0x0102),
	S5K4ECGX_REG_WRITE(0x700014C2, 0x0201),
	S5K4ECGX_REG_WRITE(0x700014C4, 0x0303),
	S5K4ECGX_REG_WRITE(0x700014C6, 0x0303),
	S5K4ECGX_REG_WRITE(0x700014C8, 0x0102),
	S5K4ECGX_REG_WRITE(0x700014CA, 0x0201),
	S5K4ECGX_REG_WRITE(0x700014CC, 0x0202),
	S5K4ECGX_REG_WRITE(0x700014CE, 0x0202),
	S5K4ECGX_REG_WRITE(0x700014D0, 0x0102),

	S5K4ECGX_REG_WRITE(0x70000938, 0x0000),

	S5K4ECGX_REG_WRITE(0x700006B8, 0x452C),
	S5K4ECGX_REG_WRITE(0x700006BA, 0x000C),

	S5K4ECGX_REG_WRITE(0x70000F2A, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000F30, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004E6, 0x077F),

	S5K4ECGX_REG_WRITE(0x700004D0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004D2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004D4, 0x0001),
	S5K4ECGX_REG_WRITE(0x700006C2, 0x0200),

	S5K4ECGX_REG_WRITE(0x70002C66, 0x0001),

	S5K4ECGX_REG_WRITE(0x70001484, 0x003C),
	S5K4ECGX_REG_WRITE(0x7000148A, 0x000F),
	S5K4ECGX_REG_WRITE(0x7000058C, 0x3520),
	S5K4ECGX_REG_WRITE(0x7000058E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000590, 0xC350),
	S5K4ECGX_REG_WRITE(0x70000592, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000594, 0x3520),
	S5K4ECGX_REG_WRITE(0x70000596, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000598, 0xC350),
	S5K4ECGX_REG_WRITE(0x7000059A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000059C, 0x0470),
	S5K4ECGX_REG_WRITE(0x7000059E, 0x0C00),
	S5K4ECGX_REG_WRITE(0x700005A0, 0x0100),
	S5K4ECGX_REG_WRITE(0x700005A2, 0x1000),

	S5K4ECGX_REG_WRITE(0x70000544, 0x0111),
	S5K4ECGX_REG_WRITE(0x70000546, 0x00EF),

	S5K4ECGX_REG_WRITE(0x70000608, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000060A, 0x0001),

	S5K4ECGX_REG_WRITE(0x70000A28, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000ADE, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000B94, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000C4A, 0x6024),
	S5K4ECGX_REG_WRITE(0x70000D00, 0x6024),

	S5K4ECGX_REG_WRITE(0x70000234, 0x0000),

	S5K4ECGX_REG_WRITE(0x70000638, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000063A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000063C, 0x0A3C),
	S5K4ECGX_REG_WRITE(0x7000063E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000640, 0x0D05),
	S5K4ECGX_REG_WRITE(0x70000642, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000644, 0x3408),
	S5K4ECGX_REG_WRITE(0x70000646, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000648, 0x3408),
	S5K4ECGX_REG_WRITE(0x7000064A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000064C, 0x6810),
	S5K4ECGX_REG_WRITE(0x7000064E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000650, 0x8214),
	S5K4ECGX_REG_WRITE(0x70000652, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000654, 0xC350),
	S5K4ECGX_REG_WRITE(0x70000656, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000658, 0xC350),
	S5K4ECGX_REG_WRITE(0x7000065A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000065C, 0xC350),
	S5K4ECGX_REG_WRITE(0x7000065E, 0x0000),

	S5K4ECGX_REG_WRITE(0x700002C2, 0x029A),	/* #REG_0TC_PCFG_usMaxFrTimeMsecMult10 */
	S5K4ECGX_REG_WRITE(0x700002C4, 0x014A),	/* #REG_0TC_PCFG_usMinFrTimeMsecMult10 */

	S5K4ECGX_REG_WRITE(0x700003B4, 0x0535),
	S5K4ECGX_REG_WRITE(0x700003B6, 0x029A),

	S5K4ECGX_REG_WRITE(0x70000266, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000026A, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000024E, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000268, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000270, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000023E, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000240, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Portrait) = {
	S5K4ECGX_REG_WRITE(0x70000A28, 0x2010),
	S5K4ECGX_REG_WRITE(0x70000ADE, 0x2010),
	S5K4ECGX_REG_WRITE(0x70000B94, 0x2010),
	S5K4ECGX_REG_WRITE(0x70000C4A, 0x2010),
	S5K4ECGX_REG_WRITE(0x70000D00, 0x2010),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Nightshot) = {
	S5K4ECGX_REG_WRITE(0x700006B8, 0xFFFF),
	S5K4ECGX_REG_WRITE(0x700006BA, 0x00FF),

	S5K4ECGX_REG_WRITE(0x70000608, 0x0001),	/* #lt_ExpGain_uSubsamplingmode */
	S5K4ECGX_REG_WRITE(0x7000060A, 0x0001),	/* #lt_ExpGain_uNonSubsampling */
	S5K4ECGX_REG_WRITE(0x7000060C, 0x0900),	/* #lt_ExpGain_ExpCurveGainMaxStr */

	S5K4ECGX_REG_WRITE(0x70000658, 0xD090),
	S5K4ECGX_REG_WRITE(0x7000065A, 0x0007),
	S5K4ECGX_REG_WRITE(0x7000065C, 0xD090),
	S5K4ECGX_REG_WRITE(0x7000065E, 0x0007),

	S5K4ECGX_REG_WRITE(0x700003B4, 0x1388),
	S5K4ECGX_REG_WRITE(0x700003B6, 0x1388),
	S5K4ECGX_REG_WRITE(0x700002C2, 0x09C4),
	S5K4ECGX_REG_WRITE(0x700002C4, 0x014A),
	S5K4ECGX_REG_WRITE(0x70000266, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000026A, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000024E, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000268, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000270, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000023E, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000240, 0x0001),

	S5K4ECGX_REG_WRITE(0x70000A1E, 0x1580),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Backlight) = {
	S5K4ECGX_REG_WRITE(0x70001492, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001494, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001496, 0x0000),
	S5K4ECGX_REG_WRITE(0x70001498, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000149A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000149C, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000149E, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014A0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014A2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014A4, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014A6, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014A8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014AA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014AC, 0x010F),
	S5K4ECGX_REG_WRITE(0x700014AE, 0x0F01),
	S5K4ECGX_REG_WRITE(0x700014B0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014B2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014B4, 0x010F),
	S5K4ECGX_REG_WRITE(0x700014B6, 0x0F01),
	S5K4ECGX_REG_WRITE(0x700014B8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014BA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014BC, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014BE, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014C0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014C2, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014C4, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014C6, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014C8, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014CA, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014CC, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014CE, 0x0000),
	S5K4ECGX_REG_WRITE(0x700014D0, 0x0000),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Landscape) = {
	S5K4ECGX_REG_WRITE(0x70001492, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001494, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001496, 0x0101),
	S5K4ECGX_REG_WRITE(0x70001498, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000149A, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000149C, 0x0101),
	S5K4ECGX_REG_WRITE(0x7000149E, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014A0, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014A2, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014A4, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014A6, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014A8, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014AA, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014AC, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014AE, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014B0, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014B2, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014B4, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014B6, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014B8, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014BA, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014BC, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014BE, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014C0, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014C2, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014C4, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014C6, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014C8, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014CA, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014CC, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014CE, 0x0101),
	S5K4ECGX_REG_WRITE(0x700014D0, 0x0101),
	S5K4ECGX_REG_WRITE(0x70000A28, 0xE082),
	S5K4ECGX_REG_WRITE(0x70000ADE, 0xE082),
	S5K4ECGX_REG_WRITE(0x70000B94, 0xE082),
	S5K4ECGX_REG_WRITE(0x70000C4A, 0xE082),
	S5K4ECGX_REG_WRITE(0x70000D00, 0xE082),
	S5K4ECGX_REG_WRITE(0x70000234, 0x0030),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Sports) = {
	S5K4ECGX_REG_WRITE(0x70000608, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000060A, 0x0000),

	S5K4ECGX_REG_WRITE(0x7000058C, 0x3520),
	S5K4ECGX_REG_WRITE(0x7000058E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000590, 0x3520),
	S5K4ECGX_REG_WRITE(0x70000592, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000594, 0x3520),
	S5K4ECGX_REG_WRITE(0x70000596, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000598, 0x3520),
	S5K4ECGX_REG_WRITE(0x7000059A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000059C, 0x0200),
	S5K4ECGX_REG_WRITE(0x7000059E, 0x0200),
	S5K4ECGX_REG_WRITE(0x700005A0, 0x0200),
	S5K4ECGX_REG_WRITE(0x700005A2, 0x0200),

	S5K4ECGX_REG_WRITE(0x70000266, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000026A, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000024E, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000268, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000270, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000023E, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000240, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Party_Indoor) = {
	S5K4ECGX_REG_WRITE(0x700004E6, 0x065F),
	S5K4ECGX_REG_WRITE(0x700004D6, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004D8, 0x0001),

	S5K4ECGX_REG_WRITE(0x700004D0, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004D2, 0x0340),
	S5K4ECGX_REG_WRITE(0x700004D4, 0x0001),
	S5K4ECGX_REG_WRITE(0x700006C2, 0x0100),

	S5K4ECGX_REG_WRITE(0x70000938, 0x0001),

	S5K4ECGX_REG_WRITE(0x70000234, 0x0030),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Beach_Snow) = {
	S5K4ECGX_REG_WRITE(0x70001484, 0x0045),	/* #TVAR_ae_BrAve */
	S5K4ECGX_REG_WRITE(0x700004E6, 0x065F),
	S5K4ECGX_REG_WRITE(0x700004D6, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004D8, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004D0, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004D2, 0x00D0),
	S5K4ECGX_REG_WRITE(0x700004D4, 0x0001),
	S5K4ECGX_REG_WRITE(0x700006C2, 0x0100),

	S5K4ECGX_REG_WRITE(0x70000938, 0x0001),

	S5K4ECGX_REG_WRITE(0x70000234, 0x0030),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Sunset) = {
	S5K4ECGX_REG_WRITE(0x700004E6, 0x0777),

	S5K4ECGX_REG_WRITE(0x700004BA, 0x05E0),
	S5K4ECGX_REG_WRITE(0x700004BC, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004BE, 0x0400),
	S5K4ECGX_REG_WRITE(0x700004C0, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004C2, 0x0530),
	S5K4ECGX_REG_WRITE(0x700004C4, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004C6, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Duskdawn) = {
	S5K4ECGX_REG_WRITE(0x700004E6, 0x0777),
	S5K4ECGX_REG_WRITE(0x700004BA, 0x0505),
	S5K4ECGX_REG_WRITE(0x700004BC, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004BE, 0x0400),
	S5K4ECGX_REG_WRITE(0x700004C0, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004C2, 0x0875),
	S5K4ECGX_REG_WRITE(0x700004C4, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004C6, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Fall_Color) = {
	S5K4ECGX_REG_WRITE(0x70000234, 0x0060),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Fireworks) = {
	S5K4ECGX_REG_WRITE(0x70000638, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000063A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000063C, 0x1478),
	S5K4ECGX_REG_WRITE(0x7000063E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000640, 0x1A0A),
	S5K4ECGX_REG_WRITE(0x70000642, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000644, 0x6810),
	S5K4ECGX_REG_WRITE(0x70000646, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000648, 0x6810),
	S5K4ECGX_REG_WRITE(0x7000064A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000064C, 0xD020),
	S5K4ECGX_REG_WRITE(0x7000064E, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000650, 0x0428),
	S5K4ECGX_REG_WRITE(0x70000652, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000654, 0x1A80),
	S5K4ECGX_REG_WRITE(0x70000656, 0x0006),
	S5K4ECGX_REG_WRITE(0x70000658, 0x1A80),
	S5K4ECGX_REG_WRITE(0x7000065A, 0x0006),
	S5K4ECGX_REG_WRITE(0x7000065C, 0x1A80),
	S5K4ECGX_REG_WRITE(0x7000065E, 0x0006),

	S5K4ECGX_REG_WRITE(0x700003B4, 0x2710),
	S5K4ECGX_REG_WRITE(0x700003B6, 0x2710),

	S5K4ECGX_REG_WRITE(0x70000266, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000026A, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000024E, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000268, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000270, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000023E, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000240, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Text) = {
	S5K4ECGX_REG_WRITE(0x70000A28, 0xA060),
	S5K4ECGX_REG_WRITE(0x70000ADE, 0xA060),
	S5K4ECGX_REG_WRITE(0x70000B94, 0xA060),
	S5K4ECGX_REG_WRITE(0x70000C4A, 0xA060),
	S5K4ECGX_REG_WRITE(0x70000D00, 0xA060),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Scene_Candle_Light) = {
	S5K4ECGX_REG_WRITE(0x700004E6, 0x0777),
	S5K4ECGX_REG_WRITE(0x700004BA, 0x05E0),
	S5K4ECGX_REG_WRITE(0x700004BC, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004BE, 0x0400),
	S5K4ECGX_REG_WRITE(0x700004C0, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004C2, 0x0530),
	S5K4ECGX_REG_WRITE(0x700004C4, 0x0001),
	S5K4ECGX_REG_WRITE(0x700004C6, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Night_Capture) = {
	S5K4ECGX_REG_WRITE(0x70000608, 0x0001),	/* #lt_ExpGain_uSubsamplingmode */
	S5K4ECGX_REG_WRITE(0x7000060A, 0x0001),	/* #lt_ExpGain_uNonSubsampling */
	S5K4ECGX_REG_WRITE(0x7000060C, 0x0900),	/* #lt_ExpGain_ExpCurveGainMaxStr */
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_AF_Return_Macro_pos) = {
	S5K4ECGX_REG_WRITE(0x700015E8, 0x0018),
	S5K4ECGX_REG_WRITE(0x700015EA, 0x002A),
	S5K4ECGX_REG_WRITE(0x700015EC, 0x0030),
	S5K4ECGX_REG_WRITE(0x700015EE, 0x0036),
	S5K4ECGX_REG_WRITE(0x700015F0, 0x003C),
	S5K4ECGX_REG_WRITE(0x700015F2, 0x0042),
	S5K4ECGX_REG_WRITE(0x700015F4, 0x0048),
	S5K4ECGX_REG_WRITE(0x700015F6, 0x004E),
	S5K4ECGX_REG_WRITE(0x700015F8, 0x0054),
	S5K4ECGX_REG_WRITE(0x700015FA, 0x005A),
	S5K4ECGX_REG_WRITE(0x700015FC, 0x0060),
	S5K4ECGX_REG_WRITE(0x700015FE, 0x0066),
	S5K4ECGX_REG_WRITE(0x70001600, 0x006C),
	S5K4ECGX_REG_WRITE(0x70001602, 0x0072),
	S5K4ECGX_REG_WRITE(0x70001604, 0x0078),
	S5K4ECGX_REG_WRITE(0x70001606, 0x007E),
	S5K4ECGX_REG_WRITE(0x70001608, 0x0084),
	S5K4ECGX_REG_WRITE(0x7000160A, 0x008A),
	S5K4ECGX_REG_WRITE(0x7000160C, 0x0090),
	S5K4ECGX_REG_WRITE(0x7000160E, 0x0096),
	S5K4ECGX_REG_WRITE(0x70001610, 0x009C),
	S5K4ECGX_REG_WRITE(0x70001612, 0x00A2),
	S5K4ECGX_REG_WRITE(0x70001614, 0x00A8),
	S5K4ECGX_REG_WRITE(0x70001616, 0x00AE),
	S5K4ECGX_REG_WRITE(0x70001618, 0x00B4),
	S5K4ECGX_REG_WRITE(0x7000161A, 0x00BA),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_AF_Normal_mode) = {
	S5K4ECGX_REG_WRITE(0x7000028E, 0x0000),
	S5K4ECGX_MDELAY(100),
	S5K4ECGX_REG_WRITE(0x7000028C, 0x0004),
	S5K4ECGX_MDELAY(200),
	S5K4ECGX_REG_WRITE(0x70001648, 0x9002),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_AF_Macro_mode) = {
	S5K4ECGX_REG_WRITE(0x7000028E, 0x00D0),
	S5K4ECGX_MDELAY(100),
	S5K4ECGX_REG_WRITE(0x7000028C, 0x0004),
	S5K4ECGX_MDELAY(200),
	S5K4ECGX_REG_WRITE(0x70001648, 0x9042),
	S5K4ECGX_REG_WRITE(0x700015DA, 0x1800),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_AF_Low_Light_Mode_On) = {
	S5K4ECGX_REG_WRITE(0x700015DA, 0x0C00),

	S5K4ECGX_REG_WRITE(0x700015E8, 0x000C),
	S5K4ECGX_REG_WRITE(0x700015EA, 0x002A),
	S5K4ECGX_REG_WRITE(0x700015EC, 0x0033),
	S5K4ECGX_REG_WRITE(0x700015EE, 0x003C),
	S5K4ECGX_REG_WRITE(0x700015F0, 0x0045),
	S5K4ECGX_REG_WRITE(0x700015F2, 0x004E),
	S5K4ECGX_REG_WRITE(0x700015F4, 0x0057),
	S5K4ECGX_REG_WRITE(0x700015F6, 0x0063),
	S5K4ECGX_REG_WRITE(0x700015F8, 0x006F),
	S5K4ECGX_REG_WRITE(0x700015FA, 0x007B),
	S5K4ECGX_REG_WRITE(0x700015FC, 0x0087),
	S5K4ECGX_REG_WRITE(0x700015FE, 0x0093),
	S5K4ECGX_REG_WRITE(0x70001600, 0x00A2),
	S5K4ECGX_REG_WRITE(0x70001602, 0x00B1),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_AF_Low_Light_Mode_Off) = {
	S5K4ECGX_REG_WRITE(0x700015DA, 0x1800),

	S5K4ECGX_REG_WRITE(0x700015E8, 0x0018),
	S5K4ECGX_REG_WRITE(0x700015EA, 0x002A),
	S5K4ECGX_REG_WRITE(0x700015EC, 0x0030),
	S5K4ECGX_REG_WRITE(0x700015EE, 0x0036),
	S5K4ECGX_REG_WRITE(0x700015F0, 0x003C),
	S5K4ECGX_REG_WRITE(0x700015F2, 0x0042),
	S5K4ECGX_REG_WRITE(0x700015F4, 0x0048),
	S5K4ECGX_REG_WRITE(0x700015F6, 0x004E),
	S5K4ECGX_REG_WRITE(0x700015F8, 0x0054),
	S5K4ECGX_REG_WRITE(0x700015FA, 0x005A),
	S5K4ECGX_REG_WRITE(0x700015FC, 0x0060),
	S5K4ECGX_REG_WRITE(0x700015FE, 0x0066),
	S5K4ECGX_REG_WRITE(0x70001600, 0x006C),
	S5K4ECGX_REG_WRITE(0x70001602, 0x0072),
	S5K4ECGX_REG_WRITE(0x70001604, 0x0078),
	S5K4ECGX_REG_WRITE(0x70001606, 0x007E),
	S5K4ECGX_REG_WRITE(0x70001608, 0x0084),
	S5K4ECGX_REG_WRITE(0x7000160A, 0x008A),
	S5K4ECGX_REG_WRITE(0x7000160C, 0x0090),
	S5K4ECGX_REG_WRITE(0x7000160E, 0x0096),
	S5K4ECGX_REG_WRITE(0x70001610, 0x009C),
	S5K4ECGX_REG_WRITE(0x70001612, 0x00A2),
	S5K4ECGX_REG_WRITE(0x70001614, 0x00A8),
	S5K4ECGX_REG_WRITE(0x70001616, 0x00AE),
	S5K4ECGX_REG_WRITE(0x70001618, 0x00B4),
	S5K4ECGX_REG_WRITE(0x7000161A, 0x00BA),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Single_AF_Start) = {
	S5K4ECGX_REG_WRITE(0x7000028C, 0x0005),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Single_AF_Off_1) = {
	S5K4ECGX_REG_WRITE(0x7000028E, 0x0000),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Single_AF_Off_2) = {
	S5K4ECGX_REG_WRITE(0x7000028C, 0x0004),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Single_AF_Off_3) = {

	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Face_Detection_On) = {
	S5K4ECGX_REG_WRITE(0x70000294, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000296, 0x00E3),
	S5K4ECGX_REG_WRITE(0x70000298, 0x0200),
	S5K4ECGX_REG_WRITE(0x7000029A, 0x0238),
	S5K4ECGX_REG_WRITE(0x7000029C, 0x01C6),
	S5K4ECGX_REG_WRITE(0x7000029E, 0x0166),
	S5K4ECGX_REG_WRITE(0x700002A0, 0x0074),
	S5K4ECGX_REG_WRITE(0x700002A2, 0x0132),
	S5K4ECGX_REG_WRITE(0x700002A4, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Face_Detection_Off) = {
	S5K4ECGX_REG_WRITE(0x70000294, 0x0100),
	S5K4ECGX_REG_WRITE(0x70000296, 0x00E3),
	S5K4ECGX_REG_WRITE(0x70000298, 0x0200),
	S5K4ECGX_REG_WRITE(0x7000029A, 0x0238),
	S5K4ECGX_REG_WRITE(0x7000029C, 0x01C6),
	S5K4ECGX_REG_WRITE(0x7000029E, 0x0166),
	S5K4ECGX_REG_WRITE(0x700002A0, 0x0074),
	S5K4ECGX_REG_WRITE(0x700002A2, 0x0132),
	S5K4ECGX_REG_WRITE(0x700002A4, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Low_Cap_On) = {
	S5K4ECGX_REG_WRITE(0x700006B8, 0xFFFF),
	S5K4ECGX_REG_WRITE(0x700006BA, 0x00FF),	/* #lt_uMaxLei */

	S5K4ECGX_REG_WRITE(0x70000A1A, 0x4A18),	/* #Gamma linearity */

	S5K4ECGX_REG_WRITE(0x70000608, 0x0001),	/* #lt_ExpGain_uSubsamplingmode */
	S5K4ECGX_REG_WRITE(0x7000060A, 0x0001),	/* #lt_ExpGain_uNonSubsampling */
	S5K4ECGX_REG_WRITE(0x7000060C, 0x0850),	/* #lt_ExpGain_ExpCurveGainMaxStr */

	S5K4ECGX_REG_WRITE(0x70000938, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000093A, 0x0012),	/* #SARR_uNormBrInDoor_0_ */
	S5K4ECGX_REG_WRITE(0x7000093C, 0x0022),	/* #SARR_uNormBrInDoor_1_ */
	S5K4ECGX_REG_WRITE(0x7000093E, 0x0384),	/* #SARR_uNormBrInDoor_2_ */
	S5K4ECGX_REG_WRITE(0x70000940, 0x07D0),	/* #SARR_uNormBrInDoor_3_ */
	S5K4ECGX_REG_WRITE(0x70000942, 0x1388),	/* #SARR_uNormBrInDoor_4_ */
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Low_Cap_Off) = {
	S5K4ECGX_REG_WRITE(0x700006B8, 0x452C),
	S5K4ECGX_REG_WRITE(0x700006BA, 0x000C),	/* #lt_uMaxLei */

	S5K4ECGX_REG_WRITE(0x70000A1A, 0x8F18),	/* #Gamma linearity */

	S5K4ECGX_REG_WRITE(0x70000608, 0x0001),	/* #lt_ExpGain_uSubsamplingmode */
	S5K4ECGX_REG_WRITE(0x7000060A, 0x0001),	/* #lt_ExpGain_uNonSubsampling */
	S5K4ECGX_REG_WRITE(0x7000060C, 0x0C00),	/* #lt_ExpGain_ExpCurveGainMaxStr */

	S5K4ECGX_REG_WRITE(0x70000938, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000093A, 0x0014),	/* #SARR_uNormBrInDoor_0_ */
	S5K4ECGX_REG_WRITE(0x7000093C, 0x00D2),	/* #SARR_uNormBrInDoor_1_ */
	S5K4ECGX_REG_WRITE(0x7000093E, 0x0384),	/* #SARR_uNormBrInDoor_2_ */
	S5K4ECGX_REG_WRITE(0x70000940, 0x07D0),	/* #SARR_uNormBrInDoor_3_ */
	S5K4ECGX_REG_WRITE(0x70000942, 0x1388),	/* #SARR_uNormBrInDoor_4_ */
	S5K4ECGX_REGSET_END
};

	/* restores crop settings to full resolution */
S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Reset_Crop) = {
	S5K4ECGX_REG_WRITE(0x70000250, 0x0A00),
	S5K4ECGX_REG_WRITE(0x70000252, 0x0780),
	S5K4ECGX_REG_WRITE(0x70000254, 0x0010),
	S5K4ECGX_REG_WRITE(0x70000256, 0x000C),
	S5K4ECGX_REG_WRITE(0x70000258, 0x0A00),
	S5K4ECGX_REG_WRITE(0x7000025A, 0x0780),
	S5K4ECGX_REG_WRITE(0x7000025C, 0x0010),
	S5K4ECGX_REG_WRITE(0x7000025E, 0x000C),
	S5K4ECGX_REG_WRITE(0x70000494, 0x0A00),
	S5K4ECGX_REG_WRITE(0x70000496, 0x0780),
	S5K4ECGX_REG_WRITE(0x70000498, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000049A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000049C, 0x0A00),
	S5K4ECGX_REG_WRITE(0x7000049E, 0x0780),
	S5K4ECGX_REG_WRITE(0x700004A0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004A2, 0x0000),

	S5K4ECGX_REG_WRITE(0x70000262, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000264, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Capture_Start) = {
	S5K4ECGX_REG_WRITE(0x70000A1E, 0x0050),

	S5K4ECGX_REG_WRITE(0x70000AD4, 0x0074),

	S5K4ECGX_REG_WRITE(0x70000608, 0x0001),	/* #lt_ExpGain_uSubsamplingmode */
	S5K4ECGX_REG_WRITE(0x7000060A, 0x0001),	/* #lt_ExpGain_uNonSubsampling */
	S5K4ECGX_REG_WRITE(0x7000060C, 0x0850),	/* #lt_ExpGain_ExpCurveGainMaxStr */

	S5K4ECGX_REG_WRITE(0x70000242, 0x0001),

	S5K4ECGX_REG_WRITE(0x7000024E, 0x0001),

	S5K4ECGX_REG_WRITE(0x70000244, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Preview_Return) = {
	S5K4ECGX_REG_WRITE(0x70000A1E, 0x0028),

	S5K4ECGX_REG_WRITE(0x70000AD4, 0x003C),

	S5K4ECGX_REG_WRITE(0x70000608, 0x0001),	/* #lt_ExpGain_uSubsamplingmode */
	S5K4ECGX_REG_WRITE(0x7000060A, 0x0001),	/* #lt_ExpGain_uNonSubsampling */
	S5K4ECGX_REG_WRITE(0x7000060C, 0x0C00),	/* #lt_ExpGain_ExpCurveGainMaxStr */

	S5K4ECGX_REG_WRITE(0x700005D0, 0x0000),

	S5K4ECGX_REG_WRITE(0x70000972, 0x0000),

	S5K4ECGX_REG_WRITE(0x70000242, 0x0000),

	S5K4ECGX_REG_WRITE(0x7000024E, 0x0001),

	S5K4ECGX_REG_WRITE(0x70000244, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Flash_init) = {
	S5K4ECGX_REG_WRITE(0x70000484, 0x0002),	/* capture flash on */

	S5K4ECGX_REG_WRITE(0x7000183A, 0x0001),	/* one frame AE */

	S5K4ECGX_REG_WRITE(0x700017F6, 0x0258),	/* AWB R point */
	S5K4ECGX_REG_WRITE(0x700017F8, 0x0248),	/* AWB B point */

	S5K4ECGX_REG_WRITE(0x70001840, 0x0001),	/* Fls AE tune start */

	S5K4ECGX_REG_WRITE(0x70001842, 0x0100),	/* fls_afl_FlsAFIn  Rin */
	S5K4ECGX_REG_WRITE(0x70001844, 0x0120),
	S5K4ECGX_REG_WRITE(0x70001846, 0x0180),
	S5K4ECGX_REG_WRITE(0x70001848, 0x0200),
	S5K4ECGX_REG_WRITE(0x7000184A, 0x0400),
	S5K4ECGX_REG_WRITE(0x7000184C, 0x0800),
	S5K4ECGX_REG_WRITE(0x7000184E, 0x0A00),
	S5K4ECGX_REG_WRITE(0x70001850, 0x1000),

	S5K4ECGX_REG_WRITE(0x70001852, 0x0100),	/* fls_afl_FlsAFOut  Rout */
	S5K4ECGX_REG_WRITE(0x70001854, 0x00A0),
	S5K4ECGX_REG_WRITE(0x70001856, 0x0090),
	S5K4ECGX_REG_WRITE(0x70001858, 0x0080),
	S5K4ECGX_REG_WRITE(0x7000185A, 0x0070),
	S5K4ECGX_REG_WRITE(0x7000185C, 0x0045),
	S5K4ECGX_REG_WRITE(0x7000185E, 0x0030),
	S5K4ECGX_REG_WRITE(0x70001860, 0x0010),

	S5K4ECGX_REG_WRITE(0x70001884, 0x0100),	/* fls_afl_FlsNBOut  flash NB default */
	S5K4ECGX_REG_WRITE(0x70001886, 0x0100),
	S5K4ECGX_REG_WRITE(0x70001888, 0x0100),
	S5K4ECGX_REG_WRITE(0x7000188A, 0x0100),
	S5K4ECGX_REG_WRITE(0x7000188C, 0x0100),
	S5K4ECGX_REG_WRITE(0x7000188E, 0x0100),
	S5K4ECGX_REG_WRITE(0x70001890, 0x0100),
	S5K4ECGX_REG_WRITE(0x70001892, 0x0100),

	S5K4ECGX_REG_WRITE(0x70001826, 0x0100),	/* fls_afl_FlashWP_Weight  flash NB default */
	S5K4ECGX_REG_WRITE(0x70001828, 0x00C0),
	S5K4ECGX_REG_WRITE(0x7000182A, 0x0080),
	S5K4ECGX_REG_WRITE(0x7000182C, 0x000A),
	S5K4ECGX_REG_WRITE(0x7000182E, 0x0000),

	S5K4ECGX_REG_WRITE(0x70001830, 0x0030),	/* fls_afl_FlashWP_Weight  flash NB default */
	S5K4ECGX_REG_WRITE(0x70001832, 0x0040),
	S5K4ECGX_REG_WRITE(0x70001834, 0x0048),
	S5K4ECGX_REG_WRITE(0x70001836, 0x0050),
	S5K4ECGX_REG_WRITE(0x70001838, 0x0060),

	S5K4ECGX_REG_WRITE(0x70004784, 0x00A0),	/* TNP_Regs_FlsWeightRIn  weight tune start in */
	S5K4ECGX_REG_WRITE(0x70004786, 0x00C0),
	S5K4ECGX_REG_WRITE(0x70004788, 0x00D0),
	S5K4ECGX_REG_WRITE(0x7000478A, 0x0100),
	S5K4ECGX_REG_WRITE(0x7000478C, 0x0200),
	S5K4ECGX_REG_WRITE(0x7000478E, 0x0300),

	S5K4ECGX_REG_WRITE(0x70004790, 0x0088),	/* TNP_Regs_FlsWeightROut  weight tune start out */
	S5K4ECGX_REG_WRITE(0x70004792, 0x00B0),
	S5K4ECGX_REG_WRITE(0x70004794, 0x00C0),
	S5K4ECGX_REG_WRITE(0x70004796, 0x0100),
	S5K4ECGX_REG_WRITE(0x70004798, 0x0200),
	S5K4ECGX_REG_WRITE(0x7000479A, 0x0300),

	S5K4ECGX_REG_WRITE(0x7000479C, 0x0120),	/* Fls  BRIn */
	S5K4ECGX_REG_WRITE(0x7000479E, 0x0150),
	S5K4ECGX_REG_WRITE(0x700047A0, 0x0200),

	S5K4ECGX_REG_WRITE(0x700047A2, 0x003C),	/* Fls  BROut */
	S5K4ECGX_REG_WRITE(0x700047A4, 0x003B),
	S5K4ECGX_REG_WRITE(0x700047A6, 0x0030),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Pre_Flash_Start) = {
	S5K4ECGX_REG_WRITE(0x70000588, 0x0000),

	S5K4ECGX_REG_WRITE(0x700017FC, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Pre_Flash_End) = {
	S5K4ECGX_REG_WRITE(0x70000588, 0x0002),

	S5K4ECGX_REG_WRITE(0x70001800, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Flash_Start) = {
	S5K4ECGX_REG_WRITE(0x700017E8, 0x0001),

	S5K4ECGX_REG_WRITE(0x7000180C, 0x0027),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Flash_End) = {
	S5K4ECGX_REG_WRITE(0x700017E8, 0x0000),
	S5K4ECGX_REGSET_END
};

	/* 2560 x 1920 */
S5K4ECGX_DEFINE_REGSET(s5k4ecgx_5M_Capture) = {
	S5K4ECGX_REG_WRITE(0x70000398, 0x0A00),	/* #REG_0TC_CCFG_usWidth */
	S5K4ECGX_REG_WRITE(0x7000039A, 0x0780),	/* #REG_0TC_CCFG_usHeight */
	S5K4ECGX_REG_WRITE(0x7000039C, 0x0009),

	S5K4ECGX_REG_WRITE(0x700003B2, 0x0002),
	S5K4ECGX_REG_WRITE(0x700003B0, 0x0002),
	S5K4ECGX_REG_WRITE(0x70000270, 0x0001),
	S5K4ECGX_REGSET_END
};
	/* 2048 x 1536 */
S5K4ECGX_DEFINE_REGSET(s5k4ecgx_3M_Capture) = {
	S5K4ECGX_REG_WRITE(0x70000398, 0x0800),	/* REG_0TC_CCFG_usWidth */
	S5K4ECGX_REG_WRITE(0x7000039A, 0x0600),	/* REG_0TC_CCFG_usWidth */
	S5K4ECGX_REG_WRITE(0x7000039C, 0x0009),	/* REG_0TC_CCFG_Format */

	S5K4ECGX_REG_WRITE(0x700003B2, 0x0002),	/* REG_0TC_CCFG_FrRateQualityType */
	S5K4ECGX_REG_WRITE(0x700003B0, 0x0002),	/* REG_0TC_CCFG_usFrTimeType */
	S5K4ECGX_REG_WRITE(0x7000024E, 0x0001),	/* REG_TC_GP_NewConfigSync */
	S5K4ECGX_REG_WRITE(0x70000270, 0x0001),	/* REG_TC_GP_CapConfigChanged */
	S5K4ECGX_REGSET_END
};
	/* 1600 x 1200 */
S5K4ECGX_DEFINE_REGSET(s5k4ecgx_2M_Capture) = {
	S5K4ECGX_REG_WRITE(0x70000398, 0x0640),	/* #REG_0TC_CCFG_usWidth */
	S5K4ECGX_REG_WRITE(0x7000039A, 0x04B0),	/* #REG_0TC_CCFG_usHeight */
	S5K4ECGX_REG_WRITE(0x7000039C, 0x0009),
	S5K4ECGX_REG_WRITE(0x700003B2, 0x0002),
	S5K4ECGX_REG_WRITE(0x700003B0, 0x0002),
	S5K4ECGX_REG_WRITE(0x7000024E, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000270, 0x0001),
	S5K4ECGX_REGSET_END
};
	/* 1280 x 960 */
S5K4ECGX_DEFINE_REGSET(s5k4ecgx_1M_Capture) = {
	S5K4ECGX_REG_WRITE(0x70000398, 0x0500),	/* #REG_0TC_CCFG_usWidth */
	S5K4ECGX_REG_WRITE(0x7000039A, 0x03C0),	/* #REG_0TC_CCFG_usHeight */
	S5K4ECGX_REG_WRITE(0x7000039C, 0x0009),
	S5K4ECGX_REG_WRITE(0x700003B2, 0x0002),
	S5K4ECGX_REG_WRITE(0x700003B0, 0x0002),
	S5K4ECGX_REG_WRITE(0x7000024E, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000270, 0x0001),
	S5K4ECGX_REGSET_END
};
	/* 640 x 480 */
S5K4ECGX_DEFINE_REGSET(s5k4ecgx_VGA_Capture) = {
	S5K4ECGX_REG_WRITE(0x70000398, 0x0280),	/* #REG_0TC_CCFG_usWidth */
	S5K4ECGX_REG_WRITE(0x7000039A, 0x01E0),	/* #REG_0TC_CCFG_usHeight */
	S5K4ECGX_REG_WRITE(0x7000039C, 0x0009),
	S5K4ECGX_REG_WRITE(0x700003B2, 0x0002),
	S5K4ECGX_REG_WRITE(0x700003B0, 0x0002),
	S5K4ECGX_REG_WRITE(0x7000024E, 0x0001),
	S5K4ECGX_REG_WRITE(0x70000270, 0x0001),
	S5K4ECGX_REGSET_END
};
	/* 720 x 480 */
S5K4ECGX_DEFINE_REGSET(s5k4ecgx_720_Preview) = {
	S5K4ECGX_REG_WRITE(0x70000250, 0x0A00),
	S5K4ECGX_REG_WRITE(0x70000252, 0x06A8),
	S5K4ECGX_REG_WRITE(0x70000254, 0x0010),
	S5K4ECGX_REG_WRITE(0x70000256, 0x0078),
	S5K4ECGX_REG_WRITE(0x70000258, 0x0A00),
	S5K4ECGX_REG_WRITE(0x7000025A, 0x06A8),
	S5K4ECGX_REG_WRITE(0x7000025C, 0x0010),
	S5K4ECGX_REG_WRITE(0x7000025E, 0x0078),
	S5K4ECGX_REG_WRITE(0x70000494, 0x0A00),
	S5K4ECGX_REG_WRITE(0x70000496, 0x06A8),
	S5K4ECGX_REG_WRITE(0x70000498, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000049A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000049C, 0x0A00),
	S5K4ECGX_REG_WRITE(0x7000049E, 0x06A8),
	S5K4ECGX_REG_WRITE(0x700004A0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004A2, 0x0000),

	S5K4ECGX_REG_WRITE(0x70000262, 0x0001),	/* #REG_TC_GP_bUseReqInputInPre */
	S5K4ECGX_REG_WRITE(0x70000A1E, 0x0028),
	S5K4ECGX_REG_WRITE(0x70000AD4, 0x003C),

	S5K4ECGX_REG_WRITE(0x700002A6, 0x02D0),
	S5K4ECGX_REG_WRITE(0x700002A8, 0x01E0),
	S5K4ECGX_REG_WRITE(0x700002AA, 0x0005),
	S5K4ECGX_REG_WRITE(0x700002B4, 0x0052),
	S5K4ECGX_REG_WRITE(0x700002BE, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002C0, 0x0001),
	S5K4ECGX_REG_WRITE(0x700002C2, 0x029A),
	S5K4ECGX_REG_WRITE(0x700002C4, 0x014D),
	S5K4ECGX_REG_WRITE(0x700002D0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002D2, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000266, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000026A, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000024E, 0x0001),	/* #REG_TC_GP_NewConfigSync */
	S5K4ECGX_REG_WRITE(0x70000268, 0x0001),	/* #REG_TC_GP_CapConfigChanged */
	S5K4ECGX_REGSET_END
};
	/* 640 x 480 */
S5K4ECGX_DEFINE_REGSET(s5k4ecgx_640_Preview) = {
	S5K4ECGX_REG_WRITE(0x70000250, 0x0A00),
	S5K4ECGX_REG_WRITE(0x70000252, 0x0780),
	S5K4ECGX_REG_WRITE(0x70000254, 0x0010),
	S5K4ECGX_REG_WRITE(0x70000256, 0x000C),
	S5K4ECGX_REG_WRITE(0x70000258, 0x0A00),
	S5K4ECGX_REG_WRITE(0x7000025A, 0x0780),
	S5K4ECGX_REG_WRITE(0x7000025C, 0x0010),
	S5K4ECGX_REG_WRITE(0x7000025E, 0x000C),
	S5K4ECGX_REG_WRITE(0x70000494, 0x0A00),
	S5K4ECGX_REG_WRITE(0x70000496, 0x0780),
	S5K4ECGX_REG_WRITE(0x70000498, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000049A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000049C, 0x0A00),
	S5K4ECGX_REG_WRITE(0x7000049E, 0x0780),
	S5K4ECGX_REG_WRITE(0x700004A0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004A2, 0x0000),

	S5K4ECGX_REG_WRITE(0x70000262, 0x0001),	/* #REG_TC_GP_bUseReqInputInPre */
	S5K4ECGX_REG_WRITE(0x70000A1E, 0x0028),
	S5K4ECGX_REG_WRITE(0x70000AD4, 0x003C),

	S5K4ECGX_REG_WRITE(0x700002A6, 0x0280),
	S5K4ECGX_REG_WRITE(0x700002A8, 0x01E0),
	S5K4ECGX_REG_WRITE(0x700002AA, 0x0005),
	S5K4ECGX_REG_WRITE(0x700002B4, 0x0052),
	S5K4ECGX_REG_WRITE(0x700002BE, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002C0, 0x0001),
	S5K4ECGX_REG_WRITE(0x700002C2, 0x029A),
	S5K4ECGX_REG_WRITE(0x700002C4, 0x014A),
	S5K4ECGX_REG_WRITE(0x700002D0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002D2, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000266, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000026A, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000024E, 0x0001),	/* #REG_TC_GP_NewConfigSync */
	S5K4ECGX_REG_WRITE(0x70000268, 0x0001),	/* #REG_TC_GP_CapConfigChanged */
	S5K4ECGX_REGSET_END
};
	/* 352 x 288 */
S5K4ECGX_DEFINE_REGSET(s5k4ecgx_352_Preview) = {
	S5K4ECGX_REG_WRITE(0x70000250, 0x0928),
	S5K4ECGX_REG_WRITE(0x70000252, 0x0780),
	S5K4ECGX_REG_WRITE(0x70000254, 0x007C),
	S5K4ECGX_REG_WRITE(0x70000256, 0x000C),
	S5K4ECGX_REG_WRITE(0x70000258, 0x0928),
	S5K4ECGX_REG_WRITE(0x7000025A, 0x0780),
	S5K4ECGX_REG_WRITE(0x7000025C, 0x007C),
	S5K4ECGX_REG_WRITE(0x7000025E, 0x000C),
	S5K4ECGX_REG_WRITE(0x70000494, 0x0928),
	S5K4ECGX_REG_WRITE(0x70000496, 0x0780),
	S5K4ECGX_REG_WRITE(0x70000498, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000049A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000049C, 0x0928),
	S5K4ECGX_REG_WRITE(0x7000049E, 0x0780),
	S5K4ECGX_REG_WRITE(0x700004A0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004A2, 0x0000),

	S5K4ECGX_REG_WRITE(0x70000262, 0x0001),	/* #REG_TC_GP_bUseReqInputInPre */
	S5K4ECGX_REG_WRITE(0x70000A1E, 0x0028),
	S5K4ECGX_REG_WRITE(0x70000AD4, 0x003C),

	S5K4ECGX_REG_WRITE(0x700002A6, 0x0160),
	S5K4ECGX_REG_WRITE(0x700002A8, 0x0120),
	S5K4ECGX_REG_WRITE(0x700002AA, 0x0005),
	S5K4ECGX_REG_WRITE(0x700002B4, 0x0052),
	S5K4ECGX_REG_WRITE(0x700002BE, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002C0, 0x0001),
	S5K4ECGX_REG_WRITE(0x700002C2, 0x029A),
	S5K4ECGX_REG_WRITE(0x700002C4, 0x014D),
	S5K4ECGX_REG_WRITE(0x700002D0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002D2, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000266, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000026A, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000024E, 0x0001),	/* #REG_TC_GP_NewConfigSync */
	S5K4ECGX_REG_WRITE(0x70000268, 0x0001),	/* #REG_TC_GP_CapConfigChanged */
	S5K4ECGX_REGSET_END
};
	/* 176 x 144 */
S5K4ECGX_DEFINE_REGSET(s5k4ecgx_176_Preview) = {
	S5K4ECGX_REG_WRITE(0x70000250, 0x0928),
	S5K4ECGX_REG_WRITE(0x70000252, 0x0780),
	S5K4ECGX_REG_WRITE(0x70000254, 0x007C),
	S5K4ECGX_REG_WRITE(0x70000256, 0x000C),
	S5K4ECGX_REG_WRITE(0x70000258, 0x0928),
	S5K4ECGX_REG_WRITE(0x7000025A, 0x0780),
	S5K4ECGX_REG_WRITE(0x7000025C, 0x007C),
	S5K4ECGX_REG_WRITE(0x7000025E, 0x000C),
	S5K4ECGX_REG_WRITE(0x70000494, 0x0928),
	S5K4ECGX_REG_WRITE(0x70000496, 0x0780),
	S5K4ECGX_REG_WRITE(0x70000498, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000049A, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000049C, 0x0928),
	S5K4ECGX_REG_WRITE(0x7000049E, 0x0780),
	S5K4ECGX_REG_WRITE(0x700004A0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700004A2, 0x0000),

	S5K4ECGX_REG_WRITE(0x70000262, 0x0001),	/* #REG_TC_GP_bUseReqInputInPre */
	S5K4ECGX_REG_WRITE(0x70000A1E, 0x0028),
	S5K4ECGX_REG_WRITE(0x70000AD4, 0x003C),

	S5K4ECGX_REG_WRITE(0x700002A6, 0x00B0),
	S5K4ECGX_REG_WRITE(0x700002A8, 0x0090),
	S5K4ECGX_REG_WRITE(0x700002AA, 0x0005),
	S5K4ECGX_REG_WRITE(0x700002B4, 0x0052),
	S5K4ECGX_REG_WRITE(0x700002BE, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002C0, 0x0001),
	S5K4ECGX_REG_WRITE(0x700002C2, 0x029A),
	S5K4ECGX_REG_WRITE(0x700002C4, 0x014D),
	S5K4ECGX_REG_WRITE(0x700002D0, 0x0000),
	S5K4ECGX_REG_WRITE(0x700002D2, 0x0000),
	S5K4ECGX_REG_WRITE(0x70000266, 0x0000),
	S5K4ECGX_REG_WRITE(0x7000026A, 0x0001),
	S5K4ECGX_REG_WRITE(0x7000024E, 0x0001),	/* #REG_TC_GP_NewConfigSync */
	S5K4ECGX_REG_WRITE(0x70000268, 0x0001),	/* #REG_TC_GP_CapConfigChanged */
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_AE_AWB_Lock_On) = {
	S5K4ECGX_REG_WRITE(0x70002C5E, 0x0000),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_AE_AWB_Lock_Off) = {
	S5K4ECGX_REG_WRITE(0x70002C5E, 0x0001),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Get_AE_Stable_Status) = {
	S5K4ECGX_REG_READ(0x70002C74),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_Get_Light_Level) = {
	S5K4ECGX_REG_READ(0x70002C18),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_get_1st_af_search_status) = {
	S5K4ECGX_REG_READ(0x70002EEE),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_get_2nd_af_search_status) = {
	S5K4ECGX_REG_READ(0x70002207),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_get_capture_status) = {
	S5K4ECGX_REG_READ(0x70000530),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_get_esd_status) = {
	S5K4ECGX_CMD_WRITE(0xFCFC, 0xD000),
	S5K4ECGX_REG_READ(0xD0000060),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_get_iso_reg) = {
	S5K4ECGX_REG_READ(0x70002BC4),
	S5K4ECGX_REGSET_END
};

S5K4ECGX_DEFINE_REGSET(s5k4ecgx_get_shutterspeed_reg) = {
	S5K4ECGX_REG_READ(0x70002BC0),
	S5K4ECGX_REGSET_END
};

#undef S5K4ECGX_DEFINE_REGSET
#undef S5K4ECGX_REGSET_END
#undef S5K4ECGX_CMD_WRITE
#undef S5K4ECGX_REG_WRITE
#undef S5K4ECGX_REG_READ
#undef S5K4ECGX_MDELAY
#undef _SWAB16
#undef _DUMMY

#endif

#if !defined(__S5K4ECGX_V1_1_DEFINE_REGSET__)
#define __S5K4ECGX_V1_1_DEFINE_REGSET__
#elif !defined(__S5K4ECGX_V1_1_DEFINE_REGSET_DATA__)
#define __S5K4ECGX_V1_1_DEFINE_REGSET_DATA__
#endif
